(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   6428502,     178870]
NotebookOptionsPosition[   6208089,     172755]
NotebookOutlinePosition[   6218441,     173042]
CellTagsIndexPosition[   6215792,     172973]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Surfaces in the Euclidean 3-Space", "Title",
 CellChangeTimes->{3.588487292274865*^9},
 TextAlignment->Center],

Cell["by Rolf Sulanke", "Subtitle",
 CellChangeTimes->{{3.5942757655247216`*^9, 3.594275786184903*^9}, 
   3.59427585467282*^9, {3.5942759066557937`*^9, 3.594275907880864*^9}},
 TextAlignment->Center],

Cell[TextData[{
 "Finished September 24, 2014\n",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " v. 9, v. 10"
}], "Text",
 CellChangeTimes->{{3.594368087244899*^9, 3.5943680914569063`*^9}, {
  3.614665568276914*^9, 3.6146656059665804`*^9}, {3.6174421006498613`*^9, 
  3.6174421041850634`*^9}, {3.6189956491303053`*^9, 3.618995673793949*^9}, {
  3.620532390543178*^9, 3.620532431056449*^9}}],

Cell[CellGroupData[{

Cell["Preface", "Subsection",
 CellChangeTimes->{
  3.541836408310753*^9, 3.5418367181098843`*^9, {3.5992053438926544`*^9, 
   3.5992053481638985`*^9}, {3.5994627461488314`*^9, 3.599462748535635*^9}}],

Cell[TextData[{
 "In this notebook we develop ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " tools for applications  to Euclidean differential geometry of surfaces. We \
construct modules for the calculation of all Euclidean invariants like \
fundamental forms and curvatures for surfaces in the 3-space, and some also \
for immersions into the n-dimensional Euclidean spaces.  This notebook may be \
considered as a continuation of the notebook EuCurves.nb devoted to  \
Euclidean curve theory which may be downloaded from my ",
 ButtonBox["homepage",
  BaseStyle->"Hyperlink",
  ButtonData->"Home"],
 ". It may be used as an interactive introduction into the Euclidean surface \
geometry, accompanying an introductory course or reading a textbook, e.g. the \
Introduction ",
 ButtonBox["[B-R]",
  BaseStyle->"Hyperlink",
  ButtonData->"B-R"],
 "  of  W. Blaschke and H. Reichardt which I often use as a  reference.  It \
may be useful to compare and to complete this notebook studying the \
pioneering work of Alfred Gray on applying ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to differential geometry, see  the book [",
 ButtonBox["G06",
  BaseStyle->"Hyperlink",
  ButtonData->"Gray"],
 "], or the German translation of the first edition [",
 ButtonBox["G94",
  BaseStyle->"Hyperlink",
  ButtonData->"Gray3"],
 "]. The third edition [G06] is accompanied by a series of 27 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " notebooks corresponding to the chapters of the book, which can be \
downloaded from the website ",
 ButtonBox["[G06nb]",
  BaseStyle->"Hyperlink",
  ButtonData->"Gray2"],
 ".  Alfred Gray presented Euclidean differential geometry with many \
applications of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". Writing his book Alfred Gray collected about 200 definitions of concrete \
curves and as many of concrete surfaces with short descriptions (formulated \
as usages) and implementations into ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". These catalogs are contained in his ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " packages  CURVES.m and SURFS.m  available from my ",
 ButtonBox["homepage",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www-irm.mathematik.hu-berlin.de/~sulanke/diffgeo.html#Gray"], 
    None},
  ButtonNote->
   "http://www-irm.mathematik.hu-berlin.de/~sulanke/diffgeo.html#Gray"],
 ".  They open many opportunities to apply the functions and miniprograms \
developed here, to deepen the insight into the differential geometry of \
curves and surfaces comparing the calculated invariants, e. g. the \
curvatures, with the shape of the geometric objects using the graphical tools \
of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ".  I am much obliged to Alfred Gray for providing this material and for \
many discussions introducing me into ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". \n\nChapter 1 of the notebook is devoted to E. Cartan\[CloseCurlyQuote]s \
method of moving frames using exterior differential forms. It gives the \
structure forms and the Frenet formulas including the integrability \
conditions for surfaces in the Euclidean 3-space. Here I followed the \
presentation in [B-R] using the differential forms ad hoc as elementary as \
possible. Also the first and the second fundamental forms of surface theory \
are treated as fields of bilinear forms not using concepts of tensor \
analysis. Spherical image and Gauss curvature are the subject of Chapter 2 \
containing a proof of Gauss famous Theorema Egregium.  Chapter 3 is devoted \
to the second fundamental form of the surface, studying the geometry of \
curves on the surface, in particular their normal curvature. Chapter 4 \
contains the absolute differentiation on the surface, expressed by the \
Christoffel symbols as a part of the inner geometry of the surface, invariant \
under isometric deformations. It is applied to describe the geodesic \
curvature of a curve on the surface and to define the geodesics as \
auto-parallel curves. The basic concepts are formulated avoiding the tensor \
concept, but admitting a straightforward extension to higher dimensional \
Riemannian and more general geometries, which can be the contents of further ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " notebooks.\n\nI hope that the notebook will help students to understand \
the Euclidean differential geometry of surfaces. By its interactive character \
it may serve as a starting point for further excursions into this interesting \
field, which joins algebraic and analytic methods to explore the heart of \
mathematics: the geometry. Studying older or modern textbooks or monographs \
of classical differential geometry it may be an exciting challenge to express \
the objects and concepts in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " terms aiming to explore or illustrate their properties, to verify well \
known facts, and, with some luck, to gain new insight.   \n\nI shall be very \
thankful for comments and corrections, please send them to \n\
sulanke@mathematik.hu-berlin.de.\n\n",
 StyleBox["Important Hint. ",
  FontColor->RGBColor[1, 0, 0]],
 "\n",
 StyleBox["Before starting working with the notebook read the Copyrigth and \
make the necessary adaption of the Section Initialization to your computer! \n\
",
  FontSlant->"Italic"],
 "\n"
}], "Text",
 CellChangeTimes->{{3.446645069921875*^9, 3.44664509953125*^9}, 
   3.446645156828125*^9, {3.446645243484375*^9, 3.446645462125*^9}, {
   3.448159668953125*^9, 3.448159713765625*^9}, 3.449203063109375*^9, {
   3.4542178296875*^9, 3.4542180669375*^9}, {3.454218801*^9, 
   3.454218865875*^9}, {3.4542223853125*^9, 3.4542224753125*^9}, {
   3.454222520640625*^9, 3.45422255271875*^9}, {3.45422428384375*^9, 
   3.45422444978125*^9}, {3.45422448125*^9, 3.454224575171875*^9}, 
   3.541681068146072*^9, {3.541682273824328*^9, 3.5416824190006227`*^9}, {
   3.541827375454864*^9, 3.541827387969111*^9}, {3.5418316529213343`*^9, 
   3.541831653441086*^9}, 3.5418317494023857`*^9, {3.541831858219041*^9, 
   3.541832023482676*^9}, {3.5418320577240677`*^9, 3.5418320930359087`*^9}, {
   3.541832178020227*^9, 3.541832187404354*^9}, {3.5418322197005577`*^9, 
   3.541832219702417*^9}, {3.5418322675411787`*^9, 3.541832354019971*^9}, 
   3.541836408310801*^9, {3.5418366180057*^9, 3.541836621524942*^9}, 
   3.541836718109921*^9, {3.59919611723792*^9, 3.599196122851241*^9}, {
   3.5991962025988026`*^9, 3.5991962289503098`*^9}, {3.5991962615901766`*^9, 
   3.599196336339452*^9}, {3.5991963763887424`*^9, 3.5991964222833676`*^9}, {
   3.5991964577643967`*^9, 3.599196467277941*^9}, {3.599196506140164*^9, 
   3.5991965150836754`*^9}, {3.5991965605252743`*^9, 3.5991965712928905`*^9}, 
   3.5992019728598423`*^9, {3.5992020307651544`*^9, 3.5992021570203757`*^9}, 
   3.599202305491868*^9, 3.5992032715491233`*^9, {3.59920388218805*^9, 
   3.599203905548386*^9}, {3.5992040181558266`*^9, 3.599204028124397*^9}, {
   3.599204085731692*^9, 3.599204105851843*^9}, {3.5992041385407124`*^9, 
   3.59920414934033*^9}, {3.599204190283672*^9, 3.5992042911484413`*^9}, {
   3.5992043640766125`*^9, 3.599204371660046*^9}, {3.59920441124231*^9, 
   3.599204411255311*^9}, {3.5992044716767664`*^9, 3.5992045492682047`*^9}, {
   3.5992045954358454`*^9, 3.599204629315783*^9}, {3.599204741172181*^9, 
   3.599204764548518*^9}, {3.5992047948372507`*^9, 3.5992048358365955`*^9}, {
   3.5992050362200565`*^9, 3.5992050588603516`*^9}, {3.599205134556681*^9, 
   3.599205261883964*^9}, 3.59920536304775*^9, {3.5992053937465057`*^9, 
   3.5992053939325166`*^9}, {3.5992054591412463`*^9, 
   3.5992055378927507`*^9}, {3.5992056833880725`*^9, 
   3.5992057380601997`*^9}, {3.59920582041291*^9, 3.599205820627922*^9}, {
   3.5992058827964783`*^9, 3.599206043644678*^9}, {3.5992060798207474`*^9, 
   3.599206163004505*^9}, {3.5992062112202625`*^9, 3.5992062367237215`*^9}, {
   3.5992063417807302`*^9, 3.5992063865722923`*^9}, {3.599206474428317*^9, 
   3.5992064839718633`*^9}, {3.599206598188396*^9, 3.599206636628595*^9}, {
   3.5992066825932236`*^9, 3.5992066871884866`*^9}, 3.5992067173322105`*^9, {
   3.599206779087743*^9, 3.599206830683694*^9}, {3.5992068737641582`*^9, 
   3.5992069266761847`*^9}, {3.5992069590400352`*^9, 
   3.5992069796602154`*^9}, {3.5992070286610174`*^9, 
   3.5992070416127586`*^9}, {3.5992070903205442`*^9, 3.599207090334545*^9}, {
   3.5992078881661787`*^9, 3.59920812438869*^9}, {3.599226725980919*^9, 
   3.599226730632185*^9}, {3.599226794136817*^9, 3.5992268145319834`*^9}, 
   3.5992268515100985`*^9, {3.599227048665375*^9, 3.599227050600486*^9}, {
   3.599227089888733*^9, 3.599227090432764*^9}, {3.5992274882425175`*^9, 
   3.599227521310409*^9}, {3.5992276061852636`*^9, 3.5992276061962643`*^9}, {
   3.599227931864891*^9, 3.599227961944612*^9}, {3.599227993192399*^9, 
   3.59922802048096*^9}, {3.5992282650969515`*^9, 3.5992282958327093`*^9}, {
   3.59922839935363*^9, 3.5992285024725285`*^9}, 3.59928617084793*^9, {
   3.5992862198164163`*^9, 3.599286314914183*^9}, {3.5994012750208035`*^9, 
   3.599401312258069*^9}, {3.5994013738781776`*^9, 3.5994014292114744`*^9}, {
   3.5994014605675297`*^9, 3.599401482969169*^9}, {3.599401529472851*^9, 
   3.5994018439226027`*^9}, 3.59940195034599*^9, 3.5994020589533806`*^9, 
   3.5994020911986375`*^9, {3.599402465084494*^9, 3.5994026765740657`*^9}, {
   3.599402733092965*^9, 3.5994027337949657`*^9}, {3.5994028421371565`*^9, 
   3.599402909529275*^9}, {3.599402944488936*^9, 3.599403082112378*^9}, {
   3.5994045003111925`*^9, 3.599404706743*^9}, {3.599405087461776*^9, 
   3.5994053763022966`*^9}, {3.5994054519166217`*^9, 
   3.5994054540677443`*^9}, {3.5994056666029005`*^9, 3.5994057112824564`*^9}, 
   3.599405747266515*^9, {3.599405778443298*^9, 3.5994057958012905`*^9}, 
   3.59940586659534*^9, {3.599462817206956*^9, 3.5994629289187517`*^9}, {
   3.599462978480039*^9, 3.59946316121876*^9}, {3.5994633805518007`*^9, 
   3.599463389584317*^9}, 3.614665761857654*^9, {3.6146658697162437`*^9, 
   3.6146659078115106`*^9}, {3.6146660355913353`*^9, 
   3.6146660382433395`*^9}, {3.6189973384975014`*^9, 3.6189973435597906`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Keywords", "Subsection",
 CellChangeTimes->{{3.541686221104368*^9, 3.541686224511538*^9}, 
   3.5418364083108387`*^9, 3.54183671810995*^9}],

Cell["\<\
absolute differential, arc length, area, asamptotic curves, Christoffel \
symbols, cone, conical surface, cylindrical surface, developable surface, \
diffeomorphism, envelope, Euler\[CloseCurlyQuote]s formula, exterior \
differential, exterior product, flat points, Frenet formulas, fundamental \
forms, Gauss curvature, Gauss map, geodesic, geodesic curvature, graph, \
helix, hypersurface, immersion,  integrability conditions, integral \
curvature, isogonal trajectory, Jacobian matrix, mean curvature, Meusnier\
\[CloseCurlyQuote]s proposition,  minimal surface, moving frame, normal, \
normal congruence, normal curvature, orientation, osculating sphere, parallel \
displacement, parameter, Pl\[UDoubleDot]cker\[CloseCurlyQuote]s conoid, \
principal curvatures, principal curves, principal directions,  regular, \
Riemannian manifold, R\[UDoubleDot]ckkehrkante,  ruled surface, singular, \
spherical image, spiral, structure forms, submanifold, surface, surface of \
revolution, surface with constant Gauss curvature, tangent plane, tangent \
surface, tangent vector, Theorema egregium, torus, total differential, \
umbilic point, vector field, volume element.\
\>", "Text",
 CellChangeTimes->{
  3.6146702447129803`*^9, {3.6146743760906925`*^9, 3.6146744046253242`*^9}, {
   3.614674471174131*^9, 3.6146744956065283`*^9}, {3.6146745698667755`*^9, 
   3.6146745918020306`*^9}, 3.6146746377306576`*^9, 3.6146748836907253`*^9, {
   3.614774678232683*^9, 3.6147746844320374`*^9}, {3.61477471629686*^9, 
   3.614774744056448*^9}, {3.6151888712415533`*^9, 3.615188905226497*^9}, {
   3.6151890327547913`*^9, 3.615189040579239*^9}, {3.615361391244278*^9, 
   3.6153614969653244`*^9}, {3.615362023628448*^9, 3.615362032140935*^9}, {
   3.617442283553323*^9, 3.6174423273218265`*^9}, {3.6174423670821004`*^9, 
   3.617442374049499*^9}, {3.6174426996831245`*^9, 3.617442706369507*^9}, {
   3.617443035034305*^9, 3.6174430418576956`*^9}, {3.6174431918342733`*^9, 
   3.6174432005217705`*^9}, {3.617443243458226*^9, 3.6174432561699533`*^9}, {
   3.6174433063858256`*^9, 3.6174433213856835`*^9}, 3.617443397977064*^9, {
   3.6174460763694725`*^9, 3.6174461022459526`*^9}, {3.6176052340530386`*^9, 
   3.617605238296246*^9}, {3.6177013931950407`*^9, 3.617701402755587*^9}, {
   3.6179404294297233`*^9, 3.6179404672753897`*^9}, {3.6179405303463*^9, 
   3.617940542997923*^9}, {3.617940949144636*^9, 3.617940969565072*^9}, {
   3.61795167381975*^9, 3.6179516976201115`*^9}, {3.6183981333230515`*^9, 
   3.618398144002662*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Copyright", "Subsection",
 CellChangeTimes->{{3.541686221104368*^9, 3.541686224511538*^9}, {
   3.541686639857975*^9, 3.541686645161036*^9}, 3.541836408310912*^9, 
   3.541836718110009*^9}],

Cell["\<\
This notebook and the accompanying packages are  public. Authors who intend \
to publish a changed or completed version of them should do it under their \
own names with the condition that they cite the original notebook with the \
Internet address or other source where they got it. I am not responsible for \
errors or damages originated by the use of the procedures contained in my \
notebooks or packages; everybody who applies them should test carefully \
whether they are appropriate for his purposes.\
\>", "Text",
 CellChangeTimes->{{3.470471120664312*^9, 3.470471146997974*^9}, {
   3.498225321006962*^9, 3.498225323459318*^9}, 3.541836408310948*^9, 
   3.541836718110042*^9, 3.5994668492244267`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Section",
 CellChangeTimes->{{3.572085090826617*^9, 3.572085097846629*^9}, {
   3.614675039233622*^9, 3.614675041977779*^9}, 3.61468526962821*^9}],

Cell["\<\
Before starting the first session insert the address of your working \
directory, e.g. for Windows 7:\
\>", "Text",
 CellChangeTimes->{{3.599463466951742*^9, 3.599463520087782*^9}, {
   3.599463875888132*^9, 3.5994638948642178`*^9}, 3.59946686361625*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", 
  "\"\<E:\\\\mymath\\\\diffgeo\\\\EuclSfTheory\>\"", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.571294164375502*^9, 3.5712942516264553`*^9}, 
   3.5919452705433164`*^9, 3.5920226711016054`*^9, 3.6089604686226373`*^9, 
   3.6089669513028173`*^9, 3.609849899827975*^9, 3.6114596276456995`*^9}],

Cell[BoxData["\<\"E:\\\\mymath\\\\diffgeo\\\\EuclSfTheory\"\>"], "Output",
 CellChangeTimes->{
  3.5883922634644036`*^9, 3.588414133752287*^9, 3.5884871186933603`*^9, 
   3.588499064221449*^9, 3.588563853736287*^9, 3.5886610880587406`*^9, 
   3.588673973072099*^9, 3.588766004227372*^9, 3.588917536367657*^9, 
   3.5889188909024363`*^9, 3.5889437528437605`*^9, 3.588998599105787*^9, 
   3.589005939878655*^9, 3.589087086964387*^9, 3.5891696685590725`*^9, 
   3.5896085361517572`*^9, 3.589772843724998*^9, 3.5898647217545643`*^9, 
   3.5898904948547745`*^9, 3.5899518816755333`*^9, 3.58995365603825*^9, 
   3.589956013393523*^9, 3.5899782809420547`*^9, 3.59003900806682*^9, 
   3.590212008822501*^9, 3.5904958179839983`*^9, 3.590640413940959*^9, 
   3.5906714818165874`*^9, 3.590715684777876*^9, 3.5907201695006275`*^9, 
   3.590734034196718*^9, 3.5908181800136023`*^9, 3.590904694832147*^9, 
   3.590910211103035*^9, 3.590987954599818*^9, 3.591163237687312*^9, 
   3.591180657532507*^9, 3.5912467882296553`*^9, 3.59133944844098*^9, 
   3.591414225531201*^9, 3.5914415471819763`*^9, 3.5915074092942204`*^9, 
   3.5915923937370896`*^9, 3.5916857030981145`*^9, 3.5917678333133383`*^9, 
   3.5919453637222805`*^9, 3.591966121874964*^9, 3.59202256562982*^9, 
   3.5920227060300665`*^9, 3.592046742576351*^9, 3.592111223351601*^9, 
   3.5921338217344375`*^9, 3.592147916983585*^9, 3.5922001243202367`*^9, 
   3.592293251985611*^9, 3.5923059771323423`*^9, 3.592373265476573*^9, 
   3.592454413533845*^9, 3.592545041198801*^9, 3.592632207870155*^9, 
   3.5926559484358325`*^9, 3.592708143015397*^9, 3.5927410466442423`*^9, 
   3.5927992828065724`*^9, 3.5929819511265974`*^9, 3.5930088464562817`*^9, 
   3.5930642934805937`*^9, 3.593146768744869*^9, 3.5931778395324836`*^9, 
   3.5933218939874735`*^9, 3.5933488148413486`*^9, 3.593405047600657*^9, 
   3.593413996525175*^9, 3.5934340783608203`*^9, 3.5935839612821684`*^9, 
   3.59361181883451*^9, 3.593668080712712*^9, 3.5938384243282795`*^9, 
   3.5938409503800817`*^9, 3.5941845726240635`*^9, 3.594192204422668*^9, 
   3.594269700938481*^9, 3.5942746439995737`*^9, 3.594363573999772*^9, 
   3.5943647087301655`*^9, 3.5946216249572606`*^9, 3.5947054227980795`*^9, 
   3.594877278328663*^9, 3.5948810675285187`*^9, 3.5949640096202908`*^9, 
   3.595048341495697*^9, 3.595133804732059*^9, 3.5951436410501156`*^9, 
   3.5952296782840705`*^9, 3.59531184162263*^9, 3.595484799812402*^9, 
   3.59548603999898*^9, 3.595488678525214*^9, 3.5955691651866627`*^9, 
   3.5955702332007494`*^9, 3.5955749392209187`*^9, 3.5956508606281414`*^9, 
   3.595659556487988*^9, 3.5958282745938473`*^9, 3.5959119978001523`*^9, 
   3.596001556442087*^9, 3.5960891809581537`*^9, 3.59626188380676*^9, 
   3.5963556626113405`*^9, 3.5963714650417423`*^9, 3.596436860987357*^9, 
   3.596521285103877*^9, 3.5972075112148523`*^9, 3.5972982542071276`*^9, 
   3.59738183996778*^9, 3.597468082930109*^9, 3.597729291643038*^9, {
   3.597737673061389*^9, 3.5977376930055304`*^9}, 3.5977612653948617`*^9, 
   3.597814065537006*^9, 3.597847427252082*^9, 3.5979019470703526`*^9, 
   3.5980092591272144`*^9, 3.5980743760379176`*^9, 3.5983626700776844`*^9, 
   3.5984255586654587`*^9, 3.598594728857094*^9, 3.598625180042141*^9, 
   3.5986755697550592`*^9, 3.5988608222529755`*^9, 3.5988821115626698`*^9, 
   3.5989404432708793`*^9, 3.599022749295374*^9, 3.599197145717746*^9, 
   3.599197248578629*^9, 3.5992870770223217`*^9, 3.599466642607609*^9, 
   3.5994872752328925`*^9, 3.599488181781685*^9, 3.599488522829484*^9, 
   3.5994888208680077`*^9, 3.599489085319672*^9, 3.5995508138487377`*^9, 
   3.5995512976991873`*^9, 3.5998033972019696`*^9, 3.6089605872920456`*^9, 
   3.6089613021633015`*^9, 3.60896575372472*^9, 3.608966188715884*^9, 
   3.6089673428132105`*^9, 3.6089688398228345`*^9, 3.6089692232887673`*^9, 
   3.6089694736550875`*^9, 3.608972204692511*^9, 3.6091370368935113`*^9, 
   3.6092151139041224`*^9, 3.6093079259349666`*^9, 3.6095588242998157`*^9, 
   3.6095609608355703`*^9, 3.609649066159087*^9, 3.609650320581836*^9, 
   3.6096724927635336`*^9, 3.609731060144006*^9, 3.6097436472742767`*^9, 
   3.609753071548847*^9, 3.609814809822024*^9, 3.6098499600128803`*^9, 
   3.6099103832138023`*^9, 3.6112083862251897`*^9, 3.6114661014580812`*^9, 
   3.611553298117771*^9, 3.61155816690925*^9, 3.6115582057344704`*^9, 
   3.611569705756506*^9, 3.611570106318417*^9, 3.611573545955366*^9, 
   3.611634120988928*^9, 3.611635192371611*^9, 3.611925014653271*^9, 
   3.6119969299089723`*^9, 3.6120721284202795`*^9, 3.6120900791340866`*^9, 
   3.612152603463379*^9, 3.612265701808558*^9, 3.6123237617561607`*^9, 
   3.6126788775526724`*^9, 3.6127543622206273`*^9, 3.612845979147431*^9, 
   3.613021067698927*^9, 3.6131050154470935`*^9, 3.6132198037843184`*^9, 
   3.6132778664073486`*^9, 3.613443504075413*^9, 3.613472884177025*^9, 
   3.613541229588033*^9, 3.6135600345671043`*^9, 3.613618998354948*^9, 
   3.613970273453272*^9, 3.6139763911964235`*^9, 3.6139942646974597`*^9, 
   3.6139943150387483`*^9, 3.6140533718265114`*^9, 3.6141460240132833`*^9, 
   3.6141639849949317`*^9, 3.614228814393713*^9, 3.6142562409054728`*^9, 
   3.6143098820616574`*^9, 3.614328235085664*^9, 3.614395948397463*^9, 
   3.6144295324745407`*^9, 3.6144822647083645`*^9, 3.614490552651587*^9, 
   3.6145052479516234`*^9, 3.614572824223324*^9, 3.614685751364764*^9, 
   3.6146861468243833`*^9, 3.6146877118979*^9, 3.6146894041646924`*^9, 
   3.614749208441539*^9, 3.6147510975424566`*^9, 3.614751229019488*^9, 
   3.614751466030704*^9, 3.614860808701294*^9, 3.614863321553707*^9, 
   3.614917496596442*^9, 3.614946635298537*^9, 3.615019712669711*^9, 
   3.615097788544916*^9, 3.6151799601511507`*^9, 3.615205944902496*^9, 
   3.6152617216762686`*^9, 3.6153520604050107`*^9, 3.6154344564394774`*^9, 
   3.6155280139390297`*^9, 3.6156114209123077`*^9, 3.615641829213318*^9, 
   3.615894501492463*^9, 3.6159531344020505`*^9, 3.6159583682580433`*^9, 
   3.616045992275729*^9, 3.61606474238317*^9, 3.616119312336298*^9, 
   3.616157580786951*^9, 3.616218243723669*^9, 3.6162978504516425`*^9, 
   3.616383945120673*^9, 3.616393915849422*^9, 3.616420474553999*^9, 
   3.6164709776249714`*^9, 3.6164870894164734`*^9, 3.616494753717366*^9, 
   3.6165019310659046`*^9, 3.6165512104420366`*^9, 3.61664661398596*^9, 
   3.616668743277629*^9, 3.6167296237592726`*^9, 3.6168144759048324`*^9, 
   3.6168995333091245`*^9, 3.6169899335415077`*^9, 3.6169925397780848`*^9, 
   3.6170750477788715`*^9, 3.6171683330365033`*^9, 3.617171604627449*^9, 
   3.617198338278181*^9, 3.6172827441791196`*^9, 3.617337036931693*^9, 
   3.6174260918304205`*^9, 3.617453875608816*^9, 3.6175113027157536`*^9, 
   3.6175272952028522`*^9, 3.617527638278655*^9, 3.6175445639174147`*^9, 
   3.6175994267164383`*^9, 3.6176155035456643`*^9, 3.6176246334362574`*^9, 
   3.617682913169327*^9, 3.617692807540215*^9, 3.617701209483533*^9, 
   3.6177695941569595`*^9, 3.6177762496614494`*^9, 3.61780349959035*^9, 
   3.6178043521630473`*^9, 3.6178595305273647`*^9, 3.617888993739566*^9, 
   3.6179402202333555`*^9, 3.6179726261941905`*^9, 3.6179750449094243`*^9, 
   3.61802445162265*^9, 3.618032283320006*^9, 3.618114536872909*^9, 
   3.6181351249761057`*^9, 3.618135723673958*^9, 3.618139922093732*^9, 
   3.6182087339679155`*^9, 3.6182168890434732`*^9, 3.6182356022072067`*^9, 
   3.618293834467221*^9, 3.6183731501160126`*^9, 3.6184658227877955`*^9, 
   3.6184683447683372`*^9, 3.6184696179489737`*^9, 3.6184698140257177`*^9, 
   3.618491162054332*^9, 3.618546046828068*^9, 3.618580306479556*^9, 
   3.6186338373638587`*^9, 3.618634209798913*^9, 3.6186407681067905`*^9, 
   3.6187188122036705`*^9, 3.6188031360928802`*^9, 3.6188333590996027`*^9, 
   3.618911215949268*^9, 3.618911284012187*^9, 3.618981321815653*^9, 
   3.618994088278688*^9, 3.6201900063486147`*^9, 3.620195841669361*^9, 
   3.62019588780177*^9, 3.6201987442437077`*^9, 3.6201987904211397`*^9, 
   3.620199186171672*^9, 3.6205365892602158`*^9}]
}, Open  ]],

Cell["\<\
Regard  eventually deviating notations depending on your operating system!\
\>", "Text",
 CellChangeTimes->{{3.599463651304287*^9, 3.599463772472217*^9}, 
   3.599466052630864*^9, {3.608967233202941*^9, 3.6089672358820944`*^9}}],

Cell[BoxData["$Path"], "Input"],

Cell[TextData[{
 " Copy all the needed ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " packages into your working directory, or a directory of $Path. \n\
Obligatory are the packages\ntensalg.m, euvec.m, eudiffgeo.m, Alfred Gray\
\[CloseCurlyQuote]s catalog SURFS.m, and Alfred Gray\[CloseCurlyQuote]s \
catalog\nCURVES.m. "
}], "Text",
 CellChangeTimes->{{3.5994639548406477`*^9, 3.599463992919826*^9}, {
   3.5994640376963873`*^9, 3.599464151447893*^9}, {3.5994642220319304`*^9, 
   3.5994642628482647`*^9}, {3.599464422128375*^9, 3.599464461632635*^9}, 
   3.5994644995758047`*^9, {3.599465959441534*^9, 3.5994660385980616`*^9}, 
   3.5994664734869356`*^9, {3.59948869731579*^9, 3.599488700560596*^9}, {
   3.6089672770904512`*^9, 3.608967282066736*^9}, {3.6089686143229365`*^9, 
   3.6089686872831097`*^9}, {3.6147521287995605`*^9, 3.614752179214444*^9}}],

Cell["\<\
All these packages together with this notebook are contained in the file \
euclidsurfaces.tgz which can be downloaded from my homepage.\
\>", "Text",
 CellChangeTimes->{{3.5994661710726385`*^9, 3.5994662775667295`*^9}, {
  3.6190050343161287`*^9, 3.6190050353701887`*^9}}],

Cell["Now save the notebook with your changes. ", "Text",
 CellChangeTimes->{{3.5994665178194714`*^9, 3.5994666645828657`*^9}, 
   3.599466711174531*^9}],

Cell[CellGroupData[{

Cell["Start Initialization", "Subsection",
 CellChangeTimes->{{3.586059422846844*^9, 3.586059429305256*^9}, {
  3.5994666801267548`*^9, 3.5994666865821238`*^9}}],

Cell[TextData[{
 "Start the session with the menu entry\n",
 StyleBox["Evaluation/Evaluate Initialization Cells",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{3.5994667527829103`*^9, 3.5994668982962337`*^9, 
  3.6174540239292994`*^9}],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<eudiffgeo`\>\"", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5866138547444267`*^9, 3.5866138692368517`*^9}, {
   3.586613950076194*^9, 3.5866139579230075`*^9}, {3.5866140674976*^9, 
   3.5866140721308084`*^9}, {3.599488731869851*^9, 3.5994887396542645`*^9}, {
   3.6146876112871456`*^9, 3.6146876600459347`*^9}, 3.620195830390541*^9, 
   3.62019876191989*^9},
 EmphasizeSyntaxErrors->True],

Cell["\<\
With this command the packages euvec.m and tensalg.m are loaded automatically.\
\>", "Text",
 CellChangeTimes->{{3.6147522693505993`*^9, 3.614752329286028*^9}, 
   3.6147549420204678`*^9}],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<SURFS`\>\"", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.585969335797983*^9, 3.5859693845168686`*^9}}],

Cell["\<\
We occasionally apply some definitions of  Alfred Gray`s list of curve:\
\>", "Text",
 CellChangeTimes->{{3.585969287625098*^9, 3.585969330509574*^9}, {
   3.599467063031656*^9, 3.599467071758155*^9}, 3.608968714234651*^9, {
   3.614749854875474*^9, 3.614749855920676*^9}, {3.614751974502735*^9, 
   3.614752017430191*^9}}],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<CURVES`\>\"", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.585969335797983*^9, 3.5859693845168686`*^9}, {
  3.599467094937481*^9, 3.599467126408281*^9}}],

Cell["\<\
We will consider surfaces in the 3-space; thus we define the dimension dim = \
3; this value may be changed during the session.\
\>", "Text",
 CellChangeTimes->{{3.5859759313146715`*^9, 3.585975988666952*^9}, {
  3.599464337184517*^9, 3.5994643851282587`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5712056261758223`*^9, 3.571205633008634*^9}, {
   3.571290521047902*^9, 3.5712905431843405`*^9}, 3.572246357078577*^9, {
   3.5859758815878277`*^9, 3.585975898307784*^9}, 3.5994643960898857`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Context", "[", "dim", "]"}]], "Input",
 CellChangeTimes->{{3.6184698263965397`*^9, 3.6184698367237577`*^9}}],

Cell[BoxData["\<\"Global`\"\>"], "Output",
 CellChangeTimes->{3.6184698376597595`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["tensalg.m", "Subsection",
 CellChangeTimes->{{3.5860594705829277`*^9, 3.5860594762925377`*^9}, {
  3.5866141508017464`*^9, 3.586614156807757*^9}, {3.5994887803547363`*^9, 
  3.599488783396742*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "tensalg`*"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.571131128509915*^9, 3.57113114290874*^9}, {
   3.571326268599413*^9, 3.5713262712705655`*^9}, 3.5866141747165885`*^9, {
   3.59948905583562*^9, 3.5994890593768263`*^9}}],

Cell[BoxData[
 DynamicModuleBox[{Typeset`open$$ = True}, 
  PaneSelectorBox[{False->
   RowBox[{
    OpenerBox[Dynamic[Typeset`open$$],
     ImageSize->Small], 
    StyleBox["tensalg`", "InfoHeading"]}], True->GridBox[{
     {
      RowBox[{
       OpenerBox[Dynamic[Typeset`open$$],
        ImageSize->Small], 
       StyleBox["tensalg`", "InfoHeading"]}]},
     {GridBox[{
        {
         ButtonBox["andtest",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"andtest", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["covec",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"covec", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["linform",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"linform", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["rank",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"rank", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["trp",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"trp", "tensalg`"}},
          ButtonNote->"tensalg`"]},
        {
         ButtonBox["ArrayTotensor",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3620543790-1087837", {"ArrayTotensor", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["covector",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"covector", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["mathff",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"mathff", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["renorm",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"renorm", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["tstb",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"tstb", "tensalg`"}},
          ButtonNote->"tensalg`"]},
        {
         ButtonBox["basis",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"basis", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["covecTotensor",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3620543790-1087837", {"covecTotensor", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["matrix",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"matrix", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["smoothing",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"smoothing", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["type",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"type", "tensalg`"}},
          ButtonNote->"tensalg`"]},
        {
         ButtonBox["blf",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"blf", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["covpermute",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"covpermute", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["noprops",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"noprops", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["stb",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"stb", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["vec",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"vec", "tensalg`"}},
          ButtonNote->"tensalg`"]},
        {
         ButtonBox["cc",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"cc", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["covs",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"covs", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["null",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"null", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["strictcoords",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"strictcoords", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["vecbasis",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"vecbasis", "tensalg`"}},
          ButtonNote->"tensalg`"]},
        {
         ButtonBox["cc$",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"cc$", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["covsym",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"covsym", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["nullmatrix",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"nullmatrix", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["sum",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"sum", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["vector",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"vector", "tensalg`"}},
          ButtonNote->"tensalg`"]},
        {
         ButtonBox["contra",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"contra", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["cr",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"cr", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["nulltensor",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"nulltensor", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["tensor",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"tensor", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["vecTotensor",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"vecTotensor", "tensalg`"}},
          ButtonNote->"tensalg`"]},
        {
         ButtonBox["contraction",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"contraction", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["dotnorme",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"dotnorme", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["ortest",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"ortest", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["tensorbasis",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"tensorbasis", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["wedge",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"wedge", "tensalg`"}},
          ButtonNote->"tensalg`"]},
        {
         ButtonBox["contralt",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"contralt", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["eps",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"eps", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["outzero",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"outzero", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["tensorproduct",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3620543790-1087837", {"tensorproduct", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["wedgeform",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"wedgeform", "tensalg`"}},
          ButtonNote->"tensalg`"]},
        {
         ButtonBox["contrapermute",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3620543790-1087837", {"contrapermute", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["epst",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"epst", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["plus",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"plus", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["tensorToArray",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3620543790-1087837", {"tensorToArray", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["wedgevector",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"wedgevector", "tensalg`"}},
          ButtonNote->"tensalg`"]},
        {
         ButtonBox["contras",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"contras", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["eps$",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"eps$", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["projpt",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"projpt", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["times",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"times", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["zero",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"zero", "tensalg`"}},
          ButtonNote->"tensalg`"]},
        {
         ButtonBox["contrasym",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"contrasym", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["equi",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"equi", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["projpt3D",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"projpt3D", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["tp",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"tp", "tensalg`"}},
          ButtonNote->"tensalg`"], ""},
        {
         ButtonBox["coords",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"coords", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["extprod",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"extprod", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["ptind",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"ptind", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["trace",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"trace", "tensalg`"}},
          ButtonNote->"tensalg`"], ""},
        {
         ButtonBox["cova",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"cova", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["formbasis",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"formbasis", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["randommatrix",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"randommatrix", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["tradf",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"tradf", "tensalg`"}},
          ButtonNote->"tensalg`"], ""},
        {
         ButtonBox["covalt",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"covalt", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["lf",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"lf", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["randomv",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"randomv", "tensalg`"}},
          ButtonNote->"tensalg`"], 
         ButtonBox["transpose",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"transpose", "tensalg`"}},
          ButtonNote->"tensalg`"], ""}
       },
       DefaultBaseStyle->"InfoGrid",
       GridBoxItemSize->{"Columns" -> {{
            Scaled[0.19]}}}]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}]}, 
   Dynamic[Typeset`open$$],
   ImageSize->Automatic]]], "Print", "InfoCell",
 CellChangeTimes->{3.620536590505287*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["euvec.m", "Subsection",
 CellChangeTimes->{{3.586059450100092*^9, 3.5860594543120995`*^9}, 
   3.6115594634664087`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "euvec`*"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5711311501159525`*^9, 3.5711311592419686`*^9}}],

Cell[BoxData[
 DynamicModuleBox[{Typeset`open$$ = True}, 
  PaneSelectorBox[{False->
   RowBox[{
    OpenerBox[Dynamic[Typeset`open$$],
     ImageSize->Small], 
    StyleBox["euvec`", "InfoHeading"]}], True->GridBox[{
     {
      RowBox[{
       OpenerBox[Dynamic[Typeset`open$$],
        ImageSize->Small], 
       StyleBox["euvec`", "InfoHeading"]}]},
     {GridBox[{
        {
         ButtonBox["center3pts",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"center3pts", "euvec`"}},
          ButtonNote->"euvec`"], 
         ButtonBox["invsterproj",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"invsterproj", "euvec`"}},
          ButtonNote->"euvec`"], 
         ButtonBox["posvec3pts",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"posvec3pts", "euvec`"}},
          ButtonNote->"euvec`"], 
         ButtonBox["sterproj",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"sterproj", "euvec`"}},
          ButtonNote->"euvec`"]},
        {
         ButtonBox["circle3D",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"circle3D", "euvec`"}},
          ButtonNote->"euvec`"], 
         ButtonBox["neglect",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"neglect", "euvec`"}},
          ButtonNote->"euvec`"], 
         ButtonBox["print",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"print", "euvec`"}},
          ButtonNote->"euvec`"], 
         ButtonBox["subsphere",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"subsphere", "euvec`"}},
          ButtonNote->"euvec`"]},
        {
         ButtonBox["circle3pts",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"circle3pts", "euvec`"}},
          ButtonNote->"euvec`"], 
         ButtonBox["norm",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"norm", "euvec`"}},
          ButtonNote->"euvec`"], 
         ButtonBox["radius3pts",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"radius3pts", "euvec`"}},
          ButtonNote->"euvec`"], 
         ButtonBox["subspheremf",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"subspheremf", "euvec`"}},
          ButtonNote->"euvec`"]},
        {
         ButtonBox["cross",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"cross", "euvec`"}},
          ButtonNote->"euvec`"], 
         ButtonBox["normed",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"normed", "euvec`"}},
          ButtonNote->"euvec`"], 
         ButtonBox["sph3D",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"sph3D", "euvec`"}},
          ButtonNote->"euvec`"], 
         ButtonBox["tg4frame",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"tg4frame", "euvec`"}},
          ButtonNote->"euvec`"]},
        {
         ButtonBox["esorthonorm",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"esorthonorm", "euvec`"}},
          ButtonNote->"euvec`"], 
         ButtonBox["orthocomplement",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3620543790-1087837", {"orthocomplement", "euvec`"}},
          ButtonNote->"euvec`"], 
         ButtonBox["sphere",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"sphere", "euvec`"}},
          ButtonNote->"euvec`"], 
         ButtonBox["tube",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"tube", "euvec`"}},
          ButtonNote->"euvec`"]},
        {
         ButtonBox["gencircle",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"gencircle", "euvec`"}},
          ButtonNote->"euvec`"], 
         ButtonBox["plotcircle3D",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"plotcircle3D", "euvec`"}},
          ButtonNote->"euvec`"], 
         ButtonBox["sphereplot3D",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"sphereplot3D", "euvec`"}},
          ButtonNote->"euvec`"], 
         ButtonBox["unit",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"unit", "euvec`"}},
          ButtonNote->"euvec`"]},
        {
         ButtonBox["hyperplane",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"hyperplane", "euvec`"}},
          ButtonNote->"euvec`"], 
         ButtonBox["plotcircle3pts",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"plotcircle3pts", "euvec`"}},
          ButtonNote->"euvec`"], 
         ButtonBox["sphericalreflection",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3620543790-1087837", {"sphericalreflection", "euvec`"}},
          ButtonNote->"euvec`"], 
         ButtonBox["unitvec",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"unitvec", "euvec`"}},
          ButtonNote->"euvec`"]},
        {
         ButtonBox["innerprod",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"innerprod", "euvec`"}},
          ButtonNote->"euvec`"], 
         ButtonBox["plotgencircle",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"plotgencircle", "euvec`"}},
          ButtonNote->"euvec`"], 
         ButtonBox["spherpt3D",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"spherpt3D", "euvec`"}},
          ButtonNote->"euvec`"], ""}
       },
       DefaultBaseStyle->"InfoGrid",
       GridBoxItemSize->{"Columns" -> {{
            Scaled[0.2375]}}}]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}]}, 
   Dynamic[Typeset`open$$],
   ImageSize->Automatic]]], "Print", "InfoCell",
 CellChangeTimes->{3.620536590536289*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"?", "Norm"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.61155672679888*^9, 3.611556761217849*^9}, {
  3.6115568297847705`*^9, 3.61155684060939*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\!\(\*RowBox[{\\\"Norm\\\", \\\"[\\\", StyleBox[\\\"expr\\\", \
\\\"TI\\\"], \\\"]\\\"}]\) gives the norm of a number, vector or matrix. \
\\n\!\(\*RowBox[{\\\"Norm\\\", \\\"[\\\", RowBox[{StyleBox[\\\"expr\\\", \
\\\"TI\\\"], \\\",\\\", StyleBox[\\\"p\\\", \\\"TI\\\"]}], \\\"]\\\"}]\) \
gives the \!\(\*StyleBox[\\\"p\\\", \\\"TI\\\"]\)\[Hyphen]norm. \"\>", "MSG"],
   "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Norm"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.611556842505498*^9},
 CellTags->"Info3611564042-9853252"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["eudiffgeo.m", "Subsection",
 CellChangeTimes->{{3.586067391757092*^9, 3.5860673977943025`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "eudiffgeo`*"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5860674081371207`*^9, 3.586067416311535*^9}}],

Cell[BoxData[
 DynamicModuleBox[{Typeset`open$$ = True}, 
  PaneSelectorBox[{False->
   RowBox[{
    OpenerBox[Dynamic[Typeset`open$$],
     ImageSize->Small], 
    StyleBox["eudiffgeo`", "InfoHeading"]}], True->GridBox[{
     {
      RowBox[{
       OpenerBox[Dynamic[Typeset`open$$],
        ImageSize->Small], 
       StyleBox["eudiffgeo`", "InfoHeading"]}]},
     {GridBox[{
        {
         ButtonBox["arc",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"arc", "eudiffgeo`"}},
          ButtonNote->"eudiffgeo`"], 
         ButtonBox["circ2D",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"circ2D", "eudiffgeo`"}},
          ButtonNote->"eudiffgeo`"], 
         ButtonBox["curvatures",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"curvatures", "eudiffgeo`"}},
          ButtonNote->"eudiffgeo`"], 
         ButtonBox["spiral",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"spiral", "eudiffgeo`"}},
          ButtonNote->"eudiffgeo`"], 
         ButtonBox["torsion",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"torsion", "eudiffgeo`"}},
          ButtonNote->"eudiffgeo`"]},
        {
         ButtonBox["arclength",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"arclength", "eudiffgeo`"}},
          ButtonNote->"eudiffgeo`"], 
         ButtonBox["circle2D",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"circle2D", "eudiffgeo`"}},
          ButtonNote->"eudiffgeo`"], 
         ButtonBox["frenet",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"frenet", "eudiffgeo`"}},
          ButtonNote->"eudiffgeo`"], 
         ButtonBox["spirgr",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"spirgr", "eudiffgeo`"}},
          ButtonNote->"eudiffgeo`"], ""},
        {
         ButtonBox["assu",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"assu", "eudiffgeo`"}},
          ButtonNote->"eudiffgeo`"], 
         ButtonBox["curvature",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"curvature", "eudiffgeo`"}},
          ButtonNote->"eudiffgeo`"], 
         ButtonBox["graph",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"graph", "eudiffgeo`"}},
          ButtonNote->"eudiffgeo`"], 
         ButtonBox["tangent",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3620543790-1087837", {"tangent", "eudiffgeo`"}},
          ButtonNote->"eudiffgeo`"], ""}
       },
       DefaultBaseStyle->"InfoGrid",
       GridBoxItemSize->{"Columns" -> {{
            Scaled[0.19]}}}]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}]}, 
   Dynamic[Typeset`open$$],
   ImageSize->Automatic]]], "Print", "InfoCell",
 CellChangeTimes->{3.6205365905652905`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"spirgr", "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.6089620258485727`*^9, 3.608962032088583*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "t"], " ", 
      RowBox[{"Cos", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", "t"]}], " ", 
      RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "t"], " ", 
      RowBox[{"Sin", "[", "t", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "t"], " ", 
      RowBox[{"Cos", "[", "t", "]"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.608962033664186*^9, 3.611553421847848*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"spiral", "[", 
   RowBox[{"a", ",", "b"}], "]"}], "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.6089620906822863`*^9, 3.6089621237855444`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"b", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"a", " ", "t"}]], " ", 
    RowBox[{"Cos", "[", "t", "]"}]}], ",", 
   RowBox[{"b", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"a", " ", "t"}]], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6089621272175503`*^9, 3.6115534261320925`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tangent", "[", 
   RowBox[{"spiral", "[", 
    RowBox[{"a", ",", "b"}], "]"}], "]"}], "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.6089621527859955`*^9, 3.608962193533267*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"b", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"a", " ", "t"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a", " ", 
        RowBox[{"Cos", "[", "t", "]"}]}], "-", 
       RowBox[{"Sin", "[", "t", "]"}]}], ")"}]}], 
    SqrtBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["a", "2"]}], ")"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", "a", " ", "t"}]]}]]], ",", 
   FractionBox[
    RowBox[{"b", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"a", " ", "t"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Cos", "[", "t", "]"}], "+", 
       RowBox[{"a", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}], 
    SqrtBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["a", "2"]}], ")"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", "a", " ", "t"}]]}]]]}], "}"}]], "Output",
 CellChangeTimes->{3.608962196013671*^9, 3.611553430593348*^9, 
  3.6115582713782253`*^9, 3.6115583811705046`*^9, 3.611569746299825*^9, 
  3.611570118593119*^9, 3.611573579401825*^9, 3.6116352158496523`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"%", ".", "%"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", " ", 
     RowBox[{"b", ">", "0"}], ",", " ", 
     RowBox[{"t", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6089622116136985`*^9, 3.6089622249205217`*^9}, {
  3.611556638801847*^9, 3.6115566467052994`*^9}, {3.6115582863300805`*^9, 
  3.6115583594252615`*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.6089622264961247`*^9, 3.6115534931579266`*^9, 
  3.611556648618408*^9, 3.6115582897112737`*^9, 3.6115583849377203`*^9, 
  3.6115701267555857`*^9, 3.6116352278616734`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SURFS.m", "Subsection",
 CellChangeTimes->{{3.5860594887413597`*^9, 3.586059509489396*^9}, {
  3.5994638339537334`*^9, 3.5994638358238406`*^9}}],

Cell[BoxData[
 RowBox[{"?", "SURFS`*"}]], "Input",
 CellChangeTimes->{{3.6201990028108015`*^9, 3.620199018676029*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphero", "[", "1", "]"}], "[", 
  RowBox[{"0", ",", 
   RowBox[{"3", 
    RowBox[{"Pi", "/", "2"}]}], ",", 
   RowBox[{
    RowBox[{"-", "Pi"}], "/", "2"}], ",", 
   RowBox[{"Pi", "/", "2"}]}], "]"}]], "Input"],

Cell["\<\
I replaced the name  \[OpenCurlyDoubleQuote]sphere\[CloseCurlyDoubleQuote] as \
defined by Alfred Gray with \[OpenCurlyDoubleQuote]sphero\
\[CloseCurlyDoubleQuote], since sphere has been defined more general in \
euvec.m:\
\>", "Text",
 CellChangeTimes->{{3.585970879065495*^9, 3.5859709333067904`*^9}, {
   3.5859710012426877`*^9, 3.5859710386748285`*^9}, {3.585971099242293*^9, 
   3.585971118058369*^9}, 3.5859754962357864`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "sphere"}]], "Input",
 CellChangeTimes->{{3.585970828271806*^9, 3.58597083093941*^9}}],

Cell[BoxData[
 StyleBox["\<\"sphere[m,r][u,v] is the parameter representation of \\nthe \
sphere with center m and radius r in the euclidean 3-space with \
geographical\\n \\ncoordinates u, 0<=u<=2 Pi, v, -Pi/2 <= v <= Pi/2.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.614752381758029*^9},
 CellTags->"Info3614759581-1510807"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Context", "[", "sphere", "]"}]], "Input",
 CellChangeTimes->{{3.585971045570223*^9, 3.585971062668201*^9}}],

Cell[BoxData["\<\"euvec`\"\>"], "Output",
 CellChangeTimes->{3.6147524144929013`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sphere", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "1"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{"sphero", "[", "1", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.58597550835948*^9, 3.5859755988446555`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.614752428258689*^9}]
}, Closed]],

Cell["Don' t confuse this with the built-in Graphics3D primitive", "Text",
 CellChangeTimes->{{3.5859715472679186`*^9, 3.585971593930588*^9}, {
  3.585971635217949*^9, 3.5859716626585183`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Sphere"}]], "Input",
 CellChangeTimes->{{3.585969549128358*^9, 3.5859695523263636`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\\!\\(\\*RowBox[{\\\"Sphere\\\", \\\"[\\\", \
StyleBox[\\\"p\\\", \\\"TI\\\"], \\\"]\\\"}]\\) represents a unit sphere \
centered at the point \\!\\(\\*StyleBox[\\\"p\\\", \
\\\"TI\\\"]\\).\\n\\!\\(\\*RowBox[{\\\"Sphere\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"p\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\"r\\\", \
\\\"TI\\\"]}], \\\"]\\\"}]\\) represents a sphere of radius \
\\!\\(\\*StyleBox[\\\"r\\\", \\\"TI\\\"]\\) centered at the point \
\\!\\(\\*StyleBox[\\\"p\\\", \
\\\"TI\\\"]\\).\\n\\!\\(\\*RowBox[{\\\"Sphere\\\", \\\"[\\\", \
RowBox[{RowBox[{\\\"{\\\", RowBox[{SubscriptBox[StyleBox[\\\"p\\\", \
\\\"TI\\\"], StyleBox[\\\"1\\\", \\\"TR\\\"]], \\\",\\\", \
SubscriptBox[StyleBox[\\\"p\\\", \\\"TI\\\"], StyleBox[\\\"2\\\", \
\\\"TR\\\"]], \\\",\\\", StyleBox[\\\"\[Ellipsis]\\\", \\\"TR\\\"]}], \\\"}\\\
\"}], \\\",\\\", StyleBox[\\\"r\\\", \\\"TI\\\"]}], \\\"]\\\"}]\\) represents \
a collection of spheres of radius \\!\\(\\*StyleBox[\\\"r\\\", \
\\\"TI\\\"]\\).\"\>", "MSG"], "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Sphere"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.614752434116024*^9},
 CellTags->"Info3614759634-1510807"]
}, Closed]],

Cell[BoxData[
 RowBox[{"Sphere", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "2"}], "}"}]}], "}"}], ",", "1"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.614752453779148*^9, 3.6147525783602743`*^9}, 
   3.6147526639211683`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Sphere", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "2"}], "}"}]}], "}"}], ",", 
   RowBox[{"1", "/", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6147526670623474`*^9, 3.6147526670953493`*^9}, {
  3.614752714673071*^9, 3.6147527157761335`*^9}}],

Cell[BoxData[
 RowBox[{"Sphere", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "2"}], "}"}]}], "}"}], ",", 
   FractionBox["1", "2"]}], "]"}]], "Output",
 CellChangeTimes->{3.6147526727006702`*^9, 3.6147527182612762`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"Graphics3D", "[", "%", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6147525998515034`*^9, 3.6147526487042975`*^9}, 
   3.6147526791610394`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["CURVES.m", "Subsection",
 CellChangeTimes->{{3.5860594887413597`*^9, 3.586059509489396*^9}, {
  3.5994638339537334`*^9, 3.5994638358238406`*^9}, {3.599469927037876*^9, 
  3.5994699297330303`*^9}}],

Cell[BoxData[
 RowBox[{"?", "CURVES`*"}]], "Input",
 CellChangeTimes->{{3.61475153190962*^9, 3.614751542782839*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Global", "Subsection",
 CellChangeTimes->{{3.5860594887413597`*^9, 3.586059509489396*^9}, {
  3.5994638339537334`*^9, 3.5994638358238406`*^9}, {3.599469927037876*^9, 
  3.5994699297330303`*^9}, {3.6201992683798122`*^9, 3.620199272233019*^9}}],

Cell["\<\
Evaluate the next cell to see the symbols actually used in Global Context\
\>", "Text",
 CellChangeTimes->{{3.6201992773654275`*^9, 3.620199340423375*^9}}],

Cell[BoxData[
 RowBox[{"?", "Global`*"}]], "Input",
 CellChangeTimes->{{3.6201992089418144`*^9, 3.6201992164298277`*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["1. The Local Structure Forms of a Surface", "Section",
 CellChangeTimes->{{3.5720851282978826`*^9, 3.5720851431179085`*^9}, {
   3.5722464122558737`*^9, 3.5722464218342905`*^9}, 3.572613861614375*^9, {
   3.5860591355255394`*^9, 3.58605916430759*^9}, 3.5860595807347217`*^9, {
   3.586924985356963*^9, 3.586924992786388*^9}, {3.5872723940085163`*^9, 
   3.5872723973337064`*^9}, {3.5994702008395367`*^9, 3.59947020282165*^9}, 
   3.599487297135331*^9}],

Cell[CellGroupData[{

Cell["1.1. Parameter Representation", "Subsection",
 CellChangeTimes->{{3.572614110263212*^9, 3.5726141131960173`*^9}, {
  3.58605919842485*^9, 3.5860592061936636`*^9}, {3.587272403656068*^9, 
  3.587272408134324*^9}}],

Cell[TextData[{
 "Definition of a ",
 StyleBox["general surface",
  FontColor->RGBColor[0, 0, 1]],
 " in a  space ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "dim"], TraditionalForm]]],
 " with arbitrary   coordinates"
}], "Text",
 CellChangeTimes->{{3.572855115891306*^9, 3.572855271251192*^9}, 
   3.588919489132287*^9, 3.5994873207225723`*^9, {3.6175282598773465`*^9, 
   3.6175282606261477`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sf", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "i", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "dim"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5728552771865315`*^9, 3.5728553233421717`*^9}, {
  3.6175282729813695`*^9, 3.6175282741981716`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", " ", "3"}], ";", 
  RowBox[{"sf", "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.57285533188666*^9, 3.5728553521568193`*^9}, {
  3.6175282908278008`*^9, 3.617528294915008*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "1", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "2", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "3", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.617528280594183*^9, 3.617528297957013*^9}}]
}, Closed]],

Cell[TextData[{
 "It is generally assumed that sf is defined on an open domain  U of real ",
 StyleBox["parameters",
  FontColor->RGBColor[0, 0, 1]],
 " u,v:\n {u,v} \[Epsilon] U, and that the components of sf are smooth \
functions. In this notebook it is assumed mostly that sf[u,v] is a point in \
the Euclidean 3-space with  orthonormal Cartesian coordinates f[i][u,v].  \
Essential for the application of analysis  to geometry is the concept of the ",
 StyleBox["differential",
  FontColor->RGBColor[0, 0, 1]],
 ". If f: U \[RightArrow] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "n"], TraditionalForm]]],
 " is a map of an open set U of the m-dimensional space ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "m"], TraditionalForm]]],
 " with real coordinates {x,y,...} and values in the n-dimensional space ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "n"], TraditionalForm]]],
 ", its differential is defined by"
}], "Text",
 CellChangeTimes->{{3.5859775598738203`*^9, 3.5859775914046235`*^9}, {
   3.585977684324938*^9, 3.5859776866680717`*^9}, 3.585979278963146*^9, {
   3.585979493235402*^9, 3.585979610219093*^9}, {3.5859796687544413`*^9, 
   3.585979806419315*^9}, {3.5859799516676226`*^9, 3.5859799900988207`*^9}, {
   3.5859805402112856`*^9, 3.585980561378496*^9}, {3.58598075813875*^9, 
   3.5859807637550716`*^9}, 3.588919461957039*^9, {3.5889196555689793`*^9, 
   3.5889199692387304`*^9}, {3.588920019283618*^9, 3.588920055085681*^9}, {
   3.5889201160973883`*^9, 3.5889201311202145`*^9}, {3.614755195935991*^9, 
   3.61475531480779*^9}, {3.61752837015394*^9, 3.6175283750055485`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Unprotect", "[", "d", "]"}], ";", 
  RowBox[{"Clear", "[", 
   RowBox[{"f", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "f_", "]"}], "[", "x___", "]"}], ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", "=", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "x", "}"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"n", "\[Equal]", "0"}], ",", " ", 
        RowBox[{"Return", " ", "[", "0", "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"MemberQ", "[", 
         RowBox[{
          RowBox[{"{", "x", "}"}], ",", "f"}], "]"}], ",", " ", 
        RowBox[{"Return", "[", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"{", "x", "}"}], ",", "f"}], "]"}], "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"f", "[", "x", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"{", "x", "}"}], "}"}]}], "]"}]}]}], "]"}]}], ";", 
  RowBox[{"Protect", "[", "d", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5889201417594333`*^9, 3.5889201798234997`*^9}, {
   3.5889202388384037`*^9, 3.5889203501757994`*^9}, {3.588939191614149*^9, 
   3.5889392203338003`*^9}, {3.5889393127327623`*^9, 
   3.5889393481136246`*^9}, {3.5889393930573034`*^9, 
   3.5889394860958667`*^9}, {3.5889395450015697`*^9, 3.588939546779973*^9}, {
   3.588939666744184*^9, 3.5889397751019745`*^9}, {3.588940059615274*^9, 
   3.5889400632032804`*^9}, {3.5889401196441793`*^9, 
   3.5889401618110533`*^9}, {3.588940313958121*^9, 3.588940369197818*^9}, 
   3.588940424718315*^9, 3.5889417824199*^9, 3.5889420050166907`*^9, {
   3.5890054518687425`*^9, 3.5890056433516946`*^9}, 3.5890056767196035`*^9, {
   3.58900585779996*^9, 3.589005857991971*^9}, {3.6092243109724207`*^9, 
   3.609224401341589*^9}, 3.6140559736302814`*^9, {3.6140560060627384`*^9, 
   3.614056036997593*^9}, 3.617527095787702*^9, {3.617527211430705*^9, 
   3.6175272458911657`*^9}, 3.6175273393665295`*^9, 3.6175276094030037`*^9, {
   3.6175278649626527`*^9, 3.6175278795018787`*^9}, {3.6175284350500546`*^9, 
   3.6175284377488585`*^9}, {3.617617903421756*^9, 3.6176179314123564`*^9}, {
   3.6176180363973618`*^9, 3.6176180579085917`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "d"}]], "Input",
 CellChangeTimes->{{3.61754602990119*^9, 3.6175460314767923`*^9}}],

Cell[BoxData[
 StyleBox["\<\"d[f][u,v,w,...] is the differential of the function \
f[u,v,w...] of several variables with values in an  n-dimensional manifold or \
space. For the variables u, v, w,... the differentials d[u][u,v,...], \
d[v][u,v,... ],... yield the standard cobasis in the cotangent space of the \
parameter manifold at the point {u, v,...}. d[f,u,v,w,...][vl] is the value \
of the differen5ial d[f][u,v,w,...] for the tangent vector vl.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.617546037077202*^9},
 CellTags->"Info3617553236-6950008"]
}, Closed]],

Cell["The definition of d[f,u,v,w...][vl] will be added later on.", "Text",
 CellChangeTimes->{{3.6092261597871666`*^9, 3.609226198843401*^9}, {
   3.6092262489872684`*^9, 3.609226298331091*^9}, 3.614773123519758*^9, {
   3.617546124109755*^9, 3.617546189988671*^9}, {3.6175463055165577`*^9, 
   3.6175463106957664`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "Sin", "]"}], "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.5954889643645163`*^9, 3.5954889724609303`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"Cos", "[", "x", "]"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5954889756433363`*^9, 3.5960223170729113`*^9, 3.6140562266783257`*^9, 
   3.6140563255200996`*^9, 3.614773084710539*^9, {3.6175273237821026`*^9, 
   3.617527346511342*^9}, 3.6175278990487127`*^9, 3.617599447682875*^9, 
   3.6176179444541025`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"Sin", "[", "x", "]"}], ",", "x"}], "]"}]], "Input",
 CellChangeTimes->{{3.6175279359895773`*^9, 3.617527939203183*^9}}],

Cell[BoxData[
 RowBox[{"Cos", "[", "x", "]"}]], "Output",
 CellChangeTimes->{3.617527943493191*^9, 3.617599451052481*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "x", "]"}], "[", 
  RowBox[{"x", ",", "y"}], "]"}]], "Input",
 CellChangeTimes->{{3.609226322838493*^9, 3.6092263283568087`*^9}, {
  3.6092263655099335`*^9, 3.609226372605339*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.60922633083395*^9, 3.6092263747484617`*^9, 
  3.614056232450336*^9, 3.614056329092506*^9, 3.6147732051704288`*^9, 
  3.617527350317749*^9, 3.6175994904425507`*^9, 3.617617949936416*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "x", "]"}], "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.609226322838493*^9, 3.6092263283568087`*^9}, {
  3.6092263655099335`*^9, 3.609226372605339*^9}, {3.61752795990442*^9, 
  3.617527968266034*^9}}],

Cell[BoxData[
 RowBox[{"{", "1", "}"}]], "Output",
 CellChangeTimes->{3.617527969295636*^9, 3.6175285014593706`*^9, 
  3.6175994949665585`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "u", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6092244631351233`*^9, 3.6092244832382736`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.6092244729436846`*^9, 3.609224484848366*^9}, 
   3.6140563583737574`*^9, 3.614773265477878*^9, 3.6175273559181585`*^9, 
   3.617599500442168*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "y", "]"}], "[", 
  RowBox[{"x", ",", "y"}], "]"}]], "Input",
 CellChangeTimes->{{3.6092244631351233`*^9, 3.609224525677701*^9}, 
   3.609226415399787*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{{3.609224514506062*^9, 3.6092245282588487`*^9}, 
   3.614773296546655*^9, 3.6175273596621656`*^9, 3.6175995037649736`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "f", "]"}], "[", "]"}]], "Input",
 CellChangeTimes->{3.589005713465705*^9, 3.6175285317078238`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5890057152608075`*^9, 3.589005864654352*^9, 
  3.5954891077599683`*^9, 3.5960223292796097`*^9, 3.6092263829839325`*^9, 
  3.6140562363971434`*^9, 3.614056332025311*^9, 3.614773210582738*^9, 
  3.6175273636089725`*^9, 3.61752853523343*^9, 3.61759950754018*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "Pi", "]"}], "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.588941818019162*^9, 3.5889418578304324`*^9}, {
   3.5889419056445165`*^9, 3.5889419058317165`*^9}, 3.5889419679354258`*^9, {
   3.5889422053522425`*^9, 3.5889422222314725`*^9}}],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{
  3.5889418591252346`*^9, 3.588941907048519*^9, 3.5889419687778273`*^9, {
   3.5889422068186455`*^9, 3.588942223261074*^9}, 3.5889437606905746`*^9, 
   3.5890056845380507`*^9, 3.5890057588463*^9, 3.589005837406794*^9, 
   3.5890058681495523`*^9, 3.595489111535175*^9, 3.5960223326098003`*^9, 
   3.6092263891512856`*^9, 3.614056335660117*^9, 3.61477323893036*^9, 
   3.6175273671189785`*^9, 3.617528540100639*^9, 3.6175995108785863`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "Pi", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.588941818019162*^9, 3.5889418578304324`*^9}, {
   3.5889419056445165`*^9, 3.5889419058317165`*^9}, 3.5889419679354258`*^9, {
   3.5889422053522425`*^9, 3.5889422222314725`*^9}, {3.588942287455187*^9, 
   3.588942303554415*^9}, {3.5890059000743785`*^9, 3.5890059004574003`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.5889423064560204`*^9, 3.5889437658853836`*^9, 
  3.589005755352101*^9, 3.5890059014214554`*^9, 3.595489116932784*^9, 
  3.596022337291068*^9, 3.6092263931175127`*^9, 3.614056240687151*^9, 
  3.6140563394977245`*^9, 3.614773244421674*^9, 3.6175273751841927`*^9, 
  3.6175285438290453`*^9, 3.6175995159797955`*^9}]
}, Closed]],

Cell[TextData[{
 "For a function the differential is almost the same as the ",
 StyleBox["gradient",
  FontColor->RGBColor[0, 0, 1]],
 " Grad"
}], "Text",
 CellChangeTimes->{{3.58892064103831*^9, 3.5889206417871113`*^9}, {
  3.5889209049439735`*^9, 3.588920957594066*^9}, {3.608968397882557*^9, 
  3.608968427011223*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Grad"}]], "Input",
 CellChangeTimes->{{3.614773387141837*^9, 3.614773389891994*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\!\(\*RowBox[{\\\"Grad\\\", \\\"[\\\", RowBox[{StyleBox[\\\"f\
\\\", \\\"TI\\\"], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]], \\\",\\\", StyleBox[\\\"\[Ellipsis]\\\", \\\"TI\\\"], \
\\\",\\\", SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"n\\\", \
\\\"TI\\\"]]}], \\\"}\\\"}]}], \\\"]\\\"}]\) gives the gradient \
\!\(\*RowBox[{\\\"(\\\", RowBox[{RowBox[{RowBox[{\\\"\[PartialD]\\\", \
StyleBox[\\\"f\\\", \\\"TI\\\"]}], \\\"/\\\", RowBox[{\\\"\[PartialD]\\\", \
SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \\\"1\\\"]}]}], \\\",\\\", \
StyleBox[\\\"\[Ellipsis]\\\", \\\"TR\\\"], \\\",\\\", RowBox[{RowBox[{\\\"\
\[PartialD]\\\", StyleBox[\\\"f\\\", \\\"TI\\\"]}], \\\"/\\\", RowBox[{\\\"\
\[PartialD]\\\", SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"n\
\\\", \\\"TI\\\"]]}]}]}], \\\")\\\"}]\).\\n\!\(\*RowBox[{\\\"Grad\\\", \
\\\"[\\\", RowBox[{StyleBox[\\\"f\\\", \\\"TI\\\"], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \
StyleBox[\\\"1\\\", \\\"TR\\\"]], \\\",\\\", StyleBox[\\\"\[Ellipsis]\\\", \\\
\"TI\\\"], \\\",\\\", SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\
\\\"n\\\", \\\"TI\\\"]]}], \\\"}\\\"}], \\\",\\\", StyleBox[\\\"chart\\\", \\\
\"TI\\\"]}], \\\"]\\\"}]\) gives the gradient in the coordinates \
\!\(\*StyleBox[\\\"chart\\\", \\\"TI\\\"]\).\"\>", "MSG"], 
  "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Grad"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.617528550459057*^9},
 CellTags->"Info3617535750-7168362"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grad", "[", 
  RowBox[{
   RowBox[{"h", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "v"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5889209644736786`*^9, 3.5889209987625384`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["h", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    SuperscriptBox["h", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.588920986766117*^9, 3.5889210002133408`*^9}, 
   3.5954891374936204`*^9, 3.599487784729788*^9, 3.6089683846498003`*^9, 
   3.61477330310403*^9, 3.61752738521501*^9, 3.617528555669466*^9, 
   3.6175995269466143`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "h", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5889204141671114`*^9, 3.5889204226535263`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["h", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    SuperscriptBox["h", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.588920425165131*^9, {3.5889394676566343`*^9, 3.5889394924294777`*^9}, 
   3.5889395533475847`*^9, 3.5889397860219936`*^9, 3.5889401813890877`*^9, 
   3.5889403829570417`*^9, 3.588943773544997*^9, 3.589005906641754*^9, 
   3.595489128133604*^9, 3.5960223428993883`*^9, 3.5994877778345757`*^9, 
   3.60896838097759*^9, 3.609224442924968*^9, 3.614056278345617*^9, 
   3.6140563482181396`*^9, 3.614773258041453*^9, 3.6175273893178177`*^9, 
   3.617528560786275*^9, 3.61759952995742*^9}]
}, Closed]],

Cell["\<\
The main differences are 1. d[h][x,...]  defines an object explicitly as a \
function of x,..., and 2. Grad can be related to many concrete coordinate \
systems often used in physical and technical applications:\
\>", "Text",
 CellChangeTimes->{{3.588921241093364*^9, 3.5889214769189787`*^9}, 
   3.588998676512214*^9, 3.5994913695242205`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grad", "[", 
  RowBox[{
   RowBox[{"h", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "v"}], "}"}], ",", "\"\<Polar\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.5889209644736786`*^9, 3.5889209987625384`*^9}, {
  3.588921087745095*^9, 3.588921103157922*^9}, {3.5889211371191816`*^9, 
  3.5889211390847845`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["h", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["h", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "u"]}], "}"}]], "Output",
 CellChangeTimes->{3.588921106324727*^9, 3.588921140301587*^9, 
  3.599487814057839*^9, 3.614773592354574*^9}]
}, Closed]],

Cell["For the parameter representation  of a surface we have", "Text",
 CellChangeTimes->{{3.588921573436348*^9, 3.5889216404540653`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";", 
  RowBox[{
   RowBox[{"d", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.588921645711275*^9, 3.5889216694545164`*^9}, {
  3.617599579612307*^9, 3.617599585197117*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.588921670359318*^9, 3.5889403906166553`*^9, 3.5954891664472713`*^9, 
   3.59602235376501*^9, 3.5994878276610627`*^9, 3.608968446340328*^9, 
   3.6147736289636683`*^9, 3.6175274019070396`*^9, 3.6175285896931257`*^9, 
   3.617599540019438*^9, 3.617599586289119*^9, 3.6176179613250675`*^9, {
   3.617618067920164*^9, 3.617618096127778*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "\[Equal]", " ", 
  RowBox[{"Grad", "[", 
   RowBox[{
    RowBox[{"sf", "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "v"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6175286024851484`*^9, 3.6175286391140127`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.6175286503928328`*^9, 3.6175995945259333`*^9}]
}, Closed]],

Cell["The differential of the map f is a family of linear maps", "Text",
 CellChangeTimes->{{3.5889228641358147`*^9, 3.588922920763914*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "f", "]"}], "[", 
   RowBox[{"x", ",", ".."}], "   ", "]"}], ":", 
  RowBox[{
   SuperscriptBox["R", "m"], " ", "\[LongRightArrow]", "  ", 
   SuperscriptBox["R", "n"]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5889229806212196`*^9, 3.58892300926287*^9}, {
  3.588923056577753*^9, 3.5889230913970137`*^9}, {3.588941572646332*^9, 
  3.5889415857815547`*^9}}],

Cell["\<\
depending on the variables (or \[OpenCurlyDoubleQuote]parameters\
\[CloseCurlyDoubleQuote]) x,..., defined by\
\>", "Text",
 CellChangeTimes->{{3.588923126356675*^9, 3.588923177306365*^9}, 
   3.588923467466874*^9, {3.588998814856127*^9, 3.588998820839469*^9}}],

Cell[BoxData[
 RowBox[{"y", " ", "\[Element]", " ", 
  RowBox[{
   SuperscriptBox["R", "m"], "\[RightTeeArrow]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "f", "]"}], "[", 
     RowBox[{"x", ",", ".."}], "]"}], ".", "y"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5889416120676007`*^9, 3.5889417133429785`*^9}, 
   3.588998736145625*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"vec", "[", 
   RowBox[{"s", ",", "2"}], "]"}], " ", "\[RightTeeArrow]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ".", 
   RowBox[{"vec", "[", 
    RowBox[{"s", ",", "2"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5889232076484184`*^9, 3.5889232636993165`*^9}, {
  3.588923319843815*^9, 3.5889234056907663`*^9}, {3.5889234950945234`*^9, 
  3.5889235095245485`*^9}, {3.5889235406622033`*^9, 3.588923649097994*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"s", "[", "1", "]"}], ",", 
    RowBox[{"s", "[", "2", "]"}]}], "}"}], "\[RightTeeArrow]", 
  RowBox[{
   RowBox[{
    RowBox[{"s", "[", "2", "]"}], " ", 
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"s", "[", "1", "]"}], " ", 
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{3.5889439598249245`*^9, 3.5889450432936277`*^9, 
  3.5954891914853153`*^9, 3.599487872089941*^9, 3.6147736672158566`*^9, 
  3.617599622340782*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], ".", 
  RowBox[{"vec", "[", 
   RowBox[{"s", ",", "2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.588940494715638*^9, 3.588940510970867*^9}, 
   3.588945080655693*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"s", "[", "2", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"s", "[", "1", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"s", "[", "2", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"s", "[", "1", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"s", "[", "2", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"s", "[", "1", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5889234094035726`*^9, 3.588923667396826*^9, 3.5889439987157927`*^9, 
   3.588945084087699*^9, {3.589005966667187*^9, 3.5890059715174646`*^9}, 
   3.5954891997689295`*^9, 3.5960223795234833`*^9, 3.5994878974087853`*^9, 
   3.609224996962657*^9, 3.6092264521578894`*^9, 3.614773684709857*^9, 
   3.61759964388442*^9}]
}, Closed]],

Cell["We test the basis forms d[u], d[v]:", "Text",
 CellChangeTimes->{{3.609226511524285*^9, 3.6092265438751354`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "f", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6092264840987163`*^9, 3.614773699887725*^9, 
  3.6175286828720894`*^9, 3.6175996709972677`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "f", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "==", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}], "*", 
    RowBox[{
     RowBox[{"d", "[", "u", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], " ", "+", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", "v"}], "]"}], "*", 
    RowBox[{
     RowBox[{"d", "[", "v", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6092245895043516`*^9, 3.6092247048079467`*^9}, {
  3.6092247607681475`*^9, 3.609224765470416*^9}, {3.6092248053196955`*^9, 
  3.609224817127371*^9}, {3.6092248482401505`*^9, 3.609224859735808*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.6092247144714994`*^9, 3.6092247686896005`*^9, 
  3.6092248192114897`*^9, 3.6092248627139783`*^9, 3.609226492330187*^9, 
  3.6147737059050694`*^9, 3.617528692372506*^9, 3.6175996753964753`*^9}]
}, Closed]],

Cell["For vector function this rule is not valid:", "Text",
 CellChangeTimes->{{3.609226650900257*^9, 3.6092266800509243`*^9}, 
   3.6147549747243385`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "==", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"sf", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", "u", "}"}]}], "]"}], ".", 
    RowBox[{
     RowBox[{"d", "[", "u", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], " ", "+", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"sf", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", "v", "}"}]}], "]"}], ".", 
    RowBox[{
     RowBox[{"d", "[", "v", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6092245895043516`*^9, 3.6092247048079467`*^9}, {
  3.6092247607681475`*^9, 3.609224765470416*^9}, {3.6092248053196955`*^9, 
  3.609224817127371*^9}, {3.6092248482401505`*^9, 3.609224859735808*^9}, {
  3.6092266116680126`*^9, 3.6092266305930953`*^9}, {3.6147743020511665`*^9, 
  3.6147743524020467`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Dot", "::", "dotsh"}], "MessageName"], ":", 
  " ", "\<\"Tensors \
\[NoBreak]\\!\\({\\(\\(\\(\\(\\*SuperscriptBox[\\(f[1]\\), TagBox[\\((1, \
0)\\), Derivative], Rule[MultilineFunction, None]]\\)\\)[\\(\\(u, v\\)\\)]\\)\
\\), \\(\\(\\(\\(\\*SuperscriptBox[\\(f[2]\\), TagBox[\\((1, 0)\\), \
Derivative], Rule[MultilineFunction, None]]\\)\\)[\\(\\(u, v\\)\\)]\\)\\), \
\\(\\(\\(\\(\\*SuperscriptBox[\\(f[3]\\), TagBox[\\((1, 0)\\), Derivative], \
Rule[MultilineFunction, None]]\\)\\)[\\(\\(u, v\\)\\)]\\)\\)}\\)\[NoBreak] \
and \[NoBreak]\\!\\({1, 0}\\)\[NoBreak] have incompatible shapes. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Dot/dotsh\\\", \
ButtonNote -> \\\"Dot::dotsh\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6092266360084047`*^9, 3.614773734558708*^9, 
  3.614774323909417*^9, 3.614774356357273*^9, 3.6175286999229193`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Dot", "::", "dotsh"}], "MessageName"], ":", 
  " ", "\<\"Tensors \
\[NoBreak]\\!\\({\\(\\(\\(\\(\\*SuperscriptBox[\\(f[1]\\), TagBox[\\((0, \
1)\\), Derivative], Rule[MultilineFunction, None]]\\)\\)[\\(\\(u, v\\)\\)]\\)\
\\), \\(\\(\\(\\(\\*SuperscriptBox[\\(f[2]\\), TagBox[\\((0, 1)\\), \
Derivative], Rule[MultilineFunction, None]]\\)\\)[\\(\\(u, v\\)\\)]\\)\\), \
\\(\\(\\(\\(\\*SuperscriptBox[\\(f[3]\\), TagBox[\\((0, 1)\\), Derivative], \
Rule[MultilineFunction, None]]\\)\\)[\\(\\(u, v\\)\\)]\\)\\)}\\)\[NoBreak] \
and \[NoBreak]\\!\\({0, 1}\\)\[NoBreak] have incompatible shapes. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Dot/dotsh\\\", \
ButtonNote -> \\\"Dot::dotsh\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6092266360084047`*^9, 3.614773734558708*^9, 
  3.614774323909417*^9, 3.614774356357273*^9, 3.6175286999541197`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "}"}]}], "}"}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ".", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}]}], "+", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ".", 
    RowBox[{"{", 
     RowBox[{"1", ",", "0"}], "}"}]}]}]}]], "Output",
 CellChangeTimes->{3.609226636047407*^9, 3.61477373459271*^9, 
  3.6147743239554195`*^9, 3.614774356402275*^9, 3.6175286999541197`*^9}]
}, Closed]],

Cell["Instead one has to use the TensorProduct;", "Text",
 CellChangeTimes->{{3.6092267184271193`*^9, 3.609226736707165*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "==", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"sf", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}], "\[TensorProduct]", 
    RowBox[{
     RowBox[{"d", "[", "u", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"sf", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", "v"}], "]"}], "\[TensorProduct]", 
    RowBox[{
     RowBox[{"d", "[", "v", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6092255700064335`*^9, 3.6092255957509055`*^9}, {
   3.6092256366472445`*^9, 3.6092256596085577`*^9}, {3.6092257240252423`*^9, 
   3.6092257378640337`*^9}, {3.6092259323801594`*^9, 3.6092259767666984`*^9}, 
   3.6175997262681646`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.6092267070714693`*^9, 3.614773749408557*^9, 
  3.6174553055356026`*^9, 3.6175287119661407`*^9, 3.617599694038508*^9, 
  3.6175997286705685`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.614773800266466*^9, 3.6147738434019337`*^9}, {
  3.6147739088996797`*^9, 3.6147741230419283`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]},
     {
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]},
     {
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.614773848227209*^9, 3.614774024695303*^9, 
  3.614774083510667*^9, 3.6147741268241444`*^9, 3.617528746333001*^9}]
}, Closed]],

Cell[TextData[{
 " A point sf[u0,v0] of the parameter representation is said to be",
 StyleBox[" regular",
  FontColor->RGBColor[0, 0, 1]],
 ", if"
}], "Text",
 CellChangeTimes->{{3.5859775598738203`*^9, 3.5859775914046235`*^9}, {
   3.585977684324938*^9, 3.5859776866680717`*^9}, 3.585979278963146*^9, {
   3.585979493235402*^9, 3.585979610219093*^9}, {3.5859796687544413`*^9, 
   3.585979806419315*^9}, {3.5859799516676226`*^9, 3.5859799900988207`*^9}, {
   3.5859805402112856`*^9, 3.585980561378496*^9}, {3.58598075813875*^9, 
   3.5859807637550716`*^9}, 3.588919461957039*^9, 3.588921688034149*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixRank", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Rule]", "u0"}], ",", 
     RowBox[{"v", "\[Rule]", "v0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5859805724181275`*^9, 3.5859806608291845`*^9}, {
  3.5859807142702413`*^9, 3.5859807199815674`*^9}, {3.585980775894766*^9, 
  3.585980799256102*^9}, {3.5889217292026215`*^9, 3.588921746565452*^9}}],

Cell[BoxData["2"], "Output",
 CellChangeTimes->{3.588921754147065*^9, 3.588945140325798*^9, 
  3.6175287551782165`*^9}]
}, Closed]],

Cell[TextData[{
 "is maximal, here equal 2, what ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " supposes generally. A smooth map of manifolds\n f: ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]]],
 " \[RightArrow] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Y", "n"], TraditionalForm]]],
 ", m \[LessEqual] n the dimensions of the manifolds, is said to be an ",
 StyleBox["immersion",
  FontColor->RGBColor[0, 0, 1]],
 ", if it is regular at all points x \[Element] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]]],
 ", that means that the differential d[f][x] has maximal rank m at each point \
x.  For the immersions considered in this notebook ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]]],
 " is supposed  to be an open connected subset of the m-dimensional real \
parameter space ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckCapitalR]", "m"], TraditionalForm]]],
 ".  Such considerations are said to be ",
 StyleBox["local",
  FontColor->RGBColor[0, 0, 1]],
 "; for global results  consult the textbooks."
}], "Text",
 CellChangeTimes->{{3.5859808863310823`*^9, 3.585981001738683*^9}, 
   3.5859812042752676`*^9, {3.58892214405415*^9, 3.5889221553329697`*^9}, {
   3.599489421188262*^9, 3.599489423153865*^9}, {3.6147748706876907`*^9, 
   3.614774889639775*^9}, 3.6175287613558273`*^9, {3.6176041768079815`*^9, 
   3.6176043174578285`*^9}, {3.6176043528230906`*^9, 
   3.6176044069395857`*^9}, {3.6176044518832645`*^9, 
   3.6176046332803836`*^9}, {3.617604677288061*^9, 3.6176047310457554`*^9}, {
   3.6176047705762243`*^9, 3.617604883754423*^9}, {3.617604917356882*^9, 
   3.6176049802249928`*^9}, {3.617605013109851*^9, 3.617605033795487*^9}, {
   3.61760506986275*^9, 3.617605161341311*^9}}],

Cell[TextData[{
 "For concrete surfaces may exist ",
 StyleBox["singular",
  FontColor->RGBColor[0, 0, 1]],
 " (i.e. non regular) points, e. g. the unit sphere"
}], "Text",
 CellChangeTimes->{{3.5859808863310823`*^9, 3.585981001738683*^9}, 
   3.5859812042752676`*^9, {3.58892214405415*^9, 3.5889221553329697`*^9}, {
   3.599489421188262*^9, 3.599489423153865*^9}, {3.6147748706876907`*^9, 
   3.614774889639775*^9}, 3.6175287613558273`*^9, {3.6176041768079815`*^9, 
   3.6176043174578285`*^9}, {3.6176043528230906`*^9, 
   3.6176044069395857`*^9}, {3.6176044518832645`*^9, 
   3.6176046332803836`*^9}, {3.617604677288061*^9, 3.6176047310457554`*^9}, {
   3.6176047705762243`*^9, 3.617604883754423*^9}, {3.617604917356882*^9, 
   3.617604989257409*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sphero", "[", "1", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5859810215718174`*^9, 3.5859810412209415`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", "u", "]"}], " ", 
    RowBox[{"Cos", "[", "v", "]"}]}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", "v", "]"}], " ", 
    RowBox[{"Sin", "[", "u", "]"}]}], ",", 
   RowBox[{"Sin", "[", "v", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5994879816801333`*^9, 3.599489409488241*^9, 
  3.6089689054865904`*^9, 3.6147748996013446`*^9, 3.6175287698110423`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Cos", "[", "v", "]"}]}], " ", 
      RowBox[{"Sin", "[", "u", "]"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Cos", "[", "u", "]"}]}], " ", 
      RowBox[{"Sin", "[", "v", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Cos", "[", "u", "]"}], " ", 
      RowBox[{"Cos", "[", "v", "]"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sin", "[", "u", "]"}]}], " ", 
      RowBox[{"Sin", "[", "v", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"Cos", "[", "v", "]"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5889220268667445`*^9, 3.599489437583891*^9, 
  3.614774904903648*^9, 3.617528773586249*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "/.", 
  RowBox[{"v", " ", "\[Rule]", " ", 
   RowBox[{"Pi", "/", "2"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      RowBox[{"Cos", "[", "u", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      RowBox[{"Sin", "[", "u", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5889219899258795`*^9, 3.596022422158922*^9, 
  3.5994894432467003`*^9, 3.6147749091558914`*^9, 3.6175287791086583`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixRank", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "/.", 
   RowBox[{"v", " ", "\[Rule]", " ", 
    RowBox[{"Pi", "/", "2"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.585981072950756*^9, 3.5859810781580544`*^9}, {
  3.5859811219425583`*^9, 3.5859811247027164`*^9}, {3.5889218032715516`*^9, 
  3.588921824487589*^9}, {3.5889218603208513`*^9, 3.588921938492589*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.5889218886661015`*^9, 3.5889219706598454`*^9, 
  3.5960224345176287`*^9, 3.599489454884321*^9, 3.6147749170973454`*^9, 
  3.61752878562947*^9}]
}, Closed]],

Cell["\<\
The \[OpenCurlyDoubleQuote]pole\[CloseCurlyDoubleQuote] is a singularity of \
the parameter representation, not of the sphere.\
\>", "Text",
 CellChangeTimes->{{3.617528858325598*^9, 3.6175288969824657`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sph", "=", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"sphero", "[", "1", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "0", ",", 
       RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"v", ",", "0", ",", 
       RowBox[{"Pi", "/", "2"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5859812477817564`*^9, 3.585981348142496*^9}, {
  3.5859815859831*^9, 3.585981590489358*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"pn", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Black", ",", 
      RowBox[{"PointSize", "[", ".03", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{
        RowBox[{"sphero", "[", "1", "]"}], "[", 
        RowBox[{"u", ",", 
         RowBox[{"Pi", "/", "2"}]}], "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.585981598798833*^9, 3.585981608132367*^9}, {
  3.5859816511338263`*^9, 3.5859816640615664`*^9}, {3.585981694846327*^9, 
  3.585981764203294*^9}, {3.5859818411426945`*^9, 3.58598188005392*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{"pn", ",", "sph"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.5859813522057285`*^9, 3.585981501934293*^9}, {
  3.585981553318232*^9, 3.5859815606696525`*^9}, {3.585981910101639*^9, 
  3.5859819154309435`*^9}}],

Cell[TextData[{
 "We define the",
 StyleBox[" tangent basis vectors of an immersion",
  FontColor->RGBColor[0, 0, 1]],
 ":"
}], "Text",
 CellChangeTimes->{{3.58598299934694*^9, 3.5859830217632217`*^9}, {
  3.585983083914777*^9, 3.5859831585790477`*^9}, {3.617602206399721*^9, 
  3.617602240641781*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tv", "::", "usage"}], " ", "=", " ", 
   "\"\<tv[i][f][u,v,...]is the tangent vector of the i-th  parameter line of \
the immersion f[u,v,...] at the point {u, v,...}. If this point is regular \
these vectors for i = 1,...,Length[{u,v,...}] form a basis of the tangent \
space image[d[f][u,v,...]].\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6147750597295036`*^9, 3.6147752023226595`*^9}, {
  3.617601685889207*^9, 3.617601763280943*^9}, {3.6176018170854373`*^9, 
  3.6176018889547634`*^9}, {3.6176019215588207`*^9, 3.617602075390691*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tv", "[", "i_", "]"}], "[", "f_", "]"}], "[", "u__", "]"}], ":=",
   " ", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"IntegerQ", "[", "i", "]"}], "&&", 
     RowBox[{"i", ">", "0"}], "&&", 
     RowBox[{"i", "\[LessEqual]", 
      RowBox[{"Length", "[", 
       RowBox[{"{", "u", "}"}], "]"}]}]}], ",", " ", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Head", "[", 
         RowBox[{"f", "[", "u", "]"}], "]"}], "\[Equal]", " ", "List"}], "&&",
        " ", 
       RowBox[{
        RowBox[{"Length", "[", 
         RowBox[{"f", "[", "u", "]"}], "]"}], ">", "1"}]}], ",", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{
         RowBox[{"d", "[", "f", "]"}], "[", "u", "]"}], "]"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"d", "[", "f", "]"}], "[", "u", "]"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"d", "[", "f", "]"}], "[", "u", "]"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Wrong i = \>\"", ",", " ", "i"}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.617600215672224*^9, 3.6176003174156027`*^9}, {
  3.6176006545477953`*^9, 3.617600705856285*^9}, {3.6176007854944253`*^9, 
  3.617600881278593*^9}, {3.617600951853117*^9, 3.6176009588419294`*^9}, {
  3.6176010154232287`*^9, 3.617601022786442*^9}, {3.617601071505327*^9, 
  3.617601080865344*^9}, {3.617601230578807*^9, 3.6176012370996184`*^9}, {
  3.617601271372878*^9, 3.6176014155483313`*^9}, {3.6176014483707895`*^9, 
  3.6176014781356416`*^9}}],

Cell["For a function we have", "Text",
 CellChangeTimes->{{3.617602506435048*^9, 3.617602516840266*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tv", "[", "2", "]"}], "[", "f", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5859821957269754`*^9, 3.5859823002309527`*^9}, {
   3.585999470135942*^9, 3.5859995456400747`*^9}, {3.587561122225507*^9, 
   3.587561164661934*^9}, {3.6141625644876366`*^9, 3.6141626502097874`*^9}, {
   3.614163514950506*^9, 3.6141636632287664`*^9}, {3.614163718749264*^9, 
   3.614163724926875*^9}, 3.617600023838687*^9, 3.6176000856927958`*^9, {
   3.6176015070424924`*^9, 3.6176015352629423`*^9}, 3.6176015768058147`*^9, {
   3.6176016248462996`*^9, 3.61760163099271*^9}, {3.6176023871260386`*^9, 
   3.6176023906516447`*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["f", 
   TagBox[
    RowBox[{"(", 
     RowBox[{"0", ",", "1"}], ")"}],
    Derivative],
   MultilineFunction->None], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwVzU0og3EAx/GZ5PVhLZqDl1ZiIm/DxLKeFZKDd22aNhsHu0wUNYaYpckB
tRIiSvKymqRNMw44SJTmQJHExpPQYiyF3//w7XP88tW6uvYgFotVgI5npVGh
HwwdUv2uJbYV0v1E1xvrgoLxS6UVXDimLnZmQWsSe1II73Yl6yLY9dsUI4dR
KWXVCpihMM13QJktNkwLc2VtASMULFcqpmHc+4xyA+ZzZXlO+BizotqDp4/G
oUu4t6OvvyL/6IUWIuPNNAR9MvTWts0cCe0Ro5dEcU/zPQULfOd92XBIXtIr
hH6eZVYMV45c4XLYM5F2OAhz1n3Bm7CSkyaxQpW78ZaYIH32EznCZo0Dpn69
ZruhrEbDPMD0RBf1B0WUVExke3idbD9Dvxgs4wLY4OPaa2ERP1SvgpxrasAE
95VmE3FtqsqxCs9akz+tMHfO6/F/M7TkofwgAIcXoo+JT0e8jB+o677JIY6c
qNTEU6+bvxhg6H/V/++Y
  "]]
}, Open  ]],

Cell["For a surface we get", "Text",
 CellChangeTimes->{{3.6176025506299257`*^9, 3.6176025626575465`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tv", "[", "1", "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.617600351439263*^9, 3.617600385182122*^9}, 
   3.617601103344983*^9, {3.6176011586470804`*^9, 3.617601175105109*^9}, 
   3.617602309032301*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "1", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "2", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "3", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6176023632579966`*^9, 3.618032374892167*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tv", "[", "2", "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5859821957269754`*^9, 3.5859823002309527`*^9}, {
   3.585999470135942*^9, 3.5859995456400747`*^9}, {3.587561122225507*^9, 
   3.587561164661934*^9}, {3.6141625644876366`*^9, 3.6141626502097874`*^9}, {
   3.614163514950506*^9, 3.6141636632287664`*^9}, {3.614163718749264*^9, 
   3.614163724926875*^9}, 3.617600023838687*^9, 3.6176000856927958`*^9, {
   3.6176015070424924`*^9, 3.6176015352629423`*^9}, 3.6176015768058147`*^9, 
   3.6176023741780157`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "1", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "2", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "3", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6176015798478203`*^9, {3.617602368484006*^9, 3.6176023753324175`*^9}, 
   3.617615504044865*^9, 3.6176246339812884`*^9, 3.617682913840128*^9, 
   3.6176928080762453`*^9, 3.6177012099995623`*^9, 3.6177695947341604`*^9, 
   3.6177762501606503`*^9, 3.6178035002143507`*^9, 3.6178043526466484`*^9, 
   3.6178595311513653`*^9, 3.6178889943011665`*^9, 3.617940220810557*^9, 
   3.6179726267622232`*^9, 3.6179750452074413`*^9, 3.6180244521530514`*^9, 
   3.6180322838504066`*^9, 3.618032378620573*^9, 3.61811453741891*^9, 
   3.6181351255533075`*^9, 3.6181357241731586`*^9, 3.618139922842533*^9, 
   3.6182087345139165`*^9, 3.6182168898702755`*^9, 3.6182356127216253`*^9, 
   3.618293838039627*^9, 3.618373153298418*^9, 3.618465823598997*^9, 
   3.6184683452363377`*^9, 3.6184696186821747`*^9, 3.61846981528932*^9, 
   3.6184911628343334`*^9, 3.6185460474676695`*^9, 3.6185803071035576`*^9, 
   3.6186338379566593`*^9, 3.618634210079713*^9, 3.6186407687548275`*^9, 
   3.6187188127028713`*^9, 3.618803136607681*^9, 3.618833360238405*^9, 
   3.618911216432869*^9, 3.6189112843241878`*^9, 3.6189813223616533`*^9, 
   3.6189940889962893`*^9, 3.620190007253416*^9, 3.620195842230962*^9, 
   3.6201958884725714`*^9, 3.6201987447585087`*^9, 3.6201987909359407`*^9, 
   3.620199187040722*^9, 3.620536590664296*^9}]
}, Open  ]],

Cell["\<\
These vectors are linearly independent at regular points, e.g. for the unit \
sphere  we have:\
\>", "Text",
 CellChangeTimes->{{3.585983209687971*^9, 3.585983232980303*^9}, {
   3.5859833216453743`*^9, 3.5859833377072935`*^9}, {3.6176024290121117`*^9, 
   3.6176024402441316`*^9}, {3.617602687020965*^9, 3.6176027192350216`*^9}, {
   3.6176027674079065`*^9, 3.617602782461933*^9}, 3.6176155345117188`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Cross", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "1", "]"}], "[", 
      RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "2", "]"}], "[", 
      RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", "u", "]"}], " ", 
    SuperscriptBox[
     RowBox[{"Cos", "[", "v", "]"}], "2"]}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
    RowBox[{"Sin", "[", "u", "]"}]}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", "v", "]"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6176028353460255`*^9}]
}, Closed]],

Cell["Only the points  with v =\[PlusMinus] \[Pi]/2 are singular:", "Text",
 CellChangeTimes->{{3.617602935342201*^9, 3.617602952377431*^9}, {
  3.617602984887888*^9, 3.6176030247771587`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "/.", " ", 
  RowBox[{"v", "\[Rule]", " ", 
   RowBox[{"Pi", "/", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.5859825732805705`*^9, 3.5859825823570895`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.5889223114268436`*^9, 3.59948956252451*^9, 
  3.614162709224691*^9, 3.6141637513377213`*^9, 3.6147753538243246`*^9, 
  3.6176029002889395`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tv", "[", "1", "]"}], "[", 
    RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "/.", " ", 
  RowBox[{"v", "\[Rule]", " ", 
   RowBox[{"Pi", "/", "2"}]}]}]], "Input",
 CellChangeTimes->{3.5859826492939177`*^9, 3.617600023854287*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.5889223155764513`*^9, 3.6141627157299023`*^9, 
  3.6147753615467663`*^9, 3.6176030350107765`*^9, 3.6180323882301903`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tv", "[", "2", "]"}], "[", 
    RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "/.", " ", 
  RowBox[{"v", "\[Rule]", " ", 
   RowBox[{"Pi", "/", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.5859826492939177`*^9, 3.5859826628216915`*^9}, 
   3.6176000856927958`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"Cos", "[", "u", "]"}]}], ",", 
   RowBox[{"-", 
    RowBox[{"Sin", "[", "u", "]"}]}], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.58892232061526*^9, 3.6141627197079096`*^9, 
  3.6141637578429327`*^9, 3.6147753651559725`*^9, 3.6176030430447903`*^9, 
  3.6180323933001995`*^9}]
}, Closed]],

Cell["\<\
Thus the poles are singularities of the parameter representation in spite of \
the fact that geometrically all points of the sphere have the same \
properties. Remark that singular is a property of the parameter \
representation, not of the surface, considered as the image of the presenting \
function sf.\
\>", "Text",
 CellChangeTimes->{{3.585983439303104*^9, 3.585983656011499*^9}, {
   3.5859837425554495`*^9, 3.585983800018736*^9}, 3.588937868466625*^9, 
   3.5889388391471305`*^9, 3.599489609168592*^9, {3.617603095211282*^9, 
   3.6176031171137204`*^9}}],

Cell["\<\
 The vertex of a cone is an example of a singularity reflecting a geometric \
property of the surface:\
\>", "Text",
 CellChangeTimes->{{3.585983439303104*^9, 3.585983656011499*^9}, {
   3.5859837425554495`*^9, 3.585983800018736*^9}, 3.588937868466625*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "circularcone"}]], "Input",
 CellChangeTimes->{{3.6147755833974557`*^9, 3.614775607648843*^9}}],

Cell[BoxData[
 StyleBox["\<\"{u,v}->circularcone[a,b][u,v] is a parametrization of a \
circular cone of radius a and slope b/a.  To plot try \
circularcone[1,0.5][-Pi,Pi,-1,1].\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.614775609294937*^9},
 CellTags->"Info3614782809-5384848"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"circularcone", "[", 
   RowBox[{".5", ",", "1"}], "]"}], "[", 
  RowBox[{
   RowBox[{"-", "Pi"}], ",", "Pi", ",", 
   RowBox[{"-", "1"}], ",", "1"}], "]"}]], "Input",
 CellChangeTimes->{{3.5859838112913804`*^9, 3.585983897230296*^9}, {
  3.614775887921873*^9, 3.6147759149784207`*^9}, {3.6147759454011607`*^9, 
  3.6147760046025467`*^9}, {3.614776258627076*^9, 3.6147762664975266`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"con", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.614776032433139*^9, 3.6147760417846737`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"circularcone", "[", 
   RowBox[{"a", ",", "b"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{3.6147761956744757`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", " ", "v", " ", 
    RowBox[{"Cos", "[", "u", "]"}]}], ",", 
   RowBox[{"a", " ", "v", " ", 
    RowBox[{"Sin", "[", "u", "]"}]}], ",", 
   RowBox[{"b", " ", "v"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6147761968275414`*^9, 3.617528963828583*^9, 
  3.617603148391775*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Cross", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "1", "]"}], "[", 
      RowBox[{"circularcone", "[", 
       RowBox[{"a", ",", "b"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "2", "]"}], "[", 
      RowBox[{"circularcone", "[", 
       RowBox[{"a", ",", "b"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5859839125391717`*^9, 3.585983965798218*^9}, {
   3.6147756341853604`*^9, 3.6147756746416745`*^9}, 3.614775705002411*^9, {
   3.6147757402034245`*^9, 3.6147757465467873`*^9}, 3.6176000238698874`*^9, 
   3.617600085708396*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", " ", "b", " ", "v", " ", 
    RowBox[{"Cos", "[", "u", "]"}]}], ",", 
   RowBox[{"a", " ", "b", " ", "v", " ", 
    RowBox[{"Sin", "[", "u", "]"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "2"]}], " ", "v"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5994896343938365`*^9, 3.6147757092446537`*^9, 
  3.6147757477588563`*^9, 3.6147762988703785`*^9, 3.617528974826602*^9, 
  3.6176031587345934`*^9, 3.617615638439101*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"v", "\[Rule]", "0"}]}]], "Input",
 CellChangeTimes->{{3.5859840514991198`*^9, 3.5859840750214653`*^9}, {
  3.614775781144766*^9, 3.6147757874811287`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.6147757950315604`*^9, 3.614776305808775*^9, 
  3.6175289820962152`*^9, 3.6176031632274017`*^9, 3.6176156429943094`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"pv", " ", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Black", ",", " ", 
      RowBox[{"PointSize", "[", ".03", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{
        RowBox[{"circularcone", "[", 
         RowBox[{".5", ",", "1"}], "]"}], "[", 
        RowBox[{"1", ",", "0"}], "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.585984234159567*^9, 3.5859843523663282`*^9}, {
  3.5859844135268264`*^9, 3.585984470358077*^9}, {3.585984555310936*^9, 
  3.585984577831224*^9}, {3.614775846146484*^9, 3.614775861514363*^9}, {
  3.614776134090953*^9, 3.6147761364340878`*^9}, {3.614776216867688*^9, 
  3.614776226506239*^9}, {3.6147763213466635`*^9, 3.614776385643341*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{"pv", ",", "con"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.585984508907282*^9, 3.5859845240771494`*^9}}],

Cell[TextData[{
 StyleBox["\nLemma",
  FontColor->RGBColor[0, 0, 1]],
 ". At any regular point sf[u,v]  of the surface sf the tangent vectors  \
tv[1][sf], tv[2][sf] are a basis of the tangent vector space, ",
 StyleBox["often this basis is named the",
  FontColor->GrayLevel[0]],
 StyleBox[" standard basis field of the immersion sf.",
  FontColor->RGBColor[0, 0, 1]],
 "  The tangent vector space T[sf][u,v]  consists of all vectors"
}], "Text",
 CellChangeTimes->{{3.5859846820571856`*^9, 3.5859849956431217`*^9}, 
   3.588922731067581*^9, 3.6176000239010873`*^9, 3.617600085723996*^9, {
   3.617603202555071*^9, 3.617603223053507*^9}, 3.6176036724278955`*^9, {
   3.6176037379480104`*^9, 3.617603739086813*^9}, {3.6176037930629077`*^9, 
   3.6176038505646086`*^9}, {3.617615688281189*^9, 3.6176157025396137`*^9}}],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"tang", "[", "f_", "]"}], "[", 
     RowBox[{"u_", ",", "v_"}], "]"}], "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], " ", ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "f", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5859849982252693`*^9, 3.5859850846312113`*^9}, {
   3.5859991497425795`*^9, 3.5859991766994267`*^9}, 3.5859996276962185`*^9, {
   3.588938928831688*^9, 3.588938963089348*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tang", "::", "usage"}], " ", "=", " ", 
   "\"\<tang[f][u,v][x,y] is the tangent vector with standard coordinates x, \
y of the surface f[u,v] at the point {u,v}.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6147768255615034`*^9, 3.614776948794552*^9}, 
   3.614776996347272*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"tang", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "[", 
   RowBox[{"x", ",", "y"}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.5859849982252693`*^9, 3.5859850846312113`*^9}, {
   3.5859991497425795`*^9, 3.5859991766994267`*^9}, 3.5859996276962185`*^9, {
   3.588938928831688*^9, 3.588938963089348*^9}, {3.588946247787343*^9, 
   3.5889462707973833`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"y", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{"x", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"y", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{"x", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"y", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{"x", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.588946272809787*^9, 3.588998599430805*^9, 3.5890059401866727`*^9, 
   3.5890870883094635`*^9, 3.589169669853875*^9, 3.5896085365105577`*^9, 
   3.5897728448014*^9, 3.5898647221289644`*^9, 3.5898904964615774`*^9, 
   3.589951882034334*^9, 3.5899536563658504`*^9, 3.589956013723542*^9, 
   3.589978282143256*^9, 3.5900390083788204`*^9, 3.590212009087702*^9, 
   3.590495818358399*^9, 3.59064041447136*^9, 3.590671482144188*^9, 
   3.590715685089877*^9, 3.590720169876649*^9, 3.590734036146722*^9, 
   3.5908181803412027`*^9, 3.590904695237748*^9, 3.590910211478057*^9, 
   3.590987954943019*^9, 3.5911632380149126`*^9, 3.59118065923291*^9, 
   3.5912467885104556`*^9, 3.59133944881538*^9, 3.5914142260304017`*^9, 
   3.591441547977578*^9, 3.5915074096282396`*^9, 3.59159239409589*^9, 
   3.591685703410115*^9, 3.5917678336409388`*^9, 3.5919453642214813`*^9, 
   3.5919661257437706`*^9, 3.592022566222621*^9, 3.5920227064668674`*^9, 
   3.592046742872752*^9, 3.5921112240848026`*^9, 3.5921338228888397`*^9, 
   3.592147917264385*^9, 3.592200124602253*^9, 3.592293252266412*^9, 
   3.5923059783959446`*^9, 3.5923732668805757`*^9, 3.5924544138146453`*^9, 
   3.5925450415548215`*^9, 3.5926322081665554`*^9, 3.5926559495590343`*^9, 
   3.592708144232199*^9, 3.5927410479858446`*^9, 3.5927992840389743`*^9, 
   3.5929819514697976`*^9, 3.5930088467994823`*^9, 3.593064293885617*^9, 
   3.5931467699928713`*^9, 3.5931778410456867`*^9, 3.5933218944086742`*^9, 
   3.5933488152157493`*^9, 3.593405049753461*^9, 3.5934139969619756`*^9, 
   3.5934340786416206`*^9, 3.593583961578569*^9, 3.5936118191153107`*^9, 
   3.593668081991914*^9, 3.5938384258570824`*^9, 3.593840950957283*^9, 
   3.594184572998464*^9, 3.5941922047190685`*^9, 3.5942697013128815`*^9, 
   3.5942746442905903`*^9, 3.5943635746861734`*^9, 3.5943647089953656`*^9, 
   3.5946216254232874`*^9, 3.59470542312568*^9, 3.594877279654665*^9, 
   3.594881067840519*^9, 3.594964009916691*^9, 3.5950483418856974`*^9, 
   3.5951338050284595`*^9, 3.5951436415881467`*^9, 3.595229678564871*^9, 
   3.595311842714632*^9, 3.5954848001556025`*^9, 3.59548604032658*^9, 
   3.5954886788528147`*^9, 3.595569165507681*^9, 3.5955702335367684`*^9, 
   3.5955749396649437`*^9, 3.595650862562545*^9, 3.5956595570380197`*^9, 
   3.5958282749648685`*^9, 3.595911998190153*^9, 3.596001556800888*^9, 
   3.596089182112556*^9, 3.5962618842279606`*^9, 3.5963556630637417`*^9, 
   3.596371465506769*^9, 3.5964368613617573`*^9, 3.596521285462677*^9, 
   3.597207512712455*^9, 3.5972982545503283`*^9, 3.59738184032658*^9, 
   3.59746808328891*^9, 3.597729292001838*^9, {3.59773767377643*^9, 
   3.5977376934395547`*^9}, 3.597761265738062*^9, 3.597814065880206*^9, 
   3.597847427548482*^9, 3.5979019474135528`*^9, 3.598009259439215*^9, 
   3.598074376334318*^9, 3.5983626703740845`*^9, 3.5984255590242586`*^9, 
   3.5985947292158937`*^9, 3.5986251805101423`*^9, 3.5986755719858627`*^9, 
   3.5988608238129787`*^9, 3.5988821120618706`*^9, 3.5989404436959033`*^9, 
   3.5990227496541743`*^9, 3.5991971462607765`*^9, 3.5991972489536505`*^9, 
   3.5992870773655224`*^9, 3.599466643104637*^9, 3.5994872774012966`*^9, 
   3.599488182421286*^9, 3.5994885254346886`*^9, 3.599488823426412*^9, 
   3.5994890860372734`*^9, 3.599550816890743*^9, 3.5995512984323883`*^9, 
   3.599803399697974*^9, 3.6089605884620476`*^9, 3.6089613030525026`*^9, 
   3.608965754660722*^9, 3.6089661896674857`*^9, 3.6089673435372515`*^9, 
   3.608968840608879*^9, 3.6089692240888133`*^9, 3.6089694743371267`*^9, 
   3.6089722055845623`*^9, 3.609137037626713*^9, 3.60921511491718*^9, 
   3.6093079267580137`*^9, 3.6095588250018167`*^9, 3.6095609615219717`*^9, 
   3.60964906691413*^9, 3.6096503212408743`*^9, 3.6096724936825857`*^9, 
   3.609731060861607*^9, 3.6097436480153193`*^9, 3.6097530767904563`*^9, 
   3.6098148106300697`*^9, 3.6098499633980865`*^9, 3.609910387529049*^9, 
   3.6112083905184355`*^9, 3.611466102915165*^9, 3.611553298895815*^9, 
   3.611558167668293*^9, 3.6115582065155153`*^9, 3.611569706608555*^9, 
   3.6115701072204685`*^9, 3.611573546750968*^9, 3.6116341217845297`*^9, 
   3.6116351931048126`*^9, 3.6119250164784746`*^9, 3.6119969341833797`*^9, 
   3.6120721293562813`*^9, 3.6120900816144905`*^9, 3.6121526062869835`*^9, 
   3.612265705989365*^9, 3.6123237626297626`*^9, 3.6126788783326735`*^9, 
   3.612754364342231*^9, 3.612845981986636*^9, 3.613021068663982*^9, 
   3.613105017069496*^9, 3.6132198046223664`*^9, 3.6132778671263895`*^9, 
   3.613443506665018*^9, 3.6134728926010394`*^9, 3.6135412362492447`*^9, 
   3.6135600354719057`*^9, 3.6136190008977523`*^9, 3.6139702744672737`*^9, 
   3.613976391664424*^9, 3.6139942675054646`*^9, 3.61399431584995*^9, 
   3.614053375835719*^9, 3.6141460247308846`*^9, 3.614163814907833*^9, 
   3.614163985478533*^9, 3.614228814892914*^9, 3.6142562416074734`*^9, 
   3.6143098827168584`*^9, 3.6143282355692644`*^9, 3.6143959532022715`*^9, 
   3.6144295346756663`*^9, 3.6144822707455754`*^9, 3.6144905531216135`*^9, 
   3.6145052491996255`*^9, 3.614572824784925*^9, 3.614685752992857*^9, 
   3.6146861472704086`*^9, 3.614687712396929*^9, 3.6146894046627207`*^9, 
   3.6147492090031395`*^9, 3.6147510981820583`*^9, 3.6147512295186887`*^9, 
   3.614751466529905*^9, 3.614776499771869*^9, 3.6148608170005083`*^9, 
   3.61486332308251*^9, 3.614917498515246*^9, 3.614946645516555*^9, 
   3.6150197145261145`*^9, 3.6150977904013195`*^9, 3.615179962069954*^9, 
   3.6152059469460993`*^9, 3.615261731731844*^9, 3.6153520622981195`*^9, 
   3.6154344582490807`*^9, 3.6155280160081477`*^9, 3.615611422721911*^9, 
   3.615641838729335*^9, 3.6158945128024826`*^9, 3.615953136227254*^9, 
   3.615958369100445*^9, 3.616046004630951*^9, 3.6160647462051773`*^9, 
   3.6161193195279107`*^9, 3.6161575876197634`*^9, 3.6162182451120715`*^9, 
   3.616297852276846*^9, 3.616383946540276*^9, 3.6163939252874384`*^9, 
   3.6164204753860464`*^9, 3.616470978894044*^9, 3.616487090250521*^9, 
   3.616494754871768*^9, 3.616501932953508*^9, 3.6165512168692484`*^9, 
   3.6166466149531617`*^9, 3.6166687444944315`*^9, 3.6167296324016876`*^9, 
   3.616814477293235*^9, 3.616899534635127*^9, 3.61698993488311*^9, 
   3.6169925405736866`*^9, 3.6170750487304735`*^9, 3.617168334190905*^9, 
   3.6171716054074507`*^9, 3.617198339089382*^9, 3.6172827456767225`*^9, 
   3.617337038165763*^9, 3.6174260932188234`*^9, 3.617453877298912*^9, 
   3.6175113050557575`*^9, 3.617527296794055*^9, 3.6175276398854575`*^9, 
   3.6175445656490173`*^9, 3.6175994286976423`*^9, 3.6176038704702435`*^9, 
   3.6176155051524673`*^9, 3.6176246351513553`*^9, 3.6176829152285304`*^9, 
   3.6176928092003098`*^9, 3.617701211150628*^9, 3.617769596013363*^9, 
   3.617776251237052*^9, 3.6178035015403533`*^9, 3.6178043537698503`*^9, 
   3.617859532508568*^9, 3.617888995705169*^9, 3.617940222167759*^9, 
   3.6179726281723037`*^9, 3.617975045313447*^9, 3.618024453510254*^9, 
   3.618032284973609*^9, 3.618032472688739*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["\n\nA technical hint",
  FontColor->RGBColor[0, 0, 1]],
 ". Inserting constants into the arguments of the function leads to error \
messages for the differential:"
}], "Text",
 CellChangeTimes->{{3.5889463078006487`*^9, 3.58894638839039*^9}, {
  3.617603448910703*^9, 3.6176034990491915`*^9}, {3.617603680867511*^9, 
  3.6176036904459276`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "f", "]"}], "[", 
  RowBox[{"u", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.588946180769625*^9, 3.588946192812846*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "ivar"}], "MessageName"], ":", 
  " ", "\<\"\[NoBreak]\\!\\(0\\)\[NoBreak] is not a valid variable. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/ivar\\\", \
ButtonNote -> \\\"General::ivar\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5960224725908065`*^9, 3.5994897479152355`*^9, 
  3.6089689680851707`*^9, 3.6141638333938656`*^9, 3.6147770260329695`*^9, 
  3.617603565536508*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[PartialD]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"u", ",", "0"}], "}"}], "}"}]], 
  RowBox[{"f", "[", 
   RowBox[{"u", ",", "0"}], "]"}]}]], "Output",
 CellChangeTimes->{3.5960224725938067`*^9, 3.5994897479152355`*^9, 
  3.6089689680871706`*^9, 3.6141638333938656`*^9, 3.6147770260369697`*^9, 
  3.617603565536508*^9}]
}, Closed]],

Cell["Instead use", "Text",
 CellChangeTimes->{{3.5889464054724197`*^9, 3.5889464087640257`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "f", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "/.", " ", 
  RowBox[{"v", "\[Rule]", " ", "0"}]}]], "Input",
 CellChangeTimes->{{3.588946414879236*^9, 3.588946440354081*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "0"}], "]"}], ",", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "0"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.588946444222888*^9, 3.5907341371568995`*^9, 
  3.596022501240445*^9, 3.59948975616765*^9, 3.6089689807008924`*^9, 
  3.6141638490718927`*^9, 3.6147770351314898`*^9, 3.6176035859413443`*^9}]
}, Closed]],

Cell[TextData[{
 "The ",
 StyleBox["tangent plane",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface f at the point f[u0,v0] has the parameter representation \
(with u0, v0  fixed, x ,y the parameters)"
}], "Text",
 CellChangeTimes->{{3.5859851459307175`*^9, 3.585985220786999*^9}, {
  3.588946109087499*^9, 3.588946114765909*^9}, {3.5889990371028385`*^9, 
  3.5889990799832916`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tplane", "[", "f_", "]"}], "[", 
    RowBox[{"u0_", ",", "v0_"}], "]"}], "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", "+", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"tang", "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Rule]", "u0"}], ",", 
     RowBox[{"v", "\[Rule]", "v0"}]}], "}"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.585985258936181*^9, 3.585985353414585*^9}, {
   3.5859991971198626`*^9, 3.585999204311475*^9}, {3.5859996025801744`*^9, 
   3.585999633468229*^9}, {3.588945457053154*^9, 3.5889454978784256`*^9}, 
   3.588945546441311*^9, {3.5889991214026604`*^9, 3.5889991285400686`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tplane", "::", " ", "usage"}], " ", "=", " ", 
   "\"\<tplane[f][uo,vo][x,y] is a parameter representation of the tangent \
plane of the surface f[u,v]at the point {uo, vo} with parameters x,y.\>\""}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6147771023553348`*^9, 3.614777261106415*^9}, 
   3.6174557564293923`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tplane", "[", 
    RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
   RowBox[{
    RowBox[{"Pi", "/", "2"}], ",", "1"}], "]"}], "[", 
  RowBox[{"x", ",", "y"}], "]"}]], "Input",
 CellChangeTimes->{{3.5889390507927017`*^9, 3.5889390514323034`*^9}, 
   3.5889455743653603`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "x"}], " ", 
    RowBox[{"Cos", "[", "1", "]"}]}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", "1", "]"}], "-", 
    RowBox[{"y", " ", 
     RowBox[{"Sin", "[", "1", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"y", " ", 
     RowBox[{"Cos", "[", "1", "]"}]}], "+", 
    RowBox[{"Sin", "[", "1", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.614163868946328*^9, 3.6147773126703644`*^9, 
  3.617615802442189*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"tpl1", " ", "=", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"tplane", "[", 
         RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
        RowBox[{"0", ",", "1."}], "]"}], "[", 
       RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"Mesh", "\[Rule]", " ", "None"}], ",", " ", 
     RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Opacity", "[", "0.5", "]"}]}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5859987751547213`*^9, 3.5859990333351746`*^9}, 
   3.5859992311435223`*^9, {3.5859993118268642`*^9, 3.585999327910492*^9}, 
   3.5859996610334773`*^9, 3.5859997184727783`*^9, {3.5859997699684687`*^9, 
   3.585999786676098*^9}, {3.585999823258162*^9, 3.5859998785290594`*^9}, {
   3.5860001388935165`*^9, 3.5860001718407745`*^9}, {3.586000360788306*^9, 
   3.586000380413141*^9}, 3.5860004924525375`*^9, {3.6147774414607306`*^9, 
   3.614777461979904*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tpn", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Black", ",", 
      RowBox[{"PointSize", "[", ".01", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{
        RowBox[{"sphero", "[", "1", "]"}], "[", 
        RowBox[{"0", ",", "1."}], "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.585981598798833*^9, 3.585981608132367*^9}, {
   3.5859816511338263`*^9, 3.5859816640615664`*^9}, {3.585981694846327*^9, 
   3.585981764203294*^9}, {3.5859818411426945`*^9, 3.58598188005392*^9}, {
   3.5859999785564346`*^9, 3.5860000137656965`*^9}, 3.5860001190502815`*^9, 
   3.586000241026896*^9}],

Cell[BoxData[
 RowBox[{"tpsph", " ", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"tpl1", ",", " ", "tpn", ",", "sph"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", " ", "All"}], ",", 
    RowBox[{"Boxed", "\[Rule]", "False"}], ",", " ", 
    RowBox[{"Axes", "\[Rule]", " ", "False"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.585999915313924*^9, 3.585999934267957*^9}, {
  3.586000024560916*^9, 3.5860001012818503`*^9}, {3.5860004230324154`*^9, 
  3.586000447462058*^9}, {3.58600067040205*^9, 3.5860006744112573`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tplane", "[", "sf", "]"}], "[", 
   RowBox[{"u0", ",", "v0"}], "]"}], "[", 
  RowBox[{"x", ",", "y"}], "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.585985258936181*^9, 3.585985353414585*^9}, {
   3.5859991971198626`*^9, 3.585999204311475*^9}, {3.5859996025801744`*^9, 
   3.585999633468229*^9}, {3.588945457053154*^9, 3.5889454978784256`*^9}, 
   3.588945546441311*^9, {3.5889991214026604`*^9, 3.5889991285400686`*^9}, {
   3.5889992556603394`*^9, 3.588999298920814*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "1", "]"}], "[", 
     RowBox[{"u0", ",", "v0"}], "]"}], "+", 
    RowBox[{"y", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u0", ",", "v0"}], "]"}]}], "+", 
    RowBox[{"x", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u0", ",", "v0"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "2", "]"}], "[", 
     RowBox[{"u0", ",", "v0"}], "]"}], "+", 
    RowBox[{"y", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u0", ",", "v0"}], "]"}]}], "+", 
    RowBox[{"x", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u0", ",", "v0"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "3", "]"}], "[", 
     RowBox[{"u0", ",", "v0"}], "]"}], "+", 
    RowBox[{"y", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u0", ",", "v0"}], "]"}]}], "+", 
    RowBox[{"x", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u0", ",", "v0"}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.588999300373897*^9, 3.589005940207674*^9, 3.58900599608587*^9, 
   3.589087089138511*^9, 3.5891696699474754`*^9, 3.5896085365417576`*^9, 
   3.5897728448794003`*^9, 3.5898647221445646`*^9, 3.5898904965395775`*^9, 
   3.5899518820499344`*^9, 3.5899536563814507`*^9, 3.589956013737543*^9, 
   3.5899782822056565`*^9, 3.5900390083944206`*^9, 3.590212009103302*^9, 
   3.590495818389599*^9, 3.59064041451816*^9, 3.5906714821753883`*^9, 
   3.590715685105477*^9, 3.59072016989565*^9, 3.5907340362559223`*^9, 
   3.5908181803724027`*^9, 3.5909046952533484`*^9, 3.5909102114930573`*^9, 
   3.590987954958619*^9, 3.591163238030513*^9, 3.5911806593421106`*^9, 
   3.5912467885260553`*^9, 3.5913394488309803`*^9, 3.5914142260460014`*^9, 
   3.591441548024378*^9, 3.591507409645241*^9, 3.5915923941114902`*^9, 
   3.5916857034257145`*^9, 3.591767833656539*^9, 3.5919453642370815`*^9, 
   3.591966125759371*^9, 3.592022566238221*^9, 3.592022706482467*^9, 
   3.5920467429039516`*^9, 3.5921112241160026`*^9, 3.5921338229512396`*^9, 
   3.5921479172955856`*^9, 3.5922001246192536`*^9, 3.592293252282012*^9, 
   3.592305978489545*^9, 3.5923732669429755`*^9, 3.5924544138302455`*^9, 
   3.5925450415738225`*^9, 3.592632208182155*^9, 3.5926559496370344`*^9, 
   3.5927081442945995`*^9, 3.5927410480482445`*^9, 3.592799284116975*^9, 
   3.5929819514853973`*^9, 3.593008846830682*^9, 3.593064293903618*^9, 
   3.593146770102072*^9, 3.593177841310887*^9, 3.5933218944242744`*^9, 
   3.593348815231349*^9, 3.593405049893861*^9, 3.593413996977576*^9, 
   3.593434078657221*^9, 3.5935839615941687`*^9, 3.593611819130911*^9, 
   3.5936680821011143`*^9, 3.5938384259506826`*^9, 3.5938409509728827`*^9, 
   3.5941845730140643`*^9, 3.5941922047346687`*^9, 3.5942697013596816`*^9, 
   3.594274644308592*^9, 3.5943635747017736`*^9, 3.594364709010966*^9, 
   3.5946216254412885`*^9, 3.59470542314128*^9, 3.594877279717065*^9, 
   3.594881067856119*^9, 3.594964009932291*^9, 3.5950483419012976`*^9, 
   3.5951338050440598`*^9, 3.595143641604148*^9, 3.595229678580471*^9, 
   3.595311842777032*^9, 3.5954848001712027`*^9, 3.5954860403421803`*^9, 
   3.595488678884015*^9, 3.5955691655286818`*^9, 3.5955702335527697`*^9, 
   3.5955749396809444`*^9, 3.595650862702945*^9, 3.5956595570550203`*^9, 
   3.5958282749828696`*^9, 3.595911998205753*^9, 3.5960015568164883`*^9, 
   3.5960891821749563`*^9, 3.5962618842591605`*^9, 3.596355663079342*^9, 
   3.59637146552277*^9, 3.5964368613773575`*^9, 3.5965212854938774`*^9, 
   3.597207512774855*^9, 3.5972982545659285`*^9, 3.5973818403577805`*^9, 
   3.5974680833201103`*^9, 3.597729292017438*^9, {3.597737673792431*^9, 
   3.5977376934545555`*^9}, 3.5977612657692623`*^9, 3.5978140658958063`*^9, 
   3.597847427564082*^9, 3.597901947429153*^9, 3.598009259454815*^9, 
   3.5980743763499184`*^9, 3.5983626703896847`*^9, 3.598425559039859*^9, 
   3.598594729231494*^9, 3.598625180525742*^9, 3.5986755721106634`*^9, 
   3.5988608239221787`*^9, 3.5988821120774703`*^9, 3.598940443715904*^9, 
   3.5990227496853743`*^9, 3.5991971462777777`*^9, 3.599197248973652*^9, 
   3.5992870773811226`*^9, 3.599466643123638*^9, 3.599487277432496*^9, 
   3.599488182436886*^9, 3.5994885254502883`*^9, 3.599488823442012*^9, 
   3.599489086052873*^9, 3.599550817015543*^9, 3.5995512984479885`*^9, 
   3.599803399838374*^9, 3.608960588477648*^9, 3.608961303068103*^9, 
   3.6089657546763215`*^9, 3.608966189683086*^9, 3.6089673435582533`*^9, 
   3.6089688406258802`*^9, 3.6089692241068144`*^9, 3.6089694743531275`*^9, 
   3.6089722056015635`*^9, 3.6091370376579127`*^9, 3.609215114988184*^9, 
   3.6093079267790146`*^9, 3.6095588250330167`*^9, 3.6095609615375714`*^9, 
   3.6096490669351315`*^9, 3.6096503212558746`*^9, 3.609672493699587*^9, 
   3.609731060877207*^9, 3.6097436480353203`*^9, 3.6097530769932566`*^9, 
   3.609814810650071*^9, 3.6098499634136868`*^9, 3.6099103875490503`*^9, 
   3.6112083905524373`*^9, 3.6114661029321656`*^9, 3.6115532989188166`*^9, 
   3.611558167685294*^9, 3.6115582065345163`*^9, 3.611569706626556*^9, 
   3.6115701072394695`*^9, 3.6115735467665677`*^9, 3.61163412180013*^9, 
   3.6116351931204123`*^9, 3.6119250165252743`*^9, 3.6119969343393803`*^9, 
   3.6120721293718815`*^9, 3.612090081942091*^9, 3.612152606396184*^9, 
   3.6122657060829654`*^9, 3.6123237626453624`*^9, 3.6126788783482733`*^9, 
   3.612754364420231*^9, 3.612845982033436*^9, 3.613021068683983*^9, 
   3.613105017116297*^9, 3.6132198046423674`*^9, 3.613277867146391*^9, 
   3.6134435067586184`*^9, 3.61347289267904*^9, 3.613541236420845*^9, 
   3.613560035487506*^9, 3.6136190009757524`*^9, 3.613970274498474*^9, 
   3.613976391680024*^9, 3.613994267599065*^9, 3.6139943158655496`*^9, 
   3.6140533759137187`*^9, 3.6141460247464848`*^9, 3.6141639495828695`*^9, 
   3.6141639855097327`*^9, 3.614228814939714*^9, 3.6142562416542735`*^9, 
   3.6143098827636585`*^9, 3.6143282356316643`*^9, 3.614395955370675*^9, 
   3.614429534856677*^9, 3.6144822708391757`*^9, 3.6144905531336145`*^9, 
   3.6145052492464256`*^9, 3.6145728248005247`*^9, 3.6146857530138583`*^9, 
   3.6146861472844095`*^9, 3.6146877124129295`*^9, 3.614689404683722*^9, 
   3.6147492090187397`*^9, 3.614751098213258*^9, 3.614751229534289*^9, 
   3.6147514665455046`*^9, 3.614777370885694*^9, 3.6148608171409087`*^9, 
   3.61486332312931*^9, 3.614917498546446*^9, 3.614946645547755*^9, 
   3.6150197145573144`*^9, 3.61509779043252*^9, 3.6151799621011543`*^9, 
   3.6152059469772997`*^9, 3.6152617317788467`*^9, 3.615352062334121*^9, 
   3.615434458264681*^9, 3.615528016030149*^9, 3.615611422753111*^9, 
   3.615641838776135*^9, 3.6158945129272833`*^9, 3.6159531362428536`*^9, 
   3.615958369116045*^9, 3.6160460047401514`*^9, 3.6160647462363772`*^9, 
   3.616119319590311*^9, 3.616157589928567*^9, 3.6162182451432714`*^9, 
   3.6162978523080454`*^9, 3.616383946571476*^9, 3.616393925427839*^9, 
   3.6164204754230485`*^9, 3.616470978932046*^9, 3.6164870902895236`*^9, 
   3.616494754918568*^9, 3.616501933000308*^9, 3.616551216994048*^9, 
   3.6166466149843616`*^9, 3.6166687445256314`*^9, 3.616729632573288*^9, 
   3.6168144773400345`*^9, 3.6168995346819267`*^9, 3.61698993491431*^9, 
   3.616992540604886*^9, 3.617075048761673*^9, 3.617168334222105*^9, 
   3.617171605438651*^9, 3.6171983391205826`*^9, 3.6172827457079225`*^9, 
   3.617337038203766*^9, 3.6174260932500234`*^9, 3.617453877326914*^9, 
   3.617511305086957*^9, 3.617527296825255*^9, 3.6175276399010572`*^9, 
   3.6175445656646175`*^9, 3.617599428728842*^9, 3.617615505183667*^9, 
   3.6176246351833572`*^9, 3.6176829152597303`*^9, 3.617692809222311*^9, 
   3.617701211168629*^9, 3.617769596028963*^9, 3.617776251252652*^9, 
   3.617803501571553*^9, 3.6178043537854505`*^9, 3.617859532539768*^9, 
   3.617888995720769*^9, 3.617940222183359*^9, 3.617972628193305*^9, 
   3.617975045341449*^9, 3.6180244535258536`*^9, 3.618032285004809*^9, 
   3.6180324972743816`*^9, 3.6181145374657097`*^9, 3.618135125584507*^9, 
   3.6181357241887584`*^9, 3.6181399228737335`*^9, 3.6182087345451164`*^9, 
   3.618216889901475*^9, 3.618235612768425*^9, 3.618293838102027*^9, 
   3.6183731534232187`*^9, 3.6184658236301975`*^9, 3.618468345251938*^9, 
   3.618469618713375*^9, 3.6184698153205204`*^9, 3.618491162849933*^9, 
   3.618546047498869*^9, 3.6185803071347575`*^9, 3.6186338379722595`*^9, 
   3.618634210095313*^9, 3.6186407687858295`*^9, 3.6187188127340717`*^9, 
   3.6188031366388807`*^9, 3.618833360285205*^9, 3.618911216464069*^9, 
   3.618911284339788*^9, 3.6189813223928537`*^9, 3.618994089027489*^9, 
   3.6201900072846165`*^9, 3.620195842262162*^9, 3.6201958884881716`*^9, 
   3.620198744774109*^9, 3.620198790967141*^9, 3.6201991870757236`*^9, 
   3.6205365906992984`*^9}]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["normal vector",
  FontColor->RGBColor[0, 0, 1]],
 " of the (oriented) surface sf at the point sf[u,v] is defined as the normal \
unit vector of  the oriented tangent plane; moreover, we define now"
}], "Text",
 CellChangeTimes->{{3.586000726421748*^9, 3.5860008523139696`*^9}, {
   3.58600106321074*^9, 3.5860010810883713`*^9}, {3.5889225134315987`*^9, 
   3.588922539031244*^9}, {3.588922572540103*^9, 3.5889225905893345`*^9}, 
   3.5889466155267887`*^9, {3.588999331519678*^9, 3.5889993553910437`*^9}, 
   3.617615934153221*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2. An Orthonormal Moving 3-Frame of the surface", "Subsection",
 CellChangeTimes->{{3.5721739619617743`*^9, 3.5721739801278133`*^9}, {
   3.5860011060172153`*^9, 3.5860011130840273`*^9}, {3.587272413023604*^9, 
   3.5872724205980372`*^9}, {3.588487546773712*^9, 3.588487560267736*^9}, {
   3.5994914425513973`*^9, 3.5994914450615406`*^9}, 3.599552816652402*^9, {
   3.614777404959643*^9, 3.614777407655797*^9}, 3.614951503403132*^9, {
   3.6176159535908546`*^9, 3.617615958161663*^9}, 3.617616389845621*^9}],

Cell[CellGroupData[{

Cell["1.2.1. The Definition", "Subsubsection",
 CellChangeTimes->{{3.5860011346276655`*^9, 3.586001146530486*^9}, {
   3.5860678825807543`*^9, 3.586067896183978*^9}, {3.5872724267433887`*^9, 
   3.587272433749789*^9}, 3.6176163958204317`*^9, 3.6176185661766634`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";"}]], "Input",
 CellChangeTimes->{{3.61761719716236*^9, 3.6176172042407646`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sf", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.617617219455635*^9, 3.617617242201936*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "1", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "2", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "3", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.617617228667162*^9, 3.617617257575815*^9}}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "1", "]"}], "[", "f_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"dotnorme", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"tv", "[", "1", "]"}], "[", "f", "]"}], "[", 
      RowBox[{"s", ",", "t"}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s", "\[Rule]", "u"}], ",", " ", 
       RowBox[{"t", "\[Rule]", "v"}]}], "}"}]}], "]"}], "/;", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Head", "[", 
       RowBox[{"f", "[", 
        RowBox[{"u", ",", "v"}], "]"}], "]"}], " ", "\[Equal]", " ", "List"}],
      "&&", 
     RowBox[{
      RowBox[{"Length", "[", 
       RowBox[{"f", "[", 
        RowBox[{"u", ",", "v"}], "]"}], "]"}], "\[Equal]", " ", "3"}]}], 
    ")"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.553950276121236*^9, {3.5860012023005843`*^9, 3.586001242361455*^9}, {
   3.5860012820791245`*^9, 3.586001290471939*^9}, {3.614861848911121*^9, 
   3.6148618489267206`*^9}, {3.6148619944905767`*^9, 3.614862019809421*^9}, 
   3.6149178247118187`*^9, 3.614917951836442*^9, 3.617600023979088*^9, {
   3.6176169240037365`*^9, 3.6176169255228233`*^9}, {3.6176170208992786`*^9, 
   3.6176170992707605`*^9}, 3.617617644972973*^9, {3.617617700828168*^9, 
   3.617617748052869*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5718247469642887`*^9, 3.5718247900827646`*^9}, {
   3.5721744197469583`*^9, 3.572174420562005*^9}, 3.6148618489267206`*^9, 
   3.614917824727419*^9, 3.6149179629904613`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"f", "[", "1", "]"}], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}], 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"]}]]], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"f", "[", "2", "]"}], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}], 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"]}]]], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"f", "[", "3", "]"}], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}], 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"]}]]]}], "}"}]], "Output",
 CellChangeTimes->{{3.599551974787176*^9, 3.599551986580797*^9}, 
   3.6115687454475794`*^9, 3.611635257205325*^9, 3.614163993122546*^9, 
   3.614860873581808*^9, 3.614863417837076*^9, 3.614946691677036*^9, 
   3.617616404010446*^9, 3.6176172575928164`*^9, 3.617617783110874*^9}]
}, Closed]],

Cell[TextData[{
 "The ",
 StyleBox["normal vector",
  FontColor->RGBColor[0, 0, 1]],
 " of the oriented surface f at the point f[u,v] is"
}], "Text",
 CellChangeTimes->{{3.5718418633550053`*^9, 3.5718418720286207`*^9}, {
  3.586001385070505*^9, 3.586001418438964*^9}, {3.586001462259441*^9, 
  3.586001488514287*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "3", "]"}], "[", "f_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"dotnorme", "[", 
    RowBox[{"Cross", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"tv", "[", "1", "]"}], "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"tv", "[", "2", "]"}], "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "]"}], "/;", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Head", "[", 
       RowBox[{"f", "[", 
        RowBox[{"u", ",", "v"}], "]"}], "]"}], " ", "\[Equal]", " ", "List"}],
      "&&", 
     RowBox[{
      RowBox[{"Length", "[", 
       RowBox[{"f", "[", 
        RowBox[{"u", ",", "v"}], "]"}], "]"}], "\[Equal]", " ", "3"}]}], 
    ")"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.571841915895898*^9, 3.5718420523961377`*^9}, {
   3.5860013177251873`*^9, 3.586001351670847*^9}, {3.614861848957921*^9, 
   3.614861848957921*^9}, 3.614862118307994*^9, 3.614917824727419*^9, 
   3.6149179656580667`*^9, 3.6176000239946876`*^9, 3.617600085723996*^9, 
   3.617617128124411*^9, 3.6176248811064234`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "2", "]"}], "[", "f_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"Cross", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "1", "]"}], "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "/;", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Head", "[", 
       RowBox[{"f", "[", 
        RowBox[{"u", ",", "v"}], "]"}], "]"}], " ", "\[Equal]", " ", "List"}],
      "&&", 
     RowBox[{
      RowBox[{"Length", "[", 
       RowBox[{"f", "[", 
        RowBox[{"u", ",", "v"}], "]"}], "]"}], "\[Equal]", " ", "3"}]}], 
    ")"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.5718421091490374`*^9, 3.5718421511287107`*^9, {3.5718422225768366`*^9, 
   3.571842229035248*^9}, {3.5718433048599377`*^9, 3.5718433055619383`*^9}, {
   3.586001531227162*^9, 3.586001556202806*^9}, {3.614861848973521*^9, 
   3.614861848973521*^9}, {3.614917824743019*^9, 3.614917824758619*^9}, {
   3.614917976219285*^9, 3.614918000305727*^9}, 3.617617135587838*^9, 
   3.6176248570180454`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"amf", "::", "usage"}], " ", "=", " ", 
   "\"\<amf[i][f][u,v]is the i-th vector, i = 1,2,3, of the orthonormal \
moving frame adapted to the parameter representation of the surface f[u,v] in \
the Euclidean 3-space.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6148635430116963`*^9, 3.6148637222872114`*^9}, {
   3.6148638592242517`*^9, 3.6148639120303445`*^9}, {3.6148639626212335`*^9, 
   3.6148639914500837`*^9}, 3.614917824758619*^9, {3.614918015094553*^9, 
   3.6149180265449734`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5718247469642887`*^9, 3.5718247900827646`*^9}, 
   3.571824823950424*^9, {3.571824855134879*^9, 3.5718248677553015`*^9}, 
   3.5718426714520245`*^9, {3.5721742134671593`*^9, 3.5721742146832294`*^9}, 
   3.614861848989121*^9, 3.614917824758619*^9, 3.6149180316617823`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], ")"}]}], ")"}]
     }], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], ")"}]}], ")"}]
     }], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], ")"}]}], ")"}]
     }]}], "}"}]], "Output",
 CellChangeTimes->{3.599551974927577*^9, 3.6096534642246428`*^9, 
  3.6141640149625845`*^9, 3.614860940864726*^9, 3.6148640088597145`*^9, 
  3.614946725981496*^9, 3.617616404072846*^9, 3.6176171514877477`*^9, 
  3.617617257817829*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5718247469642887`*^9, 3.5718247900827646`*^9}, 
   3.571824823950424*^9, {3.571824855134879*^9, 3.5718248677553015`*^9}, 
   3.5718426714520245`*^9, {3.5721742134671593`*^9, 3.5721742146832294`*^9}, 
   3.572174471475917*^9, 3.614861848989121*^9, 3.614917824774219*^9, 
   3.6149180333933854`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], ")"}]}]}], 
     ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], ")"}]}]}], 
     ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], ")"}]}]}], 
     ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.599551975598378*^9, 3.5995519997472205`*^9}, 
   3.614164030141411*^9, 3.614860952642747*^9, 3.614864015895327*^9, 
   3.6149467337035093`*^9, 3.6176164041664467`*^9, 3.6176171574570885`*^9, 
   3.617617260542985*^9}]
}, Closed]],

Cell["The orthogonality conditions are fulfilled:", "Text",
 CellChangeTimes->{{3.572174706905383*^9, 3.572174739048221*^9}, 
   3.572175509736302*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "i", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ".", 
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "j", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5718249735702868`*^9, 3.571825082302478*^9}, {
   3.571825121474147*^9, 3.571825217539116*^9}, {3.5718423315118275`*^9, 
   3.571842382430317*^9}, {3.572174517435546*^9, 3.5721745795881004`*^9}, {
   3.6148618490047207`*^9, 3.6148618490047207`*^9}, 3.6148635013128233`*^9, {
   3.614917824774219*^9, 3.614917824774219*^9}, {3.614918034984588*^9, 
   3.614918038853395*^9}, {3.6149467734835796`*^9, 3.6149467756675835`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5995519779539824`*^9, 3.5995520117436414`*^9, 
  3.6096535696136703`*^9, 3.6141640517162485`*^9, 3.614860973874384*^9, 
  3.614864039919369*^9, 3.6149468649933405`*^9, 3.6176164048216476`*^9, 
  3.617617171374885*^9, 3.6176172740677586`*^9}]
}, Closed]],

Cell["and the frame is positively oriented", "Text",
 CellChangeTimes->{{3.5885663623766937`*^9, 3.5885663832495303`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Det", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "i", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3"}], "}"}]}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5885663928903475`*^9, 3.588566463870472*^9}, {
   3.6148618490047207`*^9, 3.6148618490047207`*^9}, 3.6148635013128233`*^9, 
   3.614917824774219*^9, 3.614918046637809*^9}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.5885664657424755`*^9, 3.5995519788587837`*^9, 
  3.6096535791802177`*^9, 3.614164065974674*^9, 3.6148609838584013`*^9, 
  3.614864052960992*^9, 3.6149468748213577`*^9, 3.617616405024448*^9, 
  3.6176172772289395`*^9}]
}, Closed]],

Cell[TextData[{
 "The frame {",
 "amf[",
 "i][f][u,v]} defined above is named the",
 StyleBox[" orthonormal moving frame adapted to the parameter representation",
  FontColor->RGBColor[0, 0, 1]],
 " f[u,v]."
}], "Text",
 CellChangeTimes->{{3.586002264085249*^9, 3.5860023096529293`*^9}, {
   3.586002387465866*^9, 3.5860024607859945`*^9}, 3.614861849035921*^9, 
   3.614917824789819*^9, 3.6149180502102146`*^9}],

Cell[TextData[{
 "The",
 StyleBox[" tangent plane",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface at the point f[u,v] is also obtained by "
}], "Text",
 CellChangeTimes->{{3.572174857303985*^9, 3.572174923024744*^9}, 
   3.572255761617314*^9, 3.586002208315151*^9, 3.58600250944248*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tang2", "[", "f_", "]"}], "[", 
    RowBox[{"u0_", ",", "v0_"}], "]"}], "[", 
   RowBox[{"s1_", ",", "s2_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", "+", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"amf", "[", "1", "]"}], "[", "f", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "*", "s1"}], " ", "+", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"amf", "[", "2", "]"}], "[", "f", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "*", "s2"}]}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"u", "\[Rule]", " ", "u0"}], ",", " ", 
       RowBox[{"v", "\[Rule]", " ", "v0"}]}], "}"}]}], ")"}], "/;", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Head", "[", 
       RowBox[{"f", "[", 
        RowBox[{"u", ".", "v"}], "]"}], "]"}], " ", "\[Equal]", " ", "List"}],
      "&&", 
     RowBox[{
      RowBox[{"Length", "[", 
       RowBox[{"f", "[", 
        RowBox[{"u", ",", "v"}], "]"}], "]"}], "\[Equal]", " ", "3"}]}], 
    ")"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5721749454350257`*^9, 3.5721751309256353`*^9}, {
  3.5860025164312925`*^9, 3.58600253769413*^9}, {3.5889995834210863`*^9, 
  3.5889995911395283`*^9}, {3.5889996328979163`*^9, 3.588999681604702*^9}, {
  3.599552093004184*^9, 3.599552117262227*^9}, {3.6148618490515213`*^9, 
  3.6148618490671215`*^9}, {3.614917824805419*^9, 3.614917824805419*^9}, {
  3.614918053626621*^9, 3.614918054999423*^9}, {3.6176173159571543`*^9, 
  3.6176173279088383`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tang2", "::", "usage"}], " ", "=", " ", 
   "\"\<tang2[f][uo,vo][x,y] is the parameter representation of the tangent \
plane of the surface f[u,v] in the Euclidean 3-space adapted to the moving \
frame of the surface. x,y are orthonormal Cartesian parameters of the tangent \
plane at the point {uo,vo} of the surface.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6148641539087696`*^9, 3.614864405428011*^9}, {
   3.6148644494668884`*^9, 3.6148644830069475`*^9}, 3.614864538574245*^9, 
   3.617617381974931*^9}],

Cell[TextData[{
 StyleBox["Example",
  FontColor->RGBColor[0, 0, 1]],
 ". ",
 StyleBox["Circular Cone",
  FontColor->GrayLevel[0]]
}], "Text",
 CellChangeTimes->{{3.5995526058523445`*^9, 3.5995526242033944`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "circularcone"}]], "Input",
 CellChangeTimes->{{3.5995522936517363`*^9, 3.5995522964441414`*^9}, {
  3.6148647754450607`*^9, 3.6148648052411137`*^9}}],

Cell[BoxData[
 StyleBox["\<\"{u,v}->circularcone[a,b][u,v] is a parametrization of a \
circular cone of radius a and slope b/a.  To plot try \
circularcone[1,0.5][-Pi,Pi,-1,1].\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6176172773529463`*^9},
 CellTags->"Info3617624477-4857690"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"circularcone", "[", 
   RowBox[{"a", ",", "b"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6148649822702246`*^9, 3.6148649910374393`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", " ", "v", " ", 
    RowBox[{"Cos", "[", "u", "]"}]}], ",", 
   RowBox[{"a", " ", "v", " ", 
    RowBox[{"Sin", "[", "u", "]"}]}], ",", 
   RowBox[{"b", " ", "v"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6148649936114445`*^9, 3.614946910779421*^9, 
  3.617616405180448*^9, 3.6176172773699474`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"tang2", "[", 
     RowBox[{"circularcone", "[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "1"}], "]"}], "[", 
   RowBox[{"s1", ",", "s2"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.588999525808791*^9, 3.5889995544654303`*^9}, {
  3.5889998476021967`*^9, 3.5889998692254333`*^9}, {3.588999967738068*^9, 
  3.5889999693361597`*^9}, {3.5995521295394487`*^9, 3.5995521337046556`*^9}, {
  3.614864925345724*^9, 3.614864937404546*^9}, {3.614865041753129*^9, 
  3.6148650786939936`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", "u", "]"}], "+", 
    FractionBox[
     RowBox[{"s2", " ", 
      RowBox[{"Cos", "[", "u", "]"}]}], 
     SqrtBox["2"]], "-", 
    RowBox[{"s1", " ", 
     RowBox[{"Sin", "[", "u", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"s1", " ", 
     RowBox[{"Cos", "[", "u", "]"}]}], "+", 
    RowBox[{"Sin", "[", "u", "]"}], "+", 
    FractionBox[
     RowBox[{"s2", " ", 
      RowBox[{"Sin", "[", "u", "]"}]}], 
     SqrtBox["2"]]}], ",", 
   RowBox[{"1", "+", 
    FractionBox["s2", 
     SqrtBox["2"]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.58899955551149*^9, {3.58899984328395*^9, 3.5889998710535383`*^9}, 
   3.58899997039322*^9, 3.5995519789055834`*^9, 3.599552149242283*^9, 
   3.614164094382324*^9, 3.6148650054674654`*^9, {3.614865052064747*^9, 
   3.614865080706397*^9}, 3.6149469219646406`*^9, 3.617616405960449*^9, 
   3.617617277833974*^9}]
}, Closed]],

Cell["\<\
or as the set of the solutions {x,y,z} of the linear equation\
\>", "Text",
 CellChangeTimes->{{3.5721752650483065`*^9, 3.5721752988642406`*^9}, {
   3.5721754466666946`*^9, 3.57217544781676*^9}, {3.5860026178782706`*^9, 
   3.5860026297342916`*^9}, {3.5860027381388817`*^9, 
   3.5860027435364914`*^9}, {3.589000353591138*^9, 3.5890003553912406`*^9}, 
   3.589000402351927*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ".", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", "y", ",", "z"}], "}"}], "-", 
        RowBox[{"sf", "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], ")"}]}], " ", "\[Equal]", " ", 
     "0"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.5721753037755213`*^9, 3.5721754164589667`*^9}, {
   3.586001703139464*^9, 3.586001727569107*^9}, {3.586002570703788*^9, 
   3.5860025763353977`*^9}, {3.5860026404515104`*^9, 3.5860026441331167`*^9}, 
   3.5860026891235957`*^9, {3.589000060667383*^9, 3.5890000674507713`*^9}, {
   3.589000200076357*^9, 3.58900020817082*^9}, {3.5890004665876007`*^9, 
   3.5890004846996365`*^9}, {3.614861849098321*^9, 3.614861849098321*^9}, 
   3.614864650832042*^9, 3.614917824805419*^9, 3.6149180817846704`*^9, {
   3.6149471868219056`*^9, 3.614947213201552*^9}, {3.617617424587368*^9, 
   3.617617437755121*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Solve", "::", "svars"}], "MessageName"], ":", 
  " ", "\<\"Equations may not give solutions for all \\\"solve\\\" variables. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Solve/svars\\\", \
ButtonNote -> \\\"Solve::svars\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.61761640600725*^9, 3.6176172779049783`*^9, {3.6176174258734417`*^9, 
   3.617617439857241*^9}}]
}, Closed]],

Cell["In the case of f = circularcone[1,1][0,1]:", "Text",
 CellChangeTimes->{{3.5721752650483065`*^9, 3.5721752988642406`*^9}, {
   3.5721754466666946`*^9, 3.57217544781676*^9}, {3.5860026178782706`*^9, 
   3.5860026297342916`*^9}, {3.5860027381388817`*^9, 
   3.5860027435364914`*^9}, {3.589000353591138*^9, 3.5890003553912406`*^9}, 
   3.589000402351927*^9, {3.5890004969433365`*^9, 3.589000503406707*^9}, {
   3.6148651258996763`*^9, 3.6148651590185347`*^9}, {3.614947245400008*^9, 
   3.614947251000418*^9}, {3.6149472930736923`*^9, 3.614947322557744*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "3", "]"}], "[", 
    RowBox[{"circularcone", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"u", "\[Rule]", "0"}], ",", " ", 
    RowBox[{"v", "\[Rule]", "1"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.617617511883361*^9, 3.6176175360677443`*^9}, {
  3.6176182028678827`*^9, 3.617618245404316*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["2"]], ",", "0", ",", 
   RowBox[{"-", 
    FractionBox["1", 
     SqrtBox["2"]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6176182461473584`*^9, 3.617618312474152*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"%", ".", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}], "-", 
       RowBox[{
        RowBox[{"circularcone", "[", 
         RowBox[{"1", ",", "1"}], "]"}], "[", 
        RowBox[{"0", ",", "1"}], "]"}]}], ")"}]}], " ", "\[Equal]", " ", 
    "0"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5721753037755213`*^9, 3.5721754164589667`*^9}, {
   3.586001703139464*^9, 3.586001727569107*^9}, {3.586002570703788*^9, 
   3.5860025763353977`*^9}, {3.5860026404515104`*^9, 3.5860026441331167`*^9}, 
   3.5860026891235957`*^9, {3.589000060667383*^9, 3.5890000674507713`*^9}, {
   3.589000200076357*^9, 3.58900020817082*^9}, {3.614861849098321*^9, 
   3.614861849098321*^9}, 3.614864659848858*^9, 3.6148647314217834`*^9, {
   3.6148651794857707`*^9, 3.6148652085018215`*^9}, 3.614917824821019*^9, 
   3.6149180935314913`*^9, {3.6149473500449924`*^9, 3.6149473675482225`*^9}, 
   3.6149474635039916`*^9, 3.617618271444805*^9, 3.6176183090049534`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Solve", "::", "svars"}], "MessageName"], ":", 
  " ", "\<\"Equations may not give solutions for all \\\"solve\\\" variables. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Solve/svars\\\", \
ButtonNote -> \\\"Solve::svars\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.617618318102474*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"z", "\[Rule]", "x"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.6176183181054745`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"circularcone", "[", 
   RowBox[{"1", ",", "1"}], "]"}], "[", 
  RowBox[{"0", ",", "1"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{3.6149475752781878`*^9, 3.61761640653765*^9, 
  3.617617278198995*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "x"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", " ", 
   RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"Green", ",", 
      RowBox[{"Opacity", "[", ".4", "]"}]}], "}"}]}], ",", 
   RowBox[{"Mesh", "\[Rule]", " ", "None"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.614947511224475*^9, 3.6149475365277195`*^9}, {
   3.614947595277423*^9, 3.6149476982688036`*^9}, {3.6149477572213078`*^9, 
   3.6149477876569605`*^9}, 3.614948425947682*^9, {3.614948471546562*^9, 
   3.6149484829345818`*^9}, 3.6149487622530727`*^9, {3.61494890886213*^9, 
   3.6149489102037325`*^9}, {3.61761845439627*^9, 3.6176184585475073`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"teb", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6149478113222027`*^9, 3.614947819091016*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", ".02", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.6149478527402754`*^9, 3.614947992469721*^9}, {
   3.614948095773102*^9, 3.6149481286267595`*^9}, 3.61761836961142*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"cpt", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.614948138938378*^9, 3.614948144850788*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "t"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"Blue", ",", " ", "Thick"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.614948558157914*^9, 3.614948571230737*^9}, {
  3.6149486018379908`*^9, 3.6149486688713083`*^9}, {3.614948926302961*^9, 
  3.6149489275353627`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"cli", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6149486808833294`*^9, 3.614948690212146*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"circularcone", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", " ", 
   RowBox[{"Mesh", "\[Rule]", " ", "None"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.614948162057618*^9, 3.61494827136701*^9}, {
  3.6149489409513865`*^9, 3.614948942246189*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"co", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6149483045014687`*^9, 3.6149483106790795`*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"teb", ",", "cpt", ",", "co", ",", "cli"}], "}"}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6149483147350864`*^9, 3.614948383780808*^9}, {
  3.6149487051413727`*^9, 3.614948706467375*^9}}],

Cell["\<\
Clearly, the tangential plane of the circular cone doesn\[CloseCurlyQuote]t \
depend on v; it is constant along the generating lines.\
\>", "Text",
 CellChangeTimes->{{3.5890002696153345`*^9, 3.5890003178870955`*^9}, 
   3.6148653107288013`*^9, 3.614948837819605*^9, 3.6151172062957406`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2.2. Example: Plane", "Subsubsection",
 CellChangeTimes->{{3.587272440743189*^9, 3.5872724436063533`*^9}, 
   3.588661276850272*^9, 3.5995529828209066`*^9, 3.599566093190103*^9, 
   3.6176185715049677`*^9, 3.6176250871982107`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fpl", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", 
  RowBox[{"{", 
   RowBox[{"u", ",", "v", ",", 
    RowBox[{"u", "+", 
     RowBox[{"2", "*", "v"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.553947791570472*^9, 3.5539477933488746`*^9}, {
  3.586001848219719*^9, 3.586001869981757*^9}, {3.5860020467612677`*^9, 
  3.586002150158249*^9}}],

Cell["\<\
For a plane the vectors of the moving frame can be chosen to be constant:\
\>", "Text",
 CellChangeTimes->{{3.572176177272483*^9, 3.5721762037599983`*^9}, {
   3.572176239688053*^9, 3.572176260632251*^9}, 3.572255951175156*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"amf", "[", "1", "]"}], "[", "fpl", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{
  3.553948967562937*^9, 3.5539502761680355`*^9, {3.586002788948171*^9, 
   3.586002790726574*^9}, 3.6148618491295214`*^9, 3.6149178248366194`*^9, 
   3.6149181005671034`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["2"]], ",", "0", ",", 
   FractionBox["1", 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{3.6149491777286024`*^9, 3.6176246697003317`*^9, 
  3.6176250021213446`*^9, 3.618032700152738*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"amf", "[", "2", "]"}], "[", "fpl", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{3.553950304404085*^9, 3.586002826544237*^9, 
  3.6148618491295214`*^9, 3.6149178248366194`*^9, 3.6149181022207065`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", 
     SqrtBox["3"]]}], ",", 
   FractionBox["1", 
    SqrtBox["3"]], ",", 
   FractionBox["1", 
    SqrtBox["3"]]}], "}"}]], "Output",
 CellChangeTimes->{3.61494918194061*^9, 3.617624669764335*^9, 
  3.617625006604601*^9, 3.618032700183938*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"amf", "[", "3", "]"}], "[", "fpl", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{3.5539489906821775`*^9, 3.5539503233269186`*^9, 
  3.58600282829144*^9, 3.614861849145121*^9, 3.614917824852219*^9, 
  3.614918103531109*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", 
     SqrtBox["6"]]}], ",", 
   RowBox[{"-", 
    SqrtBox[
     FractionBox["2", "3"]]}], ",", 
   FractionBox["1", 
    SqrtBox["6"]]}], "}"}]], "Output",
 CellChangeTimes->{3.614949186667418*^9, 3.617624669782336*^9, 
  3.6176250105208254`*^9, 3.618032700199538*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "i", "]"}], "[", "fpl", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ".", 
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "j", "]"}], "[", "fpl", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.553947825625331*^9, 3.5539478262649326`*^9}, {
   3.5539479129386845`*^9, 3.5539479129386845`*^9}, {3.5539480114528575`*^9, 
   3.5539480249468813`*^9}, {3.5539490104630127`*^9, 
   3.5539490713811197`*^9}, {3.5539503233425183`*^9, 
   3.5539503233425183`*^9}, {3.5721759831323786`*^9, 3.5721760687492757`*^9}, 
   3.5721761324919214`*^9, {3.5860028308186445`*^9, 3.5860028329246483`*^9}, {
   3.6148618491607213`*^9, 3.614861849176321*^9}, 3.614863501344023*^9, {
   3.6149178248678193`*^9, 3.6149178248678193`*^9}, {3.6149181080083165`*^9, 
   3.614918109693119*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.614949197041436*^9, 3.6176250191253176`*^9, 
  3.618032700230738*^9}]
}, Closed]],

Cell["As we see, the vectors of this moving frame are constant:", "Text",
 CellChangeTimes->{{3.586003209961711*^9, 3.5860032385721607`*^9}, {
  3.5995601670382357`*^9, 3.599560167205245*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "i", "]"}], "[", "fpl", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3"}], "}"}]}], "]"}], ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.5860029528576593`*^9, 3.586003058766245*^9}, {
   3.614861849191921*^9, 3.614861849191921*^9}, 3.614863501359623*^9, 
   3.614917824883419*^9, 3.614918116510331*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6149492126726637`*^9, 3.617625039143462*^9, 
  3.618032700261938*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "i", "]"}], "[", "fpl", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3"}], "}"}]}], "]"}], ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5860029528576593`*^9, 3.5860030749746733`*^9}, {
   3.6148618492075214`*^9, 3.6148618492075214`*^9}, 3.614863501375223*^9, 
   3.6149178248990192`*^9, 3.6149181233275433`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6149492162606697`*^9, 3.6176250454198217`*^9, 
  3.6180327002775383`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2.3. Metric Invariants. First Fundamental Form", "Subsubsection",
 CellChangeTimes->{{3.5860653550319138`*^9, 3.586065364922331*^9}, {
   3.5872724489986615`*^9, 3.587272452765877*^9}, {3.5886612605950437`*^9, 
   3.588661268863058*^9}, 3.5886740069241586`*^9, {3.5902137324227285`*^9, 
   3.590213746431553*^9}, 3.6176250938625917`*^9, 3.617693466379898*^9}],

Cell["Let a smooth curve in the parameter space be given:", "Text",
 CellChangeTimes->{{3.5860654539672875`*^9, 3.5860654965397625`*^9}}],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"\[DoubledGamma]", "[", "t_", "]"}], ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
     RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "}"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5860655187074013`*^9, 3.586065549002654*^9}, {
   3.5860657022885237`*^9, 3.5860657414289923`*^9}, {3.5860658041255026`*^9, 
   3.5860658268391423`*^9}, 3.5890873523715672`*^9, 3.589088281233695*^9}],

Cell["The corresponding curve  on the surface is", "Text",
 CellChangeTimes->{{3.586066192568585*^9, 3.586066201913001*^9}, {
  3.589006059047471*^9, 3.5890060703111153`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";", 
  RowBox[{
   RowBox[{"sf\[DoubledGamma]", "[", "t_", "]"}], " ", ":=", 
   RowBox[{"sf", "[", 
    RowBox[{
     RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
     RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.58606588789765*^9, 3.586065894434061*^9}, {
  3.586066107280835*^9, 3.5860661590597258`*^9}, {3.5860670057980137`*^9, 
  3.586067018200035*^9}, {3.589087429064954*^9, 3.589087468249195*^9}, {
  3.617625177320366*^9, 3.6176251841517563`*^9}}],

Cell["Here is its tangent vector", "Text",
 CellChangeTimes->{{3.5860662109454174`*^9, 3.586066227918247*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"sf", "[", 
    RowBox[{
     RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
     RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ",", "t"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5860662523010902`*^9, 3.586066287057951*^9}, 
   3.5890874822809973`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["\[DoubledGamma]2", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
       RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[DoubledGamma]1", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
       RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["\[DoubledGamma]2", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
       RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[DoubledGamma]1", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
       RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["\[DoubledGamma]2", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
       RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[DoubledGamma]1", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
       RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5885665969231057`*^9, 3.5890882927983565`*^9, 
  3.61416277692881*^9, 3.6141631964603467`*^9, 3.61416324393123*^9, 
  3.61416416626725*^9, 3.614164225843755*^9, 3.6141642799446497`*^9, 
  3.614949743900397*^9, 3.617625151151869*^9, 3.617625195332396*^9, 
  3.61763226045192*^9, 3.617683313996431*^9, 3.6180327717568636`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", "-", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "1", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{
      RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
      RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], "*", 
    RowBox[{
     SuperscriptBox["\[DoubledGamma]1", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], " ", "-", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "2", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{
      RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
      RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], "*", 
    RowBox[{
     SuperscriptBox["\[DoubledGamma]2", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5860663716724997`*^9, 3.586066533226383*^9}, {
   3.5860665822728696`*^9, 3.586066582912471*^9}, {3.586066701659879*^9, 
   3.5860667132038994`*^9}, {3.58606687879819*^9, 3.5860669453011074`*^9}, {
   3.589087499328973*^9, 3.589087507184422*^9}, 3.589087578555504*^9, 
   3.589087612347437*^9, {3.614163211576773*^9, 3.614163233042411*^9}, 
   3.6141642723006363`*^9, 3.6176000240258875`*^9, 3.617600085739596*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.58856661661034*^9, 3.5890883080752306`*^9, 
  3.6141627892528315`*^9, 3.614163202091957*^9, 3.6141632498124404`*^9, 
  3.614164232348966*^9, 3.6141642903966684`*^9, 3.614949754352415*^9, 
  3.6176252068850565`*^9, 3.6176833179588375`*^9, 3.618032779400877*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%%", " ", "\[Equal]", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{"tang", "[", "sf", "]"}], "[", 
    RowBox[{
     RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
     RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], "[", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[DoubledGamma]1", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], ",", 
    RowBox[{
     SuperscriptBox["\[DoubledGamma]2", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5860679659785004`*^9, 3.5860680404842315`*^9}, 
   3.5890875161849365`*^9, 3.5890875882410583`*^9, 3.5890876187208014`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.588566632615968*^9, 3.5890883237541275`*^9, 
  3.6141628018420534`*^9, 3.614164319069518*^9, 3.61494976254243*^9, 
  3.6176252159685764`*^9, 3.6176833228884463`*^9, 3.6180327497140255`*^9, 
  3.6180327845800867`*^9}]
}, Closed]],

Cell["\<\
Clearly, this is a tangent vector of the surface. The metric properties: the \
arc length of the curve, intersection angles, the area  etc. are defined by \
the scalar products of  tangent vectors at the variable point {u,v} of the \
surface:\
\>", "Text",
 CellChangeTimes->{{3.586068142992011*^9, 3.586068177561672*^9}, {
   3.5860682279341607`*^9, 3.586068343514764*^9}, 3.586151985007841*^9, 
   3.5995528399297333`*^9, 3.61416242396259*^9, {3.614949815192522*^9, 
   3.6149498664854116`*^9}, 3.61762524523025*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", " ", "3"}], ";", 
  RowBox[{"ast", " ", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"tang", "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{"x1", ",", "x2"}], "]"}], ".", 
     RowBox[{
      RowBox[{
       RowBox[{"tang", "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{"y1", ",", "y2"}], "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5860683560727854`*^9, 3.5860684322165194`*^9}, {
   3.5860685573443394`*^9, 3.5860685599183435`*^9}, 3.5886615418167377`*^9, {
   3.589001060562574*^9, 3.5890010784986*^9}, 3.599565556008378*^9, 
   3.599565651376833*^9, 3.6149498906498547`*^9, {3.617683238320698*^9, 
   3.61768324505991*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"x2", " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{"x1", " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"y2", " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{"y1", " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"x2", " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{"x1", " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"y2", " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{"y1", " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"x2", " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{"x1", " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"y2", " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{"y1", " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.614949891929057*^9, 3.6176252686365886`*^9, 
  3.6176831474037385`*^9, 3.6176832491315165`*^9, 3.6180328506774025`*^9}]
}, Closed]],

Cell["\<\
This scalar product is the Euclidean scalar product restricted to the tangent \
spaces of the surface,that is a symmetric positive definite bilinear form \
whose coefficient matrix is the matrix of the scalar products of the standard \
tangent basis vectors depending on the points {u,v}. In general, they are \
neither normed nor orthogonal:\
\>", "Text",
 CellChangeTimes->{{3.617684210639206*^9, 3.617684599111088*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"rgT", ",", "f"}], "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"rgT", "[", 
      RowBox[{"i_", ",", "j_"}], "]"}], "[", "f_", "]"}], "[", "u__", "]"}], 
   " ", ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"IntegerQ", "[", "i", "]"}], "&&", 
        RowBox[{"i", ">", "0"}], "&&", 
        RowBox[{"i", "\[LessEqual]", 
         RowBox[{"Length", "[", 
          RowBox[{"{", "u", "}"}], "]"}]}]}], ")"}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"IntegerQ", "[", "j", "]"}], "&&", 
        RowBox[{"j", ">", "0"}], "&&", 
        RowBox[{"j", "\[LessEqual]", 
         RowBox[{"Length", "[", 
          RowBox[{"{", "u", "}"}], "]"}]}]}], ")"}]}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", 
          RowBox[{"f", "[", "u", "]"}], "]"}], "\[Equal]", " ", "List"}], "&&",
         " ", 
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"f", "[", "u", "]"}], "]"}], ">", "1"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"tv", "[", "i", "]"}], "[", "f", "]"}], "[", "u", "]"}], 
        ".", 
        RowBox[{
         RowBox[{
          RowBox[{"tv", "[", "j", "]"}], "[", "f", "]"}], "[", "u", "]"}]}]}],
       "]"}], ",", " ", 
     RowBox[{"Print", "[", 
      RowBox[{"\"\<Wrong {i,j} = \>\"", ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}], "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.586068574332769*^9, 3.5860686078104277`*^9}, {
   3.5860686390572824`*^9, 3.5860687084618044`*^9}, 3.6149501405622935`*^9, 
   3.6149504057159595`*^9, {3.6176000240414877`*^9, 3.6176000240414877`*^9}, 
   3.617625895736457*^9, {3.617683366818124*^9, 3.617683440606253*^9}, {
   3.617692768223966*^9, 3.6176927691900215`*^9}, {3.618028941934537*^9, 
   3.618028984023411*^9}, {3.6180299968551903`*^9, 3.6180300191164293`*^9}, {
   3.61803007644653*^9, 3.6180301031225767`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rgT", " ", "::", " ", "usage"}], " ", "=", 
   "\"\<For the immersion f of a m-dimensional manifold \!\(\*SuperscriptBox[\
\(X\), \(m\)]\) into the n-dimensional Euclidean space, m\[LessEqual]n, the \
matrix {rgT[i,j][f][u1,...,um]}, 1\[LessEqual]i,j\[LessEqual]m, is the matrix \
of the coefficients of the Riemannian metric on \!\(\*SuperscriptBox[\(X\), \
\(m\)]\) induced by the immersion f.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6176846574395905`*^9, 3.6176847979646373`*^9}, {
   3.617684835311103*^9, 3.6176851458296485`*^9}, {3.61768518668612*^9, 
   3.6176852141889687`*^9}, 3.617685283999091*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"rgT", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " "}]], "Input",
 CellChangeTimes->{3.6176835523960495`*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "1", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
  SuperscriptBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "2", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
  SuperscriptBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "3", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "2"]}]], "Output",
 CellChangeTimes->{3.617683554564453*^9, 3.6180290128366613`*^9, 
  3.618030330087375*^9, 3.6180328808322554`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"rgT", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " "}]], "Input",
 CellChangeTimes->{
  3.6176835523960495`*^9, {3.617684097336207*^9, 3.617684111657032*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "1", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "1", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "2", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "2", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "3", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "3", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.617684113482235*^9, 3.6180290202154746`*^9, 
  3.618030333176181*^9, 3.6180328840458612`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"rgT", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " "}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.586068574332769*^9, 3.5860686078104277`*^9}, {
   3.5860686390572824`*^9, 3.5860687337962494`*^9}, 3.6149501434326982`*^9, 
   3.6149504087735643`*^9, 3.6176000240414877`*^9, 3.617600085739596*^9, 
   3.617625897056532*^9, {3.617683457079882*^9, 3.6176834844579306`*^9}, 
   3.6176840514253263`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Wrong {i,j} = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}]}],
  SequenceForm["Wrong {i,j} = ", {1, 3}],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAWLpF2+89L+8cqzT1JxoDKTniKevNgfSRW+a+COBtOzU
TP8YIB3puWVuJpCermjNkQWkDx2Z/LMFSLf0V8ZMBtJ8sSfi1wDpNqYOoz1A
+smDNQl7gfSvS5sargJpPTmTPddB5oiJad0A0i6Oe11B9IUa5gQQPUVtUfBN
IO1mITMfRAunGdYyfn3l6GS8tYsbSNdxdlwF0ee+xD7iBdKTPlyu1gfSd8Pt
y42B9CvR2bNtgHTCoWOckSB9LHZH6oF0hOZ35rVA2qVf034dkO67HH4PRIsd
fP0NROcYxiXvBNKvv37UvwKk5fzTXj0B0u+lD/L+B9JGPS42IJrNSrqA6RvQ
HX9mdmsA6Y0fxHYEAulT87mqEoD0ggjBujYg/S6upw1EF07027kCSGsnKH9d
B6SjpN48+/YDGL6PvA78BNIe8wSPgej1R6S0fwNp06IHBiCaozMlCURXXr+h
uODnK0cAYeXvew==
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"rgT", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"rgT", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5886613827276583`*^9, 3.5886614689802094`*^9}, {
  3.588661500523465*^9, 3.588661516326293*^9}, {3.61762590209282*^9, 
  3.6176259031958833`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.588661470041012*^9, {3.58866150333147*^9, 3.5886615175430946`*^9}, 
   3.589001109386367*^9, 3.6141643668992023`*^9, 3.614950448350834*^9, 
   3.61762529820828*^9, 3.6176836093673496`*^9, 3.6180303457966027`*^9, 
   3.6180328936398783`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", " ", 
  RowBox[{"ast", " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"1", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "*", "x1", "*", "y1"}], " ", "+", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"1", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"x1", "*", "y2"}], " ", "+", 
       RowBox[{"x2", "*", "y1"}]}], ")"}]}], " ", "+", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"2", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "*", "x2", "*", "y2"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5860688561316643`*^9, 3.5860690418811903`*^9}, {
  3.5860690841260643`*^9, 3.586069106621304*^9}, {3.5890011430442915`*^9, 
  3.5890011879328594`*^9}, {3.617625905967042*^9, 3.617625909573248*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.614164375432418*^9, 3.614164387085638*^9}, 
   3.614950475151681*^9, 3.6176253058817186`*^9, 3.617683993346424*^9, 
   3.6180303496342096`*^9, 3.6180329024538937`*^9}]
}, Closed]],

Cell[TextData[{
 "The coefficients rgT[i,j][f][u,v] are the coordinates of a positive \
definite, symmetric bilinear form depending on the point {u,v}  of the \
parameter manifold U. It is the",
 StyleBox[" first",
  FontColor->RGBColor[0, 0, 1]],
 " or ",
 StyleBox["metric fundamental form ",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  FormBox["fund1", TraditionalForm]],
  CellChangeTimes->{{3.5861529045544357`*^9, 3.5861530716929955`*^9}, 
    3.5861532850852013`*^9, {3.5861533247654705`*^9, 3.586153326756584*^9}, 
    3.586153440461088*^9, 3.5861536097777724`*^9}],
 " of a 2-dimensional Riemannian geometry, defining the",
 StyleBox[" inner geometry",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface covering all its properties being invariant under \
isometries. A map between two surfaces is called an ",
 StyleBox["isometry",
  FontColor->RGBColor[0, 0, 1]],
 " if it preserves the arc length of  curves (see the next subsection). \nThe \
classical notation is ",
 Cell[BoxData[
  FormBox["fund1", TraditionalForm]]],
 " = ",
 Cell[BoxData[
  SuperscriptBox["ds", "2"]]],
 ", what may not be reproduced in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " formulas, since the expression  is always interpreted as a power."
}], "Text",
 CellChangeTimes->{{3.586152357579151*^9, 3.586152604679284*^9}, {
   3.5861526839358172`*^9, 3.5861527425681705`*^9}, {3.586152808759957*^9, 
   3.5861528462721024`*^9}, 3.5861533692320137`*^9, {3.586153400847822*^9, 
   3.586153548808285*^9}, 3.58615358683146*^9, {3.5861541794643564`*^9, 
   3.586154180671426*^9}, {3.586154312279953*^9, 3.5861543492690687`*^9}, {
   3.5885676557649*^9, 3.5885677678883133`*^9}, {3.5885680164035273`*^9, 
   3.5885680453391824`*^9}, {3.588661586308016*^9, 3.588661586822817*^9}, {
   3.588661624746483*^9, 3.5886616346525006`*^9}, {3.5886618514772816`*^9, 
   3.588661868418911*^9}, 3.589191183132166*^9, {3.5904957103906093`*^9, 
   3.590495710406209*^9}, 3.5995529202423267`*^9, 3.614950556365424*^9, 
   3.6176259128434353`*^9, 3.6176854156633224`*^9, {3.6176854904342537`*^9, 
   3.6176854977662663`*^9}},
 CellTags->"g(i"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     FormBox["fund1",
      TraditionalForm], "[", "f_", "]"}], "[", "u__", "]"}], "[", 
   RowBox[{"x_List", ",", "y_List"}], "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Length", "[", "x", "]"}], " ", "\[Equal]", " ", 
      RowBox[{"Length", "[", 
       RowBox[{"{", "u", "}"}], "]"}]}], "&&", 
     RowBox[{
      RowBox[{"Length", "[", "y", "]"}], " ", "\[Equal]", "  ", 
      RowBox[{"Length", "[", 
       RowBox[{"{", "u", "}"}], "]"}]}]}], ",", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", "f", "]"}], "[", "u", "]"}], 
       "*", 
       RowBox[{"x", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "*", 
       RowBox[{"y", "[", 
        RowBox[{"[", "j", "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", 
         RowBox[{"{", "u", "}"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", 
        RowBox[{"Length", "[", 
         RowBox[{"{", "u", "}"}], "]"}]}], "}"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Print", "[", "\"\<Wrong arguments!\>\"", "]"}], ";", 
     RowBox[{"Return", "[", "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5861529045544357`*^9, 3.5861530716929955`*^9}, 
   3.5861532850852013`*^9, {3.5861533247654705`*^9, 3.586153326756584*^9}, 
   3.586153440461088*^9, 3.5861536097777724`*^9, {3.5890012608770313`*^9, 
   3.5890012796371045`*^9}, 3.590495710406209*^9, 3.6176259155025873`*^9, {
   3.618028607001949*^9, 3.6180286476868205`*^9}, 3.6180288206443243`*^9, {
   3.618029334727627*^9, 3.6180293682988863`*^9}, {3.618029401433344*^9, 
   3.6180294186401744`*^9}, 3.6180295739228473`*^9, {3.6180296220645313`*^9, 
   3.6180296248413363`*^9}, {3.618029689940251*^9, 3.618029832680502*^9}, {
   3.618030383548669*^9, 3.6180303996322975`*^9}, {3.6180311010875297`*^9, 
   3.61803112412877*^9}, {3.6180313060562897`*^9, 3.618031380031619*^9}, {
   3.618031423196895*^9, 3.6180314644277678`*^9}, {3.618031496064623*^9, 
   3.61803157401796*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fund1", "::", "usage"}], " ", "=", " ", 
   "\"\<fund1[f][u1,..,um][x,y] is the value of the first fundamental form of \
the immersion f[u1,...,um] into the n_dimensional Euclidean space, for the \
tangenmt vectors x,y of the immersion.\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.6180284552448826`*^9, 3.6180285191581945`*^9}, {
   3.6180286638796487`*^9, 3.6180287896938696`*^9}, 3.618030489800456*^9}],

Cell[TextData[StyleBox["Example. The spheres:",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.5861531338965535`*^9, 3.586153139327864*^9}, {
  3.5886616891901965`*^9, 3.5886617024658194`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     FormBox["fund1",
      TraditionalForm], "[", 
     RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x1", ",", "x2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y1", ",", "y2"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5861531444481573`*^9, 3.5861532434508195`*^9}, {
   3.586153274283583*^9, 3.5861532782268085`*^9}, {3.5861536173652067`*^9, 
   3.586153627083762*^9}, {3.586153777276353*^9, 3.5861537821146297`*^9}, 
   3.5861545793562293`*^9, 3.590495710406209*^9, {3.6176856123328676`*^9, 
   3.617685662018955*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SuperscriptBox["r", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"x1", " ", "y1"}], "+", 
    RowBox[{"2", " ", "x2", " ", "y2"}], "+", 
    RowBox[{"x1", " ", "y1", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "v"}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.5890013134940405`*^9, 3.5890061005628457`*^9, 
  3.5897808555053205`*^9, 3.6149505827294703`*^9, 3.6176855400735407`*^9, 
  3.6176856638597584`*^9, 3.6180288591763916`*^9, 3.618029856829344*^9, 
  3.6180329829968348`*^9}]
}, Closed]],

Cell["Another commonly used simplification is", "Text",
 CellChangeTimes->{{3.5861541213060303`*^9, 3.586154139401065*^9}, 
   3.5861543977998447`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      FormBox["fund1",
       TraditionalForm], "[", 
      RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x1", ",", "x2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y1", ",", "y2"}], "}"}]}], "]"}], "\[Equal]", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"r", "^", "2"}], ")"}], "*", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Cos", "[", "v", "]"}], ")"}], "^", "2"}], "*", "x1", "*", 
       "y1"}], "+", 
      RowBox[{"x2", "*", "y2"}]}], " ", ")"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5861537211471424`*^9, 3.5861537348419256`*^9}, {
   3.5861539275459476`*^9, 3.586154063466722*^9}, {3.586154468125867*^9, 
   3.5861544917242165`*^9}, {3.586154603805628*^9, 3.58615467517371*^9}, 
   3.590495710406209*^9, {3.61768585274489*^9, 3.6176859259714184`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5890013451628523`*^9, 3.614164420750497*^9, 
  3.614950611995122*^9, 3.617685930308226*^9, 3.6180298484989295`*^9, 
  3.618032987786043*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "[", 
       RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.617685983083119*^9, 3.617686136446988*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "v", "]"}], "2"]}], "0"},
     {"0", 
      SuperscriptBox["r", "2"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.617686117430555*^9, 3.617686138646592*^9}, 
   3.618032994213255*^9}]
}, Closed]],

Cell["\<\
To define the area of a surface we consider the Gram determinant of two \
vectors:\
\>", "Text",
 CellChangeTimes->{{3.5722510364627957`*^9, 3.5722510654008465`*^9}, {
  3.586154782192831*^9, 3.586154814847698*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"x1", ",", "x2"}], "]"}], ";", 
  RowBox[{
   RowBox[{"gram", "[", 
    RowBox[{"x1_", ",", "x2_"}], "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x1", ".", "x1"}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{"x2", ".", "x2"}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x1", ".", "x2"}], ")"}], "^", "2"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.586069943593974*^9, 3.586069984809246*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"gram", "::", "usage"}], " ", "=", " ", 
   "\"\<gram[vx,vy] is the Gram determinant of two vectors vx,vy  in the \
n-dimensional Euclidean Space.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6149507206961126`*^9, 3.6149508409411235`*^9}, 
   3.61495087285878*^9}],

Cell["\<\
In Euclidean geometry this is the square of the area of the parallelogram \
spanned by the vectors x1,  x2:\
\>", "Text",
 CellChangeTimes->{{3.572251109876525*^9, 3.57225117556824*^9}, 
   3.586069358592946*^9, {3.5861548724479933`*^9, 3.5861549045198274`*^9}, 
   3.586156372890814*^9, {3.5890885163591433`*^9, 3.589088550846116*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Det", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"vec", "[", 
         RowBox[{"x", ",", "2"}], "]"}], ",", 
        RowBox[{"vec", "[", 
         RowBox[{"y", ",", "2"}], "]"}]}], "}"}], "]"}], ")"}], "^", "2"}], 
   " ", "\[Equal]", " ", 
   RowBox[{"gram", "[", 
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{"x", ",", "2"}], "]"}], ",", 
     RowBox[{"vec", "[", 
      RowBox[{"y", ",", "2"}], "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.572087475918888*^9, 3.5720876163876476`*^9}, {
  3.5720876693809404`*^9, 3.5720877258266935`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.589006137048932*^9, 3.6149509145732527`*^9}]
}, Closed]],

Cell["\<\
   Thus the square of  the area of a parallelogram in the tangent plane of \
the surface is defined by\
\>", "Text",
 CellChangeTimes->{{3.572251109876525*^9, 3.57225117556824*^9}, 
   3.586069358592946*^9, {3.5861548724479933`*^9, 3.5861549045198274`*^9}, 
   3.586156372890814*^9, {3.586156413240121*^9, 3.5861564361274304`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dst", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"gram", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"tang", "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{"s1", ",", "s2"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"tang", "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{"t1", ",", "t2"}], "]"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.586069422007058*^9, 3.58606947440755*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"s2", " ", "t1"}], "-", 
     RowBox[{"s1", " ", "t2"}]}], ")"}], "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.5890885764355793`*^9, 3.590734304139592*^9, 
  3.6149509327160845`*^9, 3.6176868787274923`*^9, 3.61803052039211*^9, 
  3.61803300856528*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"dst", "\[Equal]", "  ", 
   RowBox[{
    RowBox[{"Det", "[", 
     RowBox[{"Table", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "*", 
    RowBox[{
     RowBox[{"Det", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"s1", ",", "s2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t1", ",", "t2"}], "}"}]}], "}"}], "]"}], "^", "2"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5860694992583933`*^9, 3.586069705116355*^9}, {
   3.5860697555356436`*^9, 3.586069761260854*^9}, 3.586070236627984*^9, {
   3.5860702801554737`*^9, 3.586070319856745*^9}, {3.586070594851474*^9, 
   3.5860706219870253`*^9}, 3.5860707138922825`*^9, 3.5860709654996734`*^9, {
   3.586071217676097*^9, 3.5860712227553873`*^9}, 3.6148618492387214`*^9, 
   3.6148635013908234`*^9, 3.6176259295093884`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.589088585856118*^9, 3.5907343255584297`*^9, 
  3.614950946506509*^9, 3.617686890677113*^9, 3.618030528238923*^9, 
  3.618033016614894*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Det", "[", 
    RowBox[{"Table", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "\[Equal]", " ", 
   RowBox[{"gram", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"tv", "[", "1", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"tv", "[", "2", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5860694992583933`*^9, 3.586069705116355*^9}, {
   3.5860697555356436`*^9, 3.586069761260854*^9}, 3.586070236627984*^9, {
   3.5860702801554737`*^9, 3.586070319856745*^9}, {3.586070594851474*^9, 
   3.5860706219870253`*^9}, 3.5860707138922825`*^9, 3.5860709654996734`*^9, {
   3.586071217676097*^9, 3.5860712227553873`*^9}, {3.5860748660092196`*^9, 
   3.5860749408935027`*^9}, 3.6148618492543216`*^9, 3.6148635014220233`*^9, 
   3.617600024057088*^9, 3.617600085755196*^9, 3.617625931341493*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.590734334122845*^9, 3.6149509712949524`*^9, 
  3.618030532575731*^9}]
}, Closed]],

Cell[TextData[{
 "We define as  the ",
 StyleBox["area element",
  FontColor->RGBColor[0, 0, 1]],
 "  the  ",
 StyleBox["integrand of the",
  FontColor->RGBColor[0, 0, 1]],
 " ",
 StyleBox["area integral",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.586074957018425*^9, 3.5860749831289186`*^9}, {
   3.6149511390512924`*^9, 3.614951164738762*^9}, 3.6176862785320377`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "dA", "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"dA", "[", "f_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
   RowBox[{"Sqrt", "[", " ", 
    RowBox[{"Det", "[", 
     RowBox[{"Table", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", "f", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5721028398629103`*^9, 3.5721030771549273`*^9}, 
   3.5721031379326334`*^9, {3.586074746853404*^9, 3.5860747605491877`*^9}, {
   3.5860748158453503`*^9, 3.586074825492902*^9}, {3.5861549510774903`*^9, 
   3.586154964603264*^9}, {3.5862629631854534`*^9, 3.586262985017702*^9}, {
   3.5862630295142474`*^9, 3.5862630744648185`*^9}, {3.586604010786734*^9, 
   3.5866040355439777`*^9}, 3.6176000240726876`*^9, 3.617600085755196*^9, 
   3.617687181505224*^9, 3.6176873242766747`*^9, {3.617687380748774*^9, 
   3.6176874075964212`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dA", "::", "usage"}], " ", "=", " ", 
   "\"\<dA[f][u,v] is the area element of the surface f[u,v] in the Euclidean \
3-space.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6149512007068186`*^9, 3.6149512315495825`*^9}, {
   3.6149512646054735`*^9, 3.6149513092050247`*^9}, 3.6149513572857747`*^9}],

Cell["\<\
Remark, Since the first fundamental form is positively  definit its \
determinant is always positive. Therefore its non oriented integral is \
positive too. \
\>", "Text",
 CellChangeTimes->{{3.617952911137521*^9, 3.6179529253933363`*^9}, {
  3.617953007017005*^9, 3.617953011633269*^9}, {3.6179530458652267`*^9, 
  3.6179531287369666`*^9}, {3.6180305569429736`*^9, 3.6180305659909897`*^9}}],

Cell[TextData[{
 StyleBox["Example.",
  FontColor->RGBColor[0, 0, 1]],
 " Circular cone"
}], "Text",
 CellChangeTimes->{{3.6176877651178493`*^9, 3.617687777675871*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"dA", "[", 
    RowBox[{"circularcone", "[", 
     RowBox[{"a", ",", "b"}], "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5866039382466063`*^9, 3.5866039759206724`*^9}, {
  3.5866041540105853`*^9, 3.5866041641662035`*^9}, {3.6148653631292934`*^9, 
  3.6148653750945144`*^9}}],

Cell[BoxData[
 SqrtBox[
  RowBox[{
   SuperscriptBox["a", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"]}], ")"}], " ", 
   SuperscriptBox["v", "2"]}]]], "Output",
 CellChangeTimes->{3.5890886453445215`*^9, 3.5907343584744883`*^9, 
  3.614865377294118*^9, 3.6149514035384197`*^9, 3.617687301110634*^9, 
  3.61768733301269*^9, 3.6176874170656376`*^9, 3.618033041730938*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"dA", "[", 
    RowBox[{"circularcone", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5866039382466063`*^9, 3.5866039759206724`*^9}, {
  3.5866041540105853`*^9, 3.5866041641662035`*^9}, {3.6148653631292934`*^9, 
  3.6148653750945144`*^9}, {3.6148663357515907`*^9, 3.614866346896228*^9}}],

Cell[BoxData[
 RowBox[{
  SqrtBox["2"], " ", 
  SqrtBox[
   SuperscriptBox["v", "2"]]}]], "Output",
 CellChangeTimes->{3.6148663495603805`*^9, 3.614951413336981*^9, 
  3.617687427548856*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"dA", "[", 
       RowBox[{"circularcone", "[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"v", "\[GreaterEqual]", " ", "0"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", "h"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.589088773152831*^9, 3.589088850954281*^9}, {
   3.5890888926896687`*^9, 3.5890889221143513`*^9}, 3.6148618492855215`*^9, 
   3.614865446090239*^9, {3.614865726531932*^9, 3.614865741539158*^9}, {
   3.614866292275104*^9, 3.614866301169613*^9}, 3.6176875207278194`*^9}],

Cell[BoxData[
 RowBox[{
  SqrtBox["2"], " ", 
  SuperscriptBox["h", "2"], " ", "\[Pi]"}]], "Output",
 CellChangeTimes->{{3.5890888309901395`*^9, 3.5890888521643505`*^9}, 
   3.589088923367423*^9, 3.614865753566779*^9, 3.6148663892146482`*^9, 
   3.614951449785065*^9, 3.6176874483280926`*^9, 3.6176875252830276`*^9, 
   3.6180330548817616`*^9}]
}, Closed]],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.6176878245383534`*^9, 3.6176878245383534`*^9}}],

Cell[TextData[{
 "The integral over dA[sf][u,v] yields the ",
 StyleBox["area",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface. Since a parameter transformation for the surface amounts \
to the multiplication of the integrand with the Jacobian determinant of the \
parameter transformation, the integral is independent of the choice of the \
parameter representation."
}], "Text",
 CellChangeTimes->{{3.5720898734695654`*^9, 3.572089907259225*^9}, {
  3.572105272437583*^9, 3.5721052835448027`*^9}, {3.572173734631772*^9, 
  3.5721738456001186`*^9}, {3.586074789744858*^9, 3.586074792722028*^9}, {
  3.586155042023692*^9, 3.5861551192241077`*^9}, {3.5861562113125715`*^9, 
  3.5861562665757327`*^9}, {3.5861563043758945`*^9, 3.5861563220399046`*^9}, {
  3.61769233645127*^9, 3.617692342075592*^9}}],

Cell[TextData[{
 StyleBox["Example",
  FontColor->RGBColor[0, 0, 1]],
 ". Spheres"
}], "Text",
 CellChangeTimes->{{3.6176878338827696`*^9, 3.6176878428683853`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dA", "[", 
     RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{"r", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6176878844580584`*^9, 3.617687952458578*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["r", "2"], " ", 
  SqrtBox[
   SuperscriptBox[
    RowBox[{"Cos", "[", "v", "]"}], "2"]]}]], "Output",
 CellChangeTimes->{{3.617687931726142*^9, 3.6176879550325823`*^9}, 
   3.61769188750309*^9, 3.618033064928179*^9}]
}, Closed]],

Cell["The area of the hemisphere of radius r is", "Text",
 CellChangeTimes->{{3.617691530792863*^9, 3.617691555612507*^9}, {
   3.6176918647894497`*^9, 3.617691867831455*^9}, 3.6176921682166476`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"Pi", "/", "2"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.617687965328601*^9, 3.617688027135909*^9}, 
   3.617691877129071*^9}],

Cell[BoxData[
 RowBox[{"2", " ", "\[Pi]", " ", 
  SuperscriptBox["r", "2"]}]], "Output",
 CellChangeTimes->{
  3.6176880317847176`*^9, {3.6176918789542747`*^9, 3.6176918906074953`*^9}}]
}, Closed]],

Cell["\<\
Here is another parameter representation of the hemisphere of radius r:\
\>", "Text",
 CellChangeTimes->{{3.61769158015135*^9, 3.6176916295254364`*^9}, 
   3.6176921682456493`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sphf", "[", "r_", "]"}], "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], " ", ":=", "  ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "*", 
     RowBox[{"Cos", "[", "y", "]"}]}], ",", 
    RowBox[{"x", "*", 
     RowBox[{"Sin", "[", "y", "]"}]}], ",", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{"r", "^", "2"}], "-", 
      RowBox[{"x", "^", "2"}]}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.6176881577081385`*^9, 3.6176882004366136`*^9}, {
  3.617688240637884*^9, 3.617688321227626*^9}, {3.617688750072379*^9, 
  3.6176888089000826`*^9}, {3.61769068046657*^9, 3.6176907256286488`*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sphf", "[", "2", "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.61768835777849*^9, 3.617688479614704*^9}, {
   3.6176888188216996`*^9, 3.617688849678554*^9}, {3.617688879942607*^9, 
   3.61768888749302*^9}, 3.617690751774295*^9, {3.617690789963162*^9, 
   3.617690805313589*^9}}],

Cell["The area element is", "Text",
 CellChangeTimes->{{3.617691660475891*^9, 3.617691667573903*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dA", "[", 
     RowBox[{"sphf", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}], ",", " ", 
   RowBox[{"r", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6176890442264957`*^9, 3.6176890872513714`*^9}}],

Cell[BoxData[
 RowBox[{"r", " ", 
  SqrtBox[
   FractionBox[
    SuperscriptBox["x", "2"], 
    RowBox[{
     SuperscriptBox["r", "2"], "-", 
     SuperscriptBox["x", "2"]}]]]}]], "Output",
 CellChangeTimes->{3.6176890937097826`*^9, 3.617690835562042*^9, 
  3.6176911567198057`*^9, 3.6176914096742506`*^9, 3.617691453869128*^9, 
  3.617691802748141*^9}]
}, Closed]],

Cell["The area of the  hemisphere is", "Text",
 CellChangeTimes->{{3.617691697073555*^9, 3.617691713562784*^9}, 
   3.6176921682676506`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Integrate", "[", 
    RowBox[{"%", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "r"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", 
       RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"r", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6176891033193994`*^9, 3.6176891346130543`*^9}, {
   3.617689172599121*^9, 3.6176892293676205`*^9}, {3.617690863954092*^9, 
   3.617690886776932*^9}, {3.6176911210581436`*^9, 3.6176911442397842`*^9}, {
   3.6176913540913525`*^9, 3.617691383903005*^9}, 3.617691444025511*^9, {
   3.6176917597700653`*^9, 3.6176917974753313`*^9}}],

Cell[BoxData[
 RowBox[{"2", " ", "\[Pi]", " ", 
  SuperscriptBox["r", "2"]}]], "Output",
 CellChangeTimes->{
  3.617689246496451*^9, {3.61769087426571*^9, 3.6176908876973333`*^9}, 
   3.6176909998303304`*^9, {3.617691146127387*^9, 3.617691163412218*^9}, 
   3.6176914167722626`*^9, {3.6176914490955195`*^9, 3.6176914610451403`*^9}, 
   3.617691810329754*^9}]
}, Closed]],

Cell["This equals the preceding result. \[FilledSquare]", "Text",
 CellChangeTimes->{{3.617691919342746*^9, 3.617691938468379*^9}, {
   3.6176922194665794`*^9, 3.6176922237468243`*^9}, {3.6176922937228265`*^9, 
   3.617692296446982*^9}, 3.6176925683365335`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2.4. Isometries. Inner Geometry", "Subsubsection",
 CellChangeTimes->{{3.586059663992068*^9, 3.586059674943287*^9}, {
   3.5860750543689933`*^9, 3.58607505605709*^9}, {3.5866611656056275`*^9, 
   3.586661191821127*^9}, {3.5872724573591394`*^9, 3.5872724609903474`*^9}, {
   3.588661830058444*^9, 3.588661834145651*^9}, {3.5889467393286066`*^9, 
   3.58894674141901*^9}, 3.589200965451682*^9, {3.5892029279099283`*^9, 
   3.58920294017163*^9}, 3.5995661030936694`*^9, 3.5995680459337935`*^9, 
   3.614951511699607*^9, 3.615021851745468*^9, 3.6176934720992255`*^9, 
   3.617705065201067*^9}],

Cell["Let sf[u, v] and sh[uu,vv] be two regular surfaces:", "Text",
 CellChangeTimes->{{3.58867436634879*^9, 3.588674446798131*^9}, {
  3.588674735336238*^9, 3.588674760608282*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dim", " ", "=", " ", "3"}]], "Input",
 CellChangeTimes->{{3.617701255839184*^9, 3.6177012716340876`*^9}}],

Cell[BoxData["3"], "Output",
 CellChangeTimes->{{3.6177012578873014`*^9, 3.6177012727331505`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sf", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5886741949824886`*^9, 3.5886742022053013`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "1", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "2", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "3", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.588674204248905*^9, 3.6150204901126766`*^9, 
  3.6177012786384883`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sh", "[", 
   RowBox[{"uu_", ",", "vv_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", "i", "]"}], "[", 
     RowBox[{"uu", ",", "vv"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.588674462132958*^9, 3.588674468450969*^9}, {
   3.5886746092880163`*^9, 3.588674654886897*^9}, 3.614861849316722*^9, 
   3.6148635014220233`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sh", "[", 
  RowBox[{"uu", ",", "vv"}], "]"}]], "Input",
 CellChangeTimes->{{3.5886746683497205`*^9, 3.588674708613391*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"h", "[", "1", "]"}], "[", 
    RowBox[{"uu", ",", "vv"}], "]"}], ",", 
   RowBox[{
    RowBox[{"h", "[", "2", "]"}], "[", 
    RowBox[{"uu", ",", "vv"}], "]"}], ",", 
   RowBox[{
    RowBox[{"h", "[", "3", "]"}], "[", 
    RowBox[{"uu", ",", "vv"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5886746784273376`*^9, 3.5886747139954004`*^9, 3.5889467700918603`*^9, 
   3.589006155398982*^9, 3.589091312309063*^9, {3.5891698128593264`*^9, 
   3.5891698201757393`*^9}, 3.615020499301093*^9, 3.6177012932073216`*^9}]
}, Closed]],

Cell["\<\
A map f: sf \[RightArrow] sh  is defined by the map between the parameter \
regions:\
\>", "Text",
 CellChangeTimes->{{3.588674970288251*^9, 3.588675107786892*^9}, 
   3.5890024944555883`*^9, 3.6176267756617856`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", ":", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"u", ",", "v"}], "}"}], " ", "\[Element]", " ", 
    RowBox[{"U", " ", "\[RightArrow]", " ", 
     RowBox[{"f", "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}]}], " ", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"f1", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
     RowBox[{"f2", "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}], "  ", "\[Element]", " ", 
   RowBox[{"U", " ", "U"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5886751171313086`*^9, 3.5886752965160236`*^9}, {
   3.5887663043718996`*^9, 3.5887663441987696`*^9}, 3.5887664615265756`*^9, {
   3.617701328276327*^9, 3.6177013359237647`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"f1", ",", "f2", ",", "f"}], "]"}], ";", " ", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"f1", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
     RowBox[{"f2", "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.588766400343268*^9, 3.588766437346533*^9}, 
   3.588766471978594*^9, {3.589198575767*^9, 3.5891985917029114`*^9}}],

Cell[TextData[{
 "The functions f1,f2, like all functions and maps in differential geometry, \
are assumed to be continuously differentiable as often as necessary. \
Moreover, f is proposed to be bijective. Such bijective smooth maps are named \
",
 StyleBox["diffeomorphisms",
  FontColor->RGBColor[0, 0, 1]],
 ". The map"
}], "Text",
 CellChangeTimes->{{3.5886753470913124`*^9, 3.588675451190295*^9}, {
   3.5886754866335573`*^9, 3.5886755497668686`*^9}, 3.588675617580188*^9, {
   3.5886756774218926`*^9, 3.5886756818055005`*^9}, 3.5887661518192315`*^9, 
   3.588917638220236*^9, 3.5995674356568875`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"F", "[", 
   RowBox[{"sf", "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], "]"}], ":=", 
  RowBox[{"sh", "[", 
   RowBox[{
    RowBox[{"f1", "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"f2", "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.588675689121913*^9, 3.5886758305517616`*^9}},
 CellTags->"ptr"],

Cell[TextData[{
 "is said to be an",
 StyleBox[" isometry",
  FontColor->RGBColor[0, 0, 1]],
 " if for any smooth curve sf[ \[DoubledGamma][t]]"
}], "Text",
 CellChangeTimes->{{3.5886761540027294`*^9, 3.5886763175846167`*^9}, 
   3.588766216465745*^9, {3.58900491683214*^9, 3.58900496927914*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"sf\[DoubledGamma]", "[", "t", "]"}]}]], "Input",
 CellChangeTimes->{{3.58867632485423*^9, 3.588676377051922*^9}, 
   3.5886764129163847`*^9, {3.5890048989381166`*^9, 3.589004906552552*^9}, {
   3.5890912050399275`*^9, 3.5890912313764334`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "1", "]"}], "[", 
    RowBox[{
     RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
     RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "2", "]"}], "[", 
    RowBox[{
     RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
     RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "3", "]"}], "[", 
    RowBox[{
     RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
     RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5886766792868524`*^9, 3.5887665467807255`*^9, 
  3.588946812211934*^9, 3.589002599141576*^9, 3.589004977620617*^9, 
  3.5890062026986876`*^9, 3.5890912330835314`*^9, 3.5891698893618608`*^9, 
  3.615020707218258*^9, 3.6177014244958305`*^9}]
}, Closed]],

Cell[" in sf its image under F,   namely", "Text",
 CellChangeTimes->{{3.5886764221204004`*^9, 3.5886764349436235`*^9}, {
  3.588676585171887*^9, 3.588676593330701*^9}, {3.588676743387365*^9, 
  3.588676793073452*^9}, {3.588676830435518*^9, 3.588676858265967*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"F\[DoubledGamma]", "[", "t_", "]"}], " ", "=", " ", 
  RowBox[{"sh", "[", 
   RowBox[{
    RowBox[{"f1", "[", 
     RowBox[{
      RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
      RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ",", " ", 
    RowBox[{"f2", "[", 
     RowBox[{
      RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
      RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5886764432116375`*^9, 3.588676487172515*^9}, {
  3.588676519776572*^9, 3.5886765561246357`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"h", "[", "1", "]"}], "[", 
    RowBox[{
     RowBox[{"f1", "[", 
      RowBox[{
       RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
       RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ",", 
     RowBox[{"f2", "[", 
      RowBox[{
       RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
       RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"h", "[", "2", "]"}], "[", 
    RowBox[{
     RowBox[{"f1", "[", 
      RowBox[{
       RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
       RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ",", 
     RowBox[{"f2", "[", 
      RowBox[{
       RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
       RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"h", "[", "3", "]"}], "[", 
    RowBox[{
     RowBox[{"f1", "[", 
      RowBox[{
       RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
       RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ",", 
     RowBox[{"f2", "[", 
      RowBox[{
       RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
       RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "]"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5886766975700846`*^9, 3.5887665532391367`*^9, 
  3.588946934328949*^9, 3.589002606824015*^9, 3.5890027936106987`*^9, 
  3.5890062154304156`*^9, 3.5890912877396574`*^9, 3.589091322076621*^9, 
  3.58916989468147*^9, 3.6150207196982803`*^9, 3.6177014342313876`*^9}]
}, Closed]],

Cell["\<\
has the same arc length.  The tangent vector of the image curve is\
\>", "Text",
 CellChangeTimes->{{3.588676867469983*^9, 3.5886768700439873`*^9}, 
   3.5886770860263667`*^9, {3.5890026335835457`*^9, 3.5890026564708548`*^9}, 
   3.5995674706898913`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"F\[DoubledGamma]", "'"}], "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.5886768793416033`*^9, 3.5886769396825094`*^9}, {
  3.5890062311063128`*^9, 3.5890062466492014`*^9}, {3.617703363419731*^9, 
  3.6177033783065825`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"h", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"f1", "[", 
        RowBox[{
         RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
         RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ",", 
       RowBox[{"f2", "[", 
        RowBox[{
         RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
         RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["\[DoubledGamma]2", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f2", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[DoubledGamma]1", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f2", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["\[DoubledGamma]2", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f1", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[DoubledGamma]1", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f1", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}]}], ")"}], 
     " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"h", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"f1", "[", 
        RowBox[{
         RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
         RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ",", 
       RowBox[{"f2", "[", 
        RowBox[{
         RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
         RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "]"}]}]}], 
   ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"h", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"f1", "[", 
        RowBox[{
         RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
         RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ",", 
       RowBox[{"f2", "[", 
        RowBox[{
         RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
         RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["\[DoubledGamma]2", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f2", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[DoubledGamma]1", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f2", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["\[DoubledGamma]2", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f1", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[DoubledGamma]1", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f1", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}]}], ")"}], 
     " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"h", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"f1", "[", 
        RowBox[{
         RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
         RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ",", 
       RowBox[{"f2", "[", 
        RowBox[{
         RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
         RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "]"}]}]}], 
   ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"h", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"f1", "[", 
        RowBox[{
         RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
         RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ",", 
       RowBox[{"f2", "[", 
        RowBox[{
         RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
         RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["\[DoubledGamma]2", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f2", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[DoubledGamma]1", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f2", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["\[DoubledGamma]2", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f1", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[DoubledGamma]1", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f1", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}]}], ")"}], 
     " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"h", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"f1", "[", 
        RowBox[{
         RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
         RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ",", 
       RowBox[{"f2", "[", 
        RowBox[{
         RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
         RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "]"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5886788588134804`*^9, 3.588766564783157*^9, 
  3.588946906217699*^9, 3.588946941333361*^9, 3.588947055088761*^9, 
  3.589002758568694*^9, 3.589002798111956*^9, 3.589002830801826*^9, 
  3.5890028743443165`*^9, 3.5890051293872976`*^9, 3.589006248160288*^9, 
  3.5890913770967684`*^9, 3.6150207366087093`*^9, 3.617701451292363*^9, 
  3.617703381131744*^9, 3.617703431987653*^9, 3.6177036503041396`*^9, 
  3.6177039675552855`*^9, 3.617704011138778*^9, 3.617704089358252*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", " ", "-", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "sh", "]"}], "[", 
     RowBox[{
      RowBox[{"f1", "[", 
       RowBox[{
        RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
        RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ",", 
      RowBox[{"f2", "[", 
       RowBox[{
        RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
        RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"f1", "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ",", "t"}], 
       "]"}], ",", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"f2", "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ",", "t"}], 
       "]"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5886777739251747`*^9, 3.5886777838623924`*^9}, 
   3.588677815093647*^9, 3.58867788471657*^9, 3.588678039718442*^9, {
   3.5886784767844095`*^9, 3.5886784915264354`*^9}, 3.588678564362963*^9, 
   3.5886786037374325`*^9, {3.5886786817843695`*^9, 3.588678690676385*^9}, {
   3.588678745182881*^9, 3.5886787995021763`*^9}, {3.5886788985935507`*^9, 
   3.588678939902423*^9}, {3.588947001143866*^9, 3.5889470423591385`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5886789417120256`*^9, 3.588766662860529*^9, 3.588946977151024*^9, 
   3.588947059675169*^9, {3.589002816385001*^9, 3.58900283594812*^9}, 
   3.5890028774584947`*^9, 3.5890051294363003`*^9, 3.589006277692977*^9, 
   3.589091410188661*^9, 3.6150208584917235`*^9, 3.6177014742276754`*^9, 
   3.617703397340671*^9, 3.617703438852045*^9, 3.6177036559504623`*^9, 
   3.61770409509158*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%%", " ", "-", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "sh", "]"}], "[", 
     RowBox[{
      RowBox[{"f1", "[", 
       RowBox[{
        RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
        RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ",", 
      RowBox[{"f2", "[", 
       RowBox[{
        RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
        RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "]"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", "f", "]"}], "[", 
       RowBox[{
        RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
        RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ".", 
      RowBox[{
       RowBox[{"\[DoubledGamma]", "'"}], "[", "t", "]"}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{3.6177040770355473`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.617704100217873*^9}]
}, Closed]],

Cell["\<\
Thus the tangent vector of the image curve is obtained composing the \
differential d[sh] with the differential d[f] applied to the tangent vector \
of the preimage.   \
\>", "Text",
 CellChangeTimes->{{3.5889473808953333`*^9, 3.588947383016937*^9}, {
  3.589002927767372*^9, 3.5890030386547146`*^9}, {3.5890034142311964`*^9, 
  3.58900342374374*^9}, {3.5890036758001575`*^9, 3.5890036774552517`*^9}, {
  3.5891127612773533`*^9, 3.589112761698554*^9}}],

Cell[TextData[{
 "The last differential is the family of linear maps represented by the ",
 StyleBox["Jacobian matrix",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.5890036977964153`*^9, 3.589003791990803*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "f", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.5890038068086505`*^9, 3.5890038232325897`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["f1", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], 
      RowBox[{
       SuperscriptBox["f1", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]},
     {
      RowBox[{
       SuperscriptBox["f2", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], 
      RowBox[{
       SuperscriptBox["f2", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.588766757318695*^9, 3.589003825051694*^9, 
  3.589004241126492*^9, 3.589006352696267*^9, 3.61502094182707*^9, 
  3.6177015462487946`*^9}]
}, Closed]],

Cell["\<\
For any diffeomorphism the determinant of the Jacobian matrix isn\
\[CloseCurlyQuote]t zero\
\>", "Text",
 CellChangeTimes->{{3.5890040970872536`*^9, 3.5890041462870674`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Det", "[", 
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "]"}], " ", "\[NotEqual]", " ", 
  "0"}]], "Input",
 CellChangeTimes->{{3.589004155225579*^9, 3.589004184585258*^9}, 
   3.589004258554489*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["f2", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["f1", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["f1", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["f2", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}], "\[NotEqual]", "0"}]], "Output",
 CellChangeTimes->{3.5890041885824866`*^9, 3.5890042597605577`*^9, 
  3.589006357769557*^9, 3.615020959377101*^9, 3.6177015632887692`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "f", "]"}], "[", 
   RowBox[{
    RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
    RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ".", 
  RowBox[{
   RowBox[{"\[DoubledGamma]", "'"}], "[", "t", "]"}]}]], "Input",
 CellChangeTimes->{{3.5890046127287464`*^9, 3.5890047401850367`*^9}, {
  3.589007416467111*^9, 3.58900745281819*^9}, {3.617704166443661*^9, 
  3.617704174970149*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["\[DoubledGamma]2", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
       RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[DoubledGamma]1", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
       RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["\[DoubledGamma]2", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
       RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[DoubledGamma]1", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
       RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5890047437762423`*^9, 3.5890049863001137`*^9, 
  3.589006362401822*^9, 3.5890074556763535`*^9, 3.6150209693299184`*^9, 
  3.617701572634304*^9, 3.617704176202219*^9}]
}, Closed]],

Cell["\<\
This equation describes the coordinates of the image of a tangent vector by \
the coordinates of the tangent vector\
\>", "Text",
 CellChangeTimes->{{3.5890916949669495`*^9, 3.589091783910037*^9}, {
   3.5890918352069707`*^9, 3.5890918439904733`*^9}, {3.5890918758222938`*^9, 
   3.589091906262035*^9}, 3.5995675263050723`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[DoubledGamma]", "'"}], "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.617704195682334*^9, 3.6177042018896885`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[DoubledGamma]1", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], ",", 
   RowBox[{
    SuperscriptBox["\[DoubledGamma]2", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.589091929983392*^9, 3.615021000982374*^9, 
  3.617704203367773*^9}]
}, Closed]],

Cell["\<\
Since any tangent vector of a surface may serve as a tangent vector of a \
curve on the surface one concludes that the differential dF[u,v] is a linear \
isomorphism between the tangent spaces \
\>", "Text",
 CellChangeTimes->{{3.589091964014338*^9, 3.5890920320302286`*^9}, {
   3.5890920656381507`*^9, 3.5890920993430786`*^9}, {3.589092509390532*^9, 
   3.5890925559101925`*^9}, 3.589178529713417*^9, {3.589179168000925*^9, 
   3.5891791748813186`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dF", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "sh", "]"}], "[", 
    RowBox[{
     RowBox[{"f1", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"f2", "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ".", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"d", "[", "f", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.5890921347541037`*^9, 3.5890922464404917`*^9}, {
   3.5890922984424667`*^9, 3.5890923536746254`*^9}, {3.589092397100109*^9, 
   3.589092438922501*^9}, 3.589095740955264*^9, 3.589113927504202*^9, {
   3.589178440684325*^9, 3.58917847591634*^9}, {3.589178509732274*^9, 
   3.589178512492432*^9}, 3.589178572611871*^9, {3.589178676029786*^9, 
   3.589178692548731*^9}, {3.5891787467248297`*^9, 3.589178771180228*^9}}],

Cell["\<\
The image of a tangent vector of sf with the coordinates {x,y} is\
\>", "Text",
 CellChangeTimes->{{3.5891791270655837`*^9, 3.5891791611685343`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"imF", " ", "=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"dF", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ".", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5891788967184086`*^9, 3.5891789940119734`*^9}, 
   3.5891790666921306`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"y", " ", 
     RowBox[{
      SuperscriptBox["f2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"h", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"f1", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"f2", "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}], "+", 
    RowBox[{"x", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"h", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"f1", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"f2", "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"y", " ", 
        RowBox[{
         SuperscriptBox["f1", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"x", " ", 
        RowBox[{
         SuperscriptBox["f1", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"h", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"f1", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"f2", "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"y", " ", 
     RowBox[{
      SuperscriptBox["f2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"h", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"f1", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"f2", "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}], "+", 
    RowBox[{"x", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"h", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"f1", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"f2", "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"y", " ", 
        RowBox[{
         SuperscriptBox["f1", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"x", " ", 
        RowBox[{
         SuperscriptBox["f1", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"h", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"f1", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"f2", "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"y", " ", 
     RowBox[{
      SuperscriptBox["f2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"h", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"f1", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"f2", "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}], "+", 
    RowBox[{"x", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"h", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"f1", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"f2", "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"y", " ", 
        RowBox[{
         SuperscriptBox["f1", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"x", " ", 
        RowBox[{
         SuperscriptBox["f1", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"h", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"f1", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"f2", "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5891789951810403`*^9, 3.615021034709633*^9, 
  3.6177017065339622`*^9, 3.617704251884548*^9}]
}, Closed]],

Cell["The norm square of this vector is ", "Text",
 CellChangeTimes->{{3.5891792418171473`*^9, 3.589179256528989*^9}, 
   3.5995675589289384`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"imfdot", " ", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"imF", ".", "imF"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5890961486185813`*^9, 3.5890961630174046`*^9}, {
  3.589173102998705*^9, 3.5891731114071198`*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"h", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"f1", "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", 
        RowBox[{"f2", "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"y", " ", 
         RowBox[{
          SuperscriptBox["f2", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], "+", 
        RowBox[{"x", " ", 
         RowBox[{
          SuperscriptBox["f2", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"y", " ", 
         RowBox[{
          SuperscriptBox["f1", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], "+", 
        RowBox[{"x", " ", 
         RowBox[{
          SuperscriptBox["f1", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"h", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"f1", "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", 
        RowBox[{"f2", "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}]}], ")"}], "2"], "+", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"h", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"f1", "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", 
        RowBox[{"f2", "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"y", " ", 
         RowBox[{
          SuperscriptBox["f2", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], "+", 
        RowBox[{"x", " ", 
         RowBox[{
          SuperscriptBox["f2", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"y", " ", 
         RowBox[{
          SuperscriptBox["f1", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], "+", 
        RowBox[{"x", " ", 
         RowBox[{
          SuperscriptBox["f1", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"h", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"f1", "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", 
        RowBox[{"f2", "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}]}], ")"}], "2"], "+", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"h", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"f1", "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", 
        RowBox[{"f2", "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"y", " ", 
         RowBox[{
          SuperscriptBox["f2", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], "+", 
        RowBox[{"x", " ", 
         RowBox[{
          SuperscriptBox["f2", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"y", " ", 
         RowBox[{
          SuperscriptBox["f1", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], "+", 
        RowBox[{"x", " ", 
         RowBox[{
          SuperscriptBox["f1", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"h", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"f1", "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", 
        RowBox[{"f2", "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}]}], ")"}], "2"]}]], "Output",
 CellChangeTimes->{
  3.589096169258762*^9, {3.5891119529775333`*^9, 3.5891119563471394`*^9}, 
   3.5891121377286577`*^9, 3.589113143821225*^9, 3.5891132719598503`*^9, 
   3.58911357364878*^9, 3.5891139632750645`*^9, 3.589173115541127*^9, 
   3.6150210505904613`*^9, 3.6177017218958406`*^9, 3.617704259333974*^9}]
}, Closed]],

Cell["\<\
This is a symmetric, positive definite quadratic form on the tangent space of \
sf at the point sf[u,v], expressed as a  quadratic function of the \
coordinates x,y of the tangent vector; the coefficients of this form can be \
read off from the following equation:\
\>", "Text",
 CellChangeTimes->{{3.589179351104398*^9, 3.5891794335371127`*^9}, {
   3.589179471897307*^9, 3.5891794926004915`*^9}, {3.589179532632781*^9, 
   3.589179597400485*^9}, {3.589179633257536*^9, 3.589179648616415*^9}, {
   3.5891796791211596`*^9, 3.5891796974572086`*^9}, 3.589191183175168*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "-", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", "sh", "]"}], "[", 
       RowBox[{
        RowBox[{"f1", "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", 
        RowBox[{"f2", "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"d", "[", "f", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], ".", 
         RowBox[{"{", 
          RowBox[{"x", ",", "y"}], "}"}]}], ")"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"d", "[", "f", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], ".", 
         RowBox[{"{", 
          RowBox[{"x", ",", "y"}], "}"}]}], ")"}], "[", 
       RowBox[{"[", "j", "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "2"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.589006516431632*^9, 3.5890065543608017`*^9}, {
   3.58900660888992*^9, 3.5890066480421596`*^9}, {3.5890066985860505`*^9, 
   3.589006759490534*^9}, 3.589007352939478*^9, {3.589007550179759*^9, 
   3.5890075695968695`*^9}, {3.589007613876402*^9, 3.589007622562899*^9}, {
   3.5890076612551117`*^9, 3.589007699765315*^9}, {3.589007746557991*^9, 
   3.589007825304495*^9}, 3.5890079005778008`*^9, 3.5890079866817255`*^9, {
   3.5890081122659082`*^9, 3.5890081411845627`*^9}, {3.589111668230233*^9, 
   3.5891117338439484`*^9}, {3.5891117660736055`*^9, 
   3.5891117712528143`*^9}, {3.5891118153228917`*^9, 3.589111820658101*^9}, {
   3.589111873354994*^9, 3.589111932385497*^9}, {3.5891121139386163`*^9, 
   3.5891121239538336`*^9}, 3.6176259331745977`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5891131532904415`*^9, 3.589113276281058*^9, 
  3.589113581043193*^9, 3.589113970560277*^9, 3.6150211130997705`*^9, 
  3.6177018128020406`*^9, 3.6177042685004983`*^9}]
}, Closed]],

Cell["namely the coefficients are", "Text",
 CellChangeTimes->{{3.5891797362884293`*^9, 3.589179738016528*^9}, {
  3.5891807603129997`*^9, 3.589180767968438*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fg", "[", 
    RowBox[{"k_", ",", "l_"}], "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "[", "sh", "]"}], "[", 
      RowBox[{
       RowBox[{"f1", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"f2", "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "*", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", "k"}], "]"}], "]"}], "*", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"j", ",", "l"}], "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5891697933904924`*^9, 3.589169798179701*^9}, {
   3.589170043864532*^9, 3.589170095157422*^9}, {3.589170151333121*^9, 
   3.5891702382564735`*^9}, {3.5891702783641443`*^9, 3.589170311935403*^9}, {
   3.589170343884259*^9, 3.589170424786001*^9}, {3.589170462756468*^9, 
   3.5891704699168806`*^9}, {3.5891705109293523`*^9, 
   3.5891705886798887`*^9}, {3.5891710125170336`*^9, 3.589171030925066*^9}, {
   3.589171522232329*^9, 3.5891715882828445`*^9}, {3.58917227446565*^9, 
   3.589172283201665*^9}, {3.589172315946123*^9, 3.589172380982637*^9}, {
   3.5891724568767705`*^9, 3.589172569274968*^9}, {3.5891727105956163`*^9, 
   3.589172741904871*^9}, {3.589172824366616*^9, 3.589172834662634*^9}, 
   3.617626003982648*^9}],

Cell["Indeed:", "Text",
 CellChangeTimes->{{3.5891797646330504`*^9, 3.5891797678972373`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"imfdot", " ", "-", " ", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fg", "[", 
        RowBox[{"k", ",", "l"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "*", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y"}], "}"}], "[", 
       RowBox[{"[", "k", "]"}], "]"}], "*", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y"}], "}"}], "[", 
       RowBox[{"[", "l", "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", "2"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5891716389361334`*^9, 3.5891716916486263`*^9}, 
   3.589171868225336*^9, {3.589173186115651*^9, 3.589173267610194*^9}, {
   3.5891734713933525`*^9, 3.589173522998243*^9}, {3.5891735534026966`*^9, 
   3.589173565289917*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.589173526492649*^9, 3.589173571670328*^9, 
  3.615021162395858*^9, 3.6177021741887107`*^9, 3.617704282498299*^9}]
}, Closed]],

Cell["\<\
fg is the special case of the next definition with ff = sh, hh = f:\
\>", "Text",
 CellChangeTimes->{{3.589180411585054*^9, 3.589180488025426*^9}, {
  3.589180806744656*^9, 3.5891808121129627`*^9}, {3.589180947240692*^9, 
  3.5891809669288177`*^9}, {3.5891810706567507`*^9, 3.5891810736889243`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"pullbackF", "[", 
     RowBox[{"ff_", ",", "hh_"}], "]"}], "[", 
    RowBox[{"k_", ",", "l_"}], "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "[", "ff", "]"}], "[", 
      RowBox[{
       RowBox[{
        RowBox[{"hh", "[", 
         RowBox[{"u", ",", "v"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"hh", "[", 
         RowBox[{"u", ",", "v"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "*", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", "hh", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", "k"}], "]"}], "]"}], "*", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", "hh", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"j", ",", "l"}], "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5891697933904924`*^9, 3.589169798179701*^9}, {
   3.589170043864532*^9, 3.589170095157422*^9}, {3.589170151333121*^9, 
   3.5891702382564735`*^9}, {3.5891702783641443`*^9, 3.589170311935403*^9}, {
   3.589170343884259*^9, 3.589170424786001*^9}, {3.589170462756468*^9, 
   3.5891704699168806`*^9}, {3.5891705109293523`*^9, 
   3.5891705886798887`*^9}, {3.5891710125170336`*^9, 3.589171030925066*^9}, {
   3.589171522232329*^9, 3.5891715882828445`*^9}, {3.58917227446565*^9, 
   3.589172283201665*^9}, {3.589172315946123*^9, 3.589172380982637*^9}, {
   3.5891724568767705`*^9, 3.589172569274968*^9}, {3.5891727105956163`*^9, 
   3.589172741904871*^9}, {3.589172824366616*^9, 3.589172834662634*^9}, {
   3.5891770502016425`*^9, 3.5891770874233074`*^9}, {3.5891771698850527`*^9, 
   3.589177181397873*^9}, {3.589177214532331*^9, 3.589177359612586*^9}, {
   3.5891774076606703`*^9, 3.5891774078322706`*^9}, 3.617626011647086*^9, {
   3.6177024125383434`*^9, 3.617702414332446*^9}}],

Cell["Indeed:", "Text",
 CellChangeTimes->{{3.589180499913106*^9, 3.5891805025442567`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"pullbackF", "[", 
        RowBox[{"sh", ",", "f"}], "]"}], "[", 
       RowBox[{"i", ",", "j"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "-", 
     RowBox[{
      RowBox[{"fg", "[", 
       RowBox[{"i", ",", "j"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5891773678650007`*^9, 3.5891773789098196`*^9}, {
   3.5891774220126953`*^9, 3.58917745896916*^9}, {3.5891775033824387`*^9, 
   3.5891776673075266`*^9}, 3.6148618493635216`*^9, 3.614863501453223*^9, 
   3.617702399920622*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.5891775527877254`*^9, 3.589177610164626*^9}, 
   3.589177669850331*^9, 3.615021240224394*^9, 3.617702434291588*^9, 
   3.617704303377493*^9}]
}, Closed]],

Cell[TextData[{
 "Summarizing we obtain\n",
 StyleBox["Proposition",
  FontColor->RGBColor[0, 0, 1]],
 ". Let sf, sh be two surfaces in the Euclidean space and F[sf[u.v]] = \
sh[f[u,v]] a diffeomorphsm as defined above. Then the differential dF[u,v] is \
a family of linear isomorphisms between the tangent spaces of the surfaces "
}], "Text",
 CellChangeTimes->{{3.5891810884887705`*^9, 3.589181246160789*^9}, {
   3.5891813391141057`*^9, 3.589181539624574*^9}, {3.5891816073614483`*^9, 
   3.5891816585633774`*^9}, 3.589182385073931*^9, {3.5891909517719326`*^9, 
   3.589190958603323*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tang", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "[", 
   RowBox[{"x", ",", "y"}], "]"}], " ", "\[RightTeeArrow]", " ", 
  RowBox[{
   RowBox[{"dF", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ".", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5891816839978323`*^9, 3.589181696219531*^9}, {
  3.5891817267402763`*^9, 3.589181730315481*^9}, {3.58918179322808*^9, 
  3.5891818181395044`*^9}, {3.5891818644271517`*^9, 3.5891818810271015`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dF", "[", 
     RowBox[{"u", ",", "v"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}]}], "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "sh", "]"}], "[", 
     RowBox[{
      RowBox[{"f1", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
      RowBox[{"f2", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ".", 
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}]}], ")"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5891819634118137`*^9, 3.5891820500607696`*^9}, {
  3.5891821021567492`*^9, 3.5891822003973684`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.5891821879716578`*^9, 3.589182201569435*^9}, 
   3.6150213150889254`*^9, 3.6177024847634745`*^9, 3.6177043375294466`*^9}]
}, Closed]],

Cell[TextData[{
 "where the Jacobian matrix d[f][u,v] of f is invertible.  The scalar product \
of two image vectors under the map dF[u,v] can be calculated  evaluating the ",
 StyleBox["pull back of the first fundamental form",
  FontColor->RGBColor[0, 0, 1]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"fund1", "[", "sh", "]"}], " ", "to", " ", "the", " ", "surface", 
    " ", "sf"}], TraditionalForm]]],
 ", namely pullback ",
 Cell[BoxData[
  FormBox[
   RowBox[{"fund1", "[", 
    RowBox[{"sh", ",", "f"}], "]"}], TraditionalForm]]],
 ", which is a field of symmetric, positive definite bilinear forms on the \
preimage surface sf. The map F is an isometry iff this pullback coincides \
with the first fundamental form of sf:"
}], "Text",
 CellChangeTimes->{{3.5891822714574327`*^9, 3.58918234099341*^9}, 
   3.5891823920413294`*^9, {3.589182424977214*^9, 3.5891825574487906`*^9}, {
   3.5891826145780582`*^9, 3.5891828892247667`*^9}, {3.589182955201541*^9, 
   3.5891830094166417`*^9}, 3.5891911831031637`*^9, {3.590495710453009*^9, 
   3.590495710453009*^9}, 3.5995676203694525`*^9, 3.6141620282522945`*^9, 
   3.6176274924947863`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"pullbackF", "[", 
     RowBox[{"sh", ",", "f"}], "]"}], "[", 
    RowBox[{"i", ",", "j"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"rgT", "[", "sf", "]"}], "[", 
     RowBox[{"i", ",", "j"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "."}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.589183036155171*^9, 3.5891831006118574`*^9}, 
   3.6176260280920267`*^9, 3.6177023999296227`*^9}],

Cell[TextData[{
 StyleBox["Proof.",
  FontColor->RGBColor[0, 0, 1]],
 " The stated properties of the pull back form follow immediately from the \
corresponding  properties of the first fundamental form. If the corresponding \
quadratic form of the pull back form vanishes for a tangent vector {x,y}, \
then dF[u,v].{x,y] is the null vector; then {x,y} = {0,0} since dF[u,v] is a \
linear isomorphism. If the stated equation is true, the scalar products of \
the image vectors equal the scalar products of the preimage; thus, if t is \
the arc length parameter of the curve \[DoubledGamma][t] characterized by |\
\[DoubledGamma]\[CloseCurlyQuote][t]| == 1, then also F\[DoubledGamma][t] has \
this property: "
}], "Text",
 CellChangeTimes->{{3.589191329142517*^9, 3.589191399947567*^9}, {
  3.5891914342835307`*^9, 3.589191466123352*^9}, {3.5891915146831293`*^9, 
  3.5891915159472017`*^9}, {3.5891916046032724`*^9, 3.589191819059539*^9}, {
  3.5891918549235897`*^9, 3.589191867915333*^9}, {3.5891921228519144`*^9, 
  3.5891922318111467`*^9}, {3.5891923724761925`*^9, 3.589192558955858*^9}, {
  3.5995669673581023`*^9, 3.59956699126147*^9}, {3.5995676328671675`*^9, 
  3.5995676404746027`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"F\[DoubledGamma]", "'"}], "[", "t", "]"}], ".", 
  RowBox[{
   RowBox[{"F\[DoubledGamma]", "'"}], "[", "t", "]"}]}]], "Input",
 CellChangeTimes->{{3.61770298558812*^9, 3.6177030001539536`*^9}, {
  3.6177045155556293`*^9, 3.617704574818019*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"h", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"f1", "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ",", 
        RowBox[{"f2", "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["\[DoubledGamma]2", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f2", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
           RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[DoubledGamma]1", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f2", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
           RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], 
     "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["\[DoubledGamma]2", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f1", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
           RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[DoubledGamma]1", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f1", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
           RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}]}], ")"}], 
      " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"h", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"f1", "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ",", 
        RowBox[{"f2", "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "]"}]}]}], 
    ")"}], "2"], "+", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"h", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"f1", "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ",", 
        RowBox[{"f2", "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["\[DoubledGamma]2", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f2", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
           RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[DoubledGamma]1", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f2", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
           RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], 
     "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["\[DoubledGamma]2", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f1", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
           RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[DoubledGamma]1", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f1", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
           RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}]}], ")"}], 
      " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"h", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"f1", "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ",", 
        RowBox[{"f2", "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "]"}]}]}], 
    ")"}], "2"], "+", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"h", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"f1", "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ",", 
        RowBox[{"f2", "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["\[DoubledGamma]2", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f2", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
           RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[DoubledGamma]1", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f2", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
           RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], 
     "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["\[DoubledGamma]2", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f1", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
           RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[DoubledGamma]1", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f1", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
           RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}]}], ")"}], 
      " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"h", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"f1", "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], ",", 
        RowBox[{"f2", "[", 
         RowBox[{
          RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}]}], "]"}]}]}], 
    ")"}], "2"]}]], "Output",
 CellChangeTimes->{
  3.6177029511671515`*^9, 3.6177030019820576`*^9, {3.61770455105866*^9, 
   3.617704576270102*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F\[DoubledGamma]", "'"}], "[", "t", "]"}], ".", 
    RowBox[{
     RowBox[{"F\[DoubledGamma]", "'"}], "[", "t", "]"}]}], "\[Equal]", "  ", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"pullbackF", "[", 
         RowBox[{"sh", ",", "f"}], "]"}], "[", 
        RowBox[{"i", ",", "j"}], "]"}], "[", 
       RowBox[{
        RowBox[{"\[DoubledGamma]1", "[", "t", "]"}], ",", 
        RowBox[{"\[DoubledGamma]2", "[", "t", "]"}]}], "]"}], " ", "*", 
      RowBox[{
       RowBox[{
        RowBox[{"\[DoubledGamma]", "'"}], "[", "t", "]"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}], "*", 
      RowBox[{
       RowBox[{
        RowBox[{"\[DoubledGamma]", "'"}], "[", "t", "]"}], "[", 
       RowBox[{"[", "j", "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "2"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5891931354458313`*^9, 3.589193142029208*^9}, {
   3.5891932790540457`*^9, 3.58919333071*^9}, {3.5891936984700346`*^9, 
   3.5891937167750816`*^9}, {3.5891937699181213`*^9, 
   3.5891937716942225`*^9}, {3.5891938256453085`*^9, 3.589193873032019*^9}, 
   3.589193903920786*^9, 3.589193971983679*^9, {3.589194039048515*^9, 
   3.589194109337535*^9}, {3.5891941465136614`*^9, 3.589194156657242*^9}, 
   3.589194220249879*^9, 3.589194666835422*^9, 3.617702399934623*^9, 
   3.617704600998516*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.589192930133088*^9, 3.589193142966262*^9, {3.5891933049945292`*^9, 
   3.5891933319860735`*^9}, 3.589194223160045*^9, 3.6150214388907433`*^9, 
   3.617702657315344*^9, 3.617704603403654*^9}]
}, Closed]],

Cell[TextData[{
 "and this equals 1 since the pull back form of ",
 Cell[BoxData[
  FormBox["fund1", TraditionalForm]]],
 "[sh] coincides with  ",
 Cell[BoxData[
  FormBox["fund1", TraditionalForm]]],
 "[sf]. Conversely, if the arc length of curves on sf is  preserved under F, \
then at any point sf[u,v] the two symmetric,positive definite bilinear forms \
considered above, for shortness denoted by a[vv,vw], b[vv,vw], have the \
property"
}], "Text",
 CellChangeTimes->{{3.5891943126041613`*^9, 3.5891943570277023`*^9}, {
   3.589194390431613*^9, 3.589194482115857*^9}, 3.5891945521568627`*^9, {
   3.589194711692988*^9, 3.5891947172033033`*^9}, {3.5891949257642317`*^9, 
   3.589195037187605*^9}, {3.5891953686845655`*^9, 3.589195506291436*^9}, {
   3.589195639188038*^9, 3.589195646699467*^9}, {3.590495710484209*^9, 
   3.5904957104998093`*^9}, 3.5995670930302906`*^9, 3.59956764813004*^9}],

Cell["If a[vv, vv] == 1  then  b[vv, vv] == 1, ", "Text",
 CellChangeTimes->{{3.5891950703325005`*^9, 3.5891951412925596`*^9}, {
  3.5891952281335263`*^9, 3.589195290510094*^9}, {3.5891955195901966`*^9, 
  3.5891956239491663`*^9}, {3.589195666484599*^9, 3.589195686715756*^9}, {
  3.589195739051749*^9, 3.589195741803907*^9}}],

Cell["\<\
then it follows for any vector vv:   a[vv, vv] == b[vv, vv].  Applying\
\>", "Text",
 CellChangeTimes->{{3.5891957543636255`*^9, 3.5891958378053975`*^9}, {
  3.5891958964127502`*^9, 3.5891959548750935`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{
     RowBox[{"vv", "+", "vw"}], ",", " ", 
     RowBox[{"vv", "+", "vw"}]}], "]"}], " ", "-", " ", 
   RowBox[{"a", "[", 
    RowBox[{
     RowBox[{"vv", "-", "vw"}], ",", " ", 
     RowBox[{"vv", "-", "vw"}]}], "]"}]}], "  ", "\[Equal]", " ", 
  RowBox[{"4", 
   RowBox[{"a", "[", 
    RowBox[{"vv", ",", "vw"}], "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5891959953594093`*^9, 3.5891960269982185`*^9}, {
   3.589196058880042*^9, 3.589196130399133*^9}, 3.589196169014342*^9}],

Cell["\<\
and the same equation for b one concludes a[vv,vw] == b[vv,vw].\[FilledSquare]

A detailed description of an isometry is contained in subsection 2.1.3 below.\
\>", "Text",
 CellChangeTimes->{{3.589196214305932*^9, 3.5891962400524054`*^9}, {
  3.58919627719753*^9, 3.589196308979347*^9}, {3.5891963441073565`*^9, 
  3.589196358388173*^9}, {3.5896219720007825`*^9, 3.5896220330904894`*^9}, {
  3.5896220670205493`*^9, 3.589622087893386*^9}, {3.617704686345398*^9, 
  3.6177047059625196`*^9}}],

Cell[TextData[{
 "The equation defining F, see cell ",
 ButtonBox["ptr",
  BaseStyle->"Hyperlink",
  ButtonData->"ptr"],
 ", can also be interpreted in the following way:"
}], "Text",
 CellChangeTimes->{{3.5891966887550693`*^9, 3.589196765419454*^9}, {
  3.5891968196755576`*^9, 3.5891968461080694`*^9}, {3.5891970194999866`*^9, 
  3.589197069612853*^9}, {3.589197128115199*^9, 3.589197142484021*^9}, {
  3.589197185323471*^9, 3.5891972106999226`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fsh", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
  RowBox[{"sh", "[", 
   RowBox[{
    RowBox[{"f1", "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"f2", "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.589197328701672*^9, 3.589197346565694*^9}, 
   3.5891977056542325`*^9}],

Cell["\<\
is the same surface like sh, only with another parameter representation \
defined by the parameter transformation f\
\>", "Text",
 CellChangeTimes->{{3.589197261025801*^9, 3.58919729754789*^9}, {
  3.5891973541241264`*^9, 3.589197415771652*^9}, {3.5891977599153357`*^9, 
  3.589197762843504*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sh", "[", 
   RowBox[{"uu", ",", "vv"}], "]"}], " ", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"uu", " ", "->", " ", 
     RowBox[{"f1", "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], ",", " ", 
    RowBox[{"vv", " ", "->", " ", 
     RowBox[{"f2", "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5891974245691557`*^9, 3.589197425132188*^9}, {
  3.5891974678286295`*^9, 3.589197518451525*^9}, {3.5891975508463783`*^9, 
  3.5891976242305756`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"h", "[", "1", "]"}], "[", 
    RowBox[{
     RowBox[{"f1", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"f2", "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"h", "[", "2", "]"}], "[", 
    RowBox[{
     RowBox[{"f1", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"f2", "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"h", "[", "3", "]"}], "[", 
    RowBox[{
     RowBox[{"f1", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"f2", "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.589197520267629*^9, {3.5891976037774057`*^9, 3.5891976255036483`*^9}, 
   3.6177047655419273`*^9}]
}, Closed]],

Cell["\<\
Then the diffeomorphism F: sf \[LongRightArrow]fsh is a map defined by \
equality of the parameters:\
\>", "Text",
 CellChangeTimes->{{3.589197826723157*^9, 3.589197929196018*^9}, 
   3.615021585437401*^9}],

Cell["\<\
F[sf[u, v]] = fsh[u, v]. Now, after the parameter transformation, the F \
defining map ff is the identity : \
\>", "Text",
 CellChangeTimes->{{3.5891979348993444`*^9, 3.5891979721904774`*^9}, {
   3.5891980628066607`*^9, 3.5891981233641243`*^9}, 3.5891987777965555`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ff1", "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", "u"}], ";", "  ", 
  RowBox[{
   RowBox[{"ff2", "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", "v"}], ";", " ", 
  RowBox[{
   RowBox[{"ff", "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ff1", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
     RowBox[{"ff2", "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.589198193981163*^9, 3.5891982524295063`*^9}, {
  3.589198630423126*^9, 3.589198633702314*^9}, {3.5891986683262944`*^9, 
  3.5891987411504593`*^9}, {3.589198814982682*^9, 3.589198826606347*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "ff", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.5891982672443533`*^9, 3.5891982842843285`*^9}, 
   3.5891987995508003`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0"},
     {"0", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.5891982904646816`*^9, 3.589198330384965*^9, 
  3.5891988444253664`*^9, 3.6150216259662714`*^9, 3.6177048132656574`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"pullbackF", "[", 
         RowBox[{"fsh", ",", "ff"}], "]"}], "[", 
        RowBox[{"k", ",", "l"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", "-", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"k", ",", "l"}], "]"}], "[", "fsh", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"l", ",", "2"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5891984270894966`*^9, 3.5891984817756243`*^9}, {
   3.5891988527688437`*^9, 3.5891989219448004`*^9}, {3.589198952870569*^9, 
   3.589199135833034*^9}, 3.614861849379122*^9, 3.6148635014688234`*^9, 
   3.6176260299181314`*^9, 3.617702399939623*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.589199136739086*^9, 3.6150216337818856`*^9, 
  3.6177048463835516`*^9}]
}, Closed]],

Cell[TextData[{
 "We conclude:\n",
 StyleBox["Corollary",
  FontColor->RGBColor[0, 0, 1]],
 ". A map F[sf[u,v]] := sh[u,v]    defined by the equality of the parameters \
u,v is an isometry iff the coefficients of the first fundamental forms \
coincide:"
}], "Text",
 CellChangeTimes->{{3.5892004162202682`*^9, 3.589200431100119*^9}, {
  3.5892004646920404`*^9, 3.5892005485078344`*^9}, {3.5892006375559278`*^9, 
  3.589200690859977*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"rgT", "[", 
     RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"rgT", "[", 
      RowBox[{"i", ",", "j"}], "]"}], "[", "sh", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "."}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5892007019866133`*^9, 3.58920071259722*^9}, {
  3.589200746462157*^9, 3.589200819790351*^9}, {3.617626032620286*^9, 
  3.617626033843356*^9}}],

Cell["\<\
A concrete example for such an isometry is treated in subsection 2.1.4 below.\
\>", "Text",
 CellChangeTimes->{{3.5892012961075945`*^9, 3.589201446532199*^9}, {
   3.589201495700011*^9, 3.589201526347764*^9}, {3.589201570236274*^9, 
   3.5892016393642282`*^9}, {3.589201894731834*^9, 3.589201916108057*^9}, {
   3.5892020651395807`*^9, 3.5892022501801643`*^9}, {3.5892022883003445`*^9, 
   3.589202611939856*^9}, {3.58920274173628*^9, 3.5892027480046387`*^9}, {
   3.589202816884578*^9, 3.589202818035644*^9}, {3.589622502963315*^9, 
   3.589622615283512*^9}, 3.5995677538300858`*^9, 3.599567946702118*^9, 
   3.6150330015639343`*^9}],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "f", ",", "F", ",", " ", "F\[DoubledGamma]", ",", "\[DoubledGamma]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6150330185849085`*^9, 3.615033063812495*^9}}],

Cell[TextData[{
 "The compositions of isometries between surfaces is an isometry again. Thus \
the class of all smooth regular surfaces form a category with respect to the \
isometries. The ",
 StyleBox["metric properties",
  FontColor->RGBColor[0, 0, 1]],
 " of the surfaces are those being  invariant under isometries; they form the \
content of the ",
 StyleBox["inner geometry",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface. The inner geometry consists of all properties of the \
surface which can be described by measurements on the surface not using its \
embedding into the space.  If one cuts a circular cylinder along a generating \
line  one gets a surface which can be rolled out into a stripe of the plane. \
This rolling out process is a continuous family of surfaces which are all \
isometric to the stripe: The arc lengths of curves don't change  under. this \
deformation. Thus",
 StyleBox[" locally",
  FontColor->RGBColor[0, 0, 1]],
 " the geometry of the cylinder  is plane geometry; ",
 StyleBox["globally",
  FontColor->RGBColor[0, 0, 1]],
 ", of course, this isn't the case: on the (uncut) cylinder there exist \
closed curves which can't be contracted to a point."
}], "Text",
 CellChangeTimes->{{3.5892012961075945`*^9, 3.589201446532199*^9}, {
   3.589201495700011*^9, 3.589201526347764*^9}, {3.589201570236274*^9, 
   3.5892016393642282`*^9}, {3.589201894731834*^9, 3.589201916108057*^9}, {
   3.5892020651395807`*^9, 3.5892022501801643`*^9}, {3.5892022883003445`*^9, 
   3.589202611939856*^9}, {3.58920274173628*^9, 3.5892027480046387`*^9}, {
   3.589202816884578*^9, 3.589202818035644*^9}, {3.589622502963315*^9, 
   3.589622615283512*^9}, 3.5995677538300858`*^9, 3.599567946702118*^9, 
   3.6150330015639343`*^9, {3.6150330799094152`*^9, 3.615033082069539*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2.5. The Adapted Moving Frame", "Subsubsection",
 CellChangeTimes->{{3.586059663992068*^9, 3.586059674943287*^9}, {
   3.5860750543689933`*^9, 3.58607505605709*^9}, {3.5866611656056275`*^9, 
   3.586661191821127*^9}, {3.5872724573591394`*^9, 3.5872724609903474`*^9}, 
   3.5886618229136314`*^9, 3.599568052238154*^9, 3.5995684564302726`*^9, 
   3.615021859217881*^9, 3.61503663665985*^9, {3.61762772421404*^9, 
   3.6176277264301662`*^9}, 3.617627765918425*^9, 3.617705071457425*^9, 
   3.61770616075391*^9}],

Cell[TextData[{
 "The following construction joins the point sf[u,v] of the surface with its \
orthonormal moving frame to the ",
 StyleBox[" adapted moving frame",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface:"
}], "Text",
 CellChangeTimes->{{3.5995682124053154`*^9, 3.599568327117876*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"fr", "[", "0", "]"}], "[", "f_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
  RowBox[{"Prepend", "[", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", "1"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5860610379176807`*^9, 3.5860610410532866`*^9}, {
  3.586061137071455*^9, 3.5860612128251877`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fr", "[", "0", "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5860612266468124`*^9, 3.5860612409208374`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{
    RowBox[{"f", "[", "1", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "2", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "3", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6150301771223173`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"fr", "[", "i_Integer", "]"}], "[", "f_", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"Prepend", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "i", "]"}], "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "0"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"i", ">", "0"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{"i", "<", "4"}], ")"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.586061255272863*^9, 3.5860614152199435`*^9}, 
   3.6148618493947215`*^9, 3.614917824961419*^9, 3.6149182629633884`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fr", "::", "usage"}], " ", "=", 
   "\"\<fr[i][f][u,v], i = 0,1,2,3, is the i-th column of the matrix \
frame[f][u,v]. In particular fr[o] represents the point f[u,v] and fr[i] the \
i-th vector of the adapted orthonormal frame of the surface.\>\""}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6150305135993085`*^9, 3.6150306235171013`*^9}, 
   3.6150306611755676`*^9, {3.615030842853463*^9, 3.6150309915679693`*^9}, 
   3.615031036574544*^9, {3.6150310837622423`*^9, 3.6150310923837357`*^9}, 
   3.615031205239191*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fr", "[", "1", "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5860614258279624`*^9, 3.5860614510376062`*^9}, {
  3.617705834811267*^9, 3.617705859882701*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"f", "[", "1", "]"}], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}], 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"]}]]], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"f", "[", "2", "]"}], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}], 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"]}]]], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"f", "[", "3", "]"}], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}], 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"]}]]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6150302096327744`*^9, {3.617705820659458*^9, 3.6177058611437736`*^9}}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"frame", "[", "f_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", 
  RowBox[{"Transpose", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fr", "[", "j", "]"}], "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", "3"}], "}"}]}], "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.586059709294547*^9, 3.58605971650176*^9}, {
   3.5860602525343018`*^9, 3.5860604795147*^9}, {3.5860605311039906`*^9, 
   3.5860605475620193`*^9}, {3.5860605822876806`*^9, 3.586060606249323*^9}, {
   3.586060813090086*^9, 3.586060828939714*^9}, {3.586061476996052*^9, 
   3.586061557772994*^9}, {3.6148618494103217`*^9, 3.614861849425922*^9}, 
   3.6148635014844236`*^9, {3.6149178249770193`*^9, 3.6149178249926195`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"frame", "::", "usage"}], " ", "=", " ", 
   "\"\<frame[f][u,v] is the element of the Euclidean group transforming the \
standard orthonormal frame {stb[i]}, i= 1,2,3,and the origin [0,0,0} into the \
adapted moving frame of the surface f[u.v].\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.6150311612106724`*^9, 3.6150311927404757`*^9}, {
   3.615031307772055*^9, 3.615031452198316*^9}, {3.6150316663265634`*^9, 
   3.6150318326870785`*^9}, 3.615031877439638*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"frame", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.586060615328539*^9, 3.586060640460183*^9}, 
   3.6148618494415216`*^9, 3.6149178250082197`*^9, 3.6177059560121994`*^9, 
   3.6177060146115513`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", "0", "0"},
     {
      RowBox[{
       RowBox[{"f", "[", "1", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}]]], 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], 
         RowBox[{
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "-", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "-", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]]}], "-", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{"3", " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "4"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "4"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{"3", " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "4"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "4"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]]}], 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}]}], 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]]},
     {
      RowBox[{
       RowBox[{"f", "[", "2", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}]]], 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "4"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "4"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{"3", " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{"3", " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{"3", " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "4"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "4"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]]}], 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}]}], 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]]},
     {
      RowBox[{
       RowBox[{"f", "[", "3", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}]]], 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "4"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "4"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "4"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "4"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{"3", " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{"3", " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{"3", " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{"3", " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "+", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "3"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]}]]}], 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}]}], 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]]]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6177058814069324`*^9, 3.617705959762414*^9, 
  3.617706018310763*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Det", "[", "%", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.586061756330143*^9, 3.5860617723357706`*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.6150302881633124`*^9, 3.617706051242646*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"frame", "[", 
    RowBox[{"circularcone", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5860619918437567`*^9, 3.586062006351782*^9}, {
   3.5862321451928434`*^9, 3.586232152712056*^9}, 3.614861849457122*^9, 
   3.6149178250082197`*^9, {3.6149183005126543`*^9, 3.6149183068774652`*^9}, {
   3.614918369090375*^9, 3.6149183730995817`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"v", " ", 
      RowBox[{"Cos", "[", "u", "]"}]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"v", " ", 
        RowBox[{"Sin", "[", "u", "]"}]}], 
       SqrtBox[
        SuperscriptBox["v", "2"]]]}], ",", 
     FractionBox[
      RowBox[{"Cos", "[", "u", "]"}], 
      SqrtBox["2"]], ",", 
     FractionBox[
      RowBox[{"v", " ", 
       RowBox[{"Cos", "[", "u", "]"}]}], 
      RowBox[{
       SqrtBox["2"], " ", 
       SqrtBox[
        SuperscriptBox["v", "2"]]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"v", " ", 
      RowBox[{"Sin", "[", "u", "]"}]}], ",", 
     FractionBox[
      RowBox[{"v", " ", 
       RowBox[{"Cos", "[", "u", "]"}]}], 
      SqrtBox[
       SuperscriptBox["v", "2"]]], ",", 
     FractionBox[
      RowBox[{"Sin", "[", "u", "]"}], 
      SqrtBox["2"]], ",", 
     FractionBox[
      RowBox[{"v", " ", 
       RowBox[{"Sin", "[", "u", "]"}]}], 
      RowBox[{
       SqrtBox["2"], " ", 
       SqrtBox[
        SuperscriptBox["v", "2"]]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     FractionBox["1", 
      SqrtBox["2"]], ",", 
     RowBox[{"-", 
      FractionBox["v", 
       RowBox[{
        SqrtBox["2"], " ", 
        SqrtBox[
         SuperscriptBox["v", "2"]]}]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6150302952301245`*^9, 3.6177060589120855`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.586062026491417*^9, 3.586062042746646*^9}, 
   3.586232171447689*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", "0", "0"},
     {
      RowBox[{"v", " ", 
       RowBox[{"Cos", "[", "u", "]"}]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"v", " ", 
         RowBox[{"Sin", "[", "u", "]"}]}], 
        SqrtBox[
         SuperscriptBox["v", "2"]]]}], 
      FractionBox[
       RowBox[{"Cos", "[", "u", "]"}], 
       SqrtBox["2"]], 
      FractionBox[
       RowBox[{"v", " ", 
        RowBox[{"Cos", "[", "u", "]"}]}], 
       RowBox[{
        SqrtBox["2"], " ", 
        SqrtBox[
         SuperscriptBox["v", "2"]]}]]},
     {
      RowBox[{"v", " ", 
       RowBox[{"Sin", "[", "u", "]"}]}], 
      FractionBox[
       RowBox[{"v", " ", 
        RowBox[{"Cos", "[", "u", "]"}]}], 
       SqrtBox[
        SuperscriptBox["v", "2"]]], 
      FractionBox[
       RowBox[{"Sin", "[", "u", "]"}], 
       SqrtBox["2"]], 
      FractionBox[
       RowBox[{"v", " ", 
        RowBox[{"Sin", "[", "u", "]"}]}], 
       RowBox[{
        SqrtBox["2"], " ", 
        SqrtBox[
         SuperscriptBox["v", "2"]]}]]},
     {"v", "0", 
      FractionBox["1", 
       SqrtBox["2"]], 
      RowBox[{"-", 
       FractionBox["v", 
        RowBox[{
         SqrtBox["2"], " ", 
         SqrtBox[
          SuperscriptBox["v", "2"]]}]]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6150303154633603`*^9, 3.617706063908371*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Det", "[", "%", "]"}], ",", 
   RowBox[{"u", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.586062079671911*^9, 3.586062115817174*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.615030341484206*^9, 3.617706085189588*^9}]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.3. Differential Forms", "Subsection",
 CellChangeTimes->{{3.5725953757423115`*^9, 3.572595385461128*^9}, {
   3.58666439764649*^9, 3.5866644089011335`*^9}, {3.5872724756311846`*^9, 
   3.58727247921439*^9}, 3.599568542111173*^9, 3.599804993627187*^9, 
   3.6176277747189283`*^9, 3.617632840802114*^9}],

Cell[TextData[{
 "In the following we will use Cartan\[CloseCurlyQuote]s method of moving \
frames. We apply the calculus of differential forms on the parameter manifold \
U in an elementary form in dimension 2 avoiding tensor algebra, as it is \
presented in the Introduction of W. Blaschke and H. Reichardt [",
 ButtonBox["B-R",
  BaseStyle->"Hyperlink",
  ButtonData->"B-R"],
 "]. "
}], "Text",
 CellChangeTimes->{{3.5866617389574213`*^9, 3.586661854765045*^9}, {
   3.5866619107972503`*^9, 3.5866619417650213`*^9}, {3.586662052197338*^9, 
   3.5866621045253305`*^9}, 3.5866624506461277`*^9, {3.586663494477832*^9, 
   3.586663633164764*^9}, 3.586664441966025*^9, 3.5867576531566353`*^9, {
   3.5998034928760347`*^9, 3.5998035298325*^9}, {3.5998035685049677`*^9, 
   3.599803644882702*^9}}],

Cell[CellGroupData[{

Cell["1.3.1. The Differential of a 0-Form (= Function)", "Subsubsection",
 CellChangeTimes->{{3.572611276502635*^9, 3.572611281323043*^9}, {
   3.586174321969679*^9, 3.5861743363685026`*^9}, {3.5866646931983943`*^9, 
   3.586664749405609*^9}, {3.587272484902715*^9, 3.5872724953183107`*^9}, 
   3.6092316085437975`*^9, 3.609308006813593*^9, 3.6177061733856325`*^9, 
   3.6177065148971663`*^9}],

Cell["\<\
The differential of a function has been defined in section 1.1; it is a \
differential form, more exactly, the coordinate tuple of a covector field. \
The evaluation of the forms for tangent vectors or tangent vector fields is \
obtained by the Dot product with the coordinate vectors\
\>", "Text",
 CellChangeTimes->{{3.586174802937189*^9, 3.586174919432852*^9}, 
   3.5862322201509748`*^9, {3.586609483759947*^9, 3.58660954266565*^9}, {
   3.59021230392822*^9, 3.5902123231630535`*^9}, 3.595484014179422*^9, {
   3.5998037540204935`*^9, 3.599803787295352*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "h", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], ".", 
  RowBox[{"{", 
   RowBox[{"1", ",", "1"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.590212361710721*^9, 3.590212380820755*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["h", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "+", 
  RowBox[{
   SuperscriptBox["h", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"1", ",", "0"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Output",
 CellChangeTimes->{3.5902123826147575`*^9, 3.61503202222892*^9, 
  3.6175445666942196`*^9, 3.617706234813146*^9}]
}, Closed]],

Cell["\<\
Aiming  to write the tangent vector as an argument, we define\
\>", "Text",
 CellChangeTimes->{{3.586672120886234*^9, 3.5866721226773367`*^9}, {
  3.5902124263728347`*^9, 3.590212459101692*^9}, {3.5998038717695007`*^9, 
  3.5998038774791107`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "h", "]"}], ";", 
  RowBox[{"Unprotect", "[", "d", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"h_", ",", "u___"}], "]"}], "[", "l_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"args", " ", "=", 
        RowBox[{"{", "u", "}"}]}], ",", "n"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"n", "=", 
       RowBox[{"Length", "[", "args", "]"}]}], ";", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"Not", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Head", "[", "l", "]"}], "===", "List"}], ")"}], "&&", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Length", "[", "l", "]"}], " ", "\[Equal]", " ", "n"}], 
           ")"}]}], "]"}], ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<Argument \>\"", ",", " ", "l", ",", " ", 
           "\"\< incorrect!\>\""}], "]"}], ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"d", "[", "h", "]"}], "[", "u", "]"}], ".", "l"}]}]}], 
    "]"}]}], ";", 
  RowBox[{"Protect", "[", "d", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5860053895177517`*^9, 3.5860056167477508`*^9}, {
   3.5860058441181498`*^9, 3.5860058472849555`*^9}, {3.5860058953642397`*^9, 
   3.586005916205877*^9}, {3.586005987108001*^9, 3.5860059877476025`*^9}, {
   3.586157360501302*^9, 3.5861574330224495`*^9}, {3.5861574659813347`*^9, 
   3.5861575502311535`*^9}, {3.5861576010810623`*^9, 3.586157618034032*^9}, 
   3.5861672686022496`*^9, {3.586167553217529*^9, 3.5861675586908417`*^9}, {
   3.5861680230984044`*^9, 3.586168040420395*^9}, {3.5861735272862263`*^9, 
   3.586173555796857*^9}, {3.5861738431832943`*^9, 3.5861738489716253`*^9}, {
   3.586173888477885*^9, 3.5861738938371916`*^9}, {3.5861741510469027`*^9, 
   3.5861741786344805`*^9}, {3.586174369246383*^9, 3.5861743854283085`*^9}, {
   3.586174703071477*^9, 3.586174721723544*^9}, {3.5861801571087027`*^9, 
   3.586180190587618*^9}, {3.5866045654457083`*^9, 3.5866045978781652`*^9}, {
   3.5866048796926603`*^9, 3.5866049374907618`*^9}, {3.5866060979455996`*^9, 
   3.5866061415788765`*^9}, {3.5866061887845592`*^9, 
   3.5866061997981787`*^9}, {3.5866062339934387`*^9, 
   3.5866063571400547`*^9}, {3.5866064409902024`*^9, 3.586606541079978*^9}, {
   3.58660687234656*^9, 3.586606910675827*^9}, {3.586607497424058*^9, 
   3.5866075672965803`*^9}, {3.5866081806584578`*^9, 3.586608320278703*^9}, {
   3.5866083550355644`*^9, 3.586608437013708*^9}, {3.586608520614255*^9, 
   3.5866085237186604`*^9}, {3.586666493961392*^9, 3.586666832336746*^9}, {
   3.586666973216804*^9, 3.5866669881356573`*^9}, {3.5866670270078807`*^9, 
   3.5866670286629753`*^9}, {3.586667322887804*^9, 3.5866673449030633`*^9}, {
   3.5866673859834127`*^9, 3.5866674002712297`*^9}, {3.586667504080168*^9, 
   3.5866675524229326`*^9}, {3.586667875759426*^9, 3.586667932094649*^9}, {
   3.586668002592681*^9, 3.5866680095990815`*^9}, 3.5866680408898716`*^9, {
   3.5866680946029434`*^9, 3.586668379732252*^9}, 3.5866684152132816`*^9, {
   3.5866685316519413`*^9, 3.586668568757064*^9}, {3.5866686152287216`*^9, 
   3.5866686618283873`*^9}, {3.5866687358606215`*^9, 3.586668752408568*^9}, 
   3.5866688316411*^9, {3.586668916928978*^9, 3.5866689246484194`*^9}, {
   3.586669160776925*^9, 3.5866693954043455`*^9}, {3.5866694376797633`*^9, 
   3.58666947783606*^9}, 3.5866695936206827`*^9, {3.586669654315154*^9, 
   3.5866697503796487`*^9}, {3.58666978432459*^9, 3.586669873101668*^9}, {
   3.586669929454891*^9, 3.5866699427336507`*^9}, 3.58667177289433*^9, {
   3.5866718081883483`*^9, 3.586671818796955*^9}, {3.5902120419881597`*^9, 
   3.590212061222993*^9}, {3.590212141999935*^9, 3.590212160735568*^9}, 
   3.590212472205715*^9, 3.5954844475325828`*^9, {3.5954845341595354`*^9, 
   3.5954845660927916`*^9}, {3.59548460531126*^9, 3.595484620053286*^9}, {
   3.599804058189828*^9, 3.599804075365458*^9}, {3.609222274667694*^9, 
   3.6092223292498164`*^9}, {3.6092239826166396`*^9, 3.6092239851837864`*^9}, 
   3.6092305807790127`*^9, {3.614055072635099*^9, 3.6140550761451054`*^9}, 
   3.614861849472722*^9, 3.614917782279744*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "::", "usage"}], " ", "=", " ", 
   "\"\<d[f][u,v,w,...] is the differential of the function f[u,v,w...] of \
several variables with values in an  n-dimensional manifold or space. For the \
variables u, v, w,... the differentials d[u][u,v,...], d[v][u,v,... ],... \
yield the standard cobasis in the cotangent space of the parameter manifold \
at the point {u, v,...}. d[f,u,v,w,...][vl] is the value of the differen5ial \
d[f][u,v,w,...] for the tangent vector vl.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.61475558160705*^9, 3.61475562950379*^9}, {
   3.614772359656068*^9, 3.614772520995296*^9}, {3.614772556099304*^9, 
   3.6147726996365137`*^9}, 3.614772805750583*^9, {3.615032269433059*^9, 
   3.6150324531535673`*^9}, 3.615032504907528*^9, {3.61754468658043*^9, 
   3.617544773706583*^9}, {3.6175448203818645`*^9, 3.617544821723467*^9}, {
   3.6175448532199225`*^9, 3.6175448769943647`*^9}, 3.617545042245455*^9, 
   3.61754507938912*^9, 3.6175451257992015`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "h", "]"}], "[", 
  RowBox[{"u", ",", "v", ",", "w"}], "]"}]], "Input",
 CellChangeTimes->{{3.586608541643092*^9, 3.586608542891094*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["h", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
   RowBox[{
    SuperscriptBox["h", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
   RowBox[{
    SuperscriptBox["h", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.589981046903825*^9, 3.590212069069807*^9, 
  3.5902124833753347`*^9, 3.5954848200768375`*^9, 3.5954858780862956`*^9, 
  3.5954861862024364`*^9, 3.5954883989571233`*^9, 3.5954892594546347`*^9, 
  3.59980397413688*^9, 3.59980408236987*^9, 3.6092223684680595`*^9, 
  3.609230597218953*^9, 3.6140554095020905`*^9, 3.61405544900136*^9, 
  3.6140567467208395`*^9, 3.6150325215854816`*^9, 3.6177062792806897`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"h", ",", "u", ",", "v", ",", "w"}], "]"}], "[", 
  RowBox[{"{", 
   RowBox[{"0", ",", "1", ",", "0"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.6140568667942505`*^9, 3.6140569324703655`*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["h", 
   TagBox[
    RowBox[{"(", 
     RowBox[{"0", ",", "1", ",", "0"}], ")"}],
    Derivative],
   MultilineFunction->None], "[", 
  RowBox[{"u", ",", "v", ",", "w"}], "]"}]], "Output",
 CellChangeTimes->{3.6140568949990997`*^9, 3.614056937259574*^9, 
  3.615032527701831*^9, 3.6177062861700835`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.599804000142126*^9, 3.59980400803574*^9}, {
  3.5998041179067326`*^9, 3.5998041241779437`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5998040090029416`*^9, 3.599804125176346*^9, 
  3.609222371815251*^9, 3.6092306013371887`*^9, 3.614055467830593*^9, 
  3.6140558044635844`*^9, 3.61405682685818*^9, 3.615032532989134*^9, 
  3.6177062921134233`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "u", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{3.6092241389175797`*^9, 3.609230618873192*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.6092241397886295`*^9, 3.6092306198262463`*^9, 
  3.6140554838986216`*^9, 3.6140558074275894`*^9, 3.61405676990248*^9, 
  3.615032537781408*^9, 3.6177062984777875`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"u", ",", "u", ",", "v"}], "]"}], "[", 
  RowBox[{"{", 
   RowBox[{"s", ",", "t"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.6092241489101515`*^9, 3.6092241571886244`*^9}, {
   3.6092306631367235`*^9, 3.609230709273362*^9}, 3.614055563458761*^9}],

Cell[BoxData["s"], "Output",
 CellChangeTimes->{3.6150325433397255`*^9, 3.617706304964158*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "h", "]"}], "[", 
   RowBox[{"u", ",", "v", ",", "w"}], "]"}], ".", 
  RowBox[{"vec", "[", 
   RowBox[{"x", ",", "3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.586608541643092*^9, 3.586608542891094*^9}, {
   3.5866668851657677`*^9, 3.586666904446871*^9}, 3.586671913536374*^9, {
   3.5899810899432864`*^9, 3.5899811086223545`*^9}, {3.609222408284337*^9, 
   3.6092224095964117`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"x", "[", "3", "]"}], " ", 
   RowBox[{
    SuperscriptBox["h", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"x", "[", "2", "]"}], " ", 
   RowBox[{
    SuperscriptBox["h", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], " ", 
   RowBox[{
    SuperscriptBox["h", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.589981051346079*^9, 3.5899811099664316`*^9, 
  3.5902120767762203`*^9, 3.5902121735899906`*^9, 3.59021249201775*^9, 
  3.5954848491396885`*^9, 3.595485887961113*^9, 3.5954861924112473`*^9, 
  3.5954892650082445`*^9, 3.5998041428043766`*^9, 3.609222376638527*^9, 
  3.609222414963719*^9, 3.6092307230921526`*^9, 3.6140556799441657`*^9, 
  3.614055820250812*^9, 3.6150325779097033`*^9, 3.6177063109124985`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"h", ",", "u", ",", "v", ",", "w"}], "]"}], "[", 
  RowBox[{"vec", "[", 
   RowBox[{"x", ",", "3"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.586608541643092*^9, 3.586608542891094*^9}, {
   3.5866668851657677`*^9, 3.586666904446871*^9}, 3.586671913536374*^9, {
   3.5899810899432864`*^9, 3.5899811086223545`*^9}, {3.5954886029274817`*^9, 
   3.5954886331603346`*^9}, {3.609222422949176*^9, 3.6092224244042587`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"x", "[", "3", "]"}], " ", 
   RowBox[{
    SuperscriptBox["h", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"x", "[", "2", "]"}], " ", 
   RowBox[{
    SuperscriptBox["h", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], " ", 
   RowBox[{
    SuperscriptBox["h", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.6092224260983553`*^9, 3.6092307283394527`*^9, 
  3.6093079457200985`*^9, 3.614055689460182*^9, 3.6140558242600193`*^9, 
  3.6150325942676387`*^9}]
}, Closed]],

Cell["\<\
OK.
The differential of a vector function is the vector of the differentials of \
its components:\
\>", "Text",
 CellChangeTimes->{{3.586664784821635*^9, 3.586664824405899*^9}, {
   3.586672145190624*^9, 3.5866721496778803`*^9}, 3.5998049367289324`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sf", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5867577346292953`*^9, 3.5867577393255634`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "1", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "2", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "3", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.590212082907031*^9, 3.590212509723781*^9, 
  3.6150326176929784`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.586608541643092*^9, 3.586608570113142*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5902120879926405`*^9, 3.5902125127189865`*^9, 
  3.5951700561371403`*^9, 3.6089690438875065`*^9, 3.6092307369019423`*^9, 
  3.6093079539465685`*^9, 3.6140558335732355`*^9, 3.6150326215341983`*^9}]
}, Closed]],

Cell["This is a vector of differential forms:", "Text",
 CellChangeTimes->{{3.5861755001530676`*^9, 3.586175567096896*^9}, 
   3.586175620051925*^9, {3.586175719948639*^9, 3.586175730684253*^9}, {
   3.586665765597732*^9, 3.5866657669328084`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"f", "[", "i", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.58617394101589*^9, 3.5861739511384687`*^9}, {
   3.586175358458963*^9, 3.586175475179639*^9}, {3.58617562555624*^9, 
   3.586175682092474*^9}, {3.5862639673368874`*^9, 3.5862639758653755`*^9}, 
   3.6148618495195217`*^9, 3.614863501500024*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.590212096213855*^9, 3.590212518256996*^9, 
  3.609222457912175*^9, 3.609230742129242*^9, 3.6150326326998367`*^9, 
  3.617706349660715*^9}]
}, Closed]],

Cell["\<\
The local cobasis is defined by the differentials d[u], d[v]:\
\>", "Text",
 CellChangeTimes->{{3.586175113040926*^9, 3.5861751404164915`*^9}, {
  3.599804682830525*^9, 3.5998046926741424`*^9}, {3.609231165950483*^9, 
  3.6092311808063326`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"sf", ",", "u", ",", "v"}], "]"}], "[", 
  RowBox[{"{", 
   RowBox[{"s", ",", "t"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.586672163805689*^9, 3.586672202279889*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"t", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{"s", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"t", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{"s", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"t", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{"s", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.590212101939065*^9, 3.5902125223130035`*^9, 
  3.5998046488848653`*^9, 3.6089690562892156`*^9, 3.6092307476285563`*^9, 
  3.609231061035482*^9, 3.6092311397079816`*^9, 3.6093079756538105`*^9, 
  3.6140558455228567`*^9, 3.6140569632180195`*^9, 3.615032642387391*^9, 
  3.6177063582092037`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"sf", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", " ", "u"}], "]"}], "*", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"u", ",", "u", ",", "v"}], "]"}], "[", 
     RowBox[{"{", 
      RowBox[{"s", ",", "t"}], "}"}], "]"}]}], " ", "+", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"sf", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", " ", "v"}], "]"}], "*", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"v", ",", "u", ",", "v"}], "]"}], "[", 
     RowBox[{"{", 
      RowBox[{"s", ",", "t"}], "}"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6092308865074997`*^9, 3.609231047065683*^9}, {
  3.6092310939473643`*^9, 3.6092311331686077`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.609231048521766*^9, 3.6092310658527575`*^9}, 
   3.6092311438232174`*^9, 3.6093079829052253`*^9, 3.6140558620900855`*^9, 
   3.614056975573241*^9, 3.615032684125778*^9, 3.6177063738761*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"h", ",", "u", ",", "v"}], "]"}], "[", 
   RowBox[{"{", 
    RowBox[{"s", ",", "t"}], "}"}], " ", "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}], "*", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"u", ",", "u", ",", "v"}], "]"}], "[", 
     RowBox[{"{", 
      RowBox[{"s", ",", "t"}], "}"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", "v"}], "]"}], "*", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"v", ",", "u", ",", "v"}], "]"}], "[", 
     RowBox[{"{", 
      RowBox[{"s", ",", "t"}], "}"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.586232907051381*^9, 3.586232990511528*^9}, {
  3.5866071415562325`*^9, 3.5866071748934913`*^9}, {3.586607643299914*^9, 
  3.586607662534748*^9}, {3.586672926394306*^9, 3.58667295915418*^9}, {
  3.5866730242579036`*^9, 3.586673045131098*^9}, {3.609231247989175*^9, 
  3.609231300964205*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5902126440088167`*^9, 3.5998047529994483`*^9, 
  3.6092210665965967`*^9, 3.6092220169789553`*^9, 3.6092313108257694`*^9, 
  3.615032718926769*^9, 3.6177063952113204`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ".", 
   RowBox[{"{", 
    RowBox[{"s", ",", "t"}], "}"}]}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"sf", ",", "u", ",", "v"}], "]"}], "[", 
   RowBox[{"{", 
    RowBox[{"s", ",", "t"}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.586232907051381*^9, 3.586232990511528*^9}, {
  3.586233084673293*^9, 3.586233102675725*^9}, {3.5862332045595036`*^9, 
  3.586233306552483*^9}, {3.586693207585164*^9, 3.586693231078806*^9}, {
  3.5866932664596677`*^9, 3.5866933097341437`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5902126729156675`*^9, 3.5998047879903097`*^9, 
  3.6092210892128906`*^9, 3.609222028620621*^9, 3.6092313879661813`*^9, 
  3.6150327444502287`*^9, 3.617706422431877*^9}]
}, Closed]],

Cell["Remember also  the TensorProduct:", "Text",
 CellChangeTimes->{{3.6092267184271193`*^9, 3.609226736707165*^9}, {
  3.6092315366386847`*^9, 3.609231550774493*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"sf", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}], "\[TensorProduct]", 
   RowBox[{
    RowBox[{"d", "[", "u", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"sf", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "v"}], "]"}], "\[TensorProduct]", 
   RowBox[{
    RowBox[{"d", "[", "v", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6092255700064335`*^9, 3.6092255957509055`*^9}, {
  3.6092256366472445`*^9, 3.6092256596085577`*^9}, {3.6092257240252423`*^9, 
  3.6092257378640337`*^9}, {3.6092259323801594`*^9, 3.6092259767666984`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6092267070714693`*^9, 3.609231524109968*^9, 
  3.614056998692482*^9, 3.615032753007718*^9, 3.617706427634175*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "\[Equal]", 
  RowBox[{
   RowBox[{"d", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6092256755794716`*^9, 3.609225686205079*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.6092315276931734`*^9, 3.6140570035596905`*^9, 
  3.615032757290963*^9, 3.6177064427820415`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["1.3.2. Sum and Product Rules", "Subsubsection",
 CellChangeTimes->{{3.5866934699464254`*^9, 3.586693482956848*^9}, {
   3.587272502702733*^9, 3.5872725077900243`*^9}, 3.5998050004605775`*^9, 
   3.6091386762717667`*^9, 3.6177065204414835`*^9, 3.6177078203058095`*^9}],

Cell["\<\
First we consider a rule for the argumentwise addition of functions.\
\>", "Text",
 CellChangeTimes->{{3.5867582566201515`*^9, 3.586758307524063*^9}, {
   3.5998060968912897`*^9, 3.5998061000514708`*^9}, {3.608969182003406*^9, 
   3.608969183314481*^9}, {3.6089692727475967`*^9, 3.6089692751787357`*^9}, 
   3.615117528078391*^9, 3.6177065469209976`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "plus"}]], "Input",
 CellChangeTimes->{{3.6089692830481853`*^9, 3.60896928522731*^9}, 
   3.6089693522671447`*^9}],

Cell[BoxData[
 StyleBox["\<\"plus[f,..] is a pure function yielding the sum of the \
functions \\nf,..., where the arguments f,... stand for the names of  \
functions or for  numbers \\nbeing transformed into the corresponding \
constant functions. All the functions must \\nbe defined on the same domain \
and must have values in a given Abelian domain in which \\na commutative \
addition + is defined.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.617706555112466*^9},
 CellTags->"Info3617713755-3903716"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Context", "[", "plus", "]"}]], "Input",
 CellChangeTimes->{{3.608969363813805*^9, 3.6089693714922442`*^9}}],

Cell[BoxData["\<\"tensalg`\"\>"], "Output",
 CellChangeTimes->{3.608969372157282*^9, 3.6150328272209625`*^9, 
  3.617706615552923*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plus", "[", 
   RowBox[{"f", ",", "h"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6089691308184786`*^9, 3.6089691512206454`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"u", ",", "v"}], "]"}], "+", 
  RowBox[{"h", "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Output",
 CellChangeTimes->{3.6089691520286913`*^9, 3.6089694899620204`*^9, 
  3.6093080221114674`*^9, 3.615032831358199*^9, 3.6150331310923433`*^9, 
  3.617706619992177*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plus", "[", 
   RowBox[{"f", ",", 
    RowBox[{"-", "f"}]}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6089691308184786`*^9, 3.6089691512206454`*^9}, {
  3.6089693858350644`*^9, 3.6089693939485283`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6089693956076236`*^9, 3.6089694932182064`*^9, 
  3.60930802599769*^9, 3.6150331370826855`*^9, 3.6177066295277224`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zero", "[", "u", "]"}]], "Input",
 CellChangeTimes->{{3.6089609960595636`*^9, 3.6089610032199764`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6089610065739822`*^9, 3.6089694966984053`*^9, 
  3.6150331456671767`*^9, 3.617706637449176*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zero", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.608961030426424*^9, 3.6089610376336365`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6089610393652396`*^9, 3.6150331499324207`*^9, 
  3.6177066410833836`*^9}]
}, Closed]],

Cell["Adding functions f, h by Plus isn\[CloseCurlyQuote]t defined:", "Text",
 CellChangeTimes->{{3.608969532331444*^9, 3.6089695749308805`*^9}, 
   3.6089719663938813`*^9, 3.615033121402789*^9, 3.6150331679314504`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"h", "+", "f"}], ")"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{3.586697645184559*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"f", "+", "h"}], ")"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Output",
 CellChangeTimes->{3.590212721041752*^9, 3.6089611872378993`*^9, 
  3.6089695018176985`*^9, 3.6093080354092283`*^9, 3.6150331718056717`*^9, 
  3.617706650828941*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plus", "[", 
   RowBox[{"f", ",", "h"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6089695861105194`*^9, 3.608969601620407*^9}, 
   3.61503319135679*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"f", "+", "h"}], ")"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Output",
 CellChangeTimes->{3.608969605293617*^9, 3.6093080424536314`*^9, 
  3.6150331994012504`*^9, 3.6177066550221806`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"plus", "[", 
     RowBox[{"h", ",", "f"}], "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "h", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "+", " ", 
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.586170499301035*^9, 3.5861705132268314`*^9}, {
  3.5861758649549327`*^9, 3.5861759534439945`*^9}, {3.5866976110360985`*^9, 
  3.586697618680112*^9}, {3.6089719888831673`*^9, 3.6089720248992276`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.590212758825019*^9, {3.6089719990407486`*^9, 3.6089720262443047`*^9}, 
   3.6093080478359385`*^9, 3.615033210685896*^9, 3.6177066634406624`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{
      RowBox[{"plus", "[", 
       RowBox[{"h", ",", "f"}], "]"}], ",", "u", ",", "v"}], "]"}], "[", 
    RowBox[{"{", 
     RowBox[{"s", ",", "t"}], "}"}], "]"}], "\[Equal]", " ", 
   RowBox[{
    RowBox[{"plus", "[", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"h", ",", "u", ",", "v"}], "]"}], " ", ",", " ", 
      RowBox[{"d", "[", 
       RowBox[{"f", ",", "u", ",", "v"}], "]"}]}], "]"}], "[", 
    RowBox[{"{", 
     RowBox[{"s", ",", "t"}], "}"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.586170499301035*^9, 3.5861705132268314`*^9}, {
  3.5861758649549327`*^9, 3.5861759534439945`*^9}, {3.5866976110360985`*^9, 
  3.586697618680112*^9}, {3.5867587958759947`*^9, 3.5867588868802*^9}, {
  3.586758926592471*^9, 3.5867589322727966`*^9}, {3.6089720585821543`*^9, 
  3.6089721165014668`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.590212767483034*^9, 3.608972074868086*^9, 
  3.608972123116845*^9, 3.609308075370514*^9, 3.615033240382594*^9, 
  3.6177066925083246`*^9}]
}, Closed]],

Cell["\<\
The function 0[u___]  is not defined; it contradicts the syntax rule: Any \
symbol name must start with a letter.\
\>", "Text",
 CellChangeTimes->{{3.609137726555123*^9, 3.6091378124332733`*^9}, {
  3.6091378564798775`*^9, 3.609137859392044*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"h", "-", "h"}], ")"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6089722793817835`*^9, 3.6089722895793667`*^9}}],

Cell[BoxData[
 RowBox[{"0", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Output",
 CellChangeTimes->{3.608972291579481*^9, 3.6150332561194944`*^9, 
  3.617706704208994*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plus", "[", 
   RowBox[{"h", ",", 
    RowBox[{"-", "h"}]}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6091379234347067`*^9, 3.6091379441628923`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.60913794552497*^9, 3.615033262901882*^9, 
  3.617706709935322*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{
    RowBox[{"plus", "[", 
     RowBox[{"h", ",", 
      RowBox[{"-", "h"}]}], "]"}], ",", "u", ",", "v"}], "]"}], "[", 
  RowBox[{"{", 
   RowBox[{"s", ",", "t"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.586695101662491*^9, 3.5866951193685226`*^9}, 
   3.5866969664897666`*^9, {3.5866994488129263`*^9, 3.586699457517742*^9}, {
   3.5902128031758966`*^9, 3.5902128321763477`*^9}, {3.608972365484708*^9, 
   3.6089724264361944`*^9}, 3.6091380787465906`*^9, 3.609138147763538*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.59021283362715*^9, 3.608972171737626*^9, {3.6089724008407307`*^9, 
   3.608972427907278*^9}, 3.6091380815247493`*^9, 3.6091381502656813`*^9, 
   3.615033401750824*^9, 3.6177067475214715`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"plus", "[", 
    RowBox[{"h", ",", 
     RowBox[{"-", "h"}]}], "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v", ",", "w"}], "]"}]], "Input",
 CellChangeTimes->{{3.586695101662491*^9, 3.5866951193685226`*^9}, 
   3.5866969664897666`*^9, {3.5866994488129263`*^9, 3.586699457517742*^9}, {
   3.5902128031758966`*^9, 3.5902128321763477`*^9}, {3.608972365484708*^9, 
   3.608972458475027*^9}, {3.609138183562586*^9, 3.609138185298685*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.608972459441082*^9, 3.6091381863417444`*^9, 
  3.6150334077491674`*^9, 3.6177067667545714`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{
     RowBox[{"plus", "[", 
      RowBox[{"h", ",", 
       RowBox[{"-", "f"}]}], "]"}], ",", "u", ",", "v"}], "]"}], "[", 
   RowBox[{"{", 
    RowBox[{"s", ",", "t"}], "}"}], "]"}], "-", 
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"h", ",", "u", ",", "v"}], "]"}], "[", 
   RowBox[{"{", 
    RowBox[{"s", ",", "t"}], "}"}], "]"}], " ", "+", 
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"f", ",", "u", ",", "v"}], "]"}], "[", 
   RowBox[{"{", 
    RowBox[{"s", ",", "t"}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.586695101662491*^9, 3.5866951193685226`*^9}, 
   3.586696958736553*^9, {3.5866994963618097`*^9, 3.5866995074690294`*^9}, {
   3.586759049719514*^9, 3.5867590722788043`*^9}, {3.608972477076091*^9, 
   3.6089724880197167`*^9}, {3.6089725647961082`*^9, 3.608972638157304*^9}, 
   3.6091382607329993`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"t", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "-", 
  RowBox[{"t", " ", 
   RowBox[{
    SuperscriptBox["h", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
  RowBox[{"t", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["h", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], ")"}]}], "+", 
  RowBox[{"s", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "-", 
  RowBox[{"s", " ", 
   RowBox[{
    SuperscriptBox["h", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
  RowBox[{"s", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["h", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.5902127873574686`*^9, 3.5902128413179636`*^9, 
  3.608972490316848*^9, 3.608972639879402*^9, 3.6091382636851683`*^9, 
  3.6150334550668736`*^9, 3.617706820456643*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.60897264542772*^9, 3.6089726519950953`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6089726530591564`*^9, 3.609138268119422*^9, 
  3.615033460238169*^9, 3.6177068250129037`*^9}]
}, Closed]],

Cell["\<\
The next two cells led to unsatisfactory results, therefore we made them \
non-evaluable:\
\>", "Text",
 CellChangeTimes->{{3.586699608510407*^9, 3.5866996173244224`*^9}, {
   3.5866996648265057`*^9, 3.5866997222346067`*^9}, {3.586700302084093*^9, 
   3.5867003049882593`*^9}, 3.615117624077882*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Unprotect", "[", "Times", "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"h", "*", "f"}], ")"}], "[", "u___", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"h", "[", "u", "]"}], "*", 
    RowBox[{"f", "[", "u", "]"}]}]}], ";", 
  RowBox[{"Protect", "[", "Times", "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.586176146106014*^9, 3.5861761604438343`*^9}, {
   3.586176212667821*^9, 3.586176219555215*^9}, {3.5861764457641535`*^9, 
   3.586176448811328*^9}, {3.586179992161268*^9, 3.586180045256305*^9}, 
   3.5861802843079786`*^9, {3.586180325530336*^9, 3.586180335425902*^9}, 
   3.5861809246586046`*^9, {3.5861813951225133`*^9, 3.5861814146896324`*^9}, {
   3.5866948042167687`*^9, 3.5866948729192896`*^9}, {3.5866949295161886`*^9, 
   3.586694942947812*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Unprotect", "[", "Divide", "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"h_", "/", "f_"}], ")"}], "[", "u___", "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"h", "[", "u", "]"}], "/", 
    RowBox[{"f", "[", "u", "]"}]}]}], ";", 
  RowBox[{"Protect", "[", "Divide", "]"}], ";"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5861765616997843`*^9, 3.586176568130152*^9}, {
   3.5861766180670085`*^9, 3.5861766375791245`*^9}, 3.5861814251452303`*^9, {
   3.5866948895177183`*^9, 3.5866949166929665`*^9}, {3.5866950043651204`*^9, 
   3.5866950154723396`*^9}, {3.586695137339754*^9, 3.58669518073903*^9}, {
   3.586695359078543*^9, 3.5866954404014864`*^9}, 3.586700369902972*^9}],

Cell["\<\
We prefer to define first a new function corresponding to the wanted \
operation and then to apply the differential.\
\>", "Text",
 CellChangeTimes->{{3.5867003949084024`*^9, 3.5867004820113845`*^9}, {
   3.6151176307982664`*^9, 3.6151176349745054`*^9}, 3.6177068530895095`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"hf", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", 
  RowBox[{
   RowBox[{"h", "[", 
    RowBox[{"u", ",", "v"}], "]"}], "*", 
   RowBox[{"f", "[", 
    RowBox[{"u", ",", "v"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5861765616997843`*^9, 3.586176568130152*^9}, {
   3.5861766180670085`*^9, 3.5861766375791245`*^9}, 3.5861814251452303`*^9, {
   3.5866948895177183`*^9, 3.5866949166929665`*^9}, {3.5867005003014307`*^9, 
   3.5867005604948735`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "hf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5866956108941855`*^9, 3.5866956706890907`*^9}, 
   3.586700547550133*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["h", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["h", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6091383127059717`*^9, 3.6150335324462996`*^9, 
  3.6177068915007067`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "-", " ", 
  RowBox[{
   RowBox[{"h", "[", 
    RowBox[{"u", ",", "v"}], "]"}], "*", 
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], " ", "-", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "h", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "*", 
   RowBox[{"f", "[", 
    RowBox[{"u", ",", "v"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.586170588470135*^9, 3.586170596314584*^9}, {
  3.5861804177446103`*^9, 3.5861805309620857`*^9}, {3.5861805934906626`*^9, 
  3.586180596185817*^9}, {3.586180723066074*^9, 3.586180768243658*^9}, {
  3.586180807948929*^9, 3.5861808189555583`*^9}, {3.5861808559476743`*^9, 
  3.586180862659058*^9}, {3.5861811085951247`*^9, 3.5861811264421453`*^9}, {
  3.5861814751470904`*^9, 3.5861814955872593`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.6091383368463526`*^9, 3.6150335372905765`*^9, 
  3.6177068964989924`*^9}]
}, Closed]],

Cell["OK. Multiplication with a constant :", "Text",
 CellChangeTimes->{{3.5867592339080486`*^9, 3.586759258348447*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"Pi", "*", "f"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{
  3.5866957036363487`*^9, {3.5866957457408223`*^9, 3.5866957464584236`*^9}, 
   3.5866957931493053`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Pi]", " ", 
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], ",", 
   RowBox[{"\[Pi]", " ", 
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5902128905984497`*^9, 3.60913834501482*^9, 
  3.6150335437349453`*^9, 3.6177069007682366`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "-", 
   RowBox[{"Pi", "*", 
    RowBox[{
     RowBox[{"d", "[", "f", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5867006053194375`*^9, 3.5867006360301943`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.590212901159669*^9, 3.6091383512641773`*^9, 
  3.6150335472181444`*^9, 3.617706907435618*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{
    RowBox[{"N", "[", "Pi", "]"}], "*", "f"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{
  3.5866957036363487`*^9, {3.5866957457408223`*^9, 3.5866957464584236`*^9}, 
   3.5866957931493053`*^9, {3.586701009461553*^9, 3.586701015437895*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"3.141592653589793`", " ", 
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], ",", 
   RowBox[{"3.141592653589793`", " ", 
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5902129102388844`*^9, 3.6091383605597095`*^9, 
  3.615033560179886*^9, 3.6177069120298805`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"N", "[", "Pi", "]"}], "*", 
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.586701032414866*^9, 3.5867010529340396`*^9}, {
  3.586759380350425*^9, 3.5867594014706326`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.590212914934493*^9, 3.609138367005078*^9, 
  3.6150335661382265`*^9, 3.617706916301125*^9}]
}, Closed]],

Cell["\<\
OK.
Now we consider the division of functions:\
\>", "Text",
 CellChangeTimes->{{3.586759537684424*^9, 3.5867595598446913`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fqh", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"u", ",", "v"}], "]"}], "/", 
   RowBox[{"h", "[", 
    RowBox[{"u", ",", "v"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5866959701316166`*^9, 3.586695979398033*^9}, {
  3.586696045042948*^9, 3.5866960986290426`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "fqh", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5866961062886553`*^9, 3.586696119720279*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], 
     RowBox[{"h", "[", 
      RowBox[{"u", ",", "v"}], "]"}]], "-", 
    FractionBox[
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["h", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"]]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], 
     RowBox[{"h", "[", 
      RowBox[{"u", ",", "v"}], "]"}]], "-", 
    FractionBox[
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["h", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.609138456404191*^9, 3.615033602600312*^9, 
  3.617706927771781*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Together", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.6091384818996496`*^9, 3.6091384897300973`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["h", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], 
    SuperscriptBox[
     RowBox[{"h", "[", 
      RowBox[{"u", ",", "v"}], "]"}], "2"]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["h", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], 
    SuperscriptBox[
     RowBox[{"h", "[", 
      RowBox[{"u", ",", "v"}], "]"}], "2"]]}], "}"}]], "Output",
 CellChangeTimes->{3.6091384902731285`*^9, 3.6150336083606415`*^9, 
  3.617706932261038*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"qh", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{"1", "/", 
   RowBox[{"h", "[", 
    RowBox[{"u", ",", "v"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5866962450040994`*^9, 3.5866962911177807`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "qh", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.586696304674204*^9, 3.586696321225833*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["h", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["h", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6091385329865713`*^9, 3.6150336270197086`*^9, 
  3.6177069739154205`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"hsf", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"h", "[", 
    RowBox[{"u", ",", "v"}], "]"}], "*", 
   RowBox[{"sf", "[", 
    RowBox[{"u", ",", "v"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.586176146106014*^9, 3.5861761604438343`*^9}, {
   3.586176212667821*^9, 3.586176219555215*^9}, {3.5861764457641535`*^9, 
   3.586176448811328*^9}, {3.586179992161268*^9, 3.586180045256305*^9}, 
   3.5861802843079786`*^9, {3.586180325530336*^9, 3.586180335425902*^9}, 
   3.5861809246586046`*^9, {3.5861813951225133`*^9, 3.5861814146896324`*^9}, {
   3.586182028978768*^9, 3.5861820344580812`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hsf", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5861765616997843`*^9, 3.586176568130152*^9}, {
   3.5861766180670085`*^9, 3.5861766375791245`*^9}, 3.5861814251452303`*^9, 
   3.5861820437846146`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"h", "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", 
    RowBox[{
     RowBox[{"f", "[", "1", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"h", "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", 
    RowBox[{
     RowBox[{"f", "[", "2", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"h", "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", 
    RowBox[{
     RowBox[{"f", "[", "3", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.609138547595407*^9, 3.6150336395884275`*^9, 
  3.6177069882532406`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "hsf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.586175998007543*^9, 3.586176056539891*^9}, 
   3.5861761728835454`*^9, {3.5861806944574375`*^9, 3.5861807024008923`*^9}, 
   3.586181021650152*^9, 3.586181462794384*^9, 3.5861818073140893`*^9, 
   3.586182054338218*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", "1", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"h", "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", "1", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"h", "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", "2", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"h", "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", "2", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"h", "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", "3", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"h", "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", "3", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"h", "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6091385536567535`*^9, 3.6177069945796022`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"hsf", ",", "u", ",", "v"}], "]"}], "[", 
  RowBox[{"{", 
   RowBox[{"s", ",", "t"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.586175998007543*^9, 3.586176056539891*^9}, 
   3.5861761728835454`*^9, {3.5861806944574375`*^9, 3.5861807024008923`*^9}, 
   3.586181021650152*^9, 3.586181462794384*^9, 3.5861818073140893`*^9, 
   3.586182054338218*^9, 3.586182151961802*^9, {3.5867603175990324`*^9, 
   3.5867603279346237`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"t", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", "1", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"h", "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"s", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", "1", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"h", "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"t", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", "2", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"h", "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"s", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", "2", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"h", "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"t", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", "3", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"h", "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"s", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", "3", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"h", "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.609138576645068*^9, 3.615033645425761*^9, 
  3.6177070005209417`*^9, 3.617707042214327*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "-", " ", 
   RowBox[{
    RowBox[{"h", "[", 
     RowBox[{"u", ",", "v"}], "]"}], "*", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"sf", ",", "u", ",", "v"}], "]"}], "[", 
     RowBox[{"{", 
      RowBox[{"s", ",", "t"}], "}"}], "]"}]}], "-", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"h", ",", "u", ",", "v"}], "]"}], "[", 
     RowBox[{"{", 
      RowBox[{"s", ",", "t"}], "}"}], "]"}], "*", 
    RowBox[{"sf", "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.586170588470135*^9, 3.586170596314584*^9}, {
   3.5861804177446103`*^9, 3.5861805309620857`*^9}, {3.5861805934906626`*^9, 
   3.586180596185817*^9}, {3.586180723066074*^9, 3.586180768243658*^9}, {
   3.586180807948929*^9, 3.5861808189555583`*^9}, {3.5861808559476743`*^9, 
   3.586180862659058*^9}, {3.5861811085951247`*^9, 3.5861811264421453`*^9}, {
   3.5861814751470904`*^9, 3.5861814955872593`*^9}, {3.586182070963169*^9, 
   3.5861820774905424`*^9}, {3.586182197803424*^9, 3.586182239571813*^9}, {
   3.586182353181311*^9, 3.5861823536443377`*^9}, {3.5867603471997256`*^9, 
   3.586760522599758*^9}, {3.5867605830332146`*^9, 3.5867606005202146`*^9}, 
   3.5867606439676995`*^9, {3.58676070726432*^9, 3.586760716646857*^9}, 
   3.5867607994635935`*^9, {3.6177070210041137`*^9, 3.617707032411766*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.6091385975862665`*^9, 3.6150336558993607`*^9, 
  3.617707006340275*^9, 3.6177070526459236`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["1.3.3. Exterior Product", "Subsubsection",
 CellChangeTimes->{{3.586665161894202*^9, 3.586665168125559*^9}, {
   3.5872725143584003`*^9, 3.587272520677761*^9}, {3.60913869538486*^9, 
   3.6091387007281656`*^9}, 3.6092316026384597`*^9, {3.6093094046875467`*^9, 
   3.6093094080137367`*^9}, 3.609309574326249*^9, {3.6095608566429873`*^9, 
   3.6095608600281935`*^9}, 3.6177078269291887`*^9, 3.6177190550258956`*^9}],

Cell["\<\
The exterior product of  differential forms is obtained by the built-in \
\>", "Text",
 CellChangeTimes->{{3.5866638658290715`*^9, 3.586663901221096*^9}, {
   3.609308184685766*^9, 3.6093081991985965`*^9}, 3.615117640053796*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "TensorWedge"}]], "Input",
 CellChangeTimes->{{3.586614301966012*^9, 3.5866143148672347`*^9}, {
  3.6089625997735806`*^9, 3.608962603891988*^9}, {3.608963615959365*^9, 
  3.6089636229637775`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\!\(\*RowBox[{\\\"TensorWedge\\\", \\\"[\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"tensor\\\", \\\"TI\\\"], \
StyleBox[\\\"1\\\", \\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"tensor\
\\\", \\\"TI\\\"], StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", StyleBox[\\\"\
\[Ellipsis]\\\", \\\"TR\\\"]}], \\\"]\\\"}]\) represents the antisymmetrized \
tensor product of the \!\(\*SubscriptBox[StyleBox[\\\"tensor\\\", \
\\\"TI\\\"], StyleBox[\\\"i\\\", \\\"TI\\\"]]\).\"\>", "MSG"], 
  "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/TensorWedge"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.617707837850813*^9},
 CellTags->"Info3617715037-3903716"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Context", "[", "TensorWedge", "]"}]], "Input",
 CellChangeTimes->{{3.586614326286455*^9, 3.5866143340708685`*^9}, {
   3.6089625399630756`*^9, 3.6089625472170877`*^9}, 3.609139331541246*^9}],

Cell[BoxData["\<\"System`\"\>"], "Output",
 CellChangeTimes->{3.590212992544629*^9, 3.592315365391777*^9, 
  3.6089624951129966`*^9, 3.6091393338183765`*^9, 3.615033717661893*^9, 
  3.6177078490554543`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TensorWedge", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "h", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.5866075367049265`*^9, {3.5866078946943555`*^9, 3.586607923382806*^9}, {
   3.586609053713991*^9, 3.586609060437603*^9}, {3.5866091609953794`*^9, 
   3.586609167874992*^9}, 3.5866142301590858`*^9, {3.6089625185130377`*^9, 
   3.6089625203070407`*^9}, {3.6089637807424545`*^9, 
   3.6089637866548653`*^9}, {3.608963958769967*^9, 3.608964000765241*^9}, 
   3.609139366379239*^9, 3.6148618495663223`*^9, 3.6149177823421445`*^9}],

Cell[BoxData[
 TagBox[
  TemplateBox[{RowBox[{
      StyleBox[
       TagBox["StructuredArray", "SummaryHead"], "NonInterpretableSummary"], 
      StyleBox["[", "NonInterpretableSummary"], 
      DynamicModuleBox[{Typeset`open$$ = False}, 
       PanelBox[
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"], 
                 ImageSizeCache -> {24., {0., 24.}}], Appearance -> None, 
                ButtonFunction :> (Typeset`open$$ = True), Evaluator -> 
                Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}]], 
              GraphicsBox[
               
               RasterBox[{{{0.5, 0., 0.}, {0.235431, 0.32765, 0.833291}}, {{
                0.235431, 0.32765, 0.833291}, {0.5, 0., 0.}}}, {{0, 0}, {2, 
                2}}, {0, 1}], AspectRatio -> 1, Axes -> False, Frame -> False,
                FrameLabel -> {None, None}, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], 
               FrameTicks -> {{None, None}, {None, None}}, GridLinesStyle -> 
               Directive[
                 GrayLevel[0.5, 0.4]], ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}], 
               Method -> {
                "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                 Automatic, "DefaultPlotStyle" -> Automatic, "DomainPadding" -> 
                 Scaled[0.02], "RangePadding" -> Scaled[0.05]}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["SymmetrizedArray", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Dimensions: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"2", ",", "2"}], "}"}], "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Symmetry: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"Antisymmetric", "[", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "2"}], "}"}], "]"}], "SummaryItem"]}]}},
                AutoDelete -> False, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}}, AutoDelete -> 
            False, BaselinePosition -> {1, 1}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], True -> 
          GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], Appearance -> None, 
                ButtonFunction :> (Typeset`open$$ = False), Evaluator -> 
                Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}]], 
              GraphicsBox[
               
               RasterBox[{{{0.5, 0., 0.}, {0.235431, 0.32765, 0.833291}}, {{
                0.235431, 0.32765, 0.833291}, {0.5, 0., 0.}}}, {{0, 0}, {2, 
                2}}, {0, 1}], AspectRatio -> 1, Axes -> False, Frame -> False,
                FrameLabel -> {None, None}, FrameStyle -> Directive[
                 Opacity[0.5], 
                 Thickness[Tiny], 
                 RGBColor[0.368417, 0.506779, 0.709798]], 
               FrameTicks -> {{None, None}, {None, None}}, GridLinesStyle -> 
               Directive[
                 GrayLevel[0.5, 0.4]], ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}], 
               Method -> {
                "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                 Automatic, "DefaultPlotStyle" -> Automatic, "DomainPadding" -> 
                 Scaled[0.02], "RangePadding" -> Scaled[0.05]}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Type: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["SymmetrizedArray", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Dimensions: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"2", ",", "2"}], "}"}], "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Symmetry: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"Antisymmetric", "[", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "2"}], "}"}], "]"}], "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox[
                   "\"Specified independent elements: \"", 
                    "SummaryItemAnnotation"], "\[InvisibleSpace]", 
                   TagBox["1", "SummaryItem"]}]}, {
                 TagBox[
                  TagBox[
                   GridBox[{{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"1", ",", "2"}], "}"}], "\[Rule]", 
                    StyleBox[
                    PaneBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{
                    SuperscriptBox["h", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}], Derivative], 
                    MultilineFunction -> None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], " ", 
                    RowBox[{
                    SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}], Derivative], 
                    MultilineFunction -> None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}], Derivative], 
                    MultilineFunction -> None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["h", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}], Derivative], 
                    MultilineFunction -> None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], BaselinePosition -> 
                    Baseline, ContentPadding -> False, FrameMargins -> 0, 
                    ImageSize -> {{1, 300}, Automatic}, StripOnInput -> True],
                     LineBreakWithin -> False]}]}}, DefaultBaseStyle -> 
                    "Column", GridBoxAlignment -> {"Columns" -> {{Left}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
                   "Column"], "SummaryItem"]}}, AutoDelete -> False, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}}, AutoDelete -> 
            False, BaselinePosition -> {1, 1}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
        Baseline], DynamicModuleValues :> {}], 
      StyleBox["]", "NonInterpretableSummary"]}]},
   "CopyTag",
   DisplayFunction->(#& ),
   InterpretationFunction->(
    "StructuredArray[SymmetrizedArray, {2, 2}, <1,Antisymmetric[{1, 2}]>]"& )],
  False,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{
  3.5899828678469768`*^9, 3.5902130707163663`*^9, 3.592315369650584*^9, {
   3.608962503537011*^9, 3.6089625239106474`*^9}, 3.608963794579679*^9, 
   3.60896396029877*^9, 3.608964003588846*^9, 3.6091393700654497`*^9, 
   3.615033723391221*^9, 3.617707853722721*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Normal", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.6089638230497293`*^9, 3.608963830865343*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}], ",", "0"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.608963833283347*^9, 3.608963967147182*^9, 
  3.608964009204856*^9, 3.609139375930785*^9, 3.615033740775215*^9, 
  3.6177078678965316`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Normal"}]], "Input",
 CellChangeTimes->{{3.609139383471216*^9, 3.6091393864273853`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\!\(\*RowBox[{\\\"Normal\\\", \\\"[\\\", \
StyleBox[\\\"expr\\\", \\\"TI\\\"], \\\"]\\\"}]\) converts \
\!\(\*StyleBox[\\\"expr\\\", \\\"TI\\\"]\) to a normal expression, from a \
variety of special forms. \"\>", "MSG"], "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Normal"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.617707909511912*^9},
 CellTags->"Info3617715109-3903716"]
}, Closed]],

Cell["\<\
The result is an alternating bilinear form in dimension two with  the only \
strict coordinate\
\>", "Text",
 CellChangeTimes->{{3.5867611712118564`*^9, 3.586761221964759*^9}, {
  3.6092151598757515`*^9, 3.609215169273289*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "h", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{
     RowBox[{"d", "[", "f", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{
  3.5866075367049265`*^9, {3.5866078946943555`*^9, 3.586607923382806*^9}, {
   3.586609053713991*^9, 3.586609060437603*^9}, {3.5866091609953794`*^9, 
   3.586609167874992*^9}, 3.5866142301590858`*^9, {3.5867609939407167`*^9, 
   3.586761018799139*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SuperscriptBox["h", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["h", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.592315406404249*^9, 3.6089640618081484`*^9, 
  3.6091395423133016`*^9, 3.6150337722220135`*^9, 3.617707918680436*^9}]
}, Closed]],

Cell["We defined in tensalg.m", "Text",
 CellChangeTimes->{{3.6091400809761114`*^9, 3.6091400842482986`*^9}, {
  3.6095608806670294`*^9, 3.609560890167446*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"extprod", "[", "w___", "]"}], " ", ":=", " ", 
  RowBox[{"Normal", "[", 
   RowBox[{"TensorWedge", "[", "w", "]"}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.609140140859536*^9, 3.6091402137787075`*^9}, 
   3.609140254443033*^9, {3.609142536672043*^9, 3.6091425573932285`*^9}, {
   3.609143273953213*^9, 3.609143278689484*^9}, 3.6095608991218615`*^9, 
   3.614861849581922*^9, 3.614917782357744*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "extprod"}]], "Input",
 CellChangeTimes->{{3.609561048024123*^9, 3.6095610523765306`*^9}}],

Cell[BoxData[
 StyleBox["\<\"extprod[w1,w2,...] yields the exterior product of \
antisymmetric forms or \\nmultivectors represented by their Arrays of \
coordinates. It avoids the concept of tensor.\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.6177079611788673`*^9},
 CellTags->"Info3617715161-3903716"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"extprod", "[", "]"}]], "Input",
 CellChangeTimes->{3.609143301679799*^9}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.6091433028738675`*^9, 3.6092179922187524`*^9, 
  3.6150338268521385`*^9, 3.617707977875822*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Context", "[", "extprod", "]"}]], "Input",
 CellChangeTimes->{{3.615035389346508*^9, 3.615035402573264*^9}}],

Cell[BoxData["\<\"tensalg`\"\>"], "Output",
 CellChangeTimes->{3.6150354037683325`*^9, 3.6177079815940347`*^9}]
}, Closed]],

Cell["\<\
A symbolic function isn\[CloseCurlyQuote]t recognized as a 0-form, extprod is \
not evaluated:\
\>", "Text",
 CellChangeTimes->{{3.609215433394396*^9, 3.6092155061055546`*^9}, {
  3.6150338443951416`*^9, 3.6150338459312296`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"extprod", "[", 
  RowBox[{"f", "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{3.6092153726999245`*^9, 3.6150338561808157`*^9}],

Cell[BoxData[
 RowBox[{"TensorWedge", "[", 
  RowBox[{"f", "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Output",
 CellChangeTimes->{3.6150338574978914`*^9, 3.61770799515781*^9}]
}, Closed]],

Cell["A concrete function is treated as a 0-form:", "Text",
 CellChangeTimes->{{3.60921561144158*^9, 3.609215640329232*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"extprod", "[", 
  RowBox[{"Cos", "[", 
   RowBox[{"u", "*", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{
  3.6092153726999245`*^9, {3.6092155294898925`*^9, 3.609215560515667*^9}}],

Cell[BoxData[
 RowBox[{"Cos", "[", 
  RowBox[{"u", " ", "v"}], "]"}]], "Output",
 CellChangeTimes->{3.6092155637028494`*^9, 3.609218001912307*^9, 
  3.615033890633786*^9, 3.6177080198812246`*^9}]
}, Closed]],

Cell["Again", "Text",
 CellChangeTimes->{{3.6092156749692135`*^9, 3.609215677897381*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"extprod", "[", 
  RowBox[{
   RowBox[{"h", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6091402188970003`*^9, 3.609140224441317*^9}, {
   3.609142821985362*^9, 3.6091428627446938`*^9}, 3.609142910601431*^9, 
   3.615033913997123*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"h", "[", 
   RowBox[{"u", ",", "v"}], "]"}], "\[TensorWedge]", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "}"}]}]], "Output",
 CellChangeTimes->{3.609140225384371*^9, 3.6091402593943167`*^9, 
  3.609142873681319*^9, 3.609142912429535*^9, 3.6091433769141026`*^9, 
  3.609218006017542*^9, 3.6150339194924374`*^9, 3.6177080250325193`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"extprod", "[", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{"u", "*", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6091402188970003`*^9, 3.609140224441317*^9}, {
   3.609142821985362*^9, 3.6091428627446938`*^9}, 3.609142910601431*^9, {
   3.609143190727453*^9, 3.609143205793315*^9}, {3.609215712988388*^9, 
   3.609215713740431*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"u", " ", "v"}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"u", " ", "v"}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6091432073444033`*^9, 3.6092157178576665`*^9, 
  3.6092159656918416`*^9, 3.609218010219782*^9, 3.6150339415286975`*^9, 
  3.617708060203531*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"extprod", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "h", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", "%"}], "]"}]], "Input",
 CellChangeTimes->{{3.6091433804543047`*^9, 3.6091434103450146`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Cos", "[", 
         RowBox[{"u", " ", "v"}], "]"}]}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{"u", " ", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{"u", " ", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{"u", " ", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}], ",", "0"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6091434141932344`*^9, 3.6092157755539665`*^9, 
  3.609215970419112*^9, 3.6092180157540984`*^9, 3.6150339637259674`*^9, 
  3.6177081030529814`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "\[Equal]", " ", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"u", "*", "v"}], "]"}], "*", 
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", "h", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{"d", "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6092158552315235`*^9, 3.6092159353341055`*^9}, {
  3.6092159856369824`*^9, 3.6092159966696134`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.6092159367211847`*^9, 3.6092159981306973`*^9, 
  3.6092180308619623`*^9, 3.6150339946097336`*^9, 3.617708153936892*^9}]
}, Closed]],

Cell["\<\
The exterior product is Flat (associative). Clearly, the exterior product of \
three 1-forms of dimension 2 is zero:\
\>", "Text",
 CellChangeTimes->{{3.609216249538077*^9, 3.609216334377929*^9}, {
  3.6093086665503273`*^9, 3.6093086714706087`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"extprod", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "g", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "h", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{"d", "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6092160822505083`*^9, 3.609216157741826*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.609216170150536*^9, 3.6092180345681744`*^9, 
  3.615034027963641*^9, 3.6177081785553*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"extprod", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "g", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"d", "[", "h", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6092160822505083`*^9, 3.609216157741826*^9}, {
  3.609216355858158*^9, 3.6092163783164425`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.609216379512511*^9, 3.609218039589462*^9, 
  3.615034044922611*^9, 3.6177082169694977`*^9}]
}, Closed]],

Cell["Now we consider 1-forms in dimension 3:", "Text",
 CellChangeTimes->{{3.609216789849981*^9, 3.609216812481275*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"extprod", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "h", "]"}], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6091402188970003`*^9, 3.609140224441317*^9}, {
   3.609142821985362*^9, 3.6091428627446938`*^9}, 3.609142910601431*^9, {
   3.609142950990741*^9, 3.609142964984541*^9}, {3.6091435169461117`*^9, 
   3.609143530265874*^9}, 3.615034059357437*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}]}]}], ",", "0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}]}]}], ",", "0"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.609142965978598*^9, 3.6091435360442038`*^9, 
  3.609143575423456*^9, 3.609218049821047*^9, 3.615034063381667*^9, 
  3.6177082256889963`*^9}]
}, Closed]],

Cell["Again we verify the associativity:", "Text",
 CellChangeTimes->{{3.609216843546052*^9, 3.609216862265123*^9}, 
   3.6093087120219283`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a21", " ", "=", 
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "h", "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
     RowBox[{"extprod", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"d", "[", "g", "]"}], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
       RowBox[{
        RowBox[{"d", "[", "f", "]"}], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.6091433804543047`*^9, 3.6091434103450146`*^9}, {
  3.609143545472743*^9, 3.6091435497609887`*^9}, {3.609143585873054*^9, 
  3.609143586697101*^9}, {3.609216489982829*^9, 3.6092165562066174`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a111", "=", " ", 
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "h", "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
     RowBox[{
      RowBox[{"d", "[", "g", "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
     RowBox[{
      RowBox[{"d", "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6091440266972675`*^9, 3.609144079570292*^9}, {
  3.6091441215396924`*^9, 3.609144165396201*^9}, {3.6091442799737544`*^9, 
  3.6091443095794477`*^9}, {3.6092166697831135`*^9, 3.6092166863090587`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a111", " ", "\[Equal]", " ", "a21"}], "]"}]], "Input",
 CellChangeTimes->{{3.6092166921003895`*^9, 3.6092167377400002`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.609216713678624*^9, 3.6092167388270626`*^9}, 
   3.6092169330021687`*^9, 3.6092180611386943`*^9, 3.615034351071122*^9, 
   3.6177082491673393`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"a111", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2", ",", "3"}], "]"}], "]"}], " ", "-", " ", 
    RowBox[{"a21", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2", ",", "3"}], "]"}], "]"}]}], ")"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6091441764198313`*^9, 3.6091442160330973`*^9}, {
  3.609216964916994*^9, 3.609217029803705*^9}, {3.609217095364455*^9, 
  3.609217187740739*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.6091442228184853`*^9, 3.609144323989272*^9, 3.6092170452905912`*^9, {
   3.609217160549184*^9, 3.6092171894018335`*^9}, 3.60921806735605*^9, 
   3.6150343762685633`*^9, 3.617708261687055*^9}]
}, Closed]],

Cell["The operation ", "Text",
 CellChangeTimes->{{3.609139990103914*^9, 3.609139996104257*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "wedgeform"}]], "Input",
 CellChangeTimes->{{3.60913964229502*^9, 3.609139656209816*^9}}],

Cell[BoxData[
 StyleBox["\<\"wedgeform[w1,w2,...] is the alternating product of the \
covectors w1,w2,... \\nentered by their coordinate tuples or by a matrix \
whose rows are the coordinate tuples of the \\ncovectors.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.617708312803979*^9},
 CellTags->"Info3617715512-6521894"]
}, Closed]],

Cell["produces the corresponding antisymmetric tensor :", "Text",
 CellChangeTimes->{{3.6091400076729183`*^9, 3.6091400438659887`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"wedgeform", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "h", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6091397202424784`*^9, 3.609139724370715*^9}}],

Cell[BoxData[
 RowBox[{"tensor", "[", 
  RowBox[{
   RowBox[{"cova", "[", 
    RowBox[{"tp", "[", 
     RowBox[{
      RowBox[{"tensor", "[", 
       RowBox[{"tensalg`Private`xx$80415", ",", "1", ",", "0", ",", "2"}], 
       "]"}], ",", 
      RowBox[{"tensor", "[", 
       RowBox[{"tensalg`Private`xx$80416", ",", "1", ",", "0", ",", "2"}], 
       "]"}]}], "]"}], "]"}], ",", "2", ",", "0", ",", "2"}], "]"}]], "Output",
 CellChangeTimes->{
  3.6091397257627945`*^9, 3.6092174900220284`*^9, 3.6092176050996103`*^9, 
   3.6092177145028677`*^9, {3.6092180723413353`*^9, 3.609218093349537*^9}, 
   3.6092183628689528`*^9, 3.6092184246754875`*^9, 3.6150344099684906`*^9, 
   3.6177083243186374`*^9}]
}, Closed]],

Cell["The coordinates of this tensor", "Text",
 CellChangeTimes->{{3.609217804145995*^9, 3.6092178311615405`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coords", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.609139746633988*^9, 3.6091397593617163`*^9}, {
   3.6092174664596806`*^9, 3.6092174781203475`*^9}, 3.6092176008673687`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["h", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["h", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["h", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", "0", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6092174940932612`*^9, 3.6092176101689005`*^9, 3.6092177185020967`*^9, {
   3.6092180766725826`*^9, 3.6092180968177347`*^9}, 3.60921836650216*^9, 
   3.6092184279736757`*^9, 3.615034444896488*^9, 3.6177083324031*^9}]
}, Closed]],

Cell["coincide with the coordinates of", "Text",
 CellChangeTimes->{{3.609217843090223*^9, 3.6092178651704855`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"extprod", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "h", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6092175258450775`*^9, 3.609217530150324*^9}, 
   3.6092175690455484`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}], ",", "0"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6092175706576405`*^9, 3.6092177216232753`*^9, 
  3.609218102590065*^9, 3.609218371150426*^9, 3.6092184321689157`*^9, 
  3.6150344612654247`*^9, 3.6177083702942667`*^9}]
}, Closed]],

Cell["up to the Array structure, indeed:", "Text",
 CellChangeTimes->{{3.6092178773931847`*^9, 3.609217882329467*^9}, {
  3.6092183033775496`*^9, 3.609218325625822*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Flatten", "[", "%", "]"}], " ", "\[Equal]", " ", 
  RowBox[{"Flatten", "[", "%%", "]"}]}]], "Input",
 CellChangeTimes->{{3.6092176666411304`*^9, 3.6092176953477726`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.6092176983409433`*^9, 3.6092177251524773`*^9}, 
   3.6092181062492743`*^9, 3.6150344778573737`*^9, 3.6177083803528423`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coords", "[", 
  RowBox[{"wedgeform", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "h", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{
     RowBox[{"d", "[", "f", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["h", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["h", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["h", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", "0", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6177084270385127`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", 
  RowBox[{"coords", "[", 
   RowBox[{"wedgeform", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "h", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{"d", "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6092185747600718`*^9, 3.609218607205928*^9}, {
  3.609218654523634*^9, 3.6092186639891753`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{3.6092186715126057`*^9, 3.6150344839167204`*^9, 
  3.6177083855111375`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", 
  RowBox[{"extprod", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "h", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{
     RowBox[{"d", "[", "f", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6092185747600718`*^9, 3.609218607205928*^9}, {
   3.609218654523634*^9, 3.6092186930178356`*^9}, 3.609218730717992*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "2"}], "}"}]], "Output",
 CellChangeTimes->{3.609218732012066*^9, 3.615034492508212*^9, 
  3.617718954716158*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "astb", "]"}], ";", 
  RowBox[{
   RowBox[{"astb", "[", 
    RowBox[{"i_", ",", "j_"}], "]"}], ":=", " ", 
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{"stb", "[", 
      RowBox[{"i", ",", "2"}], "]"}], ",", 
     RowBox[{"stb", "[", 
      RowBox[{"j", ",", "2"}], "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.609218978260151*^9, 3.609219025731866*^9}, {
   3.6092191432765894`*^9, 3.609219180020691*^9}, {3.609219259397231*^9, 
   3.6092192606123004`*^9}, 3.60921947547759*^9, {3.609219528924647*^9, 
   3.6092195414523635`*^9}, {3.6150350891103354`*^9, 3.6150351090304747`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"astb", "[", 
  RowBox[{"1", ",", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.615034993116845*^9, 3.6150350090367556`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.615035012104931*^9, 3.6150351165629053`*^9, 
  3.6177189658077927`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"extprod", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "h", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}], ",", "0"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.615034758663435*^9, 3.617718978924543*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", " ", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"extprod", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"d", "[", "h", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", 
        RowBox[{
         RowBox[{"d", "[", "f", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", "j"}], "]"}], "]"}], "*", 
     RowBox[{"astb", "[", 
      RowBox[{"i", ",", "j"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6092190678682756`*^9, 3.6092191330150023`*^9}, {
   3.609219191174329*^9, 3.6092192513927727`*^9}, {3.6092192931361604`*^9, 
   3.6092192956713057`*^9}, {3.6092194987919235`*^9, 3.60921950030301*^9}, {
   3.609219600768756*^9, 3.6092196156726084`*^9}, {3.615034717386074*^9, 
   3.615034718041112*^9}, 3.6150348346557817`*^9, 3.6150349412718797`*^9, 
   3.6150351628795547`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}], ",", "0"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.609219269035782*^9, 3.60921932634606*^9, 3.6092195103145823`*^9, 
   3.609219578480481*^9, 3.609219616606662*^9, 3.6150345247760572`*^9, 
   3.6150347200382257`*^9, 3.615034836631894*^9, 3.615034949365342*^9, {
   3.6150351462816057`*^9, 3.615035165698716*^9}, 3.6177189938753977`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "h", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{"d", "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}], " ", "\[Equal]", "  ", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"extprod", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"d", "[", "h", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], ",", 
          RowBox[{
           RowBox[{"d", "[", "f", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "j"}], "]"}], "]"}], "*", 
       RowBox[{"astb", "[", 
        RowBox[{"i", ",", "j"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "/", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6092190678682756`*^9, 3.6092191330150023`*^9}, {
   3.609219191174329*^9, 3.6092192513927727`*^9}, {3.6092192931361604`*^9, 
   3.6092192956713057`*^9}, {3.6092194987919235`*^9, 3.60921950030301*^9}, {
   3.609219600768756*^9, 3.6092196156726084`*^9}, {3.615034717386074*^9, 
   3.615034718041112*^9}, 3.615034776780471*^9, {3.6150351991356287`*^9, 
   3.6150352002156906`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.6150352048659563`*^9, 3.6177190106293564`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "h", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{"d", "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}], " ", "-", 
   RowBox[{
    RowBox[{
     RowBox[{"extprod", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"d", "[", "h", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{
        RowBox[{"d", "[", "f", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}], "*", 
    RowBox[{"astb", "[", 
     RowBox[{"1", ",", "2"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6092190678682756`*^9, 3.6092191330150023`*^9}, {
   3.609219191174329*^9, 3.6092192513927727`*^9}, {3.6092192931361604`*^9, 
   3.6092192956713057`*^9}, {3.6092194987919235`*^9, 3.60921950030301*^9}, {
   3.609219600768756*^9, 3.6092197225507216`*^9}, 3.6092198184562073`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6092197262189317`*^9, 3.6092198270937014`*^9, 
  3.615034578119108*^9, 3.6150352355017085`*^9, 3.6177190183417974`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"extprod", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "u", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"d", "[", "v", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.609219902395008*^9, 3.609219945660483*^9}, {
   3.609221187240497*^9, 3.609221221451454*^9}, {3.609308783305005*^9, 
   3.609308810152541*^9}, {3.6093089621622353`*^9, 3.609308967298529*^9}, 
   3.6093090292660737`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.609219935008874*^9, 3.609219946857551*^9}, {
   3.6092211957229824`*^9, 3.609221222973541*^9}, 3.6093088150088186`*^9, 
   3.6093089688896203`*^9, 3.609309034378366*^9, 3.6150345910928507`*^9, 
   3.6150353264519105`*^9, 3.6177190250421805`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"extprod", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"x", "[", "1", "]"}], "]"}], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"x", "[", "2", "]"}], "]"}], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.609219902395008*^9, 3.609219945660483*^9}, {
   3.609221187240497*^9, 3.609221221451454*^9}, {3.609308783305005*^9, 
   3.609308810152541*^9}, {3.6093089621622353`*^9, 3.609308967298529*^9}, 
   3.6093090292660737`*^9, {3.6093091109147434`*^9, 3.6093091850349827`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6093091862130504`*^9, 3.6095615385212927`*^9, 
  3.615034599403326*^9, 3.617719036725849*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["1.3.4. The Exterior Differential", "Subsubsection",
 CellChangeTimes->{{3.5866649932855587`*^9, 3.586665013117693*^9}, {
   3.5872725258470573`*^9, 3.587272530654332*^9}, {3.5898752162352247`*^9, 
   3.589875218169628*^9}, 3.5899533142260494`*^9, {3.609309548254758*^9, 
   3.6093095610144877`*^9}, 3.6095615905629835`*^9, 3.6177190633933744`*^9, 
   3.6177712155926075`*^9}],

Cell[TextData[{
 "We are going to define  the  ",
 StyleBox["exterior differential",
  FontColor->RGBColor[0, 0, 1]],
 " of a differential form in two variables. Of course, the exterior \
differential can be defined more generally using tensor calculus. We restrict \
to the elementary special case which suffices for the applications to surface \
theory and corresponds to the presentation in [",
 ButtonBox["B-R",
  BaseStyle->"Hyperlink",
  ButtonData->"B-R"],
 "]."
}], "Text",
 CellChangeTimes->{{3.5725350648802934`*^9, 3.572535066877097*^9}, {
  3.5725954538048487`*^9, 3.5725954928361173`*^9}, {3.572610955875272*^9, 
  3.5726109814905167`*^9}, {3.5726191833921223`*^9, 3.5726191938753405`*^9}, {
  3.5867612571647725`*^9, 3.5867613047324934`*^9}, {3.615114957662568*^9, 
  3.6151152495158386`*^9}, {3.6151153013033066`*^9, 3.615115302223708*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"h", ",", "dd"}], "]"}], ";", 
   RowBox[{
    RowBox[{
     RowBox[{"dd", "[", "h_", "]"}], "[", 
     RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"n", "=", "1"}], ",", 
        RowBox[{"pp", "=", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], ",", "i"}], "}"}], ",", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Head", "[", 
            RowBox[{"h", "[", 
             RowBox[{"u", ",", "v"}], "]"}], "]"}], "\[Equal]", "List"}], "&&", 
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"h", "[", 
             RowBox[{"u", ",", "v"}], "]"}], "]"}], "\[Equal]", "2"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Return", "[", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"h", "[", 
               RowBox[{"u", ",", "v"}], "]"}], "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", "u"}], "]"}], "-", " ", 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"h", "[", 
               RowBox[{"u", ",", "v"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", "v"}], "]"}]}], "]"}]}], 
        "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"MatrixQ", "[", 
          RowBox[{"h", "[", 
           RowBox[{"u", ",", "v"}], "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"pp", " ", "=", " ", 
           RowBox[{"Dimensions", "[", 
            RowBox[{"h", "[", 
             RowBox[{"u", ",", "v"}], "]"}], "]"}]}], ";", " ", 
          RowBox[{"n", "=", 
           RowBox[{"pp", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"pp", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Return", "[", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"h", "[", 
                  RowBox[{"u", ",", "v"}], "]"}], "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", "u"}], "]"}], "-", " ", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"h", "[", 
                  RowBox[{"u", ",", "v"}], "]"}], "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", "v"}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "n"}], "}"}]}], "]"}], "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "\"\<invalid argument\>\"", "]"}], ";", 
       RowBox[{"Return", "[", "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{"dd", "/:", " ", 
  RowBox[{
   RowBox[{"dd", "[", 
    RowBox[{"h1_", "+", "h2_"}], "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"dd", "[", "h1", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "+", 
   RowBox[{
    RowBox[{"dd", "[", "h2", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.586611033529069*^9, 3.5866110693779316`*^9}, {
   3.5866111324644423`*^9, 3.586611457584614*^9}, 3.586611520499524*^9, {
   3.586611943603467*^9, 3.5866119702327137`*^9}, {3.586614520818796*^9, 
   3.5866145367152243`*^9}, 3.586614577431296*^9, 3.586614609473752*^9, {
   3.586762054171359*^9, 3.5867620926175575`*^9}, {3.5867621358820324`*^9, 
   3.5867623292970953`*^9}, {3.5867624177691555`*^9, 3.586762433465053*^9}, {
   3.5867760440221004`*^9, 3.586776094448984*^9}, {3.5867769739352884`*^9, 
   3.5867769950704975`*^9}, {3.589892593479661*^9, 3.589892594446862*^9}, {
   3.5898926941154375`*^9, 3.5898926998406477`*^9}, {3.589892800195624*^9, 
   3.589892805359233*^9}, {3.614861849644322*^9, 3.614861849659922*^9}, 
   3.6148635015156236`*^9, 3.6149177824045444`*^9, {3.615098252957732*^9, 
   3.615098275624572*^9}, 3.6150983436406913`*^9, {3.6151005145716925`*^9, 
   3.6151005965439014`*^9}, 3.6151006554184046`*^9, {3.6151008492175455`*^9, 
   3.6151008715411844`*^9}, {3.615100908201249*^9, 3.615101079286749*^9}, {
   3.6151012150170536`*^9, 3.615101262846738*^9}, {3.6151037500098104`*^9, 
   3.6151037619906316`*^9}, {3.617774172939002*^9, 3.6177741956526413`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dd", "::", "usage"}], " ", "=", " ", 
   "\"\<If h[u,v] is a differential form in two variables u,v or a vector of \
such differential forms then dd[h][u,v] is its exterior differential.\>\""}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6150981806204047`*^9, 3.615098198919237*^9}, {
   3.6150983764163485`*^9, 3.615098563881878*^9}, {3.615098632287998*^9, 
   3.615098639885212*^9}, 3.6150986885572968`*^9}],

Cell["\<\
In general context, the exterior differential of a differential form is an \
alternating 2-form whose only strict coordinate is just defined.\
\>", "Text",
 CellChangeTimes->{{3.586761454700071*^9, 3.5867615540287523`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"h1", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"u", "*", "v"}], "]"}], ",", 
    RowBox[{"Sin", "[", 
     RowBox[{"u", "*", "v"}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.586611682661809*^9, 3.5866117023490434`*^9}, 
   3.589952099935517*^9, {3.615102028135137*^9, 3.6151020402719584`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{"u", " ", "v"}], "]"}], ",", 
   RowBox[{"Sin", "[", 
    RowBox[{"u", " ", "v"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5898712058279524`*^9, 3.589871633019103*^9, 
  3.589871667729164*^9, 3.58987181922103*^9, 3.589873169247401*^9, 
  3.5898905261016293`*^9, 3.5898905710765085`*^9, 3.5898907021479387`*^9, 
  3.5898918359423304`*^9, 3.5898920526891108`*^9, 3.589892616427301*^9, 
  3.589892723209489*^9, 3.58989281487525*^9, 3.5899519448088446`*^9, 
  3.589952103507923*^9, 3.589953663151862*^9, 3.5899543510498714`*^9, 
  3.608964677135629*^9, 3.609559173740429*^9, 3.6150987197105513`*^9, 
  3.615102041488761*^9, 3.6151038485086775`*^9, 3.617769740032816*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"h2", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Cosh", "[", 
     RowBox[{"u", "*", "v"}], "]"}], ",", 
    RowBox[{"Sinh", "[", 
     RowBox[{"u", "*", "v"}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.589952108921133*^9, 3.589952176126051*^9}, {
   3.589952224626536*^9, 3.589952234953754*^9}, 3.615098851343583*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", 
   RowBox[{"h1", "+", "h2"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5899519548240623`*^9, 3.589951985041315*^9}, {
  3.5899521931612806`*^9, 3.5899521987928905`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"v", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"u", " ", "v"}], "]"}]}], "+", 
  RowBox[{"v", " ", 
   RowBox[{"Cosh", "[", 
    RowBox[{"u", " ", "v"}], "]"}]}], "+", 
  RowBox[{"u", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"u", " ", "v"}], "]"}]}], "-", 
  RowBox[{"u", " ", 
   RowBox[{"Sinh", "[", 
    RowBox[{"u", " ", "v"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.589952202131296*^9, 3.5899522398365626`*^9, 
  3.5899536790014906`*^9, 3.609559182679245*^9, 3.615098731160972*^9, 
  3.6150988613120003`*^9, 3.6151020563867865`*^9, 3.61510385563789*^9, 
  3.6151044503254876`*^9, 3.6177697507656345`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"h", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"h1", "[", 
    RowBox[{"u", ",", "v"}], "]"}], "+", " ", 
   RowBox[{"h2", "[", 
    RowBox[{"u", ",", "v"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5899522637670045`*^9, 3.589952293578657*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", "h", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.589952307540682*^9, 3.5899523148414946`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"v", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"u", " ", "v"}], "]"}]}], "+", 
  RowBox[{"v", " ", 
   RowBox[{"Cosh", "[", 
    RowBox[{"u", " ", "v"}], "]"}]}], "+", 
  RowBox[{"u", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"u", " ", "v"}], "]"}]}], "-", 
  RowBox[{"u", " ", 
   RowBox[{"Sinh", "[", 
    RowBox[{"u", " ", "v"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.6177700534217663`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", 
   RowBox[{"u", "*", "h1"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.589952419892079*^9, 3.589952446958126*^9}}],

Cell[BoxData["\<\"invalid argument\"\>"], "Print",
 CellChangeTimes->{
  3.5899524483933287`*^9, {3.5899528301572*^9, 3.589952835539209*^9}, 
   3.5899529901978807`*^9, 3.6089647160888977`*^9, 3.6150999168878546`*^9, 
   3.615102117226894*^9, 3.6151027373123827`*^9, 3.615103881580735*^9, 
   3.617770121266285*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Head", "[", 
  RowBox[{"u", "*", 
   RowBox[{"h1", "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input"],

Cell[BoxData["List"], "Output",
 CellChangeTimes->{3.6151040019578075`*^9, 3.6177701441047254`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Head", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"u", "*", "h1"}], ")"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6095592950930424`*^9, 3.609559297058646*^9}, 
   3.6095593286175013`*^9, {3.615102833034151*^9, 3.6151028659502087`*^9}, {
   3.61510390696198*^9, 3.6151039161512938`*^9}}],

Cell[BoxData[
 RowBox[{"h1", " ", "u"}]], "Output",
 CellChangeTimes->{3.6095593307547054`*^9, 3.6150999435171013`*^9, 
  3.6151021216729016`*^9, 3.6151028668550105`*^9, 3.6151039174460955`*^9, 
  3.617770162481558*^9}]
}, Closed]],

Cell["\<\
The reason that dd[u*h1][u,v] is not evaluated is, maybe, that dd considers \
the second expression by definition. To get the result first define\
\>", "Text",
 CellChangeTimes->{{3.615104041892352*^9, 3.6151042091479855`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"h3", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", " ", 
  RowBox[{"u", "*", 
   RowBox[{"h1", "[", 
    RowBox[{"u", ",", "v"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.589955054829507*^9, 3.5899550806319523`*^9}, 
   3.5899551571032867`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"u", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"u", " ", "v"}], "]"}]}], ",", 
   RowBox[{"u", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"u", " ", "v"}], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.589955081521154*^9, 3.5899551577272882`*^9, 
  3.6089647517505603`*^9, 3.6095596258448234`*^9, 3.615100174613553*^9, 
  3.61510350171243*^9, 3.6177701833231945`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", "h3", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.589955092331973*^9, 3.589955101255189*^9}, 
   3.589955163858099*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"u", " ", "v", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"u", " ", "v"}], "]"}]}], "+", 
  RowBox[{"Sin", "[", 
   RowBox[{"u", " ", "v"}], "]"}], "+", 
  RowBox[{
   SuperscriptBox["u", "2"], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"u", " ", "v"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.609559628652828*^9, 3.615100179730362*^9, 
  3.6151035072192397`*^9, 3.617770187831602*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Hint.",
  FontColor->RGBColor[0, 0, 1]],
 " To obtain the exterior differential of a compound expression \
f1{u,v]*w[u,v] + ...  first define the differential form ww[u_,v_] = \
f1{u,v]*w[u,v] + ... and then apply dd: dd[ww][u,v]"
}], "Text",
 CellChangeTimes->{{3.5899554102605314`*^9, 3.5899554428489885`*^9}, {
  3.589955473783843*^9, 3.5899557104518585`*^9}, {3.5899558438758273`*^9, 
  3.5899558469950056`*^9}, {3.6151001589606686`*^9, 3.6151001591634693`*^9}}],

Cell["\<\
The exterior differential of the differential of a function vanishes:\
\>", "Text",
 CellChangeTimes->{{3.5867617995727963`*^9, 3.5867618376129723`*^9}, 
   3.5898679504454346`*^9, 3.615100269508519*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", 
   RowBox[{"d", "[", "f", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.586611564975202*^9, 3.5866115972360587`*^9}, {
  3.586611662428573*^9, 3.586611668028983*^9}, {3.5866117129258623`*^9, 
  3.586611719056673*^9}, {3.5866146342933955`*^9, 3.5866146379750023`*^9}, {
  3.5866147131203337`*^9, 3.586614738844779*^9}, {3.5866148159869146`*^9, 
  3.5866148182489185`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5898929851495485`*^9, 3.5899551979597588`*^9, 
  3.6089647700337925`*^9, 3.609560009199897*^9, 3.61510027563933*^9, 
  3.617770330025852*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", "3"}], ";", 
  RowBox[{
   RowBox[{"d", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6151003339210324`*^9, 3.6151003497394605`*^9}, {
  3.617770591201511*^9, 3.61777059667712*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6151003509406624`*^9, 3.6151006753396397`*^9, 
  3.6151007578949847`*^9, 3.61777033458106*^9, 3.617770598751924*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", 
   RowBox[{"d", "[", "sf", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5867618457264366`*^9, 3.586761895606289*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.6151011305328393`*^9, 3.6151012874323807`*^9, 
  3.617770347872283*^9, 3.617770618751159*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", "g3", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5867618457264366`*^9, 3.586761895606289*^9}, {
  3.5867625598042793`*^9, 3.586762588238906*^9}}],

Cell[BoxData["\<\"invalid argument\"\>"], "Print",
 CellChangeTimes->{3.5898930119191957`*^9, 3.5899552079749765`*^9, 
  3.6089647961950383`*^9, 3.609560019386715*^9, 3.615101143044061*^9, 
  3.615101291909589*^9, 3.6151043410818253`*^9, 3.617770625552771*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", 
   RowBox[{"vec", "[", "x", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5867618457264366`*^9, 3.586761895606289*^9}, {
  3.5867625598042793`*^9, 3.586762616862543*^9}}],

Cell[BoxData["\<\"invalid argument\"\>"], "Print",
 CellChangeTimes->{3.5898930281900244`*^9, 3.5899552191133957`*^9, 
  3.6089648112334647`*^9, 3.60956004525156*^9, 3.615101297073198*^9, 
  3.615104345449833*^9, 3.617770640918798*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ff", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", 
  RowBox[{"vec", "[", "x", "]"}]}]], "Input",
 CellChangeTimes->{{3.5867628343769836`*^9, 3.5867628555821967`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], ",", 
   RowBox[{"x", "[", "2", "]"}], ",", 
   RowBox[{"x", "[", "3", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5898930364892387`*^9, 3.5899552219682007`*^9, 
  3.6089648162254734`*^9, 3.6089649577489223`*^9, 3.6095600569827805`*^9, 
  3.6151043559798512`*^9, 3.6177706496704135`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", "ff", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5867628680829115`*^9, 3.5867628796065707`*^9}}],

Cell[BoxData["\<\"invalid argument\"\>"], "Print",
 CellChangeTimes->{3.589893041590448*^9, 3.5899552383638296`*^9, 
  3.608964822871085*^9, 3.608964972974549*^9, 3.6095600637219925`*^9, 
  3.6151013030324087`*^9, 3.6151043626254625`*^9, 3.617770654802822*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ff", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", 
  RowBox[{"vec", "[", 
   RowBox[{"x", "[", 
    RowBox[{"u", ",", "v"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5867628343769836`*^9, 3.5867628555821967`*^9}, {
  3.586775896995691*^9, 3.5867759043721128`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", "1", "]"}], ",", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", "2", "]"}], ",", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", "3", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.589893054881671*^9, 3.589955242575837*^9, 
  3.608964828268695*^9, 3.608964979744961*^9, 3.6095600743300114`*^9, 
  3.6151013082896175`*^9, 3.6151043671965036`*^9, 3.6177706605748324`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "ff", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5867759283174825`*^9, 3.5867759383390555`*^9}, {
  3.5867771002355123`*^9, 3.586777105603819*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["x", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", "1", "]"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["x", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", "1", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["x", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", "2", "]"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["x", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", "2", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["x", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", "3", "]"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["x", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", "3", "]"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.589893060404081*^9, 3.589955254931059*^9, 
  3.6089648328083024`*^9, 3.608964984580969*^9, 3.6095600822236247`*^9, 
  3.6151013208788395`*^9, 3.615104372778728*^9, 3.6177706664092426`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", "ff", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5867759283174825`*^9, 3.5867759383390555`*^9}, {
  3.5867771002355123`*^9, 3.586777105603819*^9}, {3.617770731164956*^9, 
  3.6177707380757685`*^9}}],

Cell[BoxData["\<\"invalid argument\"\>"], "Print",
 CellChangeTimes->{3.6177707390117702`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"d", "[", "ff", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5867759283174825`*^9, 3.5867759383390555`*^9}, {
  3.5867771002355123`*^9, 3.586777105603819*^9}, {3.617770731164956*^9, 
  3.6177707634726133`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["x", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "[", "1", "]"}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "[", "1", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["x", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "[", "1", "]"}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "[", "1", "]"}]}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["x", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "[", "2", "]"}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "[", "2", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["x", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "[", "2", "]"}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "[", "2", "]"}]}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["x", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "[", "3", "]"}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "[", "3", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["x", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "[", "3", "]"}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "[", "3", "]"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6177707647362156`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", 
   RowBox[{"d", "[", "ff", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5867759467785387`*^9, 3.586775999747568*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.5898930709496994`*^9, 3.589955259813867*^9, 
  3.6089649933949842`*^9, 3.609560101099658*^9, 3.615101329037654*^9, 
  3.615104378878339*^9, 3.617770703677708*^9, 3.6177707803362427`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"h", ",", "ff"}], "]"}], ";", 
  RowBox[{
   RowBox[{"ff", "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], "=", " ", 
   RowBox[{
    RowBox[{"h", "[", 
     RowBox[{"u", ",", "v"}], "]"}], "*", 
    RowBox[{
     RowBox[{"d", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.58677719845613*^9, 3.5867773007009783`*^9}, 
   3.615104410515194*^9, 3.617626036060483*^9, {3.6177708820640216`*^9, 
   3.6177708901604357`*^9}, 3.6177709382397203`*^9, {3.6177709850710025`*^9, 
   3.617770986038204*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.617771021777867*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", "ff", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.586777308549427*^9, 3.5867773194350495`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["h", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{
      SuperscriptBox["h", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["h", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{
      SuperscriptBox["h", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["h", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{
      SuperscriptBox["h", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5898930903093333`*^9, 3.608965024548239*^9, 
  3.6089650965579658`*^9, 3.6095601176668873`*^9, 3.6151013501600914`*^9, 
  3.6151018958937054`*^9, 3.6151044168217144`*^9, 3.6177710447723074`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "-", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"extprod", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"d", "[", "h", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"d", "[", "sf", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.586777359339332*^9, 3.5867774925729523`*^9}, {
   3.586777531981207*^9, 3.586777539156617*^9}, {3.586777573533583*^9, 
   3.58677763886232*^9}, {3.5867777724309597`*^9, 3.586777818870616*^9}, {
   3.6089650800063367`*^9, 3.6089650838439436`*^9}, {3.609560182594201*^9, 
   3.609560186307008*^9}, 3.614861849691122*^9, 3.6148635015312233`*^9, 
   3.617770966179369*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5898931834258966`*^9, 3.608965039883066*^9, {3.6089650903491545`*^9, 
   3.608965101581175*^9}, 3.6095601897390137`*^9, 3.615101900636113*^9, 
   3.6151044282496033`*^9, 3.6177711029136095`*^9}]
}, Closed]],

Cell["\<\
Since dd yields the only strict coordinate of the alternating 2-form we had \
to specify the strict coordinate of the exterior product. In traditional \
notation the last formula can be written as\
\>", "Text",
 CellChangeTimes->{{3.586778144938266*^9, 3.5867782694653883`*^9}, {
  3.6095602428727074`*^9, 3.6095602647439456`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"d", "\[Wedge]", 
     RowBox[{"(", 
      RowBox[{"h", " ", "*", 
       RowBox[{"d", "(", "sf", ")"}]}], ")"}]}], "\[LongEqual]", "dh"}], 
   "\[And]", 
   RowBox[{"d", "(", "sf", ")"}]}], TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5867782884074717`*^9, 3.5867784070832596`*^9}, {
   3.5867784387070684`*^9, 3.5867784871388383`*^9}, 3.5867785184666305`*^9, {
   3.61777100630264*^9, 3.6177710104990473`*^9}},
 TextAlignment->Center]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.4. The Derivation Equations", "Subsection",
 CellChangeTimes->{{3.586839514507707*^9, 3.5868395266264005`*^9}, {
   3.5872725402788825`*^9, 3.5872725434780655`*^9}, 3.6095615970681953`*^9, 
   3.6096567356047544`*^9, 3.615036647915494*^9, 3.6150391086202383`*^9, 
   3.6177712240322223`*^9, 3.617772205182746*^9}],

Cell[CellGroupData[{

Cell["1.4.1. The Orthonormal Cobasis {\[Sigma][1], \[Sigma][2]}", \
"Subsubsection",
 CellChangeTimes->{{3.5867788245861397`*^9, 3.586778908304928*^9}, {
   3.5867789597698717`*^9, 3.586778962401022*^9}, 3.586839376202797*^9, {
   3.5868713690839806`*^9, 3.586871375838793*^9}, {3.587272548686363*^9, 
   3.587272552854602*^9}}],

Cell["\<\
The orthonormal cobasis   {\[Sigma][1], \[Sigma][2]} is the dual basis to the \
orthonormal Basis {amf[1], amf[2]} of the tangent spaces. It is defined by\
\>", "Text",
 CellChangeTimes->{{3.609650787300531*^9, 3.609650922932289*^9}, {
  3.6148618497223225`*^9, 3.6148618498159227`*^9}, {3.6149177824513445`*^9, 
  3.614917782482545*^9}, {3.61491854824109*^9, 3.614918549130291*^9}, {
  3.6150366787472577`*^9, 3.6150367104430704`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "[", "i_", "]"}], "[", "f_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Length", "[", 
        RowBox[{"f", "[", 
         RowBox[{"u", ",", "v"}], "]"}], "]"}], "===", "dim"}], ")"}], "&&", 
     RowBox[{"(", 
      RowBox[{"i", ">=", " ", "1"}], ")"}], "&&", 
     RowBox[{"(", 
      RowBox[{"i", "<=", " ", "dim"}], ")"}]}], ",", 
    RowBox[{"Return", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"amf", "[", "i", "]"}], "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ".", 
      RowBox[{
       RowBox[{"d", "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Print", "[", "\"\<Invalid argument!\>\"", "]"}], ";", 
     RowBox[{"Return", "[", "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5862684374261866`*^9, 3.586268590883964*^9}, {
   3.586268694356882*^9, 3.5862687381573877`*^9}, {3.5862689068290353`*^9, 
   3.586268967629513*^9}, {3.5868451322760253`*^9, 3.586845153622246*^9}, {
   3.5868451909133787`*^9, 3.5868454031145163`*^9}, {3.5868455663498526`*^9, 
   3.5868456048040524`*^9}, {3.586845689054871*^9, 3.5868457266850233`*^9}, {
   3.5868458045404763`*^9, 3.5868458267597475`*^9}, {3.586845979053458*^9, 
   3.586845987693952*^9}, {3.5868460253081036`*^9, 3.5868460401399517`*^9}, {
   3.5868461640450387`*^9, 3.586846178851886*^9}, {3.5868462272766557`*^9, 
   3.5868462390363283`*^9}, 3.5868463462864623`*^9, {3.586846553173296*^9, 
   3.58684656827516*^9}, {3.586846604924256*^9, 3.5868466802425632`*^9}, {
   3.586846871252489*^9, 3.5868468892185163`*^9}, {3.586847223476635*^9, 
   3.5868472486350737`*^9}, {3.5868472800588713`*^9, 3.586847288730367*^9}, {
   3.586847402107852*^9, 3.5868474363878126`*^9}, {3.5868475906426353`*^9, 
   3.5868476198363056`*^9}, {3.5868477813165417`*^9, 3.5868477944282913`*^9}, 
   3.609650066236288*^9, {3.6096500990871677`*^9, 3.6096501028473825`*^9}, {
   3.6096501406985474`*^9, 3.6096501659779935`*^9}, {3.609650204137176*^9, 
   3.609650254747071*^9}, {3.6096505070675025`*^9, 3.6096505316539087`*^9}, {
   3.6096505653868384`*^9, 3.6096505818417797`*^9}, 3.6148618498159227`*^9, 
   3.614917782498145*^9, 3.6149184396336985`*^9, {3.615036953864993*^9, 
   3.615036975872252*^9}, {3.617775036650119*^9, 3.6177750639501667`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Protect", "[", "\[Sigma]", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.615038622399428*^9, 3.615038629986862*^9}, {
  3.6150387321087027`*^9, 3.6150387356289043`*^9}}],

Cell[BoxData[
 RowBox[{"{", "\<\"\[Sigma]\"\>", "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0W0s1AEABvCTaUyHXbK0MWZeVjrtTlNzcf+j6Y2LXpCj85K3Ez7Ueac2
pLOKIWu5usXpDTs5yxl2RWzRmzAnbJ3rtv7KOc51aKvn/+HZ78vz6Xk8U/Ji
rljRaDQh4jc9WcA1kERm/4nmTMgaSY24DluflFbWwYvaj48H4BFx5DcdtJ+w
kTBWSULePB8WDHnnF9xOwbvezPJ3MHt4l7sW0np9O3SQ69UrdjSSRJ3DGele
2Jhs4bHhKmts7TjM3f2iLhVyZuvzJLA0IrZICX28PsWp4EbDNf4o/PUzxbII
TdLIGT1kLCU3krCYJt+zAofecH12rpHEbJmuPxD28V1uh0LOyaDwROiS1NNd
DW+enTuqgGnc74nzMPtSU+sCbEp0+22zjv6DiSI2ZN7qYRyG/nMZHjxIyINj
RdC5ZFxTBY1lnRe6YUuPQj8E+aO+xjnYrndXa6Hoq9UypfKtirkMcz63WGxM
2Glx/yQdpoeIIhhQ/OHqABMWtvvXs6HSNftlELQWVTvGw/w/MnMC1Dbk8AWQ
HHstzYJ+shDbbFgzfH+zEro4lAka4FTC+OUOGB9VyxqAFROvhINQ/aX3xjT0
lsvPaaAmLbDMaoMkbFl9EntYWCOZpmxcF2rpMM4wUxIAc2d4BWzIYbQ95MBB
9Xu7eMj4Gz1SAcmnW9adUHbnYGgXHJqMX6R04q6YKTMUwlQVVJhMAVNQF5lF
6qBy3wj9H6yxO82h1FS55+8wk0T4dkutHxQbXPui4b1H9GIhTI91Lq+GWkF9
NeUOpxjVM2hM8tnogh6uBr3Zgt+So9Sb0EHqPEr5PMztwDbcyl86RHnsR0YK
ZZtg3lO2SRL/AVfLwDM=
  "]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]", "::", "usage"}], " ", "=", " ", 
   "\"\<{\[Sigma][i][f][u,v]}, i = 1,2, is the cobasis field to the \
orthonormal basis field in the tangent bundle of the surface f[u,v], \
\[Sigma][i][f][u,v]= {0,0} for 2<i<= dim. \>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6150387743961215`*^9, 3.6150389861352324`*^9}, {
   3.6177752655025206`*^9, 3.617775347558665*^9}, 3.6177755839926805`*^9}],

Cell[CellGroupData[{

Cell[BoxData["dim"], "Input",
 CellChangeTimes->{{3.59733021329095*^9, 3.5973302565784254`*^9}, {
  3.5973819456579657`*^9, 3.597381958777589*^9}}],

Cell[BoxData["3"], "Output",
 CellChangeTimes->{3.6096491150418835`*^9, 3.617771464056644*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5862685978523626`*^9, 3.586268637618637*^9}, {
  3.5868454727975016`*^9, 3.586845508677554*^9}, {3.586847494630144*^9, 
  3.5868475090139666`*^9}, {3.6096503908708563`*^9, 3.6096504000783834`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"]}]], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}]], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.609649134637004*^9, 3.6096503369007697`*^9, 
  3.609650401504465*^9, 3.615036757253748*^9, 3.6177714727614594`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5862685978523626`*^9, 3.586268637618637*^9}, {
  3.5868454727975016`*^9, 3.586845508677554*^9}, {3.586847494630144*^9, 
  3.5868475090139666`*^9}, {3.5868477190429797`*^9, 3.586847749885744*^9}, {
  3.586847865477355*^9, 3.586847871125678*^9}, {3.609650411374029*^9, 
  3.609650424006752*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], ")"}]}], 
     ")"}], "/", 
    RowBox[{"(", 
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}]], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.60964932006361*^9, 3.609650427800969*^9, 
  3.615036851720151*^9, 3.6177715291867585`*^9}]
}, Closed]],

Cell["By definition we have", "Text",
 CellChangeTimes->{{3.6096511679643035`*^9, 3.609651177323839*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "-", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ".", 
    RowBox[{
     RowBox[{"d", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6096493267409916`*^9, 3.609649346334112*^9}, {
   3.6096499062221365`*^9, 3.6096499841265917`*^9}, 3.6148618498315225`*^9, 
   3.614917782513745*^9, 3.6149185578819065`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.6096499860397015`*^9, 3.6096504368174844`*^9, 
  3.615036881233839*^9, 3.6177715573448076`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "[", "3", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5862685978523626`*^9, 3.586268637618637*^9}, 
   3.5868463633494387`*^9, {3.586847469821725*^9, 3.586847475909073*^9}, {
   3.5868475678933344`*^9, 3.5868475750537443`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.61503700381085*^9, 3.6177715771724424`*^9, 
  3.6177751294546824`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "[", "4", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5862685978523626`*^9, 3.586268637618637*^9}, 
   3.5868463633494387`*^9, {3.586847469821725*^9, 3.586847475909073*^9}, {
   3.5868475678933344`*^9, 3.5868475750537443`*^9}, {3.617774888730659*^9, 
   3.6177748964370728`*^9}}],

Cell[BoxData["\<\"Invalid argument!\"\>"], "Print",
 CellChangeTimes->{3.6177751342594905`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "[", "1", "]"}], "[", 
    RowBox[{"vec", "[", "x", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5862685978523626`*^9, 3.586268637618637*^9}, 
   3.5868463633494387`*^9, {3.586847469821725*^9, 3.586847475909073*^9}, {
   3.5868475678933344`*^9, 3.5868475750537443`*^9}, {3.5868476634187984`*^9, 
   3.5868476818378515`*^9}}],

Cell[BoxData["\<\"Invalid argument!\"\>"], "Print",
 CellChangeTimes->{3.6096506060751657`*^9, 3.6150370245180345`*^9, 
  3.617771581821251*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]", "[", "1", "]"}], "[", 
   RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5862685978523626`*^9, 3.586268637618637*^9}, {
  3.5862690108319836`*^9, 3.5862690363924456`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "v", "]"}], "2"]}], 
     SqrtBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "2"]}]}]]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "u", "]"}], "2"]}], 
     SqrtBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "2"]}]}]]]}], ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5907363373535633`*^9, 3.6096506183858695`*^9, 
  3.615037031657443*^9, 3.6177715896368647`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", ">", "0"}], ",", " ", 
     RowBox[{"v", " ", "\[Element]", " ", "Reals"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.586834921828021*^9, 3.5868349307725325`*^9}, {
  3.6177716436597595`*^9, 3.6177716527701755`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", " ", 
    RowBox[{"Abs", "[", 
     RowBox[{"Cos", "[", "v", "]"}], "]"}]}], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.609650625755291*^9, 3.6150370533976865`*^9, 
  3.617771603645689*^9, 3.617771660538989*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Sigma]", "[", "2", "]"}], "[", 
     RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", ">", "0"}], ",", " ", 
     RowBox[{"v", " ", "\[Element]", " ", "Reals"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5862685978523626`*^9, 3.586268637618637*^9}, {
  3.5862690108319836`*^9, 3.5862690869863396`*^9}, {3.609650667958705*^9, 
  3.60965070004354*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "r"}], "}"}]], "Output",
 CellChangeTimes->{3.590736344295576*^9, 3.609650637205946*^9, 
  3.6096507012526093`*^9, 3.615037066420431*^9, 3.617771686091834*^9}]
}, Closed]],

Cell[TextData[{
 "We verify some classical formulas first expressed in traditional notation, \
then proved by calculation with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.5868371669714355`*^9, 3.586837253204368*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["1.",
    FontColor->RGBColor[0, 0, 1]], 
   StyleBox[
    RowBox[{
     StyleBox[" ",
      FontColor->RGBColor[0, 0, 1]], "  "}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"[", 
      RowBox[{"B", "-", "R"}], "]"}], ",", " ", 
     RowBox[{"(", "41.6", ")"}]}], ")"}], "                    ", 
   RowBox[{"d", "[", "sf", "]"}]}], " ", "\[Equal]", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "*", 
    RowBox[{"\[Sigma]", "[", "1", "]"}]}], " ", "+", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "*", 
    RowBox[{"\[Sigma]", "[", "2", "]"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868372815939918`*^9, 3.586837377709489*^9}, {
  3.586837463149376*^9, 3.5868375120501733`*^9}, {3.586837863366267*^9, 
  3.5868378687105727`*^9}, {3.614861849847122*^9, 3.614861849847122*^9}, {
  3.6149177825293446`*^9, 3.6149177825293446`*^9}, {3.614918462362939*^9, 
  3.6149184637981415`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ".", 
     RowBox[{"{", 
      RowBox[{"s", ",", "t"}], "}"}]}], "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "*", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ".", 
        RowBox[{"{", 
         RowBox[{"s", ",", "t"}], "}"}]}]}], " ", "+", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "*", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ".", 
        RowBox[{"{", 
         RowBox[{"s", ",", "t"}], "}"}]}]}]}], ")"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.586835336082715*^9, 3.586835446246016*^9}, {
   3.5868355063994565`*^9, 3.58683551555098*^9}, {3.586835582798826*^9, 
   3.586835692009073*^9}, {3.5897805003550973`*^9, 3.5897805009010983`*^9}, {
   3.5897806863542237`*^9, 3.589780691627033*^9}, {3.614861849847122*^9, 
   3.6148618498627224`*^9}, {3.614917782544945*^9, 3.614917782544945*^9}, 
   3.6149184651709437`*^9, 3.6149185594419093`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.5897804772514563`*^9, 3.5897805033347025`*^9}, 
   3.5897807010026493`*^9, 3.6096507423909626`*^9, 3.615037142196765*^9, 
   3.6177717186178913`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["2.",
    FontColor->RGBColor[0, 0, 1]], "   ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"[", 
      RowBox[{"B", "-", "R"}], "]"}], ",", " ", 
     RowBox[{"(", "42.13", ")"}]}], ")"}], "                ", "fund1"}], " ",
   "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "[", "1", "]"}], "^", "2"}], "  ", "+", "  ", 
   RowBox[{
    RowBox[{"\[Sigma]", "[", "2", "]"}], "^", "2", " "}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868377489117208`*^9, 3.5868378393648944`*^9}, {
   3.586837873052821*^9, 3.5868379575736556`*^9}, 3.5904957105154095`*^9}],

Cell["We evaluate the corresponding symmetric bilinear form:", "Text",
 CellChangeTimes->{{3.5868380097146378`*^9, 3.586838051907051*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"vs", "=", 
   RowBox[{"{", 
    RowBox[{"s1", ",", "s2"}], "}"}]}], ";", 
  RowBox[{"vt", "=", 
   RowBox[{"{", 
    RowBox[{"t1", ",", "t2"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.586836626522524*^9, 3.58683667733243*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{"vs", ",", "vt"}], "]"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ".", "vs"}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ".", "vt"}], ")"}]}], "-", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ".", "vs"}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ".", "vt"}], ")"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.586836684445837*^9, 3.586836692207281*^9}, {
   3.586836738835948*^9, 3.586836753262773*^9}, {3.5868367939941025`*^9, 
   3.5868368662162333`*^9}, {3.5868369358372154`*^9, 3.586836950725067*^9}, {
   3.586836982972912*^9, 3.5868370924811754`*^9}, 3.5904957105154095`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5897807322027044`*^9, 3.5897809881523542`*^9, 
  3.609651268152034*^9, 3.609651321892108*^9, 3.615037194987785*^9, 
  3.617771747524742*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["3.",
    FontColor->RGBColor[0, 0, 1]], "   ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"[", 
      RowBox[{"B", "-", "R"}], "]"}], ",", " ", 
     RowBox[{"(", "42.7", ")"}]}], ")"}], "   ", 
   StyleBox["The", "Text"], 
   StyleBox["  ", "Text"], 
   StyleBox["area", "Text"], 
   StyleBox[" ", "Text"], 
   StyleBox["element", "Text"], "             ", "dA"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{"\[Sigma]", "[", "1", "]"}], "\[Wedge]", 
   RowBox[{"\[Sigma]", "[", "2", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5868381994844923`*^9, 3.586838240604844*^9}, {
  3.586838344268773*^9, 3.5868383915254765`*^9}, {3.586838428773607*^9, 
  3.586838434333925*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dA", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "\[Equal]", " ", 
   RowBox[{"Det", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "}"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5868384410843105`*^9, 3.5868384512198906`*^9}, {
   3.586838491404189*^9, 3.586838569777672*^9}, 3.586838627365966*^9, {
   3.586838866175625*^9, 3.5868388901109934`*^9}, {3.586839064039942*^9, 
   3.586839101438081*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.588414261095311*^9, 3.6096513493326774`*^9, 
  3.6150372325879354`*^9, 3.617771762812769*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"extprod", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.588414285618554*^9, 3.5884143135270033`*^9}, {
  3.609651368687784*^9, 3.6096513743031054`*^9}, {3.609651417118554*^9, 
  3.6096514250310073`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], ")"}]}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], ")"}]}]}], 
     ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.588414315274206*^9, 3.5884147465525637`*^9, 
  3.6096513802064433`*^9, 3.6096514277981653`*^9, 3.615037252805092*^9, 
  3.6177717832020044`*^9, 3.6179534594508824`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"%", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", " ", 
   RowBox[{"Det", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "}"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.58841475574098*^9, 3.5884148014646597`*^9}, {
  3.6096514383987713`*^9, 3.6096514445281224`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5884148030402627`*^9, 3.609651394099238*^9, 
  3.609651447152272*^9, 3.6150372660208473`*^9, 3.617771805650444*^9, 
  3.6179534721636095`*^9}]
}, Closed]],

Cell["\<\
Remember that  the determinant on the right side of the equation is the only \
strict coordinate 
of \[Sigma][1]\[Wedge]\[Sigma][2] in the local basis du, dv; since (du,dv) \
and (\[Sigma][1][sf][u,v],\[Sigma][2][sf][u,v]}) define the same orientation \
of the tangent space, this determinant is always assumed to be positive.\
\>", "Text",
 CellChangeTimes->{{3.586839212899456*^9, 3.586839299018382*^9}, {
  3.590736505584259*^9, 3.5907365286878996`*^9}, {3.617953744410181*^9, 
  3.617953914697921*^9}}],

Cell[TextData[{
 StyleBox["The basis transformation.",
  FontColor->RGBColor[0, 0, 1]],
 "\nWe calculate the decomposition of the \[Sigma][i] with respect to the \
basis du,dv, stating"
}], "Text",
 CellChangeTimes->{{3.590721556004931*^9, 3.5907216598688717`*^9}, {
  3.590722468989151*^9, 3.5907224724133463`*^9}, {3.5907350609125214`*^9, 
  3.59073506573293*^9}},
 CellTags->"bastr"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[Sigma]", "(", "1", ")"}], "\[LongEqual]", 
   FractionBox[
    RowBox[{" ", 
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "(", 
        RowBox[{"1", ",", "1"}], ")"}], " ", "du"}], "+", " ", 
      RowBox[{
       RowBox[{"rgT", "(", 
        RowBox[{"1", ",", "2"}], ")"}], " ", "dv"}]}]}], 
    SqrtBox[
     RowBox[{"rgT", "(", 
      RowBox[{"1", ",", "1"}], ")"}]]]}], TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.590735088992571*^9, 3.5907351925767527`*^9}, {
  3.590735232356823*^9, 3.590735292619729*^9}, {3.6176262984584913`*^9, 
  3.617626319160675*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[Sigma]", "(", "2", ")"}], "\[LongEqual]", 
   RowBox[{
    FractionBox[
     SqrtBox[
      TemplateBox[{RowBox[{"{", 
          RowBox[{"rgT", "(", 
            RowBox[{"i", ",", "j"}], ")"}], "}"}]},
       "Det"]], 
     SqrtBox[
      RowBox[{"rgT", "(", 
       RowBox[{"1", ",", "1"}], ")"}]]], " ", "dv", " "}]}], 
  TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.590735088992571*^9, 3.5907351925767527`*^9}, {
  3.590735232356823*^9, 3.590735292619729*^9}, {3.590735627864318*^9, 
  3.5907357745045753`*^9}, {3.617626330122302*^9, 3.6176263320654135`*^9}, {
  3.6176264002583137`*^9, 3.617626413915095*^9}}],

Cell[TextData[{
 StyleBox["Proof",
  FontColor->RGBColor[0, 0, 1]],
 ":"
}], "Text",
 CellChangeTimes->{{3.5907358558431177`*^9, 3.5907358594467244`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", " ", "v"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{"s1", ",", " ", "s2"}], "}"}]}], " ", "==", " ", "\n", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", " ", "1"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}], "*", 
       RowBox[{
        RowBox[{
         RowBox[{"d", "[", "u", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ".", 
        RowBox[{"{", 
         RowBox[{"s1", ",", " ", "s2"}], "}"}]}]}], " ", "+", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", " ", "2"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}], "*", 
       RowBox[{
        RowBox[{
         RowBox[{"d", "[", "v", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ".", 
        RowBox[{"{", 
         RowBox[{"s1", ",", " ", "s2"}], "}"}]}]}]}], ")"}], "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"1", ",", " ", "1"}], "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5907173613780117`*^9, 3.5907173699605026`*^9}, {
   3.5907174455358257`*^9, 3.590717473390419*^9}, {3.5907175080954037`*^9, 
   3.5907176306184115`*^9}, {3.5907177498192296`*^9, 3.590717791333604*^9}, {
   3.5907179684707355`*^9, 3.590718084885394*^9}, {3.5907203135178647`*^9, 
   3.5907203282297063`*^9}, {3.590720362173648*^9, 3.590720399942808*^9}, 
   3.590720439646079*^9, 3.5907349903223977`*^9, {3.5907353529138346`*^9, 
   3.5907354339715767`*^9}, {3.6096516615155334`*^9, 
   3.6096516949464455`*^9}, {3.6096517297964387`*^9, 3.609651768851672*^9}, {
   3.61762605087033*^9, 3.6176260543665295`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5907176333805695`*^9, 3.5907178136518803`*^9, 
  3.5907181108218775`*^9, 3.590720448662595*^9, 3.5907349951584063`*^9, 
  3.5907354409915895`*^9, 3.6096515156921926`*^9, 3.6096517810963726`*^9, 
  3.6150373267513213`*^9, 3.617771859595339*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", " ", "v"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{"s1", ",", " ", "s2"}], "}"}]}], " ", "==", " ", "\n", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"dA", "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", " ", "v"}], "]"}], "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", " ", "1"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}], ")"}], "*", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "v", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ".", 
     RowBox[{"{", 
      RowBox[{"s1", ",", " ", "s2"}], "}"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5907173613780117`*^9, 3.5907173699605026`*^9}, {
   3.5907174455358257`*^9, 3.590717473390419*^9}, {3.5907175080954037`*^9, 
   3.5907176306184115`*^9}, {3.5907177498192296`*^9, 3.590717791333604*^9}, {
   3.5907179684707355`*^9, 3.590718084885394*^9}, {3.5907203135178647`*^9, 
   3.5907203282297063`*^9}, {3.590720362173648*^9, 3.590720399942808*^9}, 
   3.590720439646079*^9, {3.590721070544164*^9, 3.590721087006106*^9}, {
   3.5907211626374316`*^9, 3.590721228294187*^9}, 3.590721882841625*^9, {
   3.5907219660703855`*^9, 3.5907219725897584`*^9}, {3.5907220046705933`*^9, 
   3.5907220343012877`*^9}, {3.590722076702713*^9, 3.5907220826040506`*^9}, 
   3.5907355108953123`*^9, {3.6096518755697765`*^9, 3.60965190080122*^9}, 
   3.6176260623649874`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.590722052533331*^9, 3.5907220921175947`*^9, 
  3.5907355131885157`*^9, 3.6096519060255184`*^9, 3.615037338670003*^9, 
  3.617771882558579*^9}]
}, Closed]],

Cell["Here remember", "Text",
 CellChangeTimes->{{3.590735889554777*^9, 3.590735895997588*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dA", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", " ", "v"}], "]"}], "\[Equal]", " ", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"Det", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5907359427352705`*^9, 3.590736093166335*^9}, {
   3.590736161681655*^9, 3.590736167609666*^9}, 3.614861849893923*^9, 
   3.614863501578024*^9, {3.6176264560655055`*^9, 3.6176264578096056`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5907360948511376`*^9, 3.590736168452067*^9, 
  3.60965191898826*^9, 3.6150373502216635`*^9, 3.617771898361407*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", " ", "v"}], "]"}], ".", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", " ", "1"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}], ",", " ", "0"}], 
    "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.609652212502048*^9, 3.6096522185163918`*^9}, {
  3.6096522543684425`*^9, 3.609652287800355*^9}, {3.6176264757526317`*^9, 
  3.6176264781367683`*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.6096522726094856`*^9, 3.6096522890734277`*^9}, 
   3.6150373801813774`*^9, 3.6177719018714128`*^9}]
}, Closed]],

Cell["\<\
We state and test the following formulas expressing the orthonormal basis \
with respect to the tangent basis t1,t2:\
\>", "Text",
 CellChangeTimes->{{3.6096536113480573`*^9, 3.6096536808440323`*^9}, {
   3.615037408346988*^9, 3.615037421618747*^9}, 3.615117680678119*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tv", "[", "1", "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6096536860943327`*^9, 3.609653696557931*^9}, 
   3.617600024337888*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "1", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "2", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "3", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6096536989990706`*^9, 3.6150374460091424`*^9, 
  3.6177720282784348`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tv", "[", "2", "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6096537089286385`*^9, 3.609653730893895*^9}, 
   3.617600085770796*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "1", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "2", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "3", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6096537314079247`*^9, 3.6150374460871468`*^9, 
  3.6177720314452405`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "==", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "1", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"1", ",", " ", "1"}], "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.60965374165051*^9, 3.609653754030218*^9}, {
   3.60965379095033*^9, 3.609653907929021*^9}, 3.6148618499095225`*^9, 
   3.614917782591745*^9, 3.6149185669143224`*^9, 3.617600024353488*^9, 
   3.6176265331969175`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.6096538978704453`*^9, 3.6096539092070937`*^9}, 
   3.615037458699868*^9, 3.61777204835567*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "\[Equal]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         RowBox[{
          RowBox[{"tv", "[", "1", "]"}], "[", "sf", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "*", 
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", " ", "2"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"tv", "[", "2", "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "*", 
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}]}]}], " ", ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"dA", "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", " ", "v"}], "]"}], "*", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", " ", "1"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.60965374165051*^9, 3.609653754030218*^9}, {
   3.60965379095033*^9, 3.6096539246169753`*^9}, {3.6096540031054645`*^9, 
   3.609654147059698*^9}, {3.6096541915242414`*^9, 3.6096541999007206`*^9}, 
   3.6096542338676634`*^9, {3.609654281572392*^9, 3.609654289737859*^9}, 
   3.6148618499095225`*^9, 3.6149177826073446`*^9, 3.6149185725303326`*^9, 
   3.617600024353488*^9, 3.617600085786396*^9, {3.6176265366951175`*^9, 
   3.617626541950418*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.609654294616138*^9, 3.61503747464178*^9, 
  3.6177720600868907`*^9}]
}, Closed]],

Cell["\<\
The next four identities verify the duality of the orthonormal basis and \
cobasis:\
\>", "Text",
 CellChangeTimes->{{3.6096566616205225`*^9, 3.6096567048279943`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", " ", "v"}], "]"}], ".", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", " ", "1"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}], ",", "0"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.609655949502792*^9, 3.6096559526939745`*^9}, {
   3.609655983711749*^9, 3.6096559907591515`*^9}, {3.6096560255621424`*^9, 
   3.60965603671278*^9}, 3.6176265453316116`*^9}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.6096560195677996`*^9, 3.6096560378008423`*^9}, 
   3.615037521355452*^9, 3.6177721334538193`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", " ", "v"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", " ", "2"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"1", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", " ", "v"}], "]"}]}], "}"}]}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"dA", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", " ", "v"}], "]"}], "*", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"1", ",", " ", "1"}], "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.609655949502792*^9, 3.6096559526939745`*^9}, {
  3.609655983711749*^9, 3.6096559907591515`*^9}, {3.6096560255621424`*^9, 
  3.609656054616804*^9}, {3.6096561620579495`*^9, 3.609656183154156*^9}, {
  3.609656261770653*^9, 3.609656267947006*^9}, {3.609656328491469*^9, 
  3.6096563674596977`*^9}, {3.6096564022096853`*^9, 3.609656417282548*^9}, {
  3.617626547645744*^9, 3.617626552389015*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.6096560598141017`*^9, 3.6096564360936236`*^9, 
  3.6150375317140446`*^9, 3.6177721364022245`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", " ", "v"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", " ", "2"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"1", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", " ", "v"}], "]"}]}], "}"}]}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"dA", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", " ", "v"}], "]"}], "*", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"1", ",", " ", "1"}], "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.609655949502792*^9, 3.6096559526939745`*^9}, {
  3.609655983711749*^9, 3.6096559907591515`*^9}, {3.6096560255621424`*^9, 
  3.6096560682745857`*^9}, {3.6096561208885946`*^9, 3.6096561300971217`*^9}, {
  3.6096565385274825`*^9, 3.60965656017072*^9}, {3.6176265555741973`*^9, 
  3.6176265598944445`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6096565612417817`*^9, 3.615037542004633*^9, 
  3.617772136433425*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", " ", "v"}], "]"}], ".", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", " ", "1"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}], ",", "0"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.609656584423107*^9, 3.6096566004730253`*^9}, 
   3.6176265614995365`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.609656602153122*^9, 3.6150375500060906`*^9, 
  3.6177721386486287`*^9}]
}, Closed]],

Cell["\<\
In the case of orthogonal parameters u,v, i.e. rgT[1,2][sf][u,v] == 0, the \
formulas simplify to\
\>", "Text",
 CellChangeTimes->{{3.6096570629004745`*^9, 3.6096571596600094`*^9}, 
   3.617626564157688*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"amf", "[", "1", "]"}], " ", "\[Equal]", " ", 
   RowBox[{"t1", "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"rgT", "[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}]}]}], ";", " ", 
  RowBox[{
   RowBox[{"amf", "[", "2", "]"}], " ", "\[Equal]", " ", 
   RowBox[{"t2", "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"rgT", "[", 
      RowBox[{"2", ",", "2"}], "]"}], "]"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.60965716946657*^9, 3.609657242111725*^9}, {
  3.609657306679418*^9, 3.609657312062726*^9}, {3.6148618499251223`*^9, 
  3.6148618499251223`*^9}, {3.614917782622945*^9, 3.614917782622945*^9}, {
  3.6149185737315345`*^9, 3.6149185765395393`*^9}, {3.6176265667318354`*^9, 
  3.6176265693079824`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]", "[", "1", "]"}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{"d", "[", "u", "]"}], "*", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"rgT", "[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}]}]}], ";", " ", 
  RowBox[{
   RowBox[{"\[Sigma]", "[", "2", "]"}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{"d", "[", "v", "]"}], "*", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"rgT", "[", 
      RowBox[{"2", ",", "2"}], "]"}], "]"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.60965716946657*^9, 3.6096572875913267`*^9}, {
   3.609657332815913*^9, 3.609657361215537*^9}, 3.6096575886875477`*^9, 
   3.609657638831416*^9, {3.61762657188413*^9, 3.6176265734042172`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["1.4.2. Derivation of the Orthonormal Frame", "Subsubsection",
 CellChangeTimes->{{3.5868395957793555`*^9, 3.586839624635006*^9}, {
   3.587272558157905*^9, 3.587272561670106*^9}, 3.609656777205134*^9, 
   3.609673033665471*^9, 3.6177723089073277`*^9, 3.617778896920499*^9}],

Cell["\<\
Now we consider the second part of the derivation equations [B-R], (41.6), \
traditionally written as \
\>", "Text",
 CellChangeTimes->{{3.5868413763872004`*^9, 3.586841403410746*^9}, {
  3.586841435555585*^9, 3.5868414605550146`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"amf", "[", "j", "]"}], "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ".", "v"}], "]"}], "\[Equal]", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", 
      RowBox[{"j", ",", "k"}], "]"}], "*", 
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "k", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "3"}], "}"}]}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.586841471104618*^9, 3.586841517365264*^9}, {
   3.5868415742765193`*^9, 3.586841612878727*^9}, {3.5868416500478535`*^9, 
   3.586841798703356*^9}, {3.586842211630974*^9, 3.586842226862845*^9}, 
   3.5868422721024323`*^9, {3.586842430621499*^9, 3.586842442502179*^9}, {
   3.6148618499407225`*^9, 3.6148618499407225`*^9}, {3.614917782622945*^9, 
   3.614917782638545*^9}, {3.614918685490131*^9, 3.614918689499338*^9}}],

Cell["\<\
that means we decompose the derivatives of the frame vectors in the frame \
itself. The main point here is that the formula defines the local structure \
forms of the frame: \
\>", "Text",
 CellChangeTimes->{{3.5868418968969717`*^9, 3.5868419627467384`*^9}, {
   3.586842047258572*^9, 3.5868420475225873`*^9}, {3.5868420867948337`*^9, 
   3.5868421500584517`*^9}, 3.6151176978140993`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Omega]", "[", 
   RowBox[{"j", ",", "k"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"amf", "[", "j", "]"}], "]"}], ".", 
   RowBox[{"amf", "[", "k", "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868421823663*^9, 3.586842199812298*^9}, {
  3.5868422541254044`*^9, 3.5868422601407485`*^9}, {3.586842300638065*^9, 
  3.586842314316847*^9}, {3.6148618499563227`*^9, 3.6148618499563227`*^9}, {
  3.614917782638545*^9, 3.6149177826541452`*^9}, {3.6149186917613416`*^9, 
  3.6149186932433443`*^9}}],

Cell[TextData[{
 "The ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " definition of these differential forms is"
}], "Text",
 CellChangeTimes->{{3.5868424600031796`*^9, 3.586842469555726*^9}, {
  3.58684251140312*^9, 3.5868425428909206`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Unprotect", "[", "\[Omega]", "]"}]], "Input",
 CellChangeTimes->{{3.617776936920656*^9, 3.6177769636123037`*^9}}],

Cell[BoxData[
 RowBox[{"{", "\<\"\[Omega]\"\>", "}"}]], "Output",
 CellChangeTimes->{3.617776964657505*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", 
      RowBox[{"j_", ",", "k_"}], "]"}], "[", "f_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", "\[IndentingNewLine]", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"j", ">=", "1"}], "&&", 
      RowBox[{"j", "<=", "dim"}], "&&", 
      RowBox[{"k", ">=", "1"}], "&&", 
      RowBox[{"k", "<=", "dim"}], "&&", 
      RowBox[{
       RowBox[{"Length", "[", 
        RowBox[{"f", "[", 
         RowBox[{"u", ",", "v"}], "]"}], "]"}], "\[Equal]", " ", "dim"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"j", "\[Equal]", "k"}], ",", 
        RowBox[{"Return", "[", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Return", "[", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"amf", "[", "k", "]"}], "[", "f", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], ".", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{
            RowBox[{"amf", "[", "j", "]"}], "[", "f", "]"}], "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Print", "[", "\"\<Invalid arguments!\>\"", "]"}], ";", 
      RowBox[{"Return", "[", "]"}]}]}], "]"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5868425689884133`*^9, 3.5868427046631737`*^9}, 
   3.586842867103465*^9, {3.586842907943801*^9, 3.5868429135911236`*^9}, {
   3.586843065686823*^9, 3.5868430715351577`*^9}, {3.5868431113754363`*^9, 
   3.586843117103764*^9}, {3.5868431605112467`*^9, 3.586843177967245*^9}, {
   3.586843347214926*^9, 3.586843389720357*^9}, 3.586843549785512*^9, {
   3.586848184577607*^9, 3.5868482812421355`*^9}, {3.5868483466668777`*^9, 
   3.5868483813548617`*^9}, {3.586848414264744*^9, 3.5868486273089294`*^9}, 
   3.5868486965418897`*^9, 3.609658177877248*^9, {3.6096582133592772`*^9, 
   3.6096583241116123`*^9}, {3.6096583805918427`*^9, 3.6096583834950085`*^9}, 
   3.609658418040984*^9, {3.6096584928332624`*^9, 3.6096585432111435`*^9}, {
   3.6096585808842983`*^9, 3.6096586149792485`*^9}, 3.6096587385003138`*^9, {
   3.6148618499563227`*^9, 3.614861849971923*^9}, {3.6149177826541452`*^9, 
   3.614917782669745*^9}, {3.6149186977517524`*^9, 3.614918700466157*^9}, {
   3.6177767763651743`*^9, 3.6177768768137507`*^9}, 3.617776910026209*^9, {
   3.617777034561228*^9, 3.617777046370449*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", "3"}], ";"}]], "Input",
 CellChangeTimes->{{3.6177762838567095`*^9, 3.617776319034771*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Omega]", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5868429252377896`*^9, 3.5868429767887383`*^9}, {
  3.586843433238846*^9, 3.5868434795654955`*^9}, {3.586848719485202*^9, 
  3.5868487233644238`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.609657964408038*^9, 3.6096587500379734`*^9, 3.6177762162773905`*^9, {
   3.617776257102662*^9, 3.6177762728118896`*^9}, 3.6177763430276136`*^9, 
   3.6177769817707353`*^9, 3.6177770534996614`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Omega]", "[", 
    RowBox[{"1", ",", "4"}], "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5868429252377896`*^9, 3.5868429767887383`*^9}, {
  3.586843433238846*^9, 3.5868434795654955`*^9}, {3.586848719485202*^9, 
  3.5868487233644238`*^9}, {3.609672962921425*^9, 3.609672970666868*^9}}],

Cell[BoxData["\<\"Invalid arguments!\"\>"], "Print",
 CellChangeTimes->{3.617777056276466*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Omega]", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5868429252377896`*^9, 3.5868429767887383`*^9}, {
  3.586843433238846*^9, 3.5868434795654955`*^9}, {3.586843579253197*^9, 
  3.5868435857265673`*^9}, {3.5868487299978027`*^9, 3.5868487340450344`*^9}, {
  3.60967251944306*^9, 3.609672531130728*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "-", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ".", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{
       RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6096579861182795`*^9, 3.609657997869952*^9}, {
  3.60965803910231*^9, 3.609658120935991*^9}, {3.614861849987523*^9, 
  3.614861849987523*^9}, {3.6149177826853447`*^9, 3.614917782700945*^9}, {
  3.6149187024473605`*^9, 3.614918703913763*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.609658122983108*^9, 3.609672547436661*^9, 
  3.617776407752127*^9, 3.617777078990106*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%%", "+", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5868435996083612`*^9, 3.586843645676996*^9}, {
  3.5868487453106785`*^9, 3.586848749404913*^9}, {3.6096725624665203`*^9, 
  3.609672580851572*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.609672599683649*^9, 3.617776428266163*^9, 
  3.617777097242138*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Omega]", "[", 
    RowBox[{"2", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.586843679460929*^9, 3.58684368874146*^9}, {
  3.586848755308251*^9, 3.58684876770896*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.6096726583980074`*^9, 3.6177764595130177`*^9, 
  3.617777100549344*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Omega]", "[", 
    RowBox[{"2", ",", "3"}], "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.586843679460929*^9, 3.586843727773692*^9}, {
  3.5868487753243957`*^9, 3.5868487778365393`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", 
      RowBox[{"2", ",", "3"}], "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "+", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", 
      RowBox[{"3", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.586843679460929*^9, 3.586843727773692*^9}, {
  3.5868437628767*^9, 3.5868438044780793`*^9}, {3.5868487931904173`*^9, 
  3.586848796973634*^9}, {3.609672698259287*^9, 3.609672711827063*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.609672733993331*^9, 3.6177765122255106`*^9, 
  3.6177771508750324`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Omega]", "[", 
    RowBox[{"3", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5868438496236615`*^9, 3.586843878845333*^9}, {
  3.586848804459062*^9, 3.5868488065651827`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", 
      RowBox[{"3", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "+", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", 
      RowBox[{"1", ",", "3"}], "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5868438496236615`*^9, 3.586843928902196*^9}, {
  3.586848816950776*^9, 3.5868488500336685`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.60967275075229*^9, 3.617776529697541*^9, 
  3.617777163292654*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Omega]", "[", 
    RowBox[{"3", ",", "3"}], "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5868438496236615`*^9, 3.586843953133582*^9}, {
  3.586848858750167*^9, 3.586848863541441*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.6096727564216137`*^9, 3.617776923660633*^9, 
  3.617777168269063*^9}]
}, Closed]],

Cell["Following [B-R], (41.12) we define", "Text",
 CellChangeTimes->{{3.5868493567396507`*^9, 3.586849361010895*^9}, {
  3.586849409451666*^9, 3.5868494290347853`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", "1", "]"}], "[", "f_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Omega]", "[", 
       RowBox[{"2", ",", "3"}], "]"}], "[", "f", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "/;", 
    RowBox[{"dim", "\[Equal]", "3"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", "2", "]"}], "[", "f_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Omega]", "[", 
       RowBox[{"3", ",", "1"}], "]"}], "[", "f", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "/;", 
    RowBox[{"dim", "\[Equal]", "3"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", "3", "]"}], "[", "f_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Omega]", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "[", "f", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "/;", 
    RowBox[{"dim", "\[Equal]", "3"}]}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5868494748924084`*^9, 3.5868495473585534`*^9}, 
   3.617775849770347*^9, {3.6177759029820404`*^9, 3.617775946038116*^9}, {
   3.6177760265654573`*^9, 3.6177760341158705`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Protect", "[", "\[Omega]", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.615037717015643*^9, 3.615037756364894*^9}}],

Cell[BoxData[
 RowBox[{"{", "\<\"\[Omega]\"\>", "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0WlI0wEYBvDN6bqYi5kkkheCWp457cDVnFamKaOmpuZK5wpTy0GoqUxF
vFIDtUjNhkK2Am2lmDibufDqMCyd2ppKjbUPf8lj6tgSrOf/4eXHA++H9+H1
EOVeuk6lUCjpGE3CfV/PVYI3rJkpCIeUwejmTPhxRByVB080SCsa4C/LVLsK
0sxxOgOcfk+vZa0RPE7zYmQY1AqWXGLgWmdgyRikjDBc9bC+17/bAEXuqnzm
OsHzto+TOUHzT2sEG1YHfzCdhXSHroYMqJlvyq2FB6KSCvtgjPtckhLe9Szl
j8Pbh8WWJahv5c8ZYZ4o4yEBWRS54wo8PXTBi24ieBLp78EQeGjq4D0uvDER
dkYIzwnf9FRBw5Tu5Gu4zdULFyA15dHTRWhZcP1jt4E7Wr4UsqGV3scKhaPa
TPcI+L2TczkbdjROaithjVSR0APLaL3Gd9A45rP+A54yuqn10GbGZpnUKeJt
wDK0/Sqz2G0SPJPQb5oB/UJyolhQG5urCoAts/6NbBi9K7vrOHycVc1MhgqH
W/xUMnvsnyEtnxiQ3YTqdu7uLOg20mytIPcYJakPYM6VyWvd0CCuD1ZBWupQ
2hBM/NZfNgtVnXKBFkrEoVLqFvocVdbug8yaulnSIxvpegZcXZkvDoT0ucgC
NmxvfNbGgfHqz3uSYX6xYLQUlj/fpr2EXnuPcRUwYTpliXRheMVMuvMqPUMJ
z29uBWpgUVwWYYCxzmOMf1BeGc8hHe92k9iYCZ7ur6zOB9qvOg9chCYXZlEa
3El0LKmCn5LaqkhbmQLlC1hz1XtLAfud1oxmC/6VxldbofyJ4zhpeKSr7zZs
khiCSG11mSLSoDuLHh1WgvcfqPnFCw==
  "]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Omega]", "::", "usage"}], " ", "=", " ", 
   "\"\<\[Omega][i,j][f][u,v] is the (i,j)-th structure form in the \
derivation equations of the surface f[u.v]. If dim = 3 one sets \[Omega][1]=\
\[Omega][2,3], \[Omega][2]=\[Omega][3,1], \[Omega][3]=\[Omega][1,2].\>\""}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.615037843228862*^9, 3.615037851164316*^9}, {
  3.6150378904935656`*^9, 3.615037974870392*^9}, {3.6150381937269096`*^9, 
  3.615038345791607*^9}, {3.615038395609456*^9, 3.615038458136033*^9}, {
  3.617776085533561*^9, 3.6177761088088017`*^9}}],

Cell[TextData[{
 "Clearly, the matrix {\[Omega][j,k][sf][u,v]} is skew symmetric. \n\n",
 StyleBox["Example",
  FontColor->RGBColor[0, 0, 1]],
 ": The local structure forms of a sphere:"
}], "Text",
 CellChangeTimes->{{3.5868440279308605`*^9, 3.586844087339258*^9}, {
   3.586848951379465*^9, 3.5868489860914507`*^9}, 3.6177773205253305`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "[", 
     RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{
    RowBox[{"r", ">", "0"}], "&&", 
    RowBox[{"v", ">", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}]}], "&&", 
    RowBox[{"v", "<", 
     RowBox[{"Pi", "/", "2"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5868443089369326`*^9, 3.5868443716615205`*^9}, 
   3.6177773788694324`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Sin", "[", "v", "]"}], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.609672782450103*^9, 3.6177773808350363`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", "1", "]"}], "[", 
     RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{
    RowBox[{"r", ">", "0"}], "&&", 
    RowBox[{"v", ">", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}]}], "&&", 
    RowBox[{"v", "<", 
     RowBox[{"Pi", "/", "2"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5868443089369326`*^9, 3.5868443716615205`*^9}, {
   3.586844407878592*^9, 3.5868444400784335`*^9}, 3.5868495899029865`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"-", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{3.609672833171004*^9, 3.6150384702317247`*^9, 
  3.617777434857931*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", "2", "]"}], "[", 
     RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{
    RowBox[{"r", ">", "0"}], "&&", 
    RowBox[{"v", ">", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}]}], "&&", 
    RowBox[{"v", "<", 
     RowBox[{"Pi", "/", "2"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5868443089369326`*^9, 3.5868443716615205`*^9}, {
   3.586844407878592*^9, 3.5868444400784335`*^9}, 3.5868495899029865`*^9, {
   3.5868496805901737`*^9, 3.5868496948869915`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Cos", "[", "v", "]"}], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.609672837077227*^9, 3.6150384808123293`*^9, 
  3.617777439303939*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", "3", "]"}], "[", 
     RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{
    RowBox[{"r", ">", "0"}], "&&", 
    RowBox[{"v", ">", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}]}], "&&", 
    RowBox[{"v", "<", 
     RowBox[{"Pi", "/", "2"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5868443089369326`*^9, 3.5868443716615205`*^9}, {
   3.586844407878592*^9, 3.5868444400784335`*^9}, 3.5868495899029865`*^9, {
   3.5868496805901737`*^9, 3.5868497038715057`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Sin", "[", "v", "]"}], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.6096728409974513`*^9, 3.6150384885127697`*^9, 
  3.617777443843547*^9}]
}, Closed]],

Cell[BoxData[
 StyleBox["\[FilledSquare]",
  FontColor->GrayLevel[0]]], "Input",
 CellChangeTimes->{{3.6177774546699657`*^9, 3.6177774857920203`*^9}}],

Cell[TextData[{
 "With the notations introduced above",
 StyleBox[" the derivation equations",
  FontColor->RGBColor[0, 0, 1]],
 " of the moving frame are the following\n(see [B-R], (41.13))"
}], "Text",
 CellChangeTimes->{{3.586870595603422*^9, 3.5868707256452503`*^9}, 
   3.587276591534601*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "sf", "]"}], " ", "\[Equal]", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "1", "]"}], "*", 
    RowBox[{"\[Sigma]", "[", "1", "]"}]}], " ", "+", "  ", 
   RowBox[{
    RowBox[{"amf", "[", "2", "]"}], "*", 
    RowBox[{"\[Sigma]", "[", "2", "]"}], " "}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868707506520944`*^9, 3.5868707637405176`*^9}, {
  3.5868708348454423`*^9, 3.586870922985597*^9}, {3.614861850049923*^9, 
  3.614861850049923*^9}, {3.6149177827477455`*^9, 3.6149177827477455`*^9}, {
  3.614918705364566*^9, 3.6149187071117687`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"amf", "[", "1", "]"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "2", "]"}], "*", 
    RowBox[{"\[Omega]", "[", "3", "]"}]}], " ", "-", "  ", 
   RowBox[{
    RowBox[{"amf", "[", "3", "]"}], "*", 
    RowBox[{"\[Omega]", "[", "2", "]"}], " "}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.586870881739125*^9, 3.586871024151775*^9}, {
  3.614861850049923*^9, 3.614861850065523*^9}, {3.6149177827633452`*^9, 
  3.6149177827633452`*^9}, {3.6149187088433714`*^9, 3.6149187119165773`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"amf", "[", "2", "]"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"amf", "[", "1", "]"}]}], "*", 
    RowBox[{"\[Omega]", "[", "3", "]"}]}], " ", "+", "  ", 
   RowBox[{
    RowBox[{"amf", "[", "3", "]"}], "*", 
    RowBox[{"\[Omega]", "[", "1", "]"}], " "}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868711037119145`*^9, 3.5868711559408064`*^9}, {
  3.614861850065523*^9, 3.614861850065523*^9}, {3.614917782778945*^9, 
  3.614917782778945*^9}, {3.6149187133361797`*^9, 3.6149187168929863`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"amf", "[", "3", "]"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "1", "]"}], "*", 
    RowBox[{"\[Omega]", "[", "2", "]"}]}], " ", "-", "  ", 
   RowBox[{
    RowBox[{"amf", "[", "2", "]"}], "*", 
    RowBox[{"\[Omega]", "[", "1", "]"}], " "}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868712300253363`*^9, 3.5868712863882356`*^9}, 
   3.587276317927952*^9, {3.614861850081123*^9, 3.614861850081123*^9}, {
   3.614917782794545*^9, 3.614917782794545*^9}, {3.6149187181409883`*^9, 
   3.6149187213857937`*^9}}],

Cell[TextData[{
 "Prove these identities with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", e.g."
}], "Text",
 CellChangeTimes->{{3.6177787011713552`*^9, 3.617778723697795*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox["Simplify",
   FontColor->GrayLevel[0]], 
  StyleBox["[",
   FontColor->GrayLevel[0]], 
  RowBox[{
   StyleBox[
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{
        RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ".", 
     RowBox[{"{", 
      RowBox[{"s", ",", "t"}], "}"}]}],
    FontColor->GrayLevel[0]], 
   StyleBox["-",
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox[
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "*", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Omega]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ".", 
      RowBox[{"{", 
       RowBox[{"s", ",", "t"}], "}"}]}]}],
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox["+",
    FontColor->GrayLevel[0]], 
   StyleBox["  ",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}],
     FontColor->GrayLevel[0]], 
    StyleBox["*",
     FontColor->GrayLevel[0]], 
    RowBox[{
     RowBox[{
      RowBox[{
       StyleBox[
        RowBox[{"\[Omega]", "[", "1", "]"}],
        FontColor->GrayLevel[0]], "[", "sf", "]"}], " ", "[", 
      RowBox[{"u", ",", "v"}], "]"}], 
     StyleBox[".",
      FontColor->GrayLevel[0]], 
     StyleBox[
      RowBox[{"{", 
       RowBox[{"s", ",", "t"}], "}"}],
      FontColor->GrayLevel[0]]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6177774546699657`*^9, 3.6177774857920203`*^9}, 
   3.617777584618194*^9, {3.617777635658284*^9, 3.617777680789163*^9}, {
   3.6177777202260323`*^9, 3.6177778181162043`*^9}, {3.617777882045117*^9, 
   3.617777930467602*^9}, {3.617778075594657*^9, 3.617778118276332*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.61777800370973*^9, 3.6177781506775885`*^9}]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.5. The Integrability Conditions", "Subsection",
 CellChangeTimes->{{3.586871511559031*^9, 3.58687153347707*^9}, {
   3.5872725777430253`*^9, 3.5872725852784567`*^9}, 3.6150391162116723`*^9, 
   3.6151171023083725`*^9, 3.617779463887895*^9, 3.6178037497835894`*^9}],

Cell[CellGroupData[{

Cell["1.5.1. Summary", "Subsubsection",
 CellChangeTimes->{{3.5872726720544195`*^9, 3.587272684318121*^9}},
 CellTags->"intcond"],

Cell[TextData[{
 "The local structure forms {\[Sigma][1], \[Sigma][2], \[Omega][1], \
\[Omega][2], \[Omega][3] } define all the local geometric properties of the \
surface which are invariant under Euclidean motions. One can prove that if \
the parameter representations of two surfaces have the same local structure \
forms on the same parameter manifold U, then the surfaces are congruent, i.e. \
they differ by an Euclidean motion only. But the forms are not independent of \
each other: they satisfy the so-called integrability conditions, which are \
obtained by exterior differentiation of the derivation equations. This \
operation yields the null vector at the left side; thus the components of the \
frame vectors at the right side after inserting the decomposition of the \
vector differentials using the derivation equations equal zero too, and this \
gives ",
 StyleBox["the integrability conditions",
  FontColor->RGBColor[0, 0, 1]],
 " (see [B-R] (41.14)):"
}], "Text",
 CellChangeTimes->{{3.5868715874843645`*^9, 3.5868718438864145`*^9}, {
  3.5868718815136805`*^9, 3.5868721317693205`*^9}, {3.5868721625013742`*^9, 
  3.586872176073398*^9}, {3.5868722337713647`*^9, 3.5868725303553286`*^9}, {
  3.5868731941242933`*^9, 3.5868732558838263`*^9}, {3.586956213834609*^9, 
  3.5869562430378604`*^9}, {3.609673188706339*^9, 3.6096731893043737`*^9}, {
  3.6178036508950157`*^9, 3.617803683046672*^9}, {3.617803722686342*^9, 
  3.617803723263543*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "dd"}]], "Input",
 CellChangeTimes->{{3.615097909507529*^9, 3.61509791044353*^9}}],

Cell[BoxData[
 StyleBox["\<\"If h[u,v] is a differential form in two variables u,v or a \
vector of such differential forms then dd[h][u,v] is its exterior \
differential.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.615115370316635*^9},
 CellTags->"Info3615122570-1826612"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", 
   RowBox[{"\[Sigma]", "[", "1", "]"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"\[Sigma]", "[", "2", "]"}]}], "\[Wedge]", 
   RowBox[{"\[Omega]", "[", "3", "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.586872685089178*^9, 3.586872778533523*^9}, 
   3.5868730982448096`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", 
   RowBox[{"\[Sigma]", "[", "2", "]"}], "]"}], " ", "\[Equal]", "  ", 
  RowBox[{
   RowBox[{"\[Sigma]", "[", "1", "]"}], "\[Wedge]", 
   RowBox[{"\[Omega]", "[", "3", "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.586872802700906*^9, 3.586872836820857*^9}, 
   3.5868730999729085`*^9}],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"0", " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Sigma]", "[", "1", "]"}], "\[Wedge]", 
     RowBox[{"\[Omega]", "[", "2", "]"}]}], "  ", "-", 
    RowBox[{
     RowBox[{"\[Sigma]", "[", "2", "]"}], "\[Wedge]", 
     RowBox[{"\[Omega]", "[", "1", "]"}]}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.58687286695158*^9, 3.5868729460291033`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", 
   RowBox[{"\[Omega]", "[", "1", "]"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"\[Omega]", "[", "2", "]"}]}], "\[Wedge]", 
   RowBox[{"\[Omega]", "[", "3", "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868729989181285`*^9, 3.5868730083976707`*^9}, 
   3.5868731054782233`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", 
   RowBox[{"\[Omega]", "[", "2", "]"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"\[Omega]", "[", "3", "]"}]}], "\[Wedge]", 
   RowBox[{"\[Omega]", "[", "1", "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868729989181285`*^9, 3.586873060821669*^9}, 
   3.5868731077973557`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", 
   RowBox[{"\[Omega]", "[", "3", "]"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"\[Omega]", "[", "1", "]"}]}], "\[Wedge]", 
   RowBox[{"\[Omega]", "[", "2", "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868729989181285`*^9, 3.5868730307969522`*^9}, {
  3.586873067326041*^9, 3.5868731114075623`*^9}}],

Cell["\<\
Remember that dd denotes the exterior derivation of a differential form. In \
the next subsections we check these formulas verifying them for the general \
surface \
\>", "Text",
 CellChangeTimes->{{3.5868731271234617`*^9, 3.586873157483198*^9}, {
   3.5868734330679607`*^9, 3.5868734850189323`*^9}, 3.6096733558729005`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sf", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.586873495594537*^9, 3.5868735006288247`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "1", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "2", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "3", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6096736062062187`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["1.5.2. Proof of the First Three Integrability Conditions", \
"Subsubsection",
 CellChangeTimes->{{3.5868735471634865`*^9, 3.5868736064348764`*^9}, {
   3.587272697133854*^9, 3.5872727162779493`*^9}, 3.609673071961662*^9, 
   3.609673856896558*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", "3"}], ";"}]], "Input",
 CellChangeTimes->{{3.6178040647481422`*^9, 3.6178040701301517`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", 
   RowBox[{
    RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"]}]]]}], "-", 
  FractionBox[
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"f", "[", "2", "]"}], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"f", "[", "2", "]"}], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], 
   SqrtBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"]}]]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"f", "[", "3", "]"}], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"f", "[", "3", "]"}], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], 
   SqrtBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"]}]]], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"f", "[", "1", "]"}], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"f", "[", "1", "]"}], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], 
   SqrtBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"]}]]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"f", "[", "2", "]"}], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"f", "[", "2", "]"}], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], 
   SqrtBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"]}]]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"f", "[", "3", "]"}], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"f", "[", "3", "]"}], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], 
   SqrtBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"]}]]], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]]}], ")"}]}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]]}], ")"}]}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.617804406029942*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dd", "[", 
     RowBox[{
      RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "+", 
   RowBox[{
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Omega]", "[", "3", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.586873642464937*^9, 3.586873909904234*^9}, {
   3.586873966567475*^9, 3.5868740303521233`*^9}, 3.6096736847557116`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.609673638164047*^9, 3.609673772095707*^9, 
  3.6151154279018307`*^9, 3.6178039282947025`*^9, 3.617804419009165*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dd", "[", 
     RowBox[{
      RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "-", 
   RowBox[{
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Omega]", "[", "3", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.586873642464937*^9, 3.586873909904234*^9}, {
   3.586873966567475*^9, 3.5868740303521233`*^9}, {3.5869225150126677`*^9, 
   3.586922546334459*^9}, 3.6096736868738327`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6096738028024635`*^9, 3.6151154754703693`*^9, 
  3.6178039284975033`*^9, 3.6178044415512047`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Omega]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}], " ", "-", " ", 
   RowBox[{
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Omega]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.586922604102763*^9, 3.5869226717776337`*^9}, {
  3.6096736921791363`*^9, 3.6096736932831993`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6096738321971445`*^9, 3.615115528058062*^9, 
  3.617803928528703*^9, 3.6178044666672487`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["1.5.3. Proof of the Last Three Integrability Conditions", \
"Subsubsection",
 CellChangeTimes->{{3.5868735471634865`*^9, 3.5868736064348764`*^9}, {
  3.5869227233315825`*^9, 3.5869227259707336`*^9}, {3.5872727214142427`*^9, 
  3.5872727254704747`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dd", "[", 
     RowBox[{
      RowBox[{"\[Omega]", "[", "1", "]"}], "[", "sf", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "+", 
   RowBox[{
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Omega]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Omega]", "[", "3", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.586873642464937*^9, 3.586873909904234*^9}, {
   3.586873966567475*^9, 3.5868740303521233`*^9}, {3.586922786729209*^9, 
   3.586922801385047*^9}, 3.609673696218367*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.609674084528577*^9, 3.615115621261377*^9, 
  3.617804541001379*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dd", "[", 
     RowBox[{
      RowBox[{"\[Omega]", "[", "2", "]"}], "[", "sf", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "+", 
   RowBox[{
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Omega]", "[", "3", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Omega]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.586873642464937*^9, 3.586873909904234*^9}, {
   3.586873966567475*^9, 3.5868740303521233`*^9}, {3.586922786729209*^9, 
   3.586922801385047*^9}, {3.586922842405393*^9, 3.5869228588633347`*^9}, 
   3.6096736984744964`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.609674113142214*^9, 3.615115640590945*^9, 
  3.617804560298613*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dd", "[", 
     RowBox[{
      RowBox[{"\[Omega]", "[", "3", "]"}], "[", "sf", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "+", 
   RowBox[{
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Omega]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Omega]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.586873642464937*^9, 3.586873909904234*^9}, {
   3.586873966567475*^9, 3.5868740303521233`*^9}, {3.586922786729209*^9, 
   3.586922801385047*^9}, {3.586922842405393*^9, 3.586922905792019*^9}, 
   3.609673706290943*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6096741455420675`*^9, 3.6151156681412544`*^9, 
  3.617804587505061*^9}]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.6. The Local Uniqueness Theorem", "Subsection",
 CellChangeTimes->{{3.586925078299279*^9, 3.5869250892189035`*^9}, {
   3.586956741153708*^9, 3.586956744008871*^9}, {3.58727274251845*^9, 
   3.587272745541623*^9}, 3.609673862642886*^9, 3.6096744232569513`*^9}],

Cell["\<\
The following theorem shows that the coincidence of the local forms implies \
the congruence of the  surfaces, at least locally:\
\>", "Text",
 CellChangeTimes->{{3.586933018513775*^9, 3.5869331255938997`*^9}}],

Cell[TextData[{
 StyleBox["Theorem",
  FontColor->RGBColor[0, 0, 1]],
 ". Let U be a 2-dimensional smooth, connected manifold and sf, sh: U \
\[LongRightArrow] ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SuperscriptBox["E", "3"]}], TraditionalForm]]],
 " two immersions, i.e. regular surfaces. Assume that on U adapted moving \
frames \n\t\t\t{fr[i][u,v]}  =  {fr[i][sf][u,v]]} , {a[i][u,v]]}  = \
{fr[i][sh] [u,v]} \n are defined such that the local structure forms of these \
frames coincide. Then there exists an Euclidean motion g such that the images \
of the immersion are congruent under g:\n \t\t\t\t\tsh[u,v] = g(sf[u,v])."
}], "Text",
 CellChangeTimes->{{3.5869251578988323`*^9, 3.5869254337306085`*^9}, {
   3.5869254654274216`*^9, 3.586925472082802*^9}, {3.5869320455321236`*^9, 
   3.586932237993132*^9}, {3.5869322892510633`*^9, 3.5869324135211716`*^9}, {
   3.586932453442455*^9, 3.5869324812730465`*^9}, {3.5869325165130625`*^9, 
   3.5869325244015136`*^9}, {3.5869325595775256`*^9, 3.586932617057813*^9}, {
   3.58693264969768*^9, 3.586932690361006*^9}, {3.586932747721287*^9, 
   3.5869327600729933`*^9}, {3.5869328383714714`*^9, 3.586932856682519*^9}, 
   3.5869335946817303`*^9, 3.586956296499154*^9, 3.586956353798055*^9, {
   3.5869568059534144`*^9, 3.5869568158809824`*^9}, {3.614861850127923*^9, 
   3.6148618502215233`*^9}, {3.6149177828413453`*^9, 3.6149177828881454`*^9}, 
   3.614918908632923*^9, {3.614918984511456*^9, 3.6149189923426695`*^9}, {
   3.6151165748299*^9, 3.615116623223332*^9}, {3.6151166671561446`*^9, 
   3.615116667483745*^9}, 3.615117715287099*^9}],

Cell[TextData[{
 StyleBox["Proof",
  FontColor->RGBColor[0, 0, 1]],
 ". We fix a point  {uo,vo} \[Element] U.  Since the Euclidean group acts \
simply transitively on the set of all orthonormal frames {x, {amf[i]}}  there \
exist a uniquely defined Euclidean motion g such that\n \t\t\tsh[uo,vo] =  \
g(sf(uo,vo)),  a[i][uo,vo]]}   = {g(fr[i][uo,vo])}.\n Then the frame { \
{g(fr[i][sf] [u,v]}},i= 0,1,2,3, is an adapted  moving frame of the immersion \
g(sf[u,v]), and since the exterior differentiation permutes with affine \
transformations (constant linear transformations), the local structure  forms \
of the immersions sh and g(sf) coincide too. Now connect the arbitrary point  \
{u,v} \[Element] U and the point  {uo,vo} with a smooth  curve \[Gamma][t]  \
\[Element] U. Let \[Gamma]'[t] denote its tangent vector. Then the moving \
frame satisfies along the curve the linear system of differential equations \
defined by the derivation equations:   "
}], "Text",
 CellChangeTimes->{{3.5869332170111284`*^9, 3.5869333239052424`*^9}, {
   3.5869333657456355`*^9, 3.586933515737215*^9}, {3.586933547283019*^9, 
   3.5869336328259115`*^9}, {3.586933666305827*^9, 3.586933708409235*^9}, {
   3.58693374206616*^9, 3.586933749513586*^9}, {3.586933781593421*^9, 
   3.5869338632340903`*^9}, {3.586933899161145*^9, 3.586933919313298*^9}, {
   3.58693394941702*^9, 3.5869341166735864`*^9}, {3.586934188537697*^9, 
   3.586934343241545*^9}, {3.5869344038260107`*^9, 3.586934414377614*^9}, {
   3.5869344666816053`*^9, 3.5869345057538404`*^9}, {3.586934535931566*^9, 
   3.58693461397803*^9}, {3.586934647222932*^9, 3.586934701882058*^9}, {
   3.586934745481552*^9, 3.586934988265438*^9}, {3.586935061969654*^9, 
   3.586935066201896*^9}, {3.5869381562725463`*^9, 3.586938182793063*^9}, 
   3.586956913361558*^9, {3.5872007151327934`*^9, 3.587200734573905*^9}, 
   3.587200779909498*^9, 3.5882493512465467`*^9, {3.6148618504243236`*^9, 
   3.614861850705124*^9}, {3.6149177830753455`*^9, 3.614917783309346*^9}, {
   3.614919002186287*^9, 3.6149190081142974`*^9}, {3.6151167411822543`*^9, 
   3.6151167415098553`*^9}, {3.6151167961591806`*^9, 3.6151168121258764`*^9}, 
   3.6151168598544564`*^9, {3.61511689040298*^9, 3.6151169114786167`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "sh", "]"}], "[", 
   RowBox[{"\[Gamma]", "'"}], "]"}], " ", "\[Equal]", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "[", "1", "]"}], "*", 
    RowBox[{
     RowBox[{"\[Sigma]", "[", "1", "]"}], "[", 
     RowBox[{"\[Gamma]", "'"}], "]"}]}], " ", "+", "  ", 
   RowBox[{
    RowBox[{"a", "[", "2", "]"}], "*", 
    RowBox[{
     RowBox[{"\[Sigma]", "[", "2", "]"}], "[", 
     RowBox[{"\[Gamma]", "'"}], "]"}], " "}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868707506520944`*^9, 3.5868707637405176`*^9}, {
  3.5868708348454423`*^9, 3.586870922985597*^9}, {3.586935121068034*^9, 
  3.586935134571807*^9}, {3.586935166590638*^9, 3.586935170139841*^9}, {
  3.5869352335524683`*^9, 3.586935234159503*^9}, {3.586935284517383*^9, 
  3.586935293012869*^9}, {3.588249351262147*^9, 3.588249351262147*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"a", "[", "1", "]"}], "]"}], "[", 
   RowBox[{"\[Gamma]", "'"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "[", "2", "]"}], "*", 
    RowBox[{
     RowBox[{"\[Omega]", "[", "3", "]"}], "[", 
     RowBox[{"\[Gamma]", "'"}], "]"}]}], " ", "-", "  ", 
   RowBox[{
    RowBox[{"a", "[", "3", "]"}], "*", 
    RowBox[{
     RowBox[{"\[Omega]", "[", "2", "]"}], "[", 
     RowBox[{"\[Gamma]", "'"}], "]"}], " "}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.586870881739125*^9, 3.586871024151775*^9}, {
  3.586935234775538*^9, 3.586935235935604*^9}, {3.5869352988932056`*^9, 
  3.5869353290609307`*^9}, {3.588249351277747*^9, 3.588249351277747*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"a", "[", "2", "]"}], "]"}], "[", 
   RowBox[{"\[Gamma]", "'"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"a", "[", "1", "]"}]}], "*", 
    RowBox[{
     RowBox[{"\[Omega]", "[", "3", "]"}], "[", 
     RowBox[{"\[Gamma]", "'"}], "]"}]}], " ", "+", "  ", 
   RowBox[{
    RowBox[{"a", "[", "3", "]"}], "*", 
    RowBox[{
     RowBox[{"\[Omega]", "[", "1", "]"}], "[", 
     RowBox[{"\[Gamma]", "'"}], "]"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868711037119145`*^9, 3.5868711559408064`*^9}, {
  3.586935236511637*^9, 3.5869352376797037`*^9}, {3.586935304164507*^9, 
  3.5869353410446167`*^9}, {3.588249351277747*^9, 3.588249351277747*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"a", "[", "3", "]"}], "]"}], "[", 
   RowBox[{"\[Gamma]", "'"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "[", "1", "]"}], "*", 
    RowBox[{
     RowBox[{"\[Omega]", "[", "2", "]"}], "[", 
     RowBox[{"\[Gamma]", "'"}], "]"}]}], " ", "-", "  ", 
   RowBox[{
    RowBox[{"a", "[", "2", "]"}], "*", 
    RowBox[{
     RowBox[{"\[Omega]", "[", "3", "]"}], "[", 
     RowBox[{"\[Gamma]", "'"}], "]"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868712300253363`*^9, 3.5868712863882356`*^9}, {
   3.586935238407746*^9, 3.586935239094785*^9}, {3.586935307740711*^9, 
   3.586935347892008*^9}, {3.588249351277747*^9, 3.588249351277747*^9}, 
   3.6148618507363243`*^9, 3.6149177833249464`*^9, 3.6149190547115793`*^9}],

Cell["\<\
The moving frame  {g(sf[\[Gamma][t]], {g(amf[i][sf] [\[Gamma][t]]}} satisfies \
the same system of differential equations since the local structure forms \
coincide. Since the solutions are uniquely defined by the same  initial \
conditions at the point {uo,vo}, the solution coincide for all t, in \
particular we have 
sh[u,v] = g(sf[u,v]). QED.\
\>", "Text",
 CellChangeTimes->{{3.5869354369941044`*^9, 3.5869354442895217`*^9}, {
   3.58693550440296*^9, 3.5869355558179007`*^9}, {3.5869378853850527`*^9, 
   3.5869381324961863`*^9}, 3.586938166736145*^9, {3.5869381971368837`*^9, 
   3.586938204552308*^9}, {3.586956962889391*^9, 3.586957003976741*^9}, 
   3.586957622721131*^9, {3.5992328267612457`*^9, 3.5992328273532796`*^9}, 
   3.614861850767524*^9, 3.614917783356146*^9, 3.614919070732807*^9, {
   3.6178048719871607`*^9, 3.6178048748419657`*^9}}],

Cell[TextData[{
 StyleBox["A technical hint",
  FontColor->RGBColor[0, 0, 1]],
 ". The notation"
}], "Text",
 CellChangeTimes->{{3.5882281307953806`*^9, 3.588228173978851*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"p\.b4", "[", "v", "]"}], "-", " ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"p", "[", "v", "]"}], ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5882279420925875`*^9, 3.588227998653823*^9}, {
   3.58822803602296*^9, 3.588228040750231*^9}, {3.5882281856145163`*^9, 
   3.5882281962061224`*^9}, 3.58822826364598*^9, {3.5882283076694975`*^9, 
   3.5882283390942945`*^9}, {3.588249511474428*^9, 3.5882495126600304`*^9}, {
   3.5882498746829853`*^9, 3.5882498819464006`*^9}, {3.5883161677869563`*^9, 
   3.588316178531571*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"p\.b4", "[", "v", "]"}], "-", 
  RowBox[{
   SuperscriptBox["p", "\[Prime]",
    MultilineFunction->None], "[", "v", "]"}]}]], "Output",
 CellChangeTimes->{3.609674357921214*^9, 3.6151169796555457`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.6151170140388913`*^9, 3.6151170222756543`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"p\.b4", "[", "v", "]"}], "-", 
  RowBox[{
   SuperscriptBox["p", "\[Prime]",
    MultilineFunction->None], "[", "v", "]"}]}]], "Output",
 CellChangeTimes->{3.6151170240852575`*^9}]
}, Closed]],

Cell["can\[CloseCurlyQuote]t be used for denoting a derivation. Use  \
\[OpenCurlyQuote] instead:", "Text",
 CellChangeTimes->{{3.5882495550609045`*^9, 3.5882496043257914`*^9}, 
   3.5882496943756723`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"p", "'"}], "[", "v", "]"}], "-", " ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"p", "[", "v", "]"}], ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5882279420925875`*^9, 3.588227998653823*^9}, {
   3.58822803602296*^9, 3.588228040750231*^9}, {3.5882281856145163`*^9, 
   3.5882281962061224`*^9}, 3.58822826364598*^9, {3.5882283076694975`*^9, 
   3.5882283390942945`*^9}, {3.588249511474428*^9, 3.5882495126600304`*^9}, {
   3.588249718586057*^9, 3.5882497197461233`*^9}, {3.588249896938258*^9, 
   3.5882499049297156`*^9}, {3.5882506904956474`*^9, 3.5882507097617493`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.609674369699888*^9, 3.6151170382812824`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"p", "''"}], "[", "v", "]"}], "-", " ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"p", "[", "v", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5882279420925875`*^9, 3.588227998653823*^9}, {
   3.58822803602296*^9, 3.588228040750231*^9}, {3.5882281856145163`*^9, 
   3.5882281962061224`*^9}, 3.58822826364598*^9, {3.5882283076694975`*^9, 
   3.5882283390942945`*^9}, {3.588249511474428*^9, 3.5882495126600304`*^9}, {
   3.588249718586057*^9, 3.5882497197461233`*^9}, {3.588249896938258*^9, 
   3.5882499049297156`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.609674373891128*^9, 3.615117043449625*^9}]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Spherical Image and Gaussian Curvature", "Section",
 CellChangeTimes->{{3.587201424502367*^9, 3.5872014450525427`*^9}, {
   3.587272807823185*^9, 3.587272810622345*^9}, 3.615117108938384*^9, 
   3.615196425961876*^9, 3.6178038595453825`*^9, 3.617860550133771*^9}],

Cell[CellGroupData[{

Cell["2.1. The Gauss Map", "Subsection",
 CellChangeTimes->{{3.5872730558623724`*^9, 3.58727307645455*^9}, {
  3.5885090107494955`*^9, 3.5885090141486893`*^9}}],

Cell[CellGroupData[{

Cell["2.1.1. Orientation and Spherical Image", "Subsubsection",
 CellChangeTimes->{{3.587201518412738*^9, 3.587201527076234*^9}, {
   3.587272835342759*^9, 3.58727283885396*^9}, {3.587272981302108*^9, 
   3.5872730078536263`*^9}, {3.587273125318345*^9, 3.5872731524058943`*^9}, 
   3.609674435089628*^9, 3.609674810368093*^9}],

Cell[TextData[{
 "We consider the ",
 StyleBox["normal unit vector",
  FontColor->RGBColor[0, 0, 1]],
 " amf[3][sf][u,v] of the surface. Belonging to the orthogonal complement of \
the tangent plane  it is uniquely defined up to  sign by the surface. A \
choice of the normal vector is equivalent to define an ",
 StyleBox["orientation of the tangent plane",
  FontColor->RGBColor[0, 0, 1]],
 " at the point sf[u,v]: a pair of linearly independent tangent vectors \
{tu,tv} is said to be positively oriented if the triple \n{tu, tv, \
amf[3][sf][u,v]} is positively oriented, what means Det[{tu, tv, \
amf[3][sf][u,v]}]>0. The surface is said to be ",
 StyleBox["orientable",
  FontColor->RGBColor[0, 0, 1]],
 ", if there exists a continuous unit normal vector field defined globally, \
i.e. for all of its points. Locally, on a parameter region U,  any surface is \
orientable. Since almost all our considerations are of a local character we \
may assume that an ",
 StyleBox["oriented surface",
  FontColor->RGBColor[0, 0, 1]],
 " is given, where the orientation is defined by the choice of the normal \
vector field. The map"
}], "Text",
 CellChangeTimes->{{3.5872016123241096`*^9, 3.587201709836687*^9}, {
   3.587201928221178*^9, 3.5872020310770607`*^9}, {3.5872020625648623`*^9, 
   3.587202289884864*^9}, {3.587202330429183*^9, 3.587202334956442*^9}, {
   3.5872023682943487`*^9, 3.5872024447247205`*^9}, {3.587202514020684*^9, 
   3.587202534012827*^9}, 3.5872033283652616`*^9, {3.587203382236343*^9, 
   3.5872035072444925`*^9}, {3.5872036682127*^9, 3.58720378221322*^9}, {
   3.5872038187973127`*^9, 3.5872038959167233`*^9}, {3.587203950612852*^9, 
   3.5872039793004932`*^9}, {3.5872733423347573`*^9, 3.5872733493661594`*^9}, 
   3.5882544812004633`*^9, {3.6148618508767242`*^9, 3.6148618510327244`*^9}, {
   3.614917783449746*^9, 3.6149177835589466`*^9}, {3.6149194945075517`*^9, 
   3.614919498859959*^9}, 3.615180003675227*^9, 3.615263631108482*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sph", "[", "sf", "]"}], ":", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"u", ",", "v"}], "}"}], " ", "\[Element]", " ", 
    RowBox[{"U", " ", "\[RightTeeArrow]", 
     RowBox[{
      RowBox[{"sph", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}]}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "\[Element]", " ", 
   SuperscriptBox["S", "2"]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5872734225673466`*^9, 3.5872734983276796`*^9}, {
   3.5872735378889427`*^9, 3.5872735984794083`*^9}, 3.614861851063925*^9, 
   3.614917783574547*^9, 3.6149195004823623`*^9},
 TextAlignment->Center],

Cell[TextData[{
 "and often its range is named the ",
 StyleBox["Gauss map",
  FontColor->RGBColor[0, 0, 1]],
 " or the ",
 StyleBox["spherical image",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface. The range is a part of the unit sphere; eidetic, the range \
 becomes larger if the surface crooks more. As a first example we show:"
}], "Text",
 CellChangeTimes->{{3.587273389727468*^9, 3.5872734079835124`*^9}, {
   3.5872737091427374`*^9, 3.5872737288618655`*^9}, 3.587273759398612*^9, {
   3.5872738016460285`*^9, 3.5872738019420457`*^9}, {3.5872744723103886`*^9, 
   3.5872744980938635`*^9}, {3.587274591870227*^9, 3.5872747256548786`*^9}, 
   3.587274844822695*^9, {3.5872748751184273`*^9, 3.587274896542653*^9}, {
   3.5885089495569954`*^9, 3.588508967285009*^9}, {3.588563973357298*^9, 
   3.588564070217868*^9}, 3.6152638209419174`*^9, {3.6178603571017303`*^9, 
   3.617860398341089*^9}}],

Cell[TextData[{
 StyleBox["Lemma.",
  FontColor->RGBColor[0, 0, 1]],
 "  The connected, oriented surface sf[u,v] is a part of a plane iff its \
spherical image consists of a single point only, and this is the case iff the \
local structure forms \[Omega][1][sf] and \[Omega][2][sf] are null forms."
}], "Text",
 CellChangeTimes->{{3.5872749116795187`*^9, 3.58727492778244*^9}, {
   3.5872756902220488`*^9, 3.587275723389946*^9}, {3.587275757518898*^9, 
   3.587275826734857*^9}, {3.587276885118393*^9, 3.5872770007990093`*^9}, 
   3.587278493639395*^9},
 CellTags->"lem2.1.1"],

Cell[TextData[{
 StyleBox["Proof.",
  FontColor->RGBColor[0, 0, 1]],
 " If the surface is a plane, we may choose a constant orthonormal frame"
}], "Text",
 CellChangeTimes->{{3.5872758457349434`*^9, 3.587276064721469*^9}}],

Cell[" {amf[i][sf][uv]} =  {amf[i]}  =  const, ", "Text",
 CellChangeTimes->{{3.5872758457349434`*^9, 3.587276112414197*^9}, {
  3.614861851079525*^9, 3.6148618511263247`*^9}, {3.6149177835901465`*^9, 
  3.6149177836057463`*^9}, {3.6149195029939666`*^9, 3.614919505521171*^9}}],

Cell["\<\
and then the spherical image consists of the point amf[3] only. Conversely, \
assume that this is the case. Then the last derivation equation is\
\>", "Text",
 CellChangeTimes->{{3.5872758457349434`*^9, 3.587276075154066*^9}, {
   3.587276129198157*^9, 3.5872761676863585`*^9}, 3.587276210702819*^9, {
   3.587276689094181*^9, 3.58727670428605*^9}, 3.609674694729479*^9, 
   3.614861851173125*^9, 3.6149177836369467`*^9, 3.614919510154379*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"amf", "[", "3", "]"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "1", "]"}], "*", 
    RowBox[{"\[Omega]", "[", "2", "]"}]}], " ", "-", "  ", 
   RowBox[{
    RowBox[{"amf", "[", "2", "]"}], "*", 
    RowBox[{"\[Omega]", "[", "1", "]"}]}]}], " ", "\[Equal]", " ", 
  "0"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.587276222756508*^9, 3.587276254568328*^9}, {
  3.5872766188021607`*^9, 3.587276647768818*^9}, {3.6148618511887245`*^9, 
  3.6148618512043247`*^9}, {3.6149177836369467`*^9, 3.614917783652547*^9}, {
  3.614919511620782*^9, 3.614919514491187*^9}}],

Cell["\<\
what means that the structure forms \[Omega][1][sf] and \[Omega][2][sf] are \
zero. We may assume that the constant plane defined by amf[3].vec[x] == 0, \
i.e. the coordinate (x[1],x[2])-plane, contains a point say sf[u0,v0], of the \
surface. Consider a smooth curve \[Gamma][t] \[Epsilon] U with  starting at \
{u0,v0}. Then the third component\
\>", "Text",
 CellChangeTimes->{{3.5872768218717756`*^9, 3.5872768696945105`*^9}, {
   3.587277024326355*^9, 3.5872770369180756`*^9}, {3.587277075214266*^9, 
   3.5872771185187426`*^9}, {3.5872771569349403`*^9, 3.587277405814175*^9}, 
   3.587277488806922*^9, 3.588564173458849*^9, 3.6148618513291254`*^9, 
   3.6149177837773466`*^9, 3.6149195159887896`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"h", "[", "t", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"amf", "[", "3", "]"}], ".", 
   RowBox[{"sf", "[", 
    RowBox[{"\[Gamma]", "[", "t", "]"}], "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5872774239342117`*^9, 3.5872774471485395`*^9}, {
   3.587277494258234*^9, 3.5872774972324038`*^9}, 3.587277620992483*^9, 
   3.614861851344725*^9, 3.6149177837773466`*^9, 3.614919517252392*^9}],

Cell["suffices", "Text",
 CellChangeTimes->{{3.5872775523315554`*^9, 3.587277562951163*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"h", "[", "0", "]"}], " ", "=", " ", "0"}], ",", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"h", "'"}], "[", "t", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "3", "]"}], ".", 
      RowBox[{
       RowBox[{
        RowBox[{"d", "[", "sf", "]"}], "[", 
        RowBox[{"\[Gamma]", "[", "t", "]"}], "]"}], "[", 
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "t", "]"}], "]"}]}], "\[Equal]", " ", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"amf", "[", "3", "]"}], ".", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "[", 
           RowBox[{"\[Gamma]", "[", "t", "]"}], "]"}], "*", 
          RowBox[{
           RowBox[{"\[Sigma]", "[", "1", "]"}], "[", 
           RowBox[{"\[Gamma]", "[", "t", "]"}], "]"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "[", 
           RowBox[{"\[Gamma]", "[", "t", "]"}], "]"}], "*", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"\[Sigma]", "[", "2", "]"}], "[", 
           RowBox[{"\[Gamma]", "[", "t", "]"}], "]"}]}]}], ")"}], "[", 
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "t", "]"}], "]"}]}], " ", "\[Equal]", 
     " ", "0"}], ":"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.587277570849615*^9, 3.587277746249647*^9}, {
   3.587277786936974*^9, 3.587278019964302*^9}, {3.588249351308947*^9, 
   3.588249351308947*^9}, 3.5885643651051855`*^9, {3.614861851360325*^9, 
   3.614861851360325*^9}, {3.614917783792947*^9, 3.614917783808547*^9}, {
   3.614919518219593*^9, 3.6149195227748013`*^9}, 3.6178605131526556`*^9}],

Cell["\<\
h[t] is the constant 0.  Thus the curve, and especially the arbitrary points \
sf[\[Gamma][t]],  belong to the (x[1],x[2])-plane, the surface must be a part \
of it. \[FilledSquare]\
\>", "Text",
 CellChangeTimes->{{3.587278097846757*^9, 3.5872782393828526`*^9}, {
  3.587278271978717*^9, 3.5872782972861643`*^9}, {3.5872783359033732`*^9, 
  3.587278410622647*^9}, {3.6151804251099677`*^9, 3.6151804335027823`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1.2. Ruled Surfaces", "Subsubsection",
 CellChangeTimes->{{3.587278731126979*^9, 3.5872787512791314`*^9}, {
   3.587278983598419*^9, 3.5872789947820587`*^9}, 3.609674817385494*^9, 
   3.6096757163849144`*^9, 3.6097331138408127`*^9, 3.6178605575971975`*^9, 
   3.617889654026325*^9}],

Cell[TextData[{
 "A ",
 StyleBox["ruled surface",
  FontColor->RGBColor[0, 0, 1]],
 " is defined as a surface generated by a 1-parametric family  of  lines in \
the space:"
}], "Text",
 CellChangeTimes->{{3.5872798729672885`*^9, 3.587279932870714*^9}, {
   3.5872915077116566`*^9, 3.587291508071677*^9}, {3.587291538183399*^9, 
   3.5872915904473886`*^9}, {3.588140984931316*^9, 3.5881409909841266`*^9}, 
   3.6097331232008295`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ruled", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{"x", "[", "v", "]"}], "]"}], " ", "+", " ", 
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"y", "[", "v", "]"}], "]"}], "*", " ", "u"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5872799484616065`*^9, 3.5872801346102533`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ruled", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5872801382974644`*^9, 3.587280151312209*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "v", "]"}], "[", "1", "]"}], "+", 
    RowBox[{"u", " ", 
     RowBox[{
      RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "v", "]"}], "[", "2", "]"}], "+", 
    RowBox[{"u", " ", 
     RowBox[{
      RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "v", "]"}], "[", "3", "]"}], "+", 
    RowBox[{"u", " ", 
     RowBox[{
      RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6096751156885567`*^9, 3.613632328983962*^9, 
  3.615181078294633*^9, 3.6178617478062735`*^9}]
}, Closed]],

Cell[TextData[{
 "The curve ruled[x,y][0,v] == vec[x[v]] is the so called ",
 StyleBox["directrix",
  FontColor->RGBColor[0, 0, 1]],
 " of the ruled surface; its lines are named the ",
 StyleBox["rulings",
  FontColor->RGBColor[0, 0, 1]],
 " or the ",
 StyleBox["generators",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface."
}], "Text",
 CellChangeTimes->{{3.5872912912692766`*^9, 3.587291449687338*^9}, {
   3.6151807423774195`*^9, 3.615180771745099*^9}, {3.6151808356567545`*^9, 
   3.6151808665295205`*^9}, {3.6151853507540035`*^9, 
   3.6151853884411592`*^9}, {3.6178620539173813`*^9, 3.6178620744445553`*^9}, 
   3.6178621047092867`*^9}],

Cell[TextData[{
 StyleBox["Example.",
  FontColor->RGBColor[0, 0, 1]],
 " Pl\[UDoubleDot]cker's conoid"
}], "Text",
 CellChangeTimes->{{3.6178621217502613`*^9, 3.6178621217502613`*^9}, 
   3.6178621590303936`*^9, {3.617862243166206*^9, 3.6178622692116957`*^9}, 
   3.6178890558120747`*^9}],

Cell[TextData[{
 "See Pl\[UDoubleDot]cker\[CloseCurlyQuote]s conoid in ",
 Cell[BoxData[
  FormBox[
   ButtonBox["MathWorld",
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["http://mathworld.wolfram.com/RuledSurface.html"], None},
    ButtonNote->"http://mathworld.wolfram.com/RuledSurface.html"], 
   TraditionalForm]]],
 ". Here one finds the following parameter representation:"
}], "Text",
 CellChangeTimes->{{3.617864676993413*^9, 3.6178646913572345`*^9}, {
  3.617864747428441*^9, 3.617864779605282*^9}, {3.6178648119571323`*^9, 
  3.617864811959132*^9}, {3.6178649148010144`*^9, 3.6178649148050146`*^9}, {
  3.617871561964284*^9, 3.617871589563862*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"pluckerconoid", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", " ", 
     RowBox[{"2", "*", 
      RowBox[{"Cos", "[", "v", "]"}], "*", 
      RowBox[{"Sin", "[", "v", "]"}]}]}], "}"}], " ", "+", " ", 
   RowBox[{"u", "*", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Cos", "[", "v", "]"}], ",", 
      RowBox[{"Sin", "[", "v", "]"}], ",", "0"}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6178626411889715`*^9, 3.617862652022591*^9}, {
   3.617862742942791*^9, 3.6178627816790066`*^9}, {3.6178628127587843`*^9, 
   3.61786292807238*^9}, 3.617863070528528*^9}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"pluckerconoid", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6178629384309726`*^9, 3.6178630199276342`*^9}, 
   3.6178631166731677`*^9}],

Cell["In Alfred Gray\[CloseCurlyQuote]s collection SURF.m of surfaces we \
have", "Text",
 CellChangeTimes->{{3.6178716140272617`*^9, 3.617871654019549*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "plucker"}]], "Input",
 CellChangeTimes->{{3.6178651419460063`*^9, 3.61786514672528*^9}}],

Cell[BoxData[
 StyleBox["\<\"{u,v}->plucker[u,v] is the standard parametrization of \
Plucker's surface. {u,v}->plucker[n][u,v] is a parametrization of Plucker's \
surface with n folds. {u,v}->plucker[m,n,a][u,v] is a generalization of the \
monkey saddle and Plucker's surface.  To plot try plucker[-1,1,-1,1].\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.617865149505439*^9},
 CellTags->"Info3617872349-5808961"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plucker", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6178631833399806`*^9, 3.617863203720146*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"u", ",", "v", ",", 
   FractionBox[
    RowBox[{"2", " ", "u", " ", "v"}], 
    RowBox[{
     SuperscriptBox["u", "2"], "+", 
     SuperscriptBox["v", "2"]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.61786319312254*^9, 3.617863205773264*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plucker", "[", "n", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6178631833399806`*^9, 3.617863203720146*^9}, {
  3.617865251261259*^9, 3.617865266631138*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"u", ",", "v", ",", 
   RowBox[{"Sin", "[", 
    RowBox[{"n", " ", 
     RowBox[{"ArcTan", "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.617865268180227*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plucker", "[", 
   RowBox[{"m", ",", "n", ",", "a"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6178631833399806`*^9, 3.617863203720146*^9}, {
  3.617865251261259*^9, 3.617865266631138*^9}, {3.6178653096295977`*^9, 
  3.617865327110597*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", " ", "u"}], ",", 
   RowBox[{"a", " ", "v"}], ",", 
   RowBox[{"a", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"u", "+", "v"}], ")"}], 
     RowBox[{"m", "/", "2"}]], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"n", " ", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6178653306948023`*^9}]
}, Closed]],

Cell[TextData[{
 "The parameter transformation u ->  ",
 Cell[BoxData[
  RowBox[{"u", " ", 
   SqrtBox[
    RowBox[{"1", "-", 
     SuperscriptBox["v", "2"]}]]}]],
  CellChangeTimes->{3.6178655826392126`*^9, 3.617865915217235*^9}],
 ", v-> u*v, leads to another representation:"
}], "Text",
 CellChangeTimes->{{3.617871698939118*^9, 3.617871791051387*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"plucker", "[", 
    RowBox[{
     RowBox[{"u", "*", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "-", 
        RowBox[{"v", "^", "2"}]}], "]"}]}], ",", 
     RowBox[{"u", "*", "v"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", "Reals"}], ",", 
     RowBox[{
      RowBox[{"-", "1"}], "<", "v"}], ",", 
     RowBox[{"v", "<", "1"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6178631833399806`*^9, 3.617863203720146*^9}, {
  3.617865251261259*^9, 3.617865266631138*^9}, {3.6178653096295977`*^9, 
  3.617865327110597*^9}, {3.617865529005145*^9, 3.6178655743677397`*^9}, {
  3.617865892209919*^9, 3.6178659117370358`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"u", " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox["v", "2"]}]]}], ",", 
   RowBox[{"u", " ", "v"}], ",", 
   RowBox[{"2", " ", "v", " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox["v", "2"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6178655826392126`*^9, 3.617865915217235*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        SuperscriptBox["v", "2"]}]]}], ",", 
     RowBox[{"u", " ", "v"}], ",", 
     RowBox[{"2", " ", "v", " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        SuperscriptBox["v", "2"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6178656197713366`*^9, 3.6178657398552046`*^9}, {
  3.6178659266398883`*^9, 3.617866004487341*^9}, {3.617866533208582*^9, 
  3.6178665589580545`*^9}}],

Cell["Sometimes this is replaced by", "Text",
 CellChangeTimes->{{3.6178718182349415`*^9, 3.617871829883608*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        SuperscriptBox["v", "2"]}]]}], ",", 
     RowBox[{"u", " ", "v"}], ",", 
     RowBox[{"1", "-", 
      RowBox[{"v", "^", "2"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6178656197713366`*^9, 3.6178657398552046`*^9}, {
  3.6178659266398883`*^9, 3.617866004487341*^9}, {3.6178662201736774`*^9, 
  3.6178662267100515`*^9}, {3.6178662869614973`*^9, 3.6178663606737137`*^9}}],

Cell["\<\
The parameter transformation u .> u*Cos[v], v -> u*Sin[v] leads to the first \
representation \
\>", "Text",
 CellChangeTimes->{{3.6178718556990843`*^9, 3.6178719641712885`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plucker", "[", 
  RowBox[{
   RowBox[{"u", "*", 
    RowBox[{"Cos", "[", "v", "]"}]}], ",", 
   RowBox[{"u", "*", 
    RowBox[{"Sin", "[", "v", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6178631833399806`*^9, 3.617863203720146*^9}, {
  3.6178633404619675`*^9, 3.6178633596330643`*^9}, {3.617863499920088*^9, 
  3.6178635314698925`*^9}, {3.6178642016802263`*^9, 3.6178642248475513`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"u", " ", 
    RowBox[{"Cos", "[", "v", "]"}]}], ",", 
   RowBox[{"u", " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["u", "2"], " ", 
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"Sin", "[", "v", "]"}]}], 
    RowBox[{
     RowBox[{
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "v", "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "v", "]"}], "2"]}]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.617863533558012*^9, 3.6178642296488256`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", ",", " ", 
   RowBox[{"u", "\[Element]", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6178642461317687`*^9, 3.6178642963036385`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"u", " ", 
    RowBox[{"Cos", "[", "v", "]"}]}], ",", 
   RowBox[{"u", " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"Sin", "[", 
    RowBox[{"2", " ", "v"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6178642974857063`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pluckerconoid", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6178719880536547`*^9, 3.6178720015174246`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"u", " ", 
    RowBox[{"Cos", "[", "v", "]"}]}], ",", 
   RowBox[{"u", " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"2", " ", 
    RowBox[{"Cos", "[", "v", "]"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6178720055416546`*^9}]
}, Closed]],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.6178720672371836`*^9, 3.6178720672391834`*^9}}],

Cell["We may assume that the tangent vector of the lines ", "Text",
 CellChangeTimes->{{3.5872802010710545`*^9, 3.587280211198634*^9}, {
   3.5872802433104706`*^9, 3.587280252998025*^9}, 3.5872900805590277`*^9, 
   3.58729163854414*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ruled", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}], "\[Equal]", " ", 
  RowBox[{"vec", "[", 
   RowBox[{"y", "[", "v", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.587280265413735*^9, 3.5872802986966386`*^9}, {
  3.609733214002528*^9, 3.6097332291143923`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.60967524268582*^9, 3.609733238060904*^9, 
  3.6151809697624254`*^9}]
}, Closed]],

Cell["is a unit vector; thus we have", "Text",
 CellChangeTimes->{{3.587280322107978*^9, 3.5872803471424093`*^9}, {
  3.5872804063267946`*^9, 3.58728041062304*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "1", "]"}], "[", 
      RowBox[{"ruled", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", " ", 
    RowBox[{"vec", "[", 
     RowBox[{"y", "[", "v", "]"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{"y", "[", "v", "]"}], "]"}], ".", 
     RowBox[{"vec", "[", 
      RowBox[{"y", "[", "v", "]"}], "]"}]}], "\[Equal]", " ", "1"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5872806978644695`*^9, 3.587280778003053*^9}, 
   3.58728083266718*^9, 3.587289862213539*^9, 3.614861851375925*^9, 
   3.614917783808547*^9, 3.614919529482813*^9, {3.6151810048464317`*^9, 
   3.6151810151570215`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.6096752157032766`*^9, 3.609732027985306*^9, 
  3.6151809808150573`*^9, 3.6151810197632847`*^9, 3.6178891838258996`*^9}]
}, Closed]],

Cell["We calculate", "Text",
 CellChangeTimes->{{3.587280659127254*^9, 3.5872806747591476`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "2", "]"}], "[", 
     RowBox[{"ruled", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{"y", "[", "v", "]"}], "]"}], ".", 
     RowBox[{"vec", "[", 
      RowBox[{"y", "[", "v", "]"}], "]"}]}], "\[Equal]", " ", "1"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5872809006570687`*^9, 3.587280909512575*^9}, {
   3.587290118485197*^9, 3.5872901269076786`*^9}, 3.6148618516099253`*^9, 
   3.6149177838397474`*^9, 3.615181162949475*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "+", 
         RowBox[{"u", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}]}], 
        ")"}]}], "-", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
       RowBox[{
        RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "+", 
         RowBox[{"u", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}]}], 
        ")"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            "+", 
            RowBox[{"u", " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "1", 
              "]"}]}]}], ")"}]}], "-", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            "+", 
            RowBox[{"u", " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "3", 
              "]"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                "]"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                "]"}]}]}], ")"}]}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                "]"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                "]"}]}]}], ")"}]}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                "]"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                "]"}]}]}], ")"}]}]}], ")"}], "2"]}], ")"}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "-", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
       RowBox[{
        RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "+", 
         RowBox[{"u", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}]}], 
        ")"}]}], "+", 
      RowBox[{"u", " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "+", 
         RowBox[{"u", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}]}], 
        ")"}]}], "-", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
       RowBox[{
        RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "+", 
         RowBox[{"u", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                "]"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                "]"}]}]}], ")"}]}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                "]"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                "]"}]}]}], ")"}]}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                "]"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                "]"}]}]}], ")"}]}]}], ")"}], "2"]}], ")"}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}]}], " ", 
       RowBox[{
        RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "+", 
         RowBox[{"u", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}]}], 
        ")"}]}], "-", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
       RowBox[{
        RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "+", 
         RowBox[{"u", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}]}], 
        ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "+", 
         RowBox[{"u", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                "]"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                "]"}]}]}], ")"}]}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                "]"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                "]"}]}]}], ")"}]}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                "]"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                "]"}]}]}], ")"}]}]}], ")"}], "2"]}], ")"}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6151814356530724`*^9, 3.6178892207511644`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"amf", "[", "2", "]"}], "[", 
   RowBox[{"ruled", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.615181166818696*^9, 3.615181166849698*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
           SqrtBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}]}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}],
              "+", 
             RowBox[{
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}],
              "-", 
             RowBox[{"u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}],
              "+", 
             RowBox[{"u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", 
               "]"}]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
               "2"]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
               "2"]}], "-", 
             RowBox[{"2", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}],
              "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
               "2"]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
               "2"]}], "-", 
             RowBox[{"2", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "-", 
             RowBox[{"2", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
               "2"]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
               "2"]}], "+", 
             RowBox[{"2", " ", "u", " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}],
              "+", 
             RowBox[{"2", " ", "u", " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}],
              "-", 
             RowBox[{"2", " ", "u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}],
              "-", 
             RowBox[{"2", " ", "u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}],
              "+", 
             RowBox[{
              SuperscriptBox["u", "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
               "2"]}], "+", 
             RowBox[{
              SuperscriptBox["u", "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
               "2"]}], "-", 
             RowBox[{"2", " ", "u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}],
              "+", 
             RowBox[{"2", " ", "u", " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}],
              "+", 
             RowBox[{"2", " ", "u", " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}],
              "-", 
             RowBox[{"2", " ", "u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}],
              "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["u", "2"], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}],
              "+", 
             RowBox[{
              SuperscriptBox["u", "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
               "2"]}], "+", 
             RowBox[{
              SuperscriptBox["u", "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
               "2"]}], "-", 
             RowBox[{"2", " ", "u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "-", 
             RowBox[{"2", " ", "u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "+", 
             RowBox[{"2", " ", "u", " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "+", 
             RowBox[{"2", " ", "u", " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["u", "2"], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["u", "2"], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "+", 
             RowBox[{
              SuperscriptBox["u", "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
               "2"]}], "+", 
             RowBox[{
              SuperscriptBox["u", "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
               "2"]}]}], ")"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"\[Sqrt]", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{
                   RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}]}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                  "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                  "]"}]}], "-", 
                RowBox[{"u", " ", 
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                  "]"}]}], "+", 
                RowBox[{"u", " ", 
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                  "]"}]}]}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                  "]"}]}], "-", 
                RowBox[{
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                  "]"}]}], "+", 
                RowBox[{"u", " ", 
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                  "]"}]}], "-", 
                RowBox[{"u", " ", 
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                  "]"}]}]}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{
                   RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}]}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                  "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                  "]"}]}], "-", 
                RowBox[{"u", " ", 
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                  "]"}]}], "+", 
                RowBox[{"u", " ", 
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                  "]"}]}]}], ")"}], "2"]}], ")"}]}], ")"}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
           "-", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
           "+", 
           RowBox[{"u", " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
           "-", 
           RowBox[{"u", " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}],
           ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
             "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
             "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
             "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
             "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
           "-", 
           RowBox[{"2", " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
           "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
             "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
             "2"]}], "+", 
           RowBox[{"2", " ", "u", " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
           "+", 
           RowBox[{"2", " ", "u", " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
           "-", 
           RowBox[{"2", " ", "u", " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
           "-", 
           RowBox[{"2", " ", "u", " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
           "+", 
           RowBox[{
            SuperscriptBox["u", "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
             "2"]}], "+", 
           RowBox[{
            SuperscriptBox["u", "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
             "2"]}], "-", 
           RowBox[{"2", " ", "u", " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "+", 
           RowBox[{"2", " ", "u", " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "+", 
           RowBox[{"2", " ", "u", " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "-", 
           RowBox[{"2", " ", "u", " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["u", "2"], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "+", 
           RowBox[{
            SuperscriptBox["u", "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
             "2"]}], "+", 
           RowBox[{
            SuperscriptBox["u", "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
             "2"]}], "-", 
           RowBox[{"2", " ", "u", " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
           "-", 
           RowBox[{"2", " ", "u", " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
           "+", 
           RowBox[{"2", " ", "u", " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
           "+", 
           RowBox[{"2", " ", "u", " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
           "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["u", "2"], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
           "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["u", "2"], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
           "+", 
           RowBox[{
            SuperscriptBox["u", "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
             "2"]}], "+", 
           RowBox[{
            SuperscriptBox["u", "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
             "2"]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}]}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                "]"}]}], "+", 
              RowBox[{
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                "]"}]}], "-", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                "]"}]}], "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                "]"}]}], "-", 
              RowBox[{
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                "]"}]}], "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                "]"}]}], "-", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}]}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                "]"}]}], "+", 
              RowBox[{
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                "]"}]}], "-", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                "]"}]}], "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                "]"}]}]}], ")"}], "2"]}], ")"}]}], ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
          "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
          "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
          "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
          "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
          "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
          "2"]}], "+", 
        RowBox[{"2", " ", "u", " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], "+", 
        RowBox[{"2", " ", "u", " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], "-", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], "-", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
          "2"]}], "+", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
          "2"]}], "-", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], "+", 
        RowBox[{"2", " ", "u", " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], "+", 
        RowBox[{"2", " ", "u", " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], "-", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["u", "2"], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
          "2"]}], "+", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
          "2"]}], "-", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], "-", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], "+", 
        RowBox[{"2", " ", "u", " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], "+", 
        RowBox[{"2", " ", "u", " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["u", "2"], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["u", "2"], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
          "2"]}], "+", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
          "2"]}]}], ")"}]}], ")"}]}], ",", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
             SqrtBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}]}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                 "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                 "]"}]}], "-", 
               RowBox[{"u", " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                 "]"}]}], "+", 
               RowBox[{"u", " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                 "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                  "]"}], "2"]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                  "]"}], "2"]}], "-", 
               RowBox[{"2", " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}],
                 " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                 "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                  "]"}], "2"]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                  "]"}], "2"]}], "-", 
               RowBox[{"2", " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}],
                 " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                 "]"}]}], "-", 
               RowBox[{"2", " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}],
                 " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                 "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                  "]"}], "2"]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                  "]"}], "2"]}], "+", 
               RowBox[{"2", " ", "u", " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}],
                 " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                 "]"}]}], "+", 
               RowBox[{"2", " ", "u", " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}],
                 " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                 "]"}]}], "-", 
               RowBox[{"2", " ", "u", " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}],
                 " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                 "]"}]}], "-", 
               RowBox[{"2", " ", "u", " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}],
                 " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                 "]"}]}], "+", 
               RowBox[{
                SuperscriptBox["u", "2"], " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                  "]"}], "2"]}], "+", 
               RowBox[{
                SuperscriptBox["u", "2"], " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                  "]"}], "2"]}], "-", 
               RowBox[{"2", " ", "u", " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}],
                 " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                 "]"}]}], "+", 
               RowBox[{"2", " ", "u", " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}],
                 " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                 "]"}]}], "+", 
               RowBox[{"2", " ", "u", " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}],
                 " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                 "]"}]}], "-", 
               RowBox[{"2", " ", "u", " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}],
                 " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                 "]"}]}], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["u", "2"], " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}],
                 " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}
                ], "+", 
               RowBox[{
                SuperscriptBox["u", "2"], " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                  "]"}], "2"]}], "+", 
               RowBox[{
                SuperscriptBox["u", "2"], " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                  "]"}], "2"]}], "-", 
               RowBox[{"2", " ", "u", " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}],
                 " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                 "]"}]}], "-", 
               RowBox[{"2", " ", "u", " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}],
                 " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                 "]"}]}], "+", 
               RowBox[{"2", " ", "u", " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}],
                 " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                 "]"}]}], "+", 
               RowBox[{"2", " ", "u", " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}],
                 " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                 "]"}]}], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["u", "2"], " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}],
                 " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                 "]"}]}], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["u", "2"], " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}],
                 " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                 "]"}]}], "+", 
               RowBox[{
                SuperscriptBox["u", "2"], " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                  "]"}], "2"]}], "+", 
               RowBox[{
                SuperscriptBox["u", "2"], " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                  "]"}], "2"]}]}], ")"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"\[Sqrt]", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", 
                    RowBox[{
                    RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}]}], " ", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                    "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                    "]"}]}], "-", 
                  RowBox[{"u", " ", 
                   RowBox[{
                    RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                    "]"}]}], "+", 
                  RowBox[{"u", " ", 
                   RowBox[{
                    RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                    "]"}]}]}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                    "]"}]}], "-", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                    "]"}]}], "+", 
                  RowBox[{"u", " ", 
                   RowBox[{
                    RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                    "]"}]}], "-", 
                  RowBox[{"u", " ", 
                   RowBox[{
                    RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                    "]"}]}]}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", 
                    RowBox[{
                    RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}]}], " ", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                    "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                    "]"}]}], "-", 
                  RowBox[{"u", " ", 
                   RowBox[{
                    RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                    "]"}]}], "+", 
                  RowBox[{"u", " ", 
                   RowBox[{
                    RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                    "]"}]}]}], ")"}], "2"]}], ")"}]}], ")"}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
           SqrtBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}]}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}],
              "+", 
             RowBox[{
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "-", 
             RowBox[{"u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}],
              "+", 
             RowBox[{"u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", 
               "]"}]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
               "2"]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
               "2"]}], "-", 
             RowBox[{"2", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}],
              "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
               "2"]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
               "2"]}], "-", 
             RowBox[{"2", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "-", 
             RowBox[{"2", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
               "2"]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
               "2"]}], "+", 
             RowBox[{"2", " ", "u", " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}],
              "+", 
             RowBox[{"2", " ", "u", " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}],
              "-", 
             RowBox[{"2", " ", "u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}],
              "-", 
             RowBox[{"2", " ", "u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}],
              "+", 
             RowBox[{
              SuperscriptBox["u", "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
               "2"]}], "+", 
             RowBox[{
              SuperscriptBox["u", "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
               "2"]}], "-", 
             RowBox[{"2", " ", "u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}],
              "+", 
             RowBox[{"2", " ", "u", " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}],
              "+", 
             RowBox[{"2", " ", "u", " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}],
              "-", 
             RowBox[{"2", " ", "u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}],
              "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["u", "2"], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}],
              "+", 
             RowBox[{
              SuperscriptBox["u", "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
               "2"]}], "+", 
             RowBox[{
              SuperscriptBox["u", "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
               "2"]}], "-", 
             RowBox[{"2", " ", "u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "-", 
             RowBox[{"2", " ", "u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "+", 
             RowBox[{"2", " ", "u", " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "+", 
             RowBox[{"2", " ", "u", " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["u", "2"], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["u", "2"], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "+", 
             RowBox[{
              SuperscriptBox["u", "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
               "2"]}], "+", 
             RowBox[{
              SuperscriptBox["u", "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
               "2"]}]}], ")"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"\[Sqrt]", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{
                   RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}]}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                  "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                  "]"}]}], "-", 
                RowBox[{"u", " ", 
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                  "]"}]}], "+", 
                RowBox[{"u", " ", 
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                  "]"}]}]}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                  "]"}]}], "-", 
                RowBox[{
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                  "]"}]}], "+", 
                RowBox[{"u", " ", 
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                  "]"}]}], "-", 
                RowBox[{"u", " ", 
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                  "]"}]}]}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{
                   RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}]}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                  "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                  "]"}]}], "-", 
                RowBox[{"u", " ", 
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                  "]"}]}], "+", 
                RowBox[{"u", " ", 
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                  "]"}]}]}], ")"}], "2"]}], ")"}]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            "2"]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
          "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            "2"]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
          "-", 
          RowBox[{"2", " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
          "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            "2"]}], "+", 
          RowBox[{"2", " ", "u", " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
          "+", 
          RowBox[{"2", " ", "u", " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
          "-", 
          RowBox[{"2", " ", "u", " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
          "-", 
          RowBox[{"2", " ", "u", " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
          "+", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            "2"]}], "+", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            "2"]}], "-", 
          RowBox[{"2", " ", "u", " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
          "+", 
          RowBox[{"2", " ", "u", " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
          "+", 
          RowBox[{"2", " ", "u", " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
          "-", 
          RowBox[{"2", " ", "u", " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
          "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["u", "2"], " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
          "+", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            "2"]}], "+", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            "2"]}], "-", 
          RowBox[{"2", " ", "u", " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
          "-", 
          RowBox[{"2", " ", "u", " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
          "+", 
          RowBox[{"2", " ", "u", " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
          "+", 
          RowBox[{"2", " ", "u", " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
          "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["u", "2"], " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
          "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["u", "2"], " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
          "+", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            "2"]}], "+", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            "2"]}]}], ")"}]}], ")"}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
           SqrtBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}],
              "-", 
             RowBox[{
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "+", 
             RowBox[{"u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}],
              "-", 
             RowBox[{"u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", 
               "]"}]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
               "2"]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
               "2"]}], "-", 
             RowBox[{"2", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}],
              "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
               "2"]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
               "2"]}], "-", 
             RowBox[{"2", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "-", 
             RowBox[{"2", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
               "2"]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
               "2"]}], "+", 
             RowBox[{"2", " ", "u", " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}],
              "+", 
             RowBox[{"2", " ", "u", " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}],
              "-", 
             RowBox[{"2", " ", "u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}],
              "-", 
             RowBox[{"2", " ", "u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}],
              "+", 
             RowBox[{
              SuperscriptBox["u", "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
               "2"]}], "+", 
             RowBox[{
              SuperscriptBox["u", "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
               "2"]}], "-", 
             RowBox[{"2", " ", "u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}],
              "+", 
             RowBox[{"2", " ", "u", " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}],
              "+", 
             RowBox[{"2", " ", "u", " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}],
              "-", 
             RowBox[{"2", " ", "u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}],
              "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["u", "2"], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}],
              "+", 
             RowBox[{
              SuperscriptBox["u", "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
               "2"]}], "+", 
             RowBox[{
              SuperscriptBox["u", "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
               "2"]}], "-", 
             RowBox[{"2", " ", "u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "-", 
             RowBox[{"2", " ", "u", " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "+", 
             RowBox[{"2", " ", "u", " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "+", 
             RowBox[{"2", " ", "u", " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["u", "2"], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["u", "2"], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
              RowBox[{
               RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}],
              "+", 
             RowBox[{
              SuperscriptBox["u", "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
               "2"]}], "+", 
             RowBox[{
              SuperscriptBox["u", "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
               "2"]}]}], ")"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"\[Sqrt]", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{
                   RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}]}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                  "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                  "]"}]}], "-", 
                RowBox[{"u", " ", 
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                  "]"}]}], "+", 
                RowBox[{"u", " ", 
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                  "]"}]}]}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                  "]"}]}], "-", 
                RowBox[{
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                  "]"}]}], "+", 
                RowBox[{"u", " ", 
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                  "]"}]}], "-", 
                RowBox[{"u", " ", 
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                  "]"}]}]}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{
                   RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}]}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                  "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                  "]"}]}], "-", 
                RowBox[{"u", " ", 
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                  "]"}]}], "+", 
                RowBox[{"u", " ", 
                 RowBox[{
                  RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                  "]"}]}]}], ")"}], "2"]}], ")"}]}], ")"}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}]}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
           "-", 
           RowBox[{"u", " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "+", 
           RowBox[{"u", " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}],
           ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
             "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
             "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
             "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
             "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
           "-", 
           RowBox[{"2", " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
           "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
             "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
             "2"]}], "+", 
           RowBox[{"2", " ", "u", " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
           "+", 
           RowBox[{"2", " ", "u", " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
           "-", 
           RowBox[{"2", " ", "u", " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
           "-", 
           RowBox[{"2", " ", "u", " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
           "+", 
           RowBox[{
            SuperscriptBox["u", "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
             "2"]}], "+", 
           RowBox[{
            SuperscriptBox["u", "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
             "2"]}], "-", 
           RowBox[{"2", " ", "u", " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "+", 
           RowBox[{"2", " ", "u", " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "+", 
           RowBox[{"2", " ", "u", " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "-", 
           RowBox[{"2", " ", "u", " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["u", "2"], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "+", 
           RowBox[{
            SuperscriptBox["u", "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
             "2"]}], "+", 
           RowBox[{
            SuperscriptBox["u", "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
             "2"]}], "-", 
           RowBox[{"2", " ", "u", " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
           "-", 
           RowBox[{"2", " ", "u", " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
           "+", 
           RowBox[{"2", " ", "u", " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
           "+", 
           RowBox[{"2", " ", "u", " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
           "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["u", "2"], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
           "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["u", "2"], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
           "+", 
           RowBox[{
            SuperscriptBox["u", "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
             "2"]}], "+", 
           RowBox[{
            SuperscriptBox["u", "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
             "2"]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}]}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                "]"}]}], "+", 
              RowBox[{
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                "]"}]}], "-", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                "]"}]}], "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                "]"}]}], "-", 
              RowBox[{
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                "]"}]}], "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                "]"}]}], "-", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                "]"}]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}]}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                "]"}]}], "+", 
              RowBox[{
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                "]"}]}], "-", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                "]"}]}], "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                "]"}]}]}], ")"}], "2"]}], ")"}]}], ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
          "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
          "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
          "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
          "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
          "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
          "2"]}], "+", 
        RowBox[{"2", " ", "u", " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], "+", 
        RowBox[{"2", " ", "u", " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], "-", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], "-", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
          "2"]}], "+", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
          "2"]}], "-", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], "+", 
        RowBox[{"2", " ", "u", " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], "+", 
        RowBox[{"2", " ", "u", " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], "-", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["u", "2"], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
          "2"]}], "+", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
          "2"]}], "-", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], "-", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], "+", 
        RowBox[{"2", " ", "u", " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], "+", 
        RowBox[{"2", " ", "u", " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["u", "2"], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["u", "2"], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
          "2"]}], "+", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
          "2"]}]}], ")"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.617889227973977*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "3", "]"}], "[", 
     RowBox[{"ruled", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{"y", "[", "v", "]"}], "]"}], ".", 
     RowBox[{"vec", "[", 
      RowBox[{"y", "[", "v", "]"}], "]"}]}], "\[Equal]", " ", "1"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5872809006570687`*^9, 3.587280909512575*^9}, {
   3.587290118485197*^9, 3.5872901269076786`*^9}, {3.5872906447672987`*^9, 
   3.5872906711228065`*^9}, 3.6148618516411257`*^9, 3.614917783855347*^9, 
   3.6151811681617727`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "+", 
         RowBox[{"u", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}]}], 
        ")"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "+", 
         RowBox[{"u", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                "]"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                "]"}]}]}], ")"}]}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                "]"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                "]"}]}]}], ")"}]}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                "]"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                "]"}]}]}], ")"}]}]}], ")"}], "2"]}], ")"}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "+", 
         RowBox[{"u", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}]}], 
        ")"}]}], "-", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "+", 
         RowBox[{"u", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                "]"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                "]"}]}]}], ")"}]}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                "]"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                "]"}]}]}], ")"}]}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                "]"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                "]"}]}]}], ")"}]}]}], ")"}], "2"]}], ")"}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "+", 
         RowBox[{"u", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}]}], 
        ")"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "+", 
         RowBox[{"u", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}]}], 
        ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                "]"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                "]"}]}]}], ")"}]}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                "]"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                "]"}]}]}], ")"}]}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "2", 
                "]"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                "]"}]}]}], ")"}]}]}], ")"}], "2"]}], ")"}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.609675284059187*^9, 3.615181505649076*^9, 
  3.617889258565631*^9}]
}, Closed]],

Cell["\<\
As curve vec[x[v]] we may take any curve intersecting all lines of the \
family. Thus we may assume vec[x[v]] being an orthogonal trajectory of the \
rulings amf[1][ruledsf][u,v] == vec[y[v]] on the ruled surface. Then \
D[vec[x[v]],v].vec[y[v]]\[Equal] 0,  the surface ruled[x,y][u,v] is a family \
of normals of the curve vec[x[v]]. The normal unit vectors vec[y[v]] in \
general  form a curve on the unit sphere; in the neighborhood of  regular \
points of this curve we may assume that v is the arc length of this spherical \
curve. We collect these assumptions to \
\>", "Text",
 CellChangeTimes->{{3.609733354343555*^9, 3.6097334420075693`*^9}, {
   3.609733472912337*^9, 3.609733575912228*^9}, {3.6097336162885375`*^9, 
   3.6097336413759727`*^9}, {3.609733687194593*^9, 3.609733713808115*^9}, {
   3.609733771040389*^9, 3.6097338766884317`*^9}, {3.609733958888133*^9, 
   3.6097340466561527`*^9}, {3.6097340950399203`*^9, 3.609734099769191*^9}, {
   3.6097341449277735`*^9, 3.6097341633838296`*^9}, {3.609734695385258*^9, 
   3.609734749161334*^9}, 3.614919788302868*^9, 3.615263967187282*^9, {
   3.617889351635394*^9, 3.617889393225067*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ruledass", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"vec", "[", 
        RowBox[{"y", "[", "v", "]"}], "]"}], ".", 
       RowBox[{"vec", "[", 
        RowBox[{"y", "[", "v", "]"}], "]"}]}], "\[Equal]", " ", "1"}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"vec", "[", 
          RowBox[{"y", "[", "v", "]"}], "]"}], ",", "v"}], "]"}], ".", 
       RowBox[{"vec", "[", 
        RowBox[{"y", "[", "v", "]"}], "]"}]}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"vec", "[", 
          RowBox[{"y", "[", "v", "]"}], "]"}], ",", "v"}], "]"}], ".", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"vec", "[", 
          RowBox[{"y", "[", "v", "]"}], "]"}], ",", "v"}], "]"}]}], 
      "\[Equal]", " ", "1"}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"vec", "[", 
          RowBox[{"x", "[", "v", "]"}], "]"}], ",", "v"}], "]"}], ".", 
       RowBox[{"vec", "[", 
        RowBox[{"y", "[", "v", "]"}], "]"}]}], "\[Equal]", " ", "0"}]}], 
    "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.609731174164606*^9, 3.609731191246636*^9}, {
   3.6097312423211255`*^9, 3.6097313830177727`*^9}, {3.6097314152786293`*^9, 
   3.6097315223728175`*^9}, {3.6097319516387715`*^9, 3.609731998204853*^9}, 
   3.6097348047275124`*^9}],

Cell["\<\
Applying these assumptions leads to a certain simplification of the \
expression for the moving orthonormal frame:\
\>", "Text",
 CellChangeTimes->{{3.6097341810798416`*^9, 3.6097342414882965`*^9}, 
   3.6097348204804134`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "1", "]"}], "[", 
     RowBox[{"ruled", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", "ruledass"}], "]"}]], "Input",
 CellChangeTimes->{{3.5872806978644695`*^9, 3.587280778003053*^9}, 
   3.58728083266718*^9, 3.587289862213539*^9, {3.609731672757082*^9, 
   3.6097316754558864`*^9}, 3.614861851656726*^9, 3.614917783870947*^9, 
   3.6151811698088675`*^9, {3.617889476638414*^9, 3.617889479259218*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], ",", 
   RowBox[{
    RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], ",", 
   RowBox[{
    RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.609731680307495*^9, 3.609732009764474*^9, 
  3.615181651892441*^9, 3.617889480569621*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "2", "]"}], "[", 
     RowBox[{"ruled", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", "ruledass"}], "]"}]], "Input",
 CellChangeTimes->{{3.5872809006570687`*^9, 3.587280909512575*^9}, {
   3.587290118485197*^9, 3.5872901269076786`*^9}, {3.60973172877678*^9, 
   3.6097317311635847`*^9}, 3.614861851656726*^9, 3.614917783886547*^9, 
   3.615181170673917*^9, {3.617889487449233*^9, 3.6178894894616365`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "+", 
      RowBox[{"u", " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}]}], 
     ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["u", "2"], "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "2"], 
        "+", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}],
           ")"}]}]}], ")"}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "+", 
      RowBox[{"u", " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}]}], 
     ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["u", "2"], "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "2"], 
        "+", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}],
           ")"}]}]}], ")"}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "+", 
      RowBox[{"u", " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
     ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["u", "2"], "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "2"], 
        "+", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}],
           ")"}]}]}], ")"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6097326786468487`*^9, 3.6151816650191917`*^9, 
  3.6178894975736504`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "3", "]"}], "[", 
     RowBox[{"ruled", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", "ruledass"}], "]"}]], "Input",
 CellChangeTimes->{{3.5872809006570687`*^9, 3.587280909512575*^9}, {
   3.587290118485197*^9, 3.5872901269076786`*^9}, {3.5872906447672987`*^9, 
   3.5872906711228065`*^9}, 3.6097317401336*^9, 3.614861851656726*^9, 
   3.614917783886547*^9, 3.615181171545966*^9, {3.6178895031428604`*^9, 
   3.6178895055608644`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "+", 
         RowBox[{"u", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}]}], 
        ")"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "+", 
         RowBox[{"u", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["u", "2"], "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "2"], 
        "+", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}],
           ")"}]}]}], ")"}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "+", 
         RowBox[{"u", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}]}], 
        ")"}]}], "-", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "+", 
         RowBox[{"u", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["u", "2"], "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "2"], 
        "+", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}],
           ")"}]}]}], ")"}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "+", 
         RowBox[{"u", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}]}], 
        ")"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "+", 
         RowBox[{"u", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}]}], 
        ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["u", "2"], "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "2"], 
        "+", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}],
           ")"}]}]}], ")"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6097320859862075`*^9, 3.6097326905808697`*^9, 
  3.6151817742194376`*^9, 3.6178895107712736`*^9}]
}, Closed]],

Cell["\<\
For a general ruled surface the tangent plane of the surface considered along \
the generating lines  will not be constant:\
\>", "Text",
 CellChangeTimes->{{3.6097343540487347`*^9, 3.6097344491681757`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"%", ",", "u"}], "]"}], ",", "ruledass"}], "]"}]], "Input",
 CellChangeTimes->{{3.5881411069079304`*^9, 3.5881411142243433`*^9}, {
   3.588141144332396*^9, 3.5881411750956497`*^9}, 3.6097317567632294`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"u", "+", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
        ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            "+", 
            RowBox[{"u", " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "2", 
              "]"}]}]}], ")"}]}], "-", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            "+", 
            RowBox[{"u", " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "3", 
              "]"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["u", "2"], "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "2"], 
        "+", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}],
           ")"}]}]}], ")"}], 
      RowBox[{"3", "/", "2"}]]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}]}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
      ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["u", "2"], "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "2"],
          "+", 
         RowBox[{"2", " ", "u", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
             " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
            "+", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
             " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
            "+", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
             " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "3", 
              "]"}]}]}], ")"}]}]}], ")"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"u", "+", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}],
           ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "1", 
                "]"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              "+", 
              RowBox[{"u", " ", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "v", "]"}], "[", "3", 
                "]"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["u", "2"], "+", 
          SuperscriptBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
           "2"], "+", 
          SuperscriptBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
           "2"], "+", 
          SuperscriptBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
           "2"], "+", 
          RowBox[{"2", " ", "u", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}],
              "+", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}],
              "+", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
              " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "v", "]"}], "[", "3", 
               "]"}]}]}], ")"}]}]}], ")"}], 
        RowBox[{"3", "/", "2"}]]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], "-", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
      ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["u", "2"], "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "2"],
          "+", 
         RowBox[{"2", " ", "u", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
             " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
            "+", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
             " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
            "+", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
             " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "3", 
              "]"}]}]}], ")"}]}]}], ")"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "+", 
        RowBox[{"u", " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
       ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
           "-", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}]}],
           ")"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}],
           ")"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "-", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}],
           ")"}]}]}], ")"}]}], ")"}], "/", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["u", "2"], "+", 
       SuperscriptBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"], 
       "+", 
       SuperscriptBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"], 
       "+", 
       SuperscriptBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "2"], 
       "+", 
       RowBox[{"2", " ", "u", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
         ")"}]}]}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.609732134096692*^9, 3.6097327909982457`*^9, 
  3.6097328681715813`*^9, 3.615181897293477*^9, 3.6178895339685144`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "/.", 
   RowBox[{"u", "\[Rule]", " ", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6097328746299925`*^9, 3.6097328943484273`*^9}, {
  3.6097330057014227`*^9, 3.6097330357626753`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
          "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}]}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
         "-", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
        ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}]}], ")"}], "/", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"], 
       "+", 
       SuperscriptBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"], 
       "+", 
       SuperscriptBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "2"]}],
       ")"}], 
     RowBox[{"3", "/", "2"}]]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
          "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
         "-", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
         "-", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
        ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}]}], ")"}], "/", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"], 
       "+", 
       SuperscriptBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"], 
       "+", 
       SuperscriptBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "2"]}],
       ")"}], 
     RowBox[{"3", "/", "2"}]]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
           "-", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}]}],
           ")"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}],
           ")"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], 
           "-", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}],
           ")"}]}]}], ")"}]}], ")"}], "/", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"], 
       "+", 
       SuperscriptBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"], 
       "+", 
       SuperscriptBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "2"]}],
       ")"}], 
     RowBox[{"3", "/", "2"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.609732896922432*^9, 3.6097330253886576`*^9, 
  3.615181903556835*^9, 3.6178895459181356`*^9}]
}, Closed]],

Cell[TextData[{
 "A ruled surface for which the tangent planes along the generating lines are \
constant is the envelope of a 1-parametric family of planes. Such surfaces \
are said to be ",
 StyleBox["developable",
  FontColor->RGBColor[0, 0, 1]],
 ". The next subsections contain examples of developable surfaces."
}], "Text",
 CellChangeTimes->{{3.609734481608031*^9, 3.609734649871655*^9}, {
  3.609734874064478*^9, 3.60973488441607*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1.3. Circular Cones", "Subsubsection",
 CellChangeTimes->{{3.587278731126979*^9, 3.5872787512791314`*^9}, {
   3.587278983598419*^9, 3.5872789947820587`*^9}, {3.5875394069211664`*^9, 
   3.5875394299312067`*^9}, {3.5892067941410646`*^9, 3.589206796884221*^9}, 
   3.5896130524556894`*^9, 3.6096757219372315`*^9, 3.609739435859398*^9, 
   3.6178897837717533`*^9, 3.617890621555625*^9}],

Cell[TextData[{
 StyleBox["Example. ",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Circular Cones",
  FontColor->GrayLevel[0]],
 StyleBox[".",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{
  3.617941903491912*^9, {3.6179445243277154`*^9, 3.6179445260437183`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "circularcone"}]], "Input",
 CellChangeTimes->{{3.6151821603215213`*^9, 3.6151821615225897`*^9}}],

Cell[BoxData[
 StyleBox["\<\"{u,v}->circularcone[a,b][u,v] is a parametrization of a \
circular cone of radius a and slope b/a.  To plot try \
circularcone[1,0.5][-Pi,Pi,-1,1].\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.617889929288809*^9},
 CellTags->"Info3617897129-8063059"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"circularcone", "[", 
   RowBox[{"a", ",", "b"}], "]"}], "[", 
  RowBox[{"v", ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.6097399536040115`*^9, 3.6097399569472027`*^9}, 
   3.6148618516879253`*^9, 3.614864731452984*^9, 3.6151811727360344`*^9, 
   3.6151821410514193`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", " ", "u", " ", 
    RowBox[{"Cos", "[", "v", "]"}]}], ",", 
   RowBox[{"a", " ", "u", " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"b", " ", "u"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.609735537347416*^9, {3.6097399416673284`*^9, 3.609739958076267*^9}, 
   3.615182176351438*^9, 3.61788993563802*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"circularcone", "[", 
   RowBox[{"1", ",", ".5"}], "]"}], "[", 
  RowBox[{
   RowBox[{"-", "Pi"}], ",", "Pi", ",", 
   RowBox[{"-", "1"}], ",", "1"}], "]"}]], "Input",
 CellChangeTimes->{{3.6097399536040115`*^9, 3.6097399569472027`*^9}, 
   3.6148618516879253`*^9, 3.614864731452984*^9, 3.6151811727360344`*^9, 
   3.6151821410514193`*^9, {3.61518224160217*^9, 3.6151823043477592`*^9}}],

Cell[TextData[{
 "Here is the parameter representation of a",
 StyleBox[" circular cone with the opening  angle parameter a",
  FontColor->RGBColor[0, 0, 1]],
 ";"
}], "Text",
 CellChangeTimes->{{3.5875390653897667`*^9, 3.5875391467751093`*^9}, {
  3.6097367551930723`*^9, 3.609736762248476*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"u", ",", "v", ",", "a"}], "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"cone", "[", "a_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", " ", 
      RowBox[{"Cos", "[", "v", "]"}], " ", 
      RowBox[{"Sin", "[", 
       FractionBox["a", "2"], "]"}]}], ",", 
     RowBox[{"u", " ", 
      RowBox[{"Sin", "[", 
       FractionBox["a", "2"], "]"}], " ", 
      RowBox[{"Sin", "[", "v", "]"}]}], ",", 
     RowBox[{"u", " ", 
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cone", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"u", " ", 
     RowBox[{"Cos", "[", "v", "]"}]}], ",", 
    RowBox[{"u", " ", 
     RowBox[{"Sin", "[", "v", "]"}]}], ",", "u"}], "}"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5872948975265427`*^9, 3.5872949467553587`*^9}, {
   3.587295055234563*^9, 3.5872951071875343`*^9}, {3.58729514766685*^9, 
   3.5872951496909657`*^9}, {3.587295297660429*^9, 3.5872953178275824`*^9}, {
   3.5872953816602335`*^9, 3.587295400275298*^9}, 3.58729564402924*^9, {
   3.587296119420431*^9, 3.58729612220759*^9}, 3.587296180140904*^9, {
   3.5872968322122*^9, 3.58729691385187*^9}, {3.5872969927723837`*^9, 
   3.587297041619178*^9}, 3.5872995662082434`*^9, 3.5873007900452433`*^9, {
   3.587300836185882*^9, 3.587300857290089*^9}, {3.5873009825162516`*^9, 
   3.587301025218694*^9}, 3.5873015813395023`*^9, {3.5873016792821045`*^9, 
   3.5873016953790255`*^9}, 3.5873017301390133`*^9, {3.5873018736832237`*^9, 
   3.587301885521901*^9}, 3.5873023656363616`*^9, {3.587362824728996*^9, 
   3.587362858495927*^9}, {3.5873655403923225`*^9, 3.587365560400467*^9}, {
   3.587365642144143*^9, 3.5873656656024847`*^9}, 3.5873659192889943`*^9, {
   3.6097353257093105`*^9, 3.6097353561790533`*^9}, 3.60973566592377*^9, {
   3.6097357072661343`*^9, 3.6097358183264866`*^9}, {3.6097358569586964`*^9, 
   3.609735895822919*^9}, {3.6148618517035255`*^9, 3.6148618517035255`*^9}, {
   3.614864731468584*^9, 3.614864731484184*^9}}],

Cell["expressed with circularcone :", "Text",
 CellChangeTimes->{{3.609738511000499*^9, 3.609738550375751*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cone", "[", "a", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{"circularcone", "[", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"a", "/", "2"}], "]"}], ",", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"a", "/", "2"}], "]"}]}], "]"}], "[", 
   RowBox[{"v", ",", "u"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.609736354019127*^9, 3.6097364236911116`*^9}, {
  3.6148618517035255`*^9, 3.6148618517035255`*^9}, {3.614864731499784*^9, 
  3.614864731499784*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.6097353589812136`*^9, 3.6097357831784763`*^9, 
  3.609735931570964*^9, 3.6097364259922433`*^9, 3.615182538620159*^9, 
  3.6178900195505676`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"cone", "[", 
   RowBox[{"u", ",", "v"}], "]"}], "==", 
  RowBox[{
   RowBox[{"circularcone", "[", 
    RowBox[{"1", ",", " ", "1"}], "]"}], "[", 
   RowBox[{"v", ",", "u"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5872932058577847`*^9, 3.587293215873358*^9}, 
   3.5872948874259653`*^9, {3.6097364393220053`*^9, 3.6097364881637993`*^9}, {
   3.6097367155078025`*^9, 3.6097367297066145`*^9}, {3.6148618517191257`*^9, 
   3.6148618517191257`*^9}, {3.6148647315153837`*^9, 3.6148647315153837`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.6097367307006717`*^9, 3.6151825441414747`*^9, 
  3.6178900367885976`*^9}]
}, Closed]],

Cell["\<\
Here a denotes the angle between two opposite generators of the circular cone\
\>", "Text",
 CellChangeTimes->{{3.5873628884356394`*^9, 3.5873628961790824`*^9}, {
  3.5873631146025753`*^9, 3.587363137978913*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"a", "/", "2"}], "]"}], "*", 
      RowBox[{"Cos", "[", "v", "]"}]}], ",", 
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"a", "/", "2"}], "]"}], "*", 
      RowBox[{"Sin", "[", "v", "]"}]}], ",", 
     RowBox[{"Cos", "[", 
      RowBox[{"a", "/", "2"}], "]"}]}], "}"}], ".", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"a", "/", "2"}], "]"}], "*", 
      RowBox[{"Cos", "[", 
       RowBox[{"v", "+", "Pi"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"a", "/", "2"}], "]"}], "*", 
      RowBox[{"Sin", "[", 
       RowBox[{"v", "+", "Pi"}], "]"}]}], ",", 
     RowBox[{"Cos", "[", 
      RowBox[{"a", "/", "2"}], "]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.587363187949771*^9, 3.5873632063528233`*^9}, {
  3.587363405322204*^9, 3.587363414033702*^9}, {3.587364073017394*^9, 
  3.5873640870571966`*^9}, {3.587364145360532*^9, 3.5873641558491316`*^9}, {
  3.5873650971939735`*^9, 3.587365103712346*^9}, {3.5873651748564157`*^9, 
  3.587365181856816*^9}, {3.5873655843958397`*^9, 3.5873656085542216`*^9}, {
  3.587365705545769*^9, 3.5873657138572445`*^9}}],

Cell[BoxData[
 RowBox[{"Cos", "[", "a", "]"}]], "Output",
 CellChangeTimes->{3.5896086047762775`*^9, 3.6151825652476816`*^9, 
  3.617890050391822*^9}]
}, Closed]],

Cell["In the next cell try some values of a:", "Text",
 CellChangeTimes->{{3.5873652832916174`*^9, 3.587365315627467*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"cone", "[", 
     RowBox[{"8", "*", 
      RowBox[{"Pi", "/", "60"}]}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.587292881024205*^9, 3.587293043506499*^9}, {
   3.5872931006277657`*^9, 3.5872931337866626`*^9}, {3.587293221739693*^9, 
   3.5872932468991323`*^9}, {3.5872932802280383`*^9, 3.587293303739383*^9}, {
   3.5872933712442446`*^9, 3.587293384002974*^9}, 3.587295167828003*^9, {
   3.587295346019195*^9, 3.5872953481313157`*^9}, {3.587295417195266*^9, 
   3.5872954187073526`*^9}, 3.5872955288836546`*^9, {3.587295665403463*^9, 
   3.5872956745789876`*^9}, {3.5872957076028767`*^9, 3.587295718787516*^9}, 
   3.587295950548772*^9, {3.587296019203699*^9, 3.587296034386567*^9}, 
   3.587296273172225*^9, {3.5873020711465178`*^9, 3.5873020813291*^9}, 
   3.5873021189782534`*^9, {3.5873021523621635`*^9, 3.587302157585462*^9}, {
   3.587302190002316*^9, 3.5873021999618855`*^9}, 3.587302265473633*^9, {
   3.5873023851534777`*^9, 3.5873024626499104`*^9}, {3.587365325152012*^9, 
   3.5873653364146557`*^9}, {3.5873659389441185`*^9, 
   3.5873659632795105`*^9}, {3.5873775764752693`*^9, 3.587377577659337*^9}, 
   3.6148618517191257`*^9, 3.614864731530984*^9, {3.617890074603064*^9, 
   3.6178900946490993`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"cone", "[", 
    RowBox[{"u", ",", "v"}], "]"}], "-", 
   RowBox[{
    RowBox[{"cone", "[", 
     RowBox[{"Pi", "/", "2"}], "]"}], "[", 
    RowBox[{
     RowBox[{"u", "*", 
      RowBox[{"Sqrt", "[", "2", "]"}]}], ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.587292881024205*^9, 3.587293043506499*^9}, {
   3.5872931006277657`*^9, 3.5872931337866626`*^9}, {3.587293221739693*^9, 
   3.5872932468991323`*^9}, {3.5872932802280383`*^9, 3.587293303739383*^9}, {
   3.5872933712442446`*^9, 3.587293384002974*^9}, 3.587295167828003*^9, {
   3.587295346019195*^9, 3.5872953481313157`*^9}, {3.587295417195266*^9, 
   3.5872954187073526`*^9}, 3.5872955288836546`*^9, {3.587295665403463*^9, 
   3.5872956745789876`*^9}, {3.5872957076028767`*^9, 3.587295718787516*^9}, 
   3.587295950548772*^9, {3.587296019203699*^9, 3.587296034386567*^9}, 
   3.587296273172225*^9, {3.5873020711465178`*^9, 3.5873020813291*^9}, 
   3.5873021189782534`*^9, {3.5873021523621635`*^9, 3.587302157585462*^9}, {
   3.587302190002316*^9, 3.5873021999618855`*^9}, 3.587302265473633*^9, {
   3.5873023851534777`*^9, 3.587302489929471*^9}, {3.5873659905340695`*^9, 
   3.5873660240139847`*^9}, 3.5873660610071*^9, {3.5873663265912905`*^9, 
   3.5873663338547063`*^9}, {3.614861851734726*^9, 3.614861851734726*^9}, {
   3.614864731546584*^9, 3.614864731546584*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.6097385957033434`*^9, 3.615182619840804*^9, 
  3.6178901160523367`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "3", "]"}], "[", 
     RowBox[{"cone", "[", "a", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"u", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.587367193391869*^9, 3.5873672317900653`*^9}, {
   3.5873672813919024`*^9, 3.587367295423705*^9}, {3.614861851734726*^9, 
   3.614861851734726*^9}, 3.6148647315621843`*^9, 3.614917783933347*^9, 
   3.615181206984994*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"Cos", "[", "v", "]"}], " ", 
      RowBox[{"Sin", "[", "a", "]"}]}], 
     RowBox[{"2", " ", 
      SqrtBox[
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         FractionBox["a", "2"], "]"}], "2"]]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"Sin", "[", "a", "]"}], " ", 
      RowBox[{"Sin", "[", "v", "]"}]}], 
     RowBox[{"2", " ", 
      SqrtBox[
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         FractionBox["a", "2"], "]"}], "2"]]}]]}], ",", 
   SqrtBox[
    SuperscriptBox[
     RowBox[{"Sin", "[", 
      FractionBox["a", "2"], "]"}], "2"]]}], "}"}]], "Output",
 CellChangeTimes->{3.609738605863925*^9, 3.6151826502135415`*^9, 
  3.6178901239615507`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", ".", "%"}], "]"}]], "Input",
 CellChangeTimes->{{3.61518282362146*^9, 3.615182837275241*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.6151828388433304`*^9, 3.6178901320579653`*^9}]
}, Closed]],

Cell["\<\
The spherical image is a circle on the unit sphere. The vector \
amf[3][cone[a]][u,v] does not depend on u, it is constant along the \
generators.The tangent planes form a 1-parameter family;  tangent to  the \
cone along the generating lines. The cone is the envelope of this family of \
planes.\
\>", "Text",
 CellChangeTimes->{{3.5873769759596725`*^9, 3.5873769972388897`*^9}, {
   3.5873770459446754`*^9, 3.587377192903081*^9}, {3.5873775421113043`*^9, 
   3.5873775659356666`*^9}, {3.5873780405038104`*^9, 3.587378092671794*^9}, 
   3.589204165124693*^9, {3.614861851765926*^9, 3.614861851812726*^9}, 
   3.614864731593384*^9, 3.614917783964547*^9, 3.61518121426541*^9}],

Cell["\<\
Here is the first fundamental form of the circular cone with parameter a:\
\>", "Text",
 CellChangeTimes->{{3.5875392110940228`*^9, 3.5875392468024855`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    FormBox["fund1",
     TraditionalForm], "[", 
    RowBox[{"cone", "[", "a", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"s1", ",", "s2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.587302621247982*^9, 3.5873026846016054`*^9}, 
   3.5873027534025407`*^9, {3.5873033248071203`*^9, 3.5873033282391267`*^9}, 
   3.590495710531009*^9, 3.614861851843926*^9, 3.614864731624584*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["s1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}], "2"], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        FractionBox["a", "2"], "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        FractionBox["a", "2"], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "v", "]"}], "2"]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["s2", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        FractionBox["a", "2"], "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        FractionBox["a", "2"], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "v", "]"}], "2"]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.589203063104661*^9, 3.5896097052802105`*^9, 
  3.609738676483964*^9, 3.615182899361792*^9, 3.617890166846026*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.5873027745887527`*^9, 3.5873027831682434`*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["s1", "2"], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["s2", "2"], " ", 
    SuperscriptBox["u", "2"]}], "2"], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["s2", "2"], " ", 
   SuperscriptBox["u", "2"], " ", 
   RowBox[{"Cos", "[", "a", "]"}]}]}]], "Output",
 CellChangeTimes->{3.5892030689879975`*^9, 3.6097386952050347`*^9, 
  3.615182902982999*^9, 3.617890198014881*^9}]
}, Closed]],

Cell["Since", "Text",
 CellChangeTimes->{{3.5896106720295086`*^9, 3.589610673963912*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"Cos", "[", "a", "]"}]}], " ", ")"}], "/", "2"}], "\[Equal]", 
   " ", 
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{"a", "/", "2"}], "]"}], "^", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.58961068427553*^9, 3.589610786065709*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.5896107677200766`*^9, 3.5896107932573214`*^9}, 
   3.609738736961423*^9, 3.6151829907300177`*^9, 3.61789023177334*^9}]
}, Closed]],

Cell["\<\
the first fundamental form of the cone with parameter a can be written in \
traditional form as\
\>", "Text",
 CellChangeTimes->{{3.5896108644714465`*^9, 3.589610910959528*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["ds", "2"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox["du", "2"], " ", "+", " ", 
    RowBox[{
     SuperscriptBox["u", "2"], " ", 
     RowBox[{
      SuperscriptBox["sin", "2"], "(", 
      FractionBox["a", "2"], ")"}], " ", 
     SuperscriptBox["dv", "2"]}]}]}], TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5896109202103443`*^9, 3.5896110848218336`*^9}}],

Cell[TextData[{
 "The ",
 StyleBox["plane in polar coordinates",
  FontColor->RGBColor[0, 0, 1]],
 " r, \[Phi] has the parameter representation"
}], "Text",
 CellChangeTimes->{{3.589611215674863*^9, 3.5896112858281865`*^9}},
 CellTags->"polco"],

Cell[BoxData[
 RowBox[{
  RowBox[{"polcoord", "[", 
   RowBox[{"r_", ",", "\[Phi]_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"r", "*", 
     RowBox[{"Cos", "[", "\[Phi]", "]"}]}], ",", " ", 
    RowBox[{"r", "*", 
     RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], "}"}], " "}]], "Input",
 CellChangeTimes->{{3.589611309758629*^9, 3.589611399879987*^9}, 
   3.5896227230329013`*^9}],

Cell["\<\
The first fundamental form of the plane in these coordinates is\
\>", "Text",
 CellChangeTimes->{{3.5896114233736277`*^9, 3.5896114457284675`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     FormBox["fund1",
      TraditionalForm], "[", "polcoord", "]"}], "[", 
    RowBox[{"r", ",", "\[Phi]\[Phi]"}], "]"}], "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5896115173949933`*^9, 3.5896115745690937`*^9}, 
   3.5896116780440755`*^9, 3.5904957105466094`*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["s1", "2"], "+", 
  RowBox[{
   SuperscriptBox["r", "2"], " ", 
   SuperscriptBox["s2", "2"]}]}]], "Output",
 CellChangeTimes->{{3.589611548985049*^9, 3.5896115781570997`*^9}, {
   3.5896227301309137`*^9, 3.589622737774927*^9}, 3.615183078906061*^9, 
   3.6178902938302493`*^9}]
}, Closed]],

Cell["In traditional form:", "Text",
 CellChangeTimes->{{3.5896116022123423`*^9, 3.5896116119155593`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["ds", "2"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox["dr", "2"], "+", " ", 
    RowBox[{
     SuperscriptBox["r", "2"], 
     SuperscriptBox["d\[Phi]", "2"]}]}]}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.589611617359969*^9, 3.5896117282137637`*^9}}],

Cell["Thus the map ", "Text",
 CellChangeTimes->{{3.5896117816906576`*^9, 3.5896117861366653`*^9}, 
   3.5896118362283535`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{"u", ",", " ", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"a", "/", "2"}], "]"}], "*", "v"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5896118084291043`*^9, 3.589611809895507*^9}, {
  3.589611866227206*^9, 3.589611949827753*^9}}],

Cell["\<\
 is an isometry of the cone with parameter a onto a certain region of the \
plane. We consider the part of  cone[1]  with u< R=1 and obtain the picture\
\>", "Text",
 CellChangeTimes->{{3.58961199938904*^9, 3.589612149695304*^9}, {
   3.58961222168943*^9, 3.5896122512046824`*^9}, {3.5896123690160894`*^9, 
   3.5896123697492905`*^9}, {3.5896124644102564`*^9, 3.589612466797061*^9}, 
   3.614861851875126*^9, 3.6148647316557837`*^9}],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"polcoord", "[", 
    RowBox[{"u", ",", " ", 
     RowBox[{
      RowBox[{"Sin", "[", ".5", "]"}], "*", "v"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.589612155046113*^9, 3.589612207477805*^9}, {
   3.589612261875101*^9, 3.5896123416224413`*^9}, 3.589612379109307*^9, 
   3.5896124778106804`*^9, 3.589622759817766*^9}],

Cell["\<\
The map can be obtained by cutting the cone along the line v== 0 and laying \
down all its other generating lines into the x,y-plane; this often is said as \
\[OpenCurlyDoubleQuote]developing it into the plane\[CloseCurlyDoubleQuote]. \
Of course, the isometry is valid only locally: The circle u == 1 must be cut \
and is only then developable into a circle arc whose length depends on a. \
\>", "Text",
 CellChangeTimes->{{3.5896126509449844`*^9, 3.5896127547447667`*^9}, {
  3.589612787770025*^9, 3.589612852681739*^9}, {3.5896129059714327`*^9, 
  3.589612984767171*^9}, {3.5896131463990545`*^9, 3.5896132386264167`*^9}, {
  3.615264023461501*^9, 3.615264024773576*^9}}],

Cell["\<\
The built-in function Cone yields a cone as a  Graphics3D object:\
\>", "Text",
 CellChangeTimes->{{3.587555743989889*^9, 3.5875557629299726`*^9}, {
  3.587555807577526*^9, 3.5875558655058393`*^9}, {3.587556515250003*^9, 
  3.587556566753948*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Cone"}]], "Input",
 CellChangeTimes->{{3.5875558693020563`*^9, 3.5875558720292125`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\!\(\*RowBox[{\\\"Cone\\\", \\\"[\\\", \
RowBox[{RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"y\\\", \\\"TI\\\"], \
StyleBox[\\\"1\\\", \\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"z\\\", \
\\\"TI\\\"], StyleBox[\\\"1\\\", \\\"TR\\\"]]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \
StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"y\\\", \
\\\"TI\\\"], StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", \
SubscriptBox[StyleBox[\\\"z\\\", \\\"TI\\\"], StyleBox[\\\"2\\\", \
\\\"TR\\\"]]}], \\\"}\\\"}]}], \\\"}\\\"}], \\\",\\\", StyleBox[\\\"r\\\", \\\
\"TI\\\"]}], \\\"]\\\"}]\) represents a cone with a base of radius \
\!\(\*StyleBox[\\\"r\\\", \\\"TI\\\"]\) centered at \!\(\*RowBox[{\\\"(\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"y\\\", \\\"TI\\\"], \
StyleBox[\\\"1\\\", \\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"z\\\", \
\\\"TI\\\"], StyleBox[\\\"1\\\", \\\"TR\\\"]]}], \\\")\\\"}]\) and a tip at \
\!\(\*RowBox[{\\\"(\\\", RowBox[{SubscriptBox[StyleBox[\\\"x\\\", \
\\\"TI\\\"], StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", \
SubscriptBox[StyleBox[\\\"y\\\", \\\"TI\\\"], StyleBox[\\\"2\\\", \
\\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"z\\\", \\\"TI\\\"], \
StyleBox[\\\"2\\\", \\\"TR\\\"]]}], \\\")\\\"}]\). \
\\n\!\(\*RowBox[{\\\"Cone\\\", \\\"[\\\", RowBox[{\\\"{\\\", RowBox[{RowBox[{\
\\\"{\\\", RowBox[{SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \
StyleBox[\\\"1\\\", \\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"y\\\", \
\\\"TI\\\"], StyleBox[\\\"1\\\", \\\"TR\\\"]], \\\",\\\", \
SubscriptBox[StyleBox[\\\"z\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"2\\\", \
\\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"y\\\", \\\"TI\\\"], \
StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"z\\\", \
\\\"TI\\\"], StyleBox[\\\"2\\\", \\\"TR\\\"]]}], \\\"}\\\"}]}], \\\"}\\\"}], \
\\\"]\\\"}]\) represents a cone with a base of radius 1.\"\>", "MSG"], 
  "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Cone"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.6178903762607937`*^9},
 CellTags->"Info3617897576-4001495"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Cone", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"Tan", "[", 
    FractionBox["1", "2"], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{3.5875574251940484`*^9, 3.6148618519063263`*^9, 
  3.614917783995747*^9}],

Cell[BoxData[
 RowBox[{"Cone", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"Tan", "[", 
    FractionBox["1", "2"], "]"}]}], "]"}]], "Output",
 CellChangeTimes->{3.615183364432392*^9, 3.61789039108082*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"co1", " ", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"Graphics3D", "[", "%", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5875564103430023`*^9, 3.587556438523614*^9}, {
  3.587556962923608*^9, 3.5875569664438095`*^9}}],

Cell["We plot the surface of the opposite of co1  by cone", "Text",
 CellChangeTimes->{{3.587558692569538*^9, 3.587558711641629*^9}, {
  3.587558788978052*^9, 3.5875588102972717`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"cone", "[", "a", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5875559643094907`*^9, 3.587555973026989*^9}, 
   3.614861851921926*^9, 3.614864731686984*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"u", " ", 
    RowBox[{"Cos", "[", "v", "]"}], " ", 
    RowBox[{"Sin", "[", 
     FractionBox["a", "2"], "]"}]}], ",", 
   RowBox[{"u", " ", 
    RowBox[{"Sin", "[", 
     FractionBox["a", "2"], "]"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"u", " ", 
    RowBox[{"Cos", "[", 
     FractionBox["a", "2"], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6097393227639294`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"1", "/", 
   RowBox[{"Cos", "[", 
    RowBox[{"1", "/", "2"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6151842927934914`*^9, 3.615184323403242*^9}}],

Cell[BoxData["1.139493927324549`"], "Output",
 CellChangeTimes->{3.615184324951331*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"co2", " ", "=", " ", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"cone", "[", "1", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "0", ",", 
      RowBox[{"-", "1.139"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5875566103584423`*^9, 3.5875566887569265`*^9}, {
   3.5875575681262236`*^9, 3.587557569437299*^9}, {3.587557626693574*^9, 
   3.5875576269725895`*^9}, {3.5875577747100396`*^9, 3.587557780154351*^9}, {
   3.5875578458291073`*^9, 3.5875578481092377`*^9}, {3.5875584166217546`*^9, 
   3.5875584181818438`*^9}, 3.587558498653447*^9, 3.587558539606789*^9, {
   3.5875585741337643`*^9, 3.58755858018111*^9}, 3.614861851921926*^9, 
   3.6148647317025843`*^9, {3.6151836825005846`*^9, 3.615183683916666*^9}, {
   3.6151837288772373`*^9, 3.6151837305003304`*^9}, {3.615184362476477*^9, 
   3.615184364692604*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{"co1", ",", "co2"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.5875575114239807`*^9, 3.5875575243397193`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1.4. Conical Surfaces", "Subsubsection",
 CellChangeTimes->{{3.587201518412738*^9, 3.587201527076234*^9}, {
   3.587272835342759*^9, 3.58727283885396*^9}, {3.587272981302108*^9, 
   3.5872730078536263`*^9}, 3.5872731046621633`*^9, 3.587278763622837*^9, {
   3.5875395682098494`*^9, 3.58753958547908*^9}, 3.589613294661715*^9, 
   3.5896228998436117`*^9, 3.6097394807369647`*^9, 3.6097411436570787`*^9, 
   3.6178906549864836`*^9, 3.617944252481638*^9}],

Cell[TextData[{
 "The next three examples treat important special cases of developable \
surfaces.\n\n",
 StyleBox["Example 1",
  FontColor->RGBColor[0, 0, 1]],
 ". Conical surface\n A ruled surface is called ",
 StyleBox["conical ",
  FontColor->RGBColor[0, 0, 1]],
 "if all its rulings  have a common point, say the origin. Thus the surface \
is defined by  vec[y[v]] being a curve on the unit sphere:"
}], "Text",
 CellChangeTimes->{{3.587291182439052*^9, 3.587291253231101*^9}, {
   3.5872918463990283`*^9, 3.587291860454832*^9}, {3.6097350506905804`*^9, 
   3.609735056359905*^9}, 3.6179419782004433`*^9, 3.617942024688525*^9, {
   3.6179420573861823`*^9, 3.6179420643125944`*^9}, {3.6179434846950893`*^9, 
   3.617943490045899*^9}, {3.6179445410041447`*^9, 3.6179445500833607`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"conesf", "[", "y_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{"y", "[", "v", "]"}], "]"}], "*", "u"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.587292095259262*^9, 3.587292166330327*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"conesf", "::", "usage"}], " ", "=", " ", 
   "\"\<conesf[y][u,v] is the general conical surface with vertex at the \
origin. It is defined by the  curve y[v] on the unit sphere.\>\""}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6151879081844697`*^9, 3.6151881733726377`*^9}, {
   3.6179435529452095`*^9, 3.617943629603744*^9}, {3.617943683735839*^9, 
   3.617943707759881*^9}, 3.617943754403963*^9, 3.617943886052594*^9, 
   3.617948041571166*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"conesf", "[", "y", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.587292408188161*^9, 3.587292436585785*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"u", " ", 
    RowBox[{
     RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}]}], ",", 
   RowBox[{"u", " ", 
    RowBox[{
     RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}]}], ",", 
   RowBox[{"u", " ", 
    RowBox[{
     RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.609735216557068*^9, 3.617889919835192*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "conesf"}]], "Input",
 CellChangeTimes->{{3.6097395920333304`*^9, 3.609739595611535*^9}}],

Cell[BoxData[
 StyleBox["\<\"conesf[y][u,v] is the general conical surface with vertex at \
the origin. It is defined by the  curve y[v] on the unit sphere.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6179481199636497`*^9},
 CellTags->"Info3617955319-5478789"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"conesf", "[", "y", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{3.6097395787705717`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"u", " ", 
    RowBox[{
     RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}]}], ",", 
   RowBox[{"u", " ", 
    RowBox[{
     RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}]}], ",", 
   RowBox[{"u", " ", 
    RowBox[{
     RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.609739580741685*^9, 3.6151845416657267`*^9}]
}, Closed]],

Cell["\<\
As before we assume that the curve vec[y[v]] lies on the unit sphere and  \
that v is its arc length; then ruledass is satisfied;\
\>", "Text",
 CellChangeTimes->{{3.587540430813365*^9, 3.5875404624814205`*^9}, {
   3.5875404962086797`*^9, 3.5875405929912496`*^9}, {3.609740743897213*^9, 
   3.6097407692406626`*^9}, 3.615184574313594*^9, {3.6151846406823893`*^9, 
   3.6151846992017365`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["ruledass"], "Input",
 CellChangeTimes->{{3.6097406879370127`*^9, 3.6097406914172115`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{
       RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], "2"]}], "\[Equal]", 
    "1"}], "&&", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
    "\[Equal]", "0"}], "&&", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"], 
     "+", 
     SuperscriptBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"], 
     "+", 
     SuperscriptBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "2"]}], 
    "\[Equal]", "1"}], "&&", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
    "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6097406955424476`*^9, 3.615184710150363*^9, 
  3.617943991259179*^9}]
}, Closed]],

Cell[" The simplification under these condition yields:", "Text",
 CellChangeTimes->{{3.609740786200633*^9, 3.6097407934400473`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"u", ">", "0"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", 
       RowBox[{"conesf", "[", "y", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "ruledass"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.587539794488247*^9, 3.5875399826401777`*^9}, {
   3.5875400133566313`*^9, 3.5875400957715764`*^9}, 3.58754036527765*^9, {
   3.587548649578514*^9, 3.587548649812515*^9}, {3.588249351340147*^9, 
   3.588249351340147*^9}, {3.6097400255921288`*^9, 3.609740054356774*^9}, {
   3.609740095708139*^9, 3.60974011669934*^9}, {3.6097401494602137`*^9, 
   3.609740164915097*^9}, {3.6097402113237514`*^9, 3.609740268059997*^9}, 
   3.614861851953126*^9, 3.6149177840113473`*^9, 3.6151812556737785`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}]}], " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["y", "\[Prime]",
        MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}], " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["y", "\[Prime]",
        MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}], " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["y", "\[Prime]",
        MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], "-", 
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["y", "\[Prime]",
        MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}]}], " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["y", "\[Prime]",
        MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}], " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["y", "\[Prime]",
        MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.6097400591060457`*^9, 3.6097401202135406`*^9, 3.6097401665981936`*^9, {
   3.6097402501129704`*^9, 3.6097402707551513`*^9}, 3.615184827827094*^9, 
   3.6151849781946945`*^9, 3.617944022599634*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"u", ">", "0"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"%", ".", "%"}], ",", "ruledass"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.615184854845639*^9, 3.61518486657131*^9}, {
  3.615184929956935*^9, 3.6151849709232783`*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.615184868181402*^9, 3.615184983819016*^9, 
  3.6179440369204593`*^9}]
}, Closed]],

Cell["\<\
The normal vector of the surface is constant along the generating lines, the \
surface is developable, once more: \
\>", "Text",
 CellChangeTimes->{{3.5875406082012763`*^9, 3.587540632225319*^9}, {
   3.587548159254053*^9, 3.587548167506468*^9}, 3.587548689857785*^9, {
   3.6097404018726506`*^9, 3.6097404565847797`*^9}, {3.6097411060729284`*^9, 
   3.6097411181606197`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"%%", ",", "u"}], "]"}], ",", "ruledass"}], "]"}]], "Input",
 CellChangeTimes->{{3.5875401840365314`*^9, 3.5875402950931263`*^9}, {
   3.5875485494419384`*^9, 3.587548549675939*^9}, {3.588249351355747*^9, 
   3.5882493513713474`*^9}, {3.609740484835396*^9, 3.6097404878005657`*^9}, 
   3.6151850264194527`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.609740494805966*^9, 3.615185033345849*^9, 
  3.6179440532848883`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "1", "]"}], "[", 
      RowBox[{"conesf", "[", "y", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "-", " ", 
    RowBox[{"vec", "[", 
     RowBox[{"y", "[", "v", "]"}], "]"}]}], ",", "ruledass"}], "]"}]], "Input",
 CellChangeTimes->{{3.5875483343955607`*^9, 3.5875483387791686`*^9}, 
   3.5875483973260717`*^9, {3.5875484361857395`*^9, 3.5875485398323216`*^9}, 
   3.5875487665475197`*^9, {3.5882493513713474`*^9, 3.588249351386947*^9}, {
   3.6097405338642*^9, 3.609740552621273*^9}, 3.614861851953126*^9, 
   3.6149177840269475`*^9, 3.615181257120861*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.609740554857401*^9, 3.615185056109151*^9, 
  3.617944084531743*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"u", ">", "0"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "2", "]"}], "[", 
       RowBox[{"conesf", "[", "y", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "ruledass"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5875483343955607`*^9, 3.5875483387791686`*^9}, 
   3.5875483973260717`*^9, {3.5875484361857395`*^9, 3.5875485398323216`*^9}, {
   3.5875487665475197`*^9, 3.58754880069598*^9}, {3.587548900848156*^9, 
   3.5875489599566593`*^9}, {3.5875489994247293`*^9, 3.587549030718384*^9}, 
   3.5875490897488875`*^9, {3.6097405719843807`*^9, 3.6097405966487913`*^9}, 
   3.6097406267725143`*^9, 3.614861851968726*^9, 3.614917784042547*^9, 
   3.6151812583689327`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["y", "\[Prime]",
      MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["y", "\[Prime]",
      MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["y", "\[Prime]",
      MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6097406318988075`*^9, 3.6151850710230036`*^9, 
  3.617944095670162*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", " ", "\[Equal]", "  ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"y", "[", "v", "]"}], "]"}], ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.587549103554912*^9, 3.5875491348797665`*^9}, {
  3.587549217154311*^9, 3.5875492390099497`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.609740637645136*^9, 3.615185074055177*^9, 
  3.617944102237774*^9}]
}, Closed]],

Cell["Thus, under the above assumptions, we have: The vectors ", "Text",
 CellChangeTimes->{{3.5875493479449415`*^9, 3.58754937602499*^9}, {
  3.5875496573714848`*^9, 3.5875496662635*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "1", "]"}], "[", 
     RowBox[{"conesf", "[", "y", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", " ", 
   RowBox[{"vec", "[", 
    RowBox[{"y", "[", "v", "]"}], "]"}]}], ";", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "2", "]"}], "[", 
     RowBox[{"conesf", "[", "y", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", " ", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{"y", "[", "v", "]"}], "]"}], ",", "v"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "3", "]"}], "[", 
     RowBox[{"conesf", "[", "y", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", 
   RowBox[{"Cross", "[", 
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{"y", "[", "v", "]"}], "]"}], ",", " ", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"vec", "[", 
        RowBox[{"y", "[", "v", "]"}], "]"}], ",", "v"}], "]"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.587549409190649*^9, 3.587549645827464*^9}, {
   3.587549711363179*^9, 3.587549807303348*^9}, 3.587549850172223*^9, {
   3.6148618519843264`*^9, 3.6148618519999266`*^9}, {3.614917784042547*^9, 
   3.6149177840581474`*^9}, {3.6151812596670065`*^9, 3.615181270946652*^9}}],

Cell["\<\
form the orthonormal moving 3-frame of the surface; it does not depend on u.\
\>", "Text",
 CellChangeTimes->{{3.5875498669734526`*^9, 3.5875499120107317`*^9}, {
  3.587549954926407*^9, 3.587549970245634*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"u", ">", "0"}], ",", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"amf", "[", "3", "]"}], "[", 
        RowBox[{"conesf", "[", "y", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", 
      RowBox[{"Cross", "[", 
       RowBox[{
        RowBox[{"vec", "[", 
         RowBox[{"y", "[", "v", "]"}], "]"}], ",", " ", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"vec", "[", 
           RowBox[{"y", "[", "v", "]"}], "]"}], ",", "v"}], "]"}]}], "]"}]}], 
     ",", "ruledass"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.587549976423245*^9, 3.5875500258129315`*^9}, {
   3.6097408644981112`*^9, 3.609740903912366*^9}, 3.6148618520155263`*^9, 
   3.6149177840737476`*^9, 3.6151812746748652`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.609740907559574*^9, 3.6151851320294933`*^9, 
  3.617944153359064*^9}]
}, Closed]],

Cell["Here is the first fundamental form of the  conical surface:", "Text",
 CellChangeTimes->{{3.5875392110940228`*^9, 3.5875392468024855`*^9}, {
   3.5875503815403566`*^9, 3.5875504304308424`*^9}, 3.6179442107983646`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"u", ">", "0"}], ",", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        FormBox["fund1",
         TraditionalForm], "[", 
        RowBox[{"conesf", "[", "y", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"s1", ",", "s2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], ",", "ruledass"}], "]"}]}],
   "]"}]], "Input",
 CellChangeTimes->{{3.587302621247982*^9, 3.5873026846016054`*^9}, 
   3.5873027534025407`*^9, {3.5873033248071203`*^9, 3.5873033282391267`*^9}, {
   3.5875504420840626`*^9, 3.5875505150141907`*^9}, 3.590495710562209*^9, {
   3.609740930352878*^9, 3.609740964005803*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["s1", "2"], "+", 
  RowBox[{
   SuperscriptBox["s2", "2"], " ", 
   SuperscriptBox["u", "2"]}]}]], "Output",
 CellChangeTimes->{3.589622192070369*^9, 3.609740965318878*^9, 
  3.6151851412970233`*^9, 3.6179442170851755`*^9}]
}, Closed]],

Cell["Thus, in traditional notation, the first fundamental form is", "Text",
 CellChangeTimes->{{3.588144859952071*^9, 3.5881448887037153`*^9}, {
  3.5896222176076136`*^9, 3.5896222211800203`*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["ds", "2"], " ", "==", 
  RowBox[{
   SuperscriptBox["du", 
    RowBox[{"2", "  "}]], "+", " ", 
   RowBox[{
    SuperscriptBox["u", "2"], 
    SuperscriptBox["dv", "2"]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.588144893206973*^9, 3.588144994745781*^9}}],

Cell[TextData[{
 "and with the map defined by the equality of the parameters   r = u, \[Phi]  \
= v we obtain a local  isometry of the conical surface with the Euclidean \
plane in polar coordinates see ",
 ButtonBox["above",
  BaseStyle->"Hyperlink",
  ButtonData->"polco"],
 " ."
}], "Text",
 CellChangeTimes->{{3.58814502199934*^9, 3.5881450378552465`*^9}, {
  3.58814511029739*^9, 3.5881451394640584`*^9}, {3.588145246302169*^9, 
  3.5881452463101697`*^9}, {3.588145293663878*^9, 3.588145374903525*^9}, {
  3.5881609609546366`*^9, 3.588160965305886*^9}, {3.5896223283834085`*^9, 
  3.5896223388510265`*^9}, {3.589622379957099*^9, 3.589622382078703*^9}, {
  3.589622940793684*^9, 3.5896229828357573`*^9}, {3.5896230368274527`*^9, 
  3.5896230368274527`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1.5. Cylindrical Surfaces", "Subsubsection",
 CellChangeTimes->{{3.587201518412738*^9, 3.587201527076234*^9}, {
   3.587272835342759*^9, 3.58727283885396*^9}, {3.587272981302108*^9, 
   3.5872730078536263`*^9}, 3.5872731046621633`*^9, 3.587278763622837*^9, {
   3.5875395682098494`*^9, 3.58753958547908*^9}, {3.5875506376928062`*^9, 
   3.58755065084363*^9}, 3.6097411500414433`*^9, 3.609744994379327*^9, 
   3.617944348905407*^9, 3.6179453910184374`*^9}],

Cell[TextData[{
 StyleBox["Example 2",
  FontColor->RGBColor[0, 0, 1]],
 ". Cylindrical surface"
}], "Text",
 CellChangeTimes->{{3.617944654400744*^9, 3.6179446785963864`*^9}}],

Cell[TextData[{
 "A ruled surface is said to be ",
 StyleBox["cylindrical",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" or a",
  FontColor->GrayLevel[0]],
 StyleBox[" cylinder,",
  FontColor->RGBColor[0, 0, 1]],
 " if all its generating lines are parallel. In this case its parameter \
representation has the form vec[x[v]] + u vec[a], vec[a] = constant, not the \
null vector. We assume vec[a] = stb[3], that the directrix intersects the \
generating lines orthogonally and lies in the plane z==0. Thus we suppose the \
parameter representation to be"
}], "Text",
 CellChangeTimes->{{3.587553102264791*^9, 3.587553151345598*^9}, {
   3.587553246298029*^9, 3.5875534525058236`*^9}, {3.587553671769365*^9, 
   3.587553876378068*^9}, {3.587554060673609*^9, 3.5875540834409113`*^9}, {
   3.588564643440874*^9, 3.5885646536744924`*^9}, {3.5885647572430744`*^9, 
   3.588564762640684*^9}, {3.5885648533236427`*^9, 3.588564937423391*^9}, 
   3.5885649858302755`*^9, {3.5885650220535393`*^9, 3.5885650255167456`*^9}, {
   3.588565093548465*^9, 3.588565129428528*^9}, 3.5885651668217936`*^9, {
   3.588565473877133*^9, 3.588565491099563*^9}, 3.6097437815449567`*^9, 
   3.615185309945669*^9, {3.615264079771722*^9, 3.6152640993158393`*^9}, {
   3.617944759092528*^9, 3.617944795518592*^9}, 3.617944826391046*^9, {
   3.617944945918456*^9, 3.6179449649660892`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cylindersf", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "[", "v", "]"}], ",", 
    RowBox[{"y", "[", "v", "]"}], ",", "u"}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5875539174934196`*^9, 3.5875540237964993`*^9}, {
   3.5875544463496685`*^9, 3.587554446916701*^9}, 3.5875549322674613`*^9, {
   3.5875550888534174`*^9, 3.587555104389306*^9}, {3.6097443219728675`*^9, 
   3.6097443494924417`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cylindersf", "::", " ", "usage"}], " ", "=", " ", 
   "\"\<cylindersf[x,y][u,v] is the cylinder with rulings parallel to the \
z-axis erected over the curve {x[v],y[v],0} in the x,y-plane.\>\""}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.615187599736828*^9, 3.6151877880615993`*^9}, 
   3.6179448499938874`*^9}],

Cell["A special case is", "Text",
 CellChangeTimes->{{3.6097443626391935`*^9, 3.609744379281145*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "circularcylinder"}]], "Input",
 CellChangeTimes->{{3.6097439348607264`*^9, 3.609743944041251*^9}}],

Cell[BoxData[
 StyleBox["\<\"{u,v}->circularcylinder[a][u,v] is a parametrization of a \
circular cylinder of radius a.  To plot try circularcylinder[1][-Pi,Pi,-4,4].\
\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.617945161947635*^9},
 CellTags->"Info3617952361-9601952"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"circularcylinder", "[", "a", "]"}], "[", 
   RowBox[{"v", ",", "u"}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.609744115587063*^9, 3.6097441296198654`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", " ", 
    RowBox[{"Cos", "[", "v", "]"}]}], ",", 
   RowBox[{"a", " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", "u"}], "}"}]], "Output",
 CellChangeTimes->{
  3.609744040688779*^9, {3.6097441205083447`*^9, 3.609744130584921*^9}, 
   3.6151858585620484`*^9, 3.6179451711672516`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cylinder", "[", "a_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"circularcylinder", "[", "a", "]"}], "[", 
   RowBox[{"v", ",", "u"}], "]"}], " "}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5875539174934196`*^9, 3.5875540237964993`*^9}, {
   3.5875544463496685`*^9, 3.5875545218449864`*^9}, {3.587554553540799*^9, 
   3.587554574661007*^9}, 3.5875549421500263`*^9, {3.58755512963875*^9, 
   3.5875551798056197`*^9}, {3.587555221229989*^9, 3.5875552221160393`*^9}, 
   3.5875552711018414`*^9, 3.587555335188507*^9, {3.5875607561415677`*^9, 
   3.58756076387001*^9}, {3.5875609656385503`*^9, 3.587560970365821*^9}, {
   3.6097442549010315`*^9, 3.6097442800674706`*^9}}],

Cell[BoxData[
 RowBox[{"cy1", " ", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"cylinder", "[", ".5", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", 
      RowBox[{"-", "1"}], ",", "2.3"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.587554597538316*^9, 3.587554678861967*^9}, {
   3.5875548571821666`*^9, 3.5875548631575084`*^9}, {3.587555015485221*^9, 
   3.587555031589142*^9}, {3.587560057349599*^9, 3.587560095149761*^9}, {
   3.609744228741535*^9, 3.6097442294445753`*^9}, 3.6148618520311265`*^9, 
   3.6149177840737476`*^9}],

Cell["In Mathematica Cylinder is a Graphics3D object :", "Text",
 CellChangeTimes->{{3.588565563780091*^9, 3.5885656192069883`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Cylinder"}]], "Input",
 CellChangeTimes->{{3.587559881636549*^9, 3.5875598989385386`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\!\(\*RowBox[{\\\"Cylinder\\\", \\\"[\\\", RowBox[{RowBox[{\\\
\"{\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{SubscriptBox[StyleBox[\\\"x\\\", \
\\\"TI\\\"], StyleBox[\\\"1\\\", \\\"TR\\\"]], \\\",\\\", \
SubscriptBox[StyleBox[\\\"y\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"z\\\", \\\"TI\\\"], \
StyleBox[\\\"1\\\", \\\"TR\\\"]]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \
StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"y\\\", \
\\\"TI\\\"], StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", \
SubscriptBox[StyleBox[\\\"z\\\", \\\"TI\\\"], StyleBox[\\\"2\\\", \
\\\"TR\\\"]]}], \\\"}\\\"}]}], \\\"}\\\"}], \\\",\\\", StyleBox[\\\"r\\\", \\\
\"TI\\\"]}], \\\"]\\\"}]\) represents a cylinder of radius \
\!\(\*StyleBox[\\\"r\\\", \\\"TI\\\"]\) around the line from \!\(\*RowBox[{\\\
\"(\\\", RowBox[{SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"1\
\\\", \\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"y\\\", \\\"TI\\\"], \
StyleBox[\\\"1\\\", \\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"z\\\", \
\\\"TI\\\"], StyleBox[\\\"1\\\", \\\"TR\\\"]]}], \\\")\\\"}]\) to \
\!\(\*RowBox[{\\\"(\\\", RowBox[{SubscriptBox[StyleBox[\\\"x\\\", \
\\\"TI\\\"], StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", \
SubscriptBox[StyleBox[\\\"y\\\", \\\"TI\\\"], StyleBox[\\\"2\\\", \
\\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"z\\\", \\\"TI\\\"], \
StyleBox[\\\"2\\\", \\\"TR\\\"]]}], \\\")\\\"}]\). \
\\n\!\(\*RowBox[{\\\"Cylinder\\\", \\\"[\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", RowBox[{SubscriptBox[StyleBox[\\\"x\\\", \
\\\"TI\\\"], StyleBox[\\\"1\\\", \\\"TR\\\"]], \\\",\\\", \
SubscriptBox[StyleBox[\\\"y\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"z\\\", \\\"TI\\\"], \
StyleBox[\\\"1\\\", \\\"TR\\\"]]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \
StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"y\\\", \
\\\"TI\\\"], StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", \
SubscriptBox[StyleBox[\\\"z\\\", \\\"TI\\\"], StyleBox[\\\"2\\\", \
\\\"TR\\\"]]}], \\\"}\\\"}]}], \\\"}\\\"}], \\\"]\\\"}]\) represents a \
cylinder of radius 1. \"\>", "MSG"], "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Cylinder"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.6151858953991556`*^9},
 CellTags->"Info3615193095-5730655"]
}, Closed]],

Cell[BoxData[
 RowBox[{"cy2", " ", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"Cylinder", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{"-", "1.3"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "2"}], "}"}]}], "}"}], ",", ".5"}], 
     "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.587559923827962*^9, 3.587560042114728*^9}, {
  3.58756010946058*^9, 3.5875601130607853`*^9}, {3.5875601522060246`*^9, 
  3.58756016296564*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"cy1", ",", "cy2"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.587560120740225*^9, 3.587560134066987*^9}, {
  3.587560249348581*^9, 3.587560256972017*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "3", "]"}], "[", 
     RowBox[{"cylinder", "[", "a", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"(", 
    RowBox[{"a", ">", "0"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5875610023946524`*^9, 3.58756104606015*^9}, {
   3.58756133208951*^9, 3.587561367965562*^9}, {3.5875614118850737`*^9, 
   3.5875614266689196`*^9}, {3.5875615312299004`*^9, 
   3.5875615491479254`*^9}, {3.60974449055751*^9, 3.6097444971398864`*^9}, 
   3.6148618520311265`*^9, 3.614917784089348*^9, 3.615181284609433*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"Cos", "[", "v", "]"}]}], ",", 
   RowBox[{"-", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.6097444989939923`*^9, 3.6151859191925163`*^9, 
  3.617945287964657*^9}]
}, Closed]],

Cell["\<\
The normal vector doesn\[CloseCurlyQuote]t depend on u, the cylinder is \
developable. The spherical image is the unit circle.  For a cylindrical \
surface the spherical image is a part of the equator:\
\>", "Text",
 CellChangeTimes->{{3.5875615964976335`*^9, 3.5875616142576494`*^9}, {
   3.5875617607620287`*^9, 3.5875618261617694`*^9}, 3.5876201866455812`*^9, {
   3.6097446080412292`*^9, 3.60974465385685*^9}, 3.6152641126426015`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "3", "]"}], "[", 
    RowBox[{"cylindersf", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.587561671403918*^9, 3.5875617060689*^9}, 
   3.614861852046726*^9, 3.6149177841049476`*^9, 3.615181286408536*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["y", "\[Prime]",
       MultilineFunction->None], "[", "v", "]"}], 
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["x", "\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "2"]}]]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "\[Prime]",
      MultilineFunction->None], "[", "v", "]"}], 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "2"]}]]], ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.609744532531911*^9, 3.6151859320342507`*^9, 
  3.617945348289963*^9}]
}, Closed]],

Cell["\<\
These surfaces are developable too. The first fundamental form is\
\>", "Text",
 CellChangeTimes->{{3.587620372457508*^9, 3.5876203935175447`*^9}, {
  3.609744685168641*^9, 3.609744702696644*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      FormBox["fund1",
       TraditionalForm], "[", 
      RowBox[{"cylindersf", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", "v", 
       "]"}], "^", "2"}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "v", 
       "]"}], "^", "2"}]}], "\[Equal]", "1"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.588145723022436*^9, 3.588145758972492*^9}, 
   3.5881457897422523`*^9, 3.5904957105778093`*^9, {3.6148618520623264`*^9, 
   3.6148618520779266`*^9}, {3.6149177841205473`*^9, 3.6149177841205473`*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["s1", "2"], "+", 
  SuperscriptBox["s2", "2"]}]], "Output",
 CellChangeTimes->{3.589623248972225*^9, 3.6097445672888985`*^9, 
  3.6151859549825635`*^9, 3.6179453634999895`*^9}]
}, Closed]],

Cell["\<\
Obviously, this metric equals the metric of the Euclidean plane in \
orthonormal Cartesian coordinates. Thus the surface is locally isometric to \
the Euclidean plane, the isometry is defined by equal  parameters.\
\>", "Text",
 CellChangeTimes->{{3.588145812464552*^9, 3.5881458169518085`*^9}, {
   3.588160786594664*^9, 3.588160926090643*^9}, 3.589623261935848*^9, {
   3.5896233630623236`*^9, 3.589623446423092*^9}, {3.609744915512816*^9, 
   3.6097449577452316`*^9}, 3.615185967266266*^9, 3.6152641629144773`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1.6. Tangent Surfaces", "Subsubsection",
 CellChangeTimes->{{3.587201518412738*^9, 3.587201527076234*^9}, {
   3.587272835342759*^9, 3.58727283885396*^9}, {3.587272981302108*^9, 
   3.5872730078536263`*^9}, 3.5872731046621633`*^9, 3.587278763622837*^9, {
   3.5875395682098494`*^9, 3.58753958547908*^9}, {3.5875506376928062`*^9, 
   3.58755065084363*^9}, {3.5875621007464747`*^9, 3.5875621112900777`*^9}, 
   3.609745012249349*^9, 3.6098188216334867`*^9, 3.6179455096254463`*^9, 
   3.617947264841502*^9}],

Cell[TextData[{
 StyleBox["Example 3. ",
  FontColor->RGBColor[0, 0, 1]],
 "Tangent surfaces\nLet x{v] be an arbitrary smooth regular curve in the \
space. Then its ",
 StyleBox["tangent surface",
  FontColor->RGBColor[0, 0, 1]],
 " (also named ",
 StyleBox["tangent developable",
  FontColor->RGBColor[0, 0, 1]],
 ") is defined by"
}], "Text",
 CellChangeTimes->{{3.587620429179208*^9, 3.587620528239382*^9}, {
  3.58762060146591*^9, 3.5876206099835253`*^9}, {3.5882547189130597`*^9, 
  3.5882547566322174`*^9}, {3.6179455507315183`*^9, 3.6179456100116224`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tangsf", "[", "x_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"x", "[", "v", "]"}], " ", "+", " ", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"x", "[", "v", "]"}], ",", "v"}], "]"}], "*", 
    "u"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5876205386446*^9, 3.587620546663014*^9}, {
   3.587620618813141*^9, 3.587620638874776*^9}, {3.587620784657032*^9, 
   3.5876208247491026`*^9}, 3.587731804014976*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tangsf", "::", " ", "usage"}], " ", "=", " ", 
   "\"\<tangsf[x][u,v] is a parameter representation of the developable \
surface formed by the tangents of the space curve x[v].\>\""}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6151860940185156`*^9, 3.61518611857092*^9}, {
   3.615187275916306*^9, 3.6151873529487123`*^9}, {3.615187448988205*^9, 
   3.615187498012009*^9}, 3.6151875548302593`*^9}],

Cell["\<\
The curve itself lies on its tangent surface: set u=0. A general space curve \
is \
\>", "Text",
 CellChangeTimes->{{3.587621303264343*^9, 3.587621319441571*^9}, {
  3.587621391529298*^9, 3.5876214238837547`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"curve", "[", "v_", "]"}], ":=", 
  RowBox[{"vec", "[", 
   RowBox[{"x", "[", "v", "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5876209324048915`*^9, 3.5876209401893053`*^9}, {
   3.587620972294162*^9, 3.587620981076977*^9}, 3.6148618520779266`*^9, 
   3.6149177841361475`*^9}],

Cell[TextData[{
 StyleBox["All points of the space curve are singularities of its tangent \
surface",
  FontColor->RGBColor[0, 0, 1]],
 ":"
}], "Text",
 CellChangeTimes->{{3.587621445770593*^9, 3.5876214903866715`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Cross", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "1", "]"}], "[", 
      RowBox[{"tangsf", "[", "curve", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "2", "]"}], "[", 
      RowBox[{"tangsf", "[", "curve", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.587620867742778*^9, 3.587620899972434*^9}, {
   3.587620992870598*^9, 3.5876210110446296`*^9}, {3.5876210566279097`*^9, 
   3.5876210894971676`*^9}, 3.6176000248214893`*^9, 3.617600085801996*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"u", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
     ")"}]}], ",", 
   RowBox[{"u", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], "-", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
     ")"}]}], ",", 
   RowBox[{"u", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}]}], 
     ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.609814994364579*^9, 3.615188270589198*^9, 
  3.6179459937722964`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"u", "\[Rule]", " ", "0"}]}]], "Input",
 CellChangeTimes->{{3.5876211520064774`*^9, 3.587621171943312*^9}, {
  3.5876212035333676`*^9, 3.5876212069809732`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.6098150048401785`*^9, 3.615188276009508*^9, 
  3.6179460035691137`*^9}]
}, Closed]],

Cell["We shall assume that v is the arc length of the space curve:", "Text",
 CellChangeTimes->{{3.5876215279827375`*^9, 3.587621564190401*^9}, 
   3.6152641666586914`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"arcl", " ", "=", 
  RowBox[{"Evaluate", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"curve", "[", "v", "]"}], ",", "v"}], "]"}], ".", " ", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"curve", "[", "v", "]"}], ",", "v"}], "]"}]}], "==", "1"}], 
     ",", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"curve", "[", "v", "]"}], ",", "v"}], "]"}], ".", " ", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"curve", "[", "v", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"v", ",", "2"}], "}"}]}], "]"}]}], "==", " ", "0"}]}], 
    "}"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.58762160342447*^9, 3.58762167150299*^9}, {
  3.5876218099844327`*^9, 3.5876218138688393`*^9}, {3.587621898998189*^9, 
  3.587621913833815*^9}, {3.5876219516638813`*^9, 3.5876219707739153`*^9}, {
  3.587622105526952*^9, 3.587622222090357*^9}, {3.587732305290656*^9, 
  3.5877323565367465`*^9}, {3.5877346417807617`*^9, 3.5877346617487965`*^9}, {
  3.5877347212941017`*^9, 3.5877347303421173`*^9}, {3.588162712104797*^9, 
  3.5881627655508537`*^9}, {3.588162871047888*^9, 3.588162886310761*^9}, {
  3.614861852109126*^9, 3.6148618521247263`*^9}, {3.6149177841361475`*^9, 
  3.614917784167348*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"], 
     "+", 
     SuperscriptBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"], 
     "+", 
     SuperscriptBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "2"]}], 
    "\[Equal]", "1"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
    "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0H0s1AEAxnHkdZJ1W5jpclqm2B1O1LKu38UxFWF0zPu5ojPXTEzpWF6W
K02lvOumazuFWIbjxEzK2mjexnVeJl3rJ+ctF1rq+f3x7PPH89+XkSQOExoa
GBgkYsUF3a/0OpJQjPH59qskoQyfyj4HmcoLFSlwkHst4Cbkl+cVlsET+8af
q+Be5uUvS1B+ykJKWyMJb5uF82fg+NjC4SBIl3tI3kP3AWv6Ilz1YDUtQU31
cJb1OkkwSkPq7OC9+L9cNqR7Dm/4Q4PHzWUCOBL5VCyFXF50TjusdpjnK6Fd
b37IEHTiXd2eg886Qqe0UJ4oLCfh/jzFIR2UeMc4m26QRH3u924vaBNsX8KB
gdxAv1jI0XS2FUPa6OzpVhjX9zVWAyujKl7MQmeN44rJJkkYVY7msKGLaQft
JJROixy50Ex+9ooI7maOzBTBztzWiDbYoGnXvoMLfq7rapj2jdG/CIVhxsuU
PKKXuQz3gmXbJr9IwjGWOWYFWW/TA2hQ9ClDxYS5u6xHbEio0177wPIfJdZR
cJYmDomhfl5PXSrU1RPm1+GlgaqdQqh4kB/zBArVI/FN0Dj1oacKpiz3JfTC
os9d+ZOw42hj+AysF/jcMdxCb/ceqSXMMCudpDyWkbxoBem6mdss6DXpn82G
yWWKGl/4UjVhEQW3suIG86BeZmncDEcL/DktMDoofY6Sw1nTU7q9EQiUMGvz
N2sCNl5MI5cgr+qD1T9obhLpSzlh5HTDSE8Skzmy+y7QV+fQFQp/1h68lQDd
Im0lxZA5XVtM+fFAhFIB784e32qB9pXrWv02SfTNh/bvwIka2yHKhoEjrn9g
v1jrTilZESVRqrvmGbIdkvgPQo/D4A==
  "]]
}, Open  ]],

Cell["\<\
Now we calculate the spherical image of the regular part of the tangent \
surface:\
\>", "Text",
 CellChangeTimes->{{3.5876231220247374`*^9, 3.5876231738636284`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "3", "]"}], "[", 
     RowBox[{"tangsf", "[", "curve", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", "arcl"}], "]"}]], "Input",
 CellChangeTimes->{{3.5881630905624437`*^9, 3.5881631391492224`*^9}, 
   3.6148618521403265`*^9, 3.6149177841829476`*^9, 3.6151813113289614`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"u", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
      ")"}]}], 
    SqrtBox[
     RowBox[{
      SuperscriptBox["u", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
         "2"]}], ")"}]}]]], ",", 
   FractionBox[
    RowBox[{"u", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], "-", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
      ")"}]}], 
    SqrtBox[
     RowBox[{
      SuperscriptBox["u", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
         "2"]}], ")"}]}]]], ",", 
   FractionBox[
    RowBox[{"u", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}]}], 
      ")"}]}], 
    SqrtBox[
     RowBox[{
      SuperscriptBox["u", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
         "2"]}], ")"}]}]]]}], "}"}]], "Output",
 CellChangeTimes->{3.6098150791874304`*^9, 3.61518833146268*^9, 
  3.6179460613828154`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", 
       RowBox[{"tangsf", "[", "curve", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", ">", "0"}], ",", "arcl"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.587621684622613*^9, 3.587621793027203*^9}, 
   3.5876222348823795`*^9, {3.5876223777942305`*^9, 3.5876223968730636`*^9}, {
   3.5881629216867847`*^9, 3.5881629433340225`*^9}, {3.5881630472379656`*^9, 
   3.5881630616367893`*^9}, 3.6148618521559267`*^9, 3.6149177841985474`*^9, 
   3.615181313257072*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.6098151229639344`*^9, 3.6151883423463025`*^9, 
  3.617946092255269*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", 
       RowBox[{"tangsf", "[", "curve", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "<", "0"}], ",", "arcl"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.587621684622613*^9, 3.587621793027203*^9}, 
   3.5876222348823795`*^9, {3.5876223777942305`*^9, 3.5876223968730636`*^9}, {
   3.5881629216867847`*^9, 3.5881629433340225`*^9}, {3.588162991834797*^9, 
   3.5881630291659317`*^9}, 3.609815167604488*^9, 3.614861852171527*^9, 
   3.6149177841985474`*^9, 3.61518131444914*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.6098151717147226`*^9, 3.615188345588488*^9, 
  3.6179461220201216`*^9}]
}, Closed]],

Cell["\<\
Obviously, this vector does not depend on u. It is proportional to the \
binormal vector of the curve. Indeed, denote  the orthonormal Frenet frame of \
the curve by fr[i][v]\
\>", "Text",
 CellChangeTimes->{{3.587732407077636*^9, 3.587732462603733*^9}, {
   3.5881617314507065`*^9, 3.588161813658409*^9}, {3.5881619205945253`*^9, 
   3.5881620015621567`*^9}, 3.588162068818003*^9, 3.5881621797223463`*^9, {
   3.5881632090832224`*^9, 3.5881632112343454`*^9}, {3.6098152094808826`*^9, 
   3.609815219712468*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "frenet"}]], "Input",
 CellChangeTimes->{{3.5881621858806987`*^9, 3.5881621891138835`*^9}}],

Cell[BoxData[
 StyleBox["\<\"frenet[curve][t] yields the Frenet frame for a generally \
curved \\ncurve[t] in the n-dimensional Euclidean space. Generally curved \
means that the \\nrank of the first n-1 derivatives of curve[t] must be n-1 \
at each point t.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6179461491953692`*^9},
 CellTags->"Info3617953349-6268934"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fr", "[", "i_", "]"}], "[", "v_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"frenet", "[", "curve", "]"}], "[", "v", "]"}], "[", 
   RowBox[{"[", "i", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5881620864630127`*^9, 3.5881621696497707`*^9}, {
  3.588162213157259*^9, 3.5881622519004745`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fr", "[", "1", "]"}], "[", "v", "]"}], ",", "arcl"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.588162260438963*^9, 3.588162294247897*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "\[Prime]",
      MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "\[Prime]",
      MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "\[Prime]",
      MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6098152819570284`*^9, 3.61518837290005*^9, 
  3.6179461656845984`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fr", "[", "2", "]"}], "[", "v", "]"}], ",", "arcl"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.588162260438963*^9, 3.58816232507666*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"], 
      "+", 
      SuperscriptBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"], 
      "+", 
      SuperscriptBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
       "2"]}]]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"], 
      "+", 
      SuperscriptBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"], 
      "+", 
      SuperscriptBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
       "2"]}]]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"], 
      "+", 
      SuperscriptBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"], 
      "+", 
      SuperscriptBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
       "2"]}]]]}], "}"}]], "Output",
 CellChangeTimes->{3.609815286512289*^9, 3.615188377636321*^9, 
  3.617946170052606*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"fr", "[", "3", "]"}], "[", "v", "]"}], "-", 
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", 
       RowBox[{"tangsf", "[", "curve", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "/.", 
    RowBox[{"u", "\[Rule]", "1"}]}], ",", "arcl"}], "]"}]], "Input",
 CellChangeTimes->{{3.5881624193480525`*^9, 3.5881624769663477`*^9}, 
   3.588162509207192*^9, 3.588163534773851*^9, {3.588163584366688*^9, 
   3.5881636160775013`*^9}, {3.6098154243721743`*^9, 3.609815444524327*^9}, 
   3.6148618522027264`*^9, 3.6149177841985474`*^9, 3.6151813235776625`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.6098153224873466`*^9, {3.60981543216962*^9, 3.609815446406434*^9}, 
   3.61518839091308*^9, 3.6179461960734515`*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Lemma",
  FontColor->RGBColor[0, 0, 1]],
 ". The tangent  planes of the tangent surface of a regular generally curved  \
curve form a 1-parametric family of planes, namely the osculating planes of \
the curve.",
 "\[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.588163746058936*^9, 3.588163855090172*^9}, {
   3.588163888538085*^9, 3.588163931786559*^9}, 3.609815337807223*^9, 
   3.6098153803756576`*^9, {3.6098158536767287`*^9, 3.6098158536827292`*^9}}],

Cell["\<\
Again the spherical image  is a curve on the unit sphere only.  The first \
fundamental form of the tangent surface is\
\>", "Text",
 CellChangeTimes->{{3.5876231834576454`*^9, 3.5876232754354067`*^9}, {
  3.587732519481433*^9, 3.5877325282954483`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"u", ">", "0"}], ",", " ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        FormBox["fund1",
         TraditionalForm], "[", 
        RowBox[{"tangsf", "[", "curve", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"s1", ",", "s2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], ",", "arcl"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5876233192090836`*^9, 3.5876233215178876`*^9}, {
   3.58762344825251*^9, 3.5876235183590336`*^9}, 3.5904957105934095`*^9, {
   3.609815592204774*^9, 3.6098156350922265`*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["s1", "2"], "+", 
  RowBox[{"2", " ", "s1", " ", "s2"}], "+", 
  RowBox[{
   SuperscriptBox["s2", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{
      SuperscriptBox["u", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], 
         "2"]}], ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.6098155111541376`*^9, 3.609815637414359*^9, 
  3.6151884511455255`*^9, 3.6179462619991674`*^9}]
}, Closed]],

Cell[TextData[{
 "The coefficient of ",
 Cell[BoxData[
  SuperscriptBox["s2", "2"]],
  CellChangeTimes->{3.587623484054573*^9, 3.587623520870638*^9, 
   3.587731983789692*^9, 3.5877325449718776`*^9, 3.588143353745921*^9, 
   3.5881434770949764`*^9}],
 " depends on the curvature of the curve:"
}], "Text",
 CellChangeTimes->{{3.5881611650823126`*^9, 3.5881612328341875`*^9}, 
   3.5881615556586523`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"1", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"u", "*", 
        RowBox[{
         RowBox[{"curvature", "[", "curve", "]"}], "[", "v", "]"}]}], ")"}], 
      "^", "2"}]}], "\[Equal]", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"rgT", "[", 
       RowBox[{"2", ",", "2"}], "]"}], "[", 
      RowBox[{"tangsf", "[", "curve", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], ",", "arcl"}], "]"}]], "Input",
 CellChangeTimes->{{3.587732635249236*^9, 3.587732665138889*^9}, {
   3.587734459322841*^9, 3.5877344750476685`*^9}, {3.587734557213013*^9, 
   3.587734573624242*^9}, {3.588143552923313*^9, 3.588143610522608*^9}, {
   3.588143658443349*^9, 3.588143660107444*^9}, {3.5881437021078463`*^9, 
   3.5881437113943777`*^9}, 3.6098156989718804`*^9, 3.6148618522183266`*^9, 
   3.6148631365061827`*^9, {3.61518849458801*^9, 3.6151885227476206`*^9}, {
   3.617946380169375*^9, 3.6179464749551415`*^9}, {3.6179465495700727`*^9, 
   3.617946552346877*^9}, {3.617946583468932*^9, 3.617946594357751*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.6098157016870356`*^9, 3.615188470859653*^9, 
  3.6151885256957893`*^9, 3.6179462864444103`*^9, 3.6179464787927485`*^9, 
  3.6179465570268855`*^9, 3.6179465973685565`*^9}]
}, Closed]],

Cell["\<\
Denote the curvature of the generating curve by k[v]. Then the first \
fundamental form is in traditional notation\
\>", "Text",
 CellChangeTimes->{{3.58816433061037*^9, 3.588164431618148*^9}, {
  3.588166702827053*^9, 3.5881667068342824`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["ds", "2"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox["du", "2"], "+", 
    RowBox[{"2", " ", "du", " ", "dv"}], "+", 
    RowBox[{
     SuperscriptBox["dv", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        SuperscriptBox["u", "2"]}], "+", "1"}], ")"}]}]}]}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.5881644831580954`*^9, 3.5881645610145483`*^9}, {
   3.588164594589469*^9, 3.5881646515087247`*^9}, 3.588164796428014*^9, {
   3.588166618812248*^9, 3.5881666271647253`*^9}, {3.588166660402627*^9, 
   3.588166674374426*^9}}],

Cell[TextData[{
 StyleBox["Lemma",
  FontColor->RGBColor[0, 0, 1]],
 ". A tangent surface of a generally curved curve is locally isometric to the \
Euclidean plane."
}], "Text",
 CellChangeTimes->{{3.5881661309633446`*^9, 3.5881661511865015`*^9}, {
   3.5881661837943664`*^9, 3.588166194841998*^9}, {3.5881662727544546`*^9, 
   3.5881663097305694`*^9}, {3.5881663506989126`*^9, 
   3.5881664278183236`*^9}, {3.588166502170576*^9, 3.5881666479229126`*^9}, 
   3.588166770114902*^9}],

Cell[TextData[{
 StyleBox["Proof",
  FontColor->RGBColor[0, 0, 1]],
 ". Let k[v] be the curvature of the curve as a function of the arc length.  \
We consider a plane curve with the same curvature.Then the tangent surface of \
this curve is a part of the plane and this part with the coordinates u,v of \
the tangent surface has the same first fundamental form as ",
 Cell[BoxData[
  StyleBox[
   SuperscriptBox["ds", "2"],
   FontWeight->"Bold"]],
  CellChangeTimes->{{3.5881644831580954`*^9, 3.5881645610145483`*^9}, {
    3.588164594589469*^9, 3.5881646515087247`*^9}, 3.588164796428014*^9, {
    3.588166618812248*^9, 3.5881666271647253`*^9}}],
 " above; the map defined by equal parameters  is an isometry.\[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.5881661309633446`*^9, 3.5881661511865015`*^9}, {
   3.5881661837943664`*^9, 3.588166194841998*^9}, {3.5881662727544546`*^9, 
   3.5881663097305694`*^9}, {3.5881663506989126`*^9, 
   3.5881664278183236`*^9}, {3.588166502170576*^9, 3.5881666479229126`*^9}, {
   3.588166770114902*^9, 3.588166781762568*^9}, {3.589623715895505*^9, 
   3.589623784606435*^9}, {3.609815789441055*^9, 3.6098157902561016`*^9}, {
   3.6098158333205643`*^9, 3.609815833331565*^9}, 3.615264176211238*^9, {
   3.6179466864915133`*^9, 3.617946694260327*^9}, 3.6179473026156626`*^9}],

Cell[TextData[{
 StyleBox["Example.",
  FontColor->RGBColor[0, 0, 1]],
 " To plot an image of a tangent surface it isn\[CloseCurlyQuote]t necessary \
to assume v to be the arc length of the curve. If not yet done, first load ",
 ButtonBox["CURVES`",
  BaseStyle->"Hyperlink",
  ButtonData->"curves"],
 " Take a space curve of A. Gray\[CloseCurlyQuote]s list, e. g."
}], "Text",
 CellChangeTimes->{{3.6098159294240613`*^9, 3.6098160902722616`*^9}, {
   3.6098165374328375`*^9, 3.60981659482412*^9}, {3.6098166414167852`*^9, 
   3.6098166414217854`*^9}, 3.6152641791634064`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "twistedn"}]], "Input",
 CellChangeTimes->{{3.6151885869542933`*^9, 3.61518858813136*^9}}],

Cell[BoxData[
 StyleBox["\<\"t->twistedn[n,a][t] is the curve t->a*{t,t^2,...,t^n}.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.617946732246393*^9},
 CellTags->"Info3617953932-5478789"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"twistedn", "[", 
   RowBox[{"3", ",", "1"}], "]"}], "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.6098163918435106`*^9, 3.6098164178099957`*^9}, 
   3.6098166758507547`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"t", ",", 
   SuperscriptBox["t", "2"], ",", 
   SuperscriptBox["t", "3"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.609816323593607*^9, {3.609816400191988*^9, 3.609816419447089*^9}, 
   3.6098166890555096`*^9, 3.6151886160059547`*^9, 3.6179467504360256`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"twistedn", "[", 
      RowBox[{"3", ",", "1"}], "]"}], "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
    RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", " ", "Red"}], "}"}]}]}], "]"}], "\n"}]], "Input",
 CellChangeTimes->{{3.6098167011682024`*^9, 3.6098167997948437`*^9}, {
   3.6098172238280973`*^9, 3.609817253964821*^9}, 3.6098184802129583`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"cubic", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6098172685086527`*^9, 3.6098172828574734`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tangsf", "[", 
   RowBox[{"twistedn", "[", 
    RowBox[{"3", ",", "1"}], "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{3.609817055443466*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"u", "+", "v"}], ",", 
   RowBox[{
    RowBox[{"2", " ", "u", " ", "v"}], "+", 
    SuperscriptBox["v", "2"]}], ",", 
   RowBox[{
    RowBox[{"3", " ", "u", " ", 
     SuperscriptBox["v", "2"]}], "+", 
    SuperscriptBox["v", "3"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6098170564845257`*^9, 3.6151886361241055`*^9, 
  3.617946776519271*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"tangsf", "[", 
       RowBox[{"twistedn", "[", 
        RowBox[{"3", ",", "1"}], "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", 
      RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], "\n"}]], "Input",
 CellChangeTimes->{{3.6098167011682024`*^9, 3.6098167997948437`*^9}, {
   3.609816865372595*^9, 3.6098169849714355`*^9}, {3.609817087804317*^9, 
   3.6098171001240215`*^9}, {3.609817172053136*^9, 3.609817178644513*^9}, {
   3.6098175673657465`*^9, 3.6098175700919023`*^9}, 3.6148618522183266`*^9, 
   3.6149177842141476`*^9, {3.61794697485802*^9, 3.617946978024825*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"cubic", ",", "%"}], "}"}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6098174162581034`*^9, 3.6098174565804095`*^9}}],

Cell[TextData[{
 "As  shown at the beginning of this subsection, the curve itself consists of \
singularities of the surface; in German such a singular curve is named the ",
 StyleBox["R\[UDoubleDot]ckkehrkante",
  FontColor->RGBColor[0, 0, 1]],
 " of the tangent surface"
}], "Text",
 CellChangeTimes->{{3.609818220856124*^9, 3.6098183795682015`*^9}, 
   3.615264200418622*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1.7. Developable Surfaces 1", "Subsubsection",
 CellChangeTimes->{{3.587201518412738*^9, 3.587201527076234*^9}, {
   3.587272835342759*^9, 3.58727283885396*^9}, {3.587272981302108*^9, 
   3.5872730078536263`*^9}, 3.5872731046621633`*^9, 3.587278763622837*^9, {
   3.5875395682098494`*^9, 3.58753958547908*^9}, {3.5875506376928062`*^9, 
   3.58755065084363*^9}, {3.5875621007464747`*^9, 3.5875621112900777`*^9}, {
   3.5881675117713223`*^9, 3.5881675315864553`*^9}, {3.590039110793*^9, 
   3.590039112899004*^9}, 3.609818829057911*^9, 3.6098201375367517`*^9, 
   3.617947335801561*^9, 3.6179498973303094`*^9}],

Cell[TextData[{
 "The surfaces considered in subsections 2.1.3 - 6 have the following common \
properties:\n1. Locally, in a neighborhood of its regular points, they are \
isometric to open sets in the Euclidean plane. \n2. They are ruled surfaces \
whose tangent planes are constant along the rulings; the tangent planes form \
a 1-parameter family, and the surface is the ",
 StyleBox["envelope",
  FontColor->RGBColor[0, 0, 1]],
 " of this family. Such surfaces are named ",
 StyleBox["developable",
  FontColor->RGBColor[0, 0, 1]],
 " ",
 StyleBox["surfaces",
  FontColor->RGBColor[0, 0, 1]],
 " (also ",
 StyleBox["torses",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[").",
  FontColor->GrayLevel[0]]
}], "Text",
 CellChangeTimes->{{3.588167702162212*^9, 3.588167785762994*^9}, {
  3.5881678992664857`*^9, 3.5881680912674675`*^9}, {3.588168243835194*^9, 
  3.5881683815790725`*^9}, {3.5881684601945686`*^9, 3.5881684888672085`*^9}, {
  3.5881685413312097`*^9, 3.5881685562750645`*^9}, {3.5881687263187904`*^9, 
  3.5881687325821486`*^9}, {3.588313711952491*^9, 3.5883137251212435`*^9}, {
  3.617947741961583*^9, 3.617947772433326*^9}, {3.6179478375380497`*^9, 
  3.617947840217203*^9}}],

Cell[TextData[{
 StyleBox["Remark",
  FontColor->RGBColor[0, 0, 1]],
 ". Sometimes the surfaces having the property 1 are called developable. We \
shall see that both properties are equivalent."
}], "Text",
 CellChangeTimes->{{3.588168501626939*^9, 3.5881685296505413`*^9}, {
   3.588168564514536*^9, 3.588168628546198*^9}, 3.588168834290966*^9, 
   3.588168905955065*^9}],

Cell["\<\
We shall specify the concept of the envelope of a 1-parametric family of \
planes. Consider this family as defined by the Hesse normal form of the plane \
equation\
\>", "Text",
 CellChangeTimes->{{3.5881689795302734`*^9, 3.58816911077878*^9}, 
   3.588223189320817*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", "1", ")"}], "         ", 
    RowBox[{"H", "[", "v", "]"}]}], ":", "   ", 
   RowBox[{
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{"n", "[", "v", "]"}], "]"}], ".", 
     RowBox[{"vec", "[", "x", "]"}]}], " ", "\[Equal]", " ", 
    RowBox[{"p", "[", "v", "]"}]}]}], ";"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.58816914451871*^9, 3.588169184516998*^9}, {
  3.588169223453225*^9, 3.5881692616134076`*^9}, {3.588169784484314*^9, 
  3.588169790045632*^9}, {3.588170630071679*^9, 3.588170636168028*^9}, {
  3.5882232147176614`*^9, 3.5882232961654043`*^9}}],

Cell[BoxData[
 RowBox[{"         ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{"n", "[", "v", "]"}], "]"}], ".", 
     RowBox[{"vec", "[", 
      RowBox[{"n", "[", "v", "]"}], "]"}]}], "\[Equal]", " ", "1"}], ";"}], 
  "                              "}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.58816914451871*^9, 3.588169184516998*^9}, {
  3.588169223453225*^9, 3.5881692616134076`*^9}, {3.588169784484314*^9, 
  3.588169790045632*^9}, {3.588170630071679*^9, 3.588170636168028*^9}, {
  3.5882232147176614`*^9, 3.5882232961654043`*^9}}],

Cell["\<\
vec[n[v]] is the unit normal vector of the plane, and p[v] is its oriented \
distance to the origin. We assume that in general two neighbored planes of \
the family are not parallel. Then the neighbored plane\
\>", "Text",
 CellChangeTimes->{{3.5881692817635603`*^9, 3.588169296634411*^9}, {
   3.5881693277151885`*^9, 3.5881693600910397`*^9}, {3.5881694707303686`*^9, 
   3.5881694890984187`*^9}, {3.588169563994703*^9, 3.5881696304745054`*^9}, 
   3.5882233336678705`*^9, 3.6151891048899174`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"H", "[", 
   RowBox[{"v", "+", "\[CapitalDelta]v"}], "]"}], ":", "   ", 
  RowBox[{
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"n", "[", 
      RowBox[{"v", "+", "\[CapitalDelta]v"}], "]"}], "]"}], ".", 
    RowBox[{"vec", "[", "x", "]"}]}], " ", "\[Equal]", " ", 
   RowBox[{"p", "[", 
    RowBox[{"v", "+", "\[CapitalDelta]v"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5881696746290307`*^9, 3.5881697198396163`*^9}, {
  3.5881706549351006`*^9, 3.5881706928302684`*^9}}],

Cell["\<\
and the plane (1) intersect in a line. Subtracting (1) from the last equation \
we get the equivalent system with (1) and\
\>", "Text",
 CellChangeTimes->{{3.588169817044176*^9, 3.5881699449544926`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{"n", "[", 
       RowBox[{"v", "+", "\[CapitalDelta]v"}], "]"}], "]"}], "-", 
     RowBox[{"vec", "[", 
      RowBox[{"n", "[", "v", "]"}], "]"}]}], ")"}], ".", 
   RowBox[{"vec", "[", "x", "]"}]}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"p", "[", 
    RowBox[{"v", "+", "\[CapitalDelta]v"}], "]"}], " ", "-", 
   RowBox[{"p", "[", "v", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5881696746290307`*^9, 3.5881697198396163`*^9}, {
   3.5881699584912663`*^9, 3.5881700206618223`*^9}, 3.5881709190392065`*^9}],

Cell["\<\
Dividing by \[CapitalDelta]v and considering the limit for \[CapitalDelta]v \
-> 0 we obtain\
\>", "Text",
 CellChangeTimes->{{3.5881701424827905`*^9, 3.5881702165230255`*^9}, {
  3.5882235164354544`*^9, 3.588223517291504*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", "2", ")"}], "                 ", 
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{
       RowBox[{"n", "'"}], "[", "v", "]"}], "]"}], ".", 
     RowBox[{"vec", "[", "x", "]"}]}]}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{"p", "'"}], "[", "v", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5881703486705837`*^9, 3.5881704729966946`*^9}, {
  3.5882233724339385`*^9, 3.5882233992659855`*^9}, {3.588249351418147*^9, 
  3.588249351418147*^9}}],

Cell[TextData[{
 "The linear system (1), (2) defines the limit of the intersection line of \
two neighbored planes; it is a line L[v] \[Subset] H[v].  The family of these \
lines  describes a surface, called the ",
 StyleBox["envelope",
  FontColor->RGBColor[0, 0, 1]],
 " of the plane family.We will find a parameter representation of this \
surface. \n First we exclude the trivial case: vec[n[v]] = constant  Then by \
(2)  there exists a solution only iff also p[v)== constant, and the solution \
is the whole plane given by (1).  Now we assume"
}], "Text",
 CellChangeTimes->{{3.588170493386861*^9, 3.588170564282916*^9}, 
   3.5881706131627116`*^9, {3.5881707202988396`*^9, 3.5881708395146585`*^9}, 
   3.588223422057626*^9, {3.588223503955741*^9, 3.588223504307761*^9}, 
   3.5882235387797327`*^9, 3.588223578346996*^9, {3.588223678451721*^9, 
   3.588223703267141*^9}, {3.5882237384271517`*^9, 3.5882239335233107`*^9}, {
   3.588223980171979*^9, 3.588224014403937*^9}, {3.588224092035377*^9, 
   3.5882240997228165`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"vec", "[", 
   RowBox[{
    RowBox[{"n", "'"}], "[", "v", "]"}], "]"}], "\[NotEqual]", " ", 
  RowBox[{"null", "[", "]"}]}]], "Input",
 CellChangeTimes->{{3.588224154310939*^9, 3.5882241641175003`*^9}, 
   3.588249351418147*^9}],

Cell[TextData[{
 "for all values of v; that means we exclude the",
 StyleBox[" singular planes",
  FontColor->RGBColor[0, 0, 1]],
 " of the family not satisfying this assumption. Further we assume that v is \
the arc length of the curve vec[n[v]] on the unit sphere. It follows"
}], "Text",
 CellChangeTimes->{{3.588224215228423*^9, 3.5882242746508217`*^9}, {
  3.5882243074997005`*^9, 3.588224418731063*^9}, {3.6152642253870506`*^9, 
  3.6152642280992055`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{
     RowBox[{"n", "'"}], "[", "v", "]"}], "]"}], ".", 
   RowBox[{"vec", "[", 
    RowBox[{
     RowBox[{"n", "'"}], "[", "v", "]"}], "]"}]}], "\[Equal]", "1"}]], "Input",
 CellChangeTimes->{{3.588224458469336*^9, 3.5882244813016415`*^9}, {
  3.588249351418147*^9, 3.5882493514337473`*^9}}],

Cell["and by derivation", "Text",
 CellChangeTimes->{{3.588224538131892*^9, 3.5882245496755524`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{"n", "[", "v", "]"}], "]"}], ".", 
   RowBox[{"vec", "[", 
    RowBox[{
     RowBox[{"n", "'"}], "[", "v", "]"}], "]"}]}], "\[Equal]", " ", 
  "0"}]], "Input",
 CellChangeTimes->{{3.5882245658614783`*^9, 3.588224670981491*^9}, 
   3.588249351464947*^9}],

Cell[BoxData[
 RowBox[{"  ", 
  RowBox[{
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{
      RowBox[{"n", "'"}], "[", "v", "]"}], "]"}], ".", 
    RowBox[{"vec", "[", 
     RowBox[{
      RowBox[{"n", "''"}], "[", "v", "]"}], "]"}]}], "\[Equal]", " ", 
   "0"}]}]], "Input",
 CellChangeTimes->{{3.5882245658614783`*^9, 3.588224670981491*^9}, {
  3.588249351480547*^9, 3.588249351480547*^9}}],

Cell["\<\
Since vec[n[v]], vec[n'[v]] are orthogonal unit vectors the lines L[v] as \
solutions of the system (1), (2) exist and are uniquely defined. We choose an \
arbitrary smooth curve of solution points vec[x[v]] \[Element] L[v]. Then the \
difference vector with any solution vector\
\>", "Text",
 CellChangeTimes->{{3.588224756027355*^9, 3.588225057963625*^9}, {
   3.5882250974998865`*^9, 3.588225159196415*^9}, 3.5882493515117474`*^9, {
   3.5883143728092895`*^9, 3.5883144417842345`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"vec", "[", "x", "]"}], "-", 
  RowBox[{"vec", "[", 
   RowBox[{"x", "[", "v", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.588225162159585*^9, 3.5882251621605844`*^9}}],

Cell["satisfies", "Text",
 CellChangeTimes->{{3.5882251698270235`*^9, 3.588225182027721*^9}}],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"n", "[", "v", "]"}], "]"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"vec", "[", "x", "]"}], "-", 
      RowBox[{"vec", "[", 
       RowBox[{"x", "[", "v", "]"}], "]"}]}], ")"}]}], "\[Equal]", " ", 
   "0"}]}]], "Input",
 CellChangeTimes->{{3.5882252507816534`*^9, 3.588225301341545*^9}}],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{
      RowBox[{"n", "'"}], "[", "v", "]"}], "]"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"vec", "[", "x", "]"}], "-", 
      RowBox[{"vec", "[", 
       RowBox[{"x", "[", "v", "]"}], "]"}]}], ")"}]}], "\[Equal]", " ", 
   "0"}]}]], "Input",
 CellChangeTimes->{{3.5882252507816534`*^9, 3.588225337870635*^9}, 
   3.5882493515273476`*^9}],

Cell[" and with", "Text",
 CellChangeTimes->{{3.588225361011958*^9, 3.588225364643166*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"m", "[", "v_", "]"}], ":=", " ", 
  RowBox[{"Cross", "[", 
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"n", "[", "v", "]"}], "]"}], ",", 
    RowBox[{"vec", "[", 
     RowBox[{
      RowBox[{"n", "'"}], "[", "v", "]"}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5882253883235207`*^9, 3.588225509749466*^9}, 
   3.5882493515273476`*^9}],

Cell["\<\
we obtain the wanted parameter representation of the envelope as the ruled \
surface\
\>", "Text",
 CellChangeTimes->{{3.5882255299016185`*^9, 3.588225543363388*^9}, {
  3.588225639010859*^9, 3.5882256690675783`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"solsf", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{"x", "[", "v", "]"}], "]"}], " ", "+", " ", 
   RowBox[{"u", "*", 
    RowBox[{"m", "[", "v", "]"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5882255749011917`*^9, 3.588225629869336*^9}, {
  3.588227285079009*^9, 3.5882272865500927`*^9}}],

Cell[BoxData[
 RowBox[{"solsf", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5882256864725733`*^9, 3.5882256943570247`*^9}, {
  3.5882272973097086`*^9, 3.588227298808794*^9}}],

Cell["\<\
Regard that (vec[n[v]] ,vec[n'[v]], m[v]) form a family of positively \
oriented orthonormal frames of the Euclidean vector space.\
\>", "Text",
 CellChangeTimes->{{3.588226562763695*^9, 3.5882266954272823`*^9}, 
   3.5882493515741477`*^9, {3.5883145374247046`*^9, 3.5883145665123687`*^9}, 
   3.615264263011202*^9}],

Cell["\<\
We will specify the choice of the up to now arbitrary line vec[x[v]] \
\[Element] L[v]. The lines L(v) \[Subset] solsf form a 1-parameter family of \
lines on solsf and this family may have an envelope being a curve in solsf. \
Considering the intersection point of two neighbored lines and forming the \
limit as before for the planes we obtain the new equation\
\>", "Text",
 CellChangeTimes->{{3.5882270884837637`*^9, 3.588227163644063*^9}, {
  3.5882272044033947`*^9, 3.5882272723632812`*^9}, {3.5882273138996572`*^9, 
  3.588227314427687*^9}, {3.5882273797874255`*^9, 3.5882274552117395`*^9}, {
  3.588227606035366*^9, 3.588227705715068*^9}, {3.5882277412511005`*^9, 
  3.5882277753560505`*^9}, {3.588314581137205*^9, 3.5883146185293436`*^9}, {
  3.5896240502636294`*^9, 3.589624065926525*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", "3", ")"}], "        ", 
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{
      RowBox[{"n", "''"}], "[", "v", "]"}], "]"}], ".", 
    RowBox[{"vec", "[", "x", "]"}]}]}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"p", "''"}], "[", "v", "]"}]}]], "Input",
 CellChangeTimes->{{3.5882277882617893`*^9, 3.588227862166016*^9}, {
  3.588227911814856*^9, 3.5882279124458923`*^9}, {3.5882493515897474`*^9, 
  3.5882493515897474`*^9}, {3.588249855162869*^9, 3.588249862274276*^9}}],

Cell["\<\
Now considering the system (1), (2), (3) we assume that the vectors \
vec[n[v]],  vec[n\[CloseCurlyQuote][v]], vec[n\[CloseCurlyQuote]\
\[CloseCurlyQuote][v]] are linearly independent. Then for any value of v \
there exists a uniquely defined solution of the system, say vec[z[v]]. \
Inserting this solution and differentiating (1) we obtain using (2):\
\>", "Text",
 CellChangeTimes->{{3.5882507314879923`*^9, 3.5882508650476313`*^9}, {
   3.588250898919568*^9, 3.588250988743706*^9}, {3.588251026695877*^9, 
   3.5882510652160797`*^9}, {3.5882515321277857`*^9, 3.5882515797755113`*^9}, 
   3.5882544666876335`*^9, {3.588314657265559*^9, 3.588314702873168*^9}, 
   3.617948569314351*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"n", "[", "v", "]"}], "]"}], ".", 
    RowBox[{"vec", "[", 
     RowBox[{
      RowBox[{"z", "'"}], "[", "v", "]"}], "]"}]}], " ", "+", " ", 
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{
      RowBox[{"n", "'"}], "[", "v", "]"}], "]"}], ".", 
    RowBox[{"vec", "[", 
     RowBox[{"z", "[", "v", "]"}], "]"}]}]}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"p", "'"}], "[", "v", "]"}]}]], "Input",
 CellChangeTimes->{{3.588251647891407*^9, 3.5882517007304296`*^9}, {
  3.588252009659099*^9, 3.5882520141383553`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{"n", "[", "v", "]"}], "]"}], ".", 
   RowBox[{"vec", "[", 
    RowBox[{
     RowBox[{"z", "'"}], "[", "v", "]"}], "]"}]}], "\[Equal]", " ", 
  "0"}]], "Input",
 CellChangeTimes->{{3.5882517374495296`*^9, 3.5882517400336776`*^9}}],

Cell["Analogously, differentiating (2) and using (3) we obtain", "Text",
 CellChangeTimes->{{3.588251764577081*^9, 3.588251813207863*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{
       RowBox[{"n", "''"}], "[", "v", "]"}], "]"}], ".", 
     RowBox[{"vec", "[", 
      RowBox[{"z", "[", "v", "]"}], "]"}]}], " ", "+", " ", 
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{
       RowBox[{"n", "'"}], "[", "v", "]"}], "]"}], ".", 
     RowBox[{"vec", "[", 
      RowBox[{
       RowBox[{"z", "'"}], "[", "v", "]"}], "]"}]}]}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{"p", "''"}], "[", "v"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.588251647891407*^9, 3.5882517007304296`*^9}, {
  3.5882519593002186`*^9, 3.588252024290936*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{
     RowBox[{"n", "'"}], "[", "v", "]"}], "]"}], ".", 
   RowBox[{"vec", "[", 
    RowBox[{
     RowBox[{"z", "'"}], "[", "v", "]"}], "]"}]}], "\[Equal]", " ", 
  "0"}]], "Input",
 CellChangeTimes->{{3.5882517374495296`*^9, 3.5882517400336776`*^9}, 
   3.588252071458634*^9}],

Cell["\<\
Remembering that vec[n[v]], vec[n\[CloseCurlyQuote][v]],  m[v] form an \
orthonormal frame we conclude\
\>", "Text",
 CellChangeTimes->{{3.5882520842993684`*^9, 3.588252111823943*^9}, {
  3.588252162215825*^9, 3.5882522530560207`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"vec", "[", 
   RowBox[{
    RowBox[{"z", "'"}], "[", "v", "]"}], "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{"h", "[", "v", "]"}], "*", 
   RowBox[{"m", "[", "v", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.588252291249205*^9, 3.5882523068100953`*^9}}],

Cell["\<\
 for a certain function h[v]. If vec[z\[CloseCurlyQuote][v]] \[NotEqual] \
null[], the tangents of the curve vec[z[v]] coincide with L[v], we may take \
x[v].= z[v] in the description of the envelope and see that the envelope is \
the tangent surface of the solution vec[z[v]]. If, on the other hand, vec[z\
\[CloseCurlyQuote][v]] == null[] the solution vec[z[v]] ==  vec[z] is \
constant, and the envelope is a conical surface with the vertex vec[z].  It \
remains to consider the case that vec[n[v]], vec[n\[CloseCurlyQuote][v]], \
vec[n\[CloseCurlyQuote]\[CloseCurlyQuote][v]] are linearly dependent. Since \
vec[n[v]], vec[n\[CloseCurlyQuote][v]] are linearly independent there exist \
two functions h[v], f[v] such that\
\>", "Text",
 CellChangeTimes->{{3.5882523323675575`*^9, 3.5882523659594784`*^9}, {
   3.588252403119604*^9, 3.5882525301118674`*^9}, {3.588252562376713*^9, 
   3.588252669647848*^9}, {3.588252736247658*^9, 3.5882527644802723`*^9}, {
   3.5882527968651247`*^9, 3.5882528233836412`*^9}, {3.588252933663949*^9, 
   3.588252998519659*^9}, {3.5882537708398333`*^9, 3.5882538299282126`*^9}, {
   3.588254100159669*^9, 3.5882541141364684`*^9}, {3.58825416206621*^9, 
   3.588254201264452*^9}, {3.588254344448642*^9, 3.588254427728405*^9}, 
   3.588254475112115*^9, {3.588254820552873*^9, 3.588254859344092*^9}, 
   3.5882558381370754`*^9, {3.5883147947924256`*^9, 3.5883148574810114`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", "4", ")"}], "        ", 
   RowBox[{"vec", "[", 
    RowBox[{
     RowBox[{"n", "''"}], "[", "v", "]"}], "]"}]}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "v", "]"}], "*", 
    RowBox[{"vec", "[", 
     RowBox[{"n", "[", "v", "]"}], "]"}]}], "+", " ", 
   RowBox[{
    RowBox[{"h", "[", "v", "]"}], "*", 
    RowBox[{"vec", "[", 
     RowBox[{
      RowBox[{"n", "'"}], "[", "v", "]"}], "]"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5882548846685405`*^9, 3.588254949778264*^9}, {
  3.5882554002110276`*^9, 3.5882554059073534`*^9}}],

Cell["\<\
The Dot product with vec[n\[CloseCurlyQuote][v]] yields h[v] == 0.  \
Differentiating vec[n[v]].vec[n\[CloseCurlyQuote][v]] == 0 we obtain\
\>", "Text",
 CellChangeTimes->{{3.588254991015623*^9, 3.5882551163277903`*^9}, {
  3.5882552475522957`*^9, 3.588255277408004*^9}}],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"n", "[", "v", "]"}], "]"}], ".", 
    RowBox[{"vec", "[", 
     RowBox[{
      RowBox[{"n", "''"}], "[", "v", "]"}], "]"}]}], " ", "\[Equal]", " ", 
   RowBox[{"-", 
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{
       RowBox[{"n", "'"}], "[", "v", "]"}], "]"}], ".", 
     RowBox[{"vec", "[", 
      RowBox[{
       RowBox[{"n", "'"}], "[", "v", "]"}], "]"}]}]}], " ", "\[Equal]", " ", 
   RowBox[{"-", "1"}]}]}]], "Input",
 CellChangeTimes->{{3.58825529726814*^9, 3.5882553831390514`*^9}, 
   3.588255433762947*^9}],

Cell["\<\
and the Dot product of  (4) with vec[n[v]]  yields f[v] == -1, thus we have \
\>", "Text",
 CellChangeTimes->{{3.588255445336609*^9, 3.58825551791176*^9}, {
  3.588255961705143*^9, 3.5882559648163214`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", "5", ")"}], "       ", 
   RowBox[{"vec", "[", 
    RowBox[{
     RowBox[{"n", "''"}], "[", "v", "]"}], "]"}]}], "\[Equal]", " ", 
  RowBox[{"-", " ", 
   RowBox[{"vec", "[", 
    RowBox[{"n", "[", "v", "]"}], "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5882556594018526`*^9, 3.588255677505888*^9}, {
  3.5882559714417*^9, 3.5882559760659647`*^9}}],

Cell["\<\
Now we consider the tangent vector m[v] = Cross[vec[n[v]], vec[n\
\[CloseCurlyQuote][v]]] of the line L[v]. We derive this equation and obtain \
\>", "Text",
 CellChangeTimes->{{3.5882557291788435`*^9, 3.588255736385256*^9}, {
  3.588255779688732*^9, 3.58825579258447*^9}, {3.5882560164642754`*^9, 
  3.5882560741835766`*^9}, {3.5882561426084905`*^9, 3.588256154536173*^9}, {
  3.588256323640845*^9, 3.5882563745037537`*^9}, {3.5883149684323573`*^9, 
  3.588315003656372*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"m", "'"}], "[", "v", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Cross", "[", 
     RowBox[{
      RowBox[{"vec", "[", 
       RowBox[{
        RowBox[{"n", "'"}], "[", "v", "]"}], "]"}], ",", " ", 
      RowBox[{"vec", "[", 
       RowBox[{
        RowBox[{"n", "'"}], "[", "v", "]"}], "]"}]}], "]"}], "  ", "+", " ", 
    RowBox[{"Cross", "[", 
     RowBox[{
      RowBox[{"vec", "[", 
       RowBox[{"n", "[", "v", "]"}], "]"}], ",", " ", 
      RowBox[{"vec", "[", 
       RowBox[{
        RowBox[{"n", "''"}], "[", "v", "]"}], "]"}]}], "]"}]}], " ", 
   "\[Equal]", " ", 
   RowBox[{"null", "[", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5882561811636953`*^9, 3.5882562189628572`*^9}, {
   3.5882562738379965`*^9, 3.5882563086289864`*^9}, 3.5883150319099874`*^9}],

Cell["\<\
Therefore m[v] is constant, and the envelope is a cylindrical surface.  \
Summarizing we proved:\
\>", "Text",
 CellChangeTimes->{{3.5882567953318243`*^9, 3.58825682305641*^9}, {
   3.5882568771925063`*^9, 3.588256903752025*^9}, 3.588315098768812*^9, {
   3.5883151461535225`*^9, 3.5883151633765073`*^9}}],

Cell[TextData[{
 StyleBox["Proposition",
  FontColor->RGBColor[0, 0, 1]],
 ". The envelope of a family of planes (1) is the set of  all solutions of \
the system (1), (2).  If vec[n[v]] is constant the envelope is a plane. \
Otherwise the envelope is locally, in the neighborhood of a plane with "
}], "Text",
 CellChangeTimes->{{3.5883151680647755`*^9, 3.588315182672611*^9}, {
   3.5883152262491035`*^9, 3.588315279185131*^9}, {3.5883153113609715`*^9, 
   3.588315350529212*^9}, {3.5883153994650106`*^9, 3.588315515048622*^9}, {
   3.5883159339855833`*^9, 3.588315946921324*^9}, 3.6152643301310415`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{
     RowBox[{"n", "'"}], "[", "v", "]"}], "]"}], " ", "\[NotEqual]", " ", 
   RowBox[{"null", "[", "]"}]}], ","}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5883155376899166`*^9, 3.588315562603342*^9}}],

Cell["\<\
a developable surface, namely a tangent surface, a conical or a cylindrical \
surface. Any such surface is the envelope of a 1-parametric family of planes, \
namely its tangent planes. Thus its spherical image is a curve. These \
surfaces are locally isometric to plane regions.\[FilledSquare]\
\>", "Text",
 CellChangeTimes->{{3.5883155891288586`*^9, 3.5883156337204094`*^9}, {
   3.588315687208469*^9, 3.588315892569215*^9}, 3.589624400446659*^9, {
   3.609820118876684*^9, 3.6098201188846846`*^9}}],

Cell["\<\
The last statement has been proved for each of the three types in subsections \
2.1.4-6.\
\>", "Text",
 CellChangeTimes->{{3.589624420686816*^9, 3.589624461254137*^9}, {
  3.5896244950710707`*^9, 3.589624519638476*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1.8. One-Sheeted Hyperboloids", "Subsubsection",
 CellChangeTimes->{{3.587201518412738*^9, 3.587201527076234*^9}, {
   3.587272835342759*^9, 3.58727283885396*^9}, {3.587272981302108*^9, 
   3.5872730078536263`*^9}, 3.5872731046621633`*^9, 3.587278763622837*^9, {
   3.5875395682098494`*^9, 3.58753958547908*^9}, {3.5875506376928062`*^9, 
   3.58755065084363*^9}, {3.5875621007464747`*^9, 3.5875621112900777`*^9}, {
   3.5881675117713223`*^9, 3.5881675315864553`*^9}, {3.58831735340977*^9, 
   3.588317395129156*^9}, 3.6098201445611534`*^9, 3.6098236513987246`*^9, 
   3.6179500274097495`*^9, 3.617951459497492*^9}],

Cell[TextData[{
 "One-sheeted hyperboloids are the standard examples of a ruled, non \
developable surface, see ",
 ButtonBox["MathWorld",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/One-SheetedHyperboloid.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/One-SheetedHyperboloid.html"],
 ". We consider the surface generated by rotating a hyperbola in the x, z- \
plane around the z-axis. A parameter representation is"
}], "Text",
 CellChangeTimes->{{3.588317415403316*^9, 3.5883175018172584`*^9}, {
   3.5883175511190786`*^9, 3.5883175511240788`*^9}, {3.5883175887452307`*^9, 
   3.5883175964246693`*^9}, {3.5883176462165174`*^9, 
   3.5883176956253433`*^9}, {3.5883177767289824`*^9, 3.5883178420087166`*^9}, 
   3.588336208915674*^9, 3.589624589599478*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "hyperboloid"}]], "Input",
 CellChangeTimes->{{3.5883362179324903`*^9, 3.5883362240945005`*^9}}],

Cell[BoxData[
 StyleBox["\<\"{u,v}->hyperboloid[a,c][u,v] is the standard parametrization \
of a circular hyperboloid of one sheet. {u,v}->hyperboloid[a,b,c][u,v] is the \
standard parametrization of an elliptical hyperboloid of one sheet.  To plot \
try hyperboloid[1,2,3][0,3Pi/2,-2,2].\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6179508832957034`*^9},
 CellTags->"Info3617958083-5478789"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hyperboloid", "[", 
   RowBox[{"a", ",", "b", ",", "c"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{
  3.5883403874176536`*^9, {3.5883404244667726`*^9, 3.5883404263938828`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", " ", 
    RowBox[{"Cos", "[", "u", "]"}], " ", 
    RowBox[{"Cosh", "[", "v", "]"}]}], ",", 
   RowBox[{"b", " ", 
    RowBox[{"Cosh", "[", "v", "]"}], " ", 
    RowBox[{"Sin", "[", "u", "]"}]}], ",", 
   RowBox[{"c", " ", 
    RowBox[{"Sinh", "[", "v", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.609822385848339*^9, 3.615195658257966*^9, 
  3.6179508902230997`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"hyperboloid", "[", 
   RowBox[{"1", ",", "2", ",", "3"}], "]"}], "[", 
  RowBox[{"0", ",", 
   RowBox[{"3", 
    RowBox[{"Pi", "/", "2"}]}], ",", 
   RowBox[{"-", "2"}], ",", "2"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hyperboloid", "[", 
   RowBox[{"1", ",", "1", ",", "1"}], "]"}], "[", 
  RowBox[{"0", ",", 
   RowBox[{"2", "*", "Pi"}], ",", 
   RowBox[{"-", "2"}], ",", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.5883386193385253`*^9, 3.58833863724955*^9}}],

Cell["We consider", "Text",
 CellChangeTimes->{{3.6151958465297346`*^9, 3.6151958510249915`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"hypsf", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", 
  RowBox[{
   RowBox[{"hyperboloid", "[", 
    RowBox[{"1", ",", "1", ",", "1"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.588318033245654*^9, 3.5883180445303*^9}, {
  3.588318457179902*^9, 3.5883184740108647`*^9}, {3.588336256043357*^9, 
  3.588336269974181*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hypsf", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.588336161585191*^9, 3.5883361828948283`*^9}, {
  3.588336306119445*^9, 3.588336306805846*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", "u", "]"}], " ", 
    RowBox[{"Cosh", "[", "v", "]"}]}], ",", 
   RowBox[{
    RowBox[{"Cosh", "[", "v", "]"}], " ", 
    RowBox[{"Sin", "[", "u", "]"}]}], ",", 
   RowBox[{"Sinh", "[", "v", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5896246355991087`*^9, 3.609822469806141*^9, 
  3.615195860887556*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"hyp", " ", "=", " ", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"hypsf", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"u", ",", "0", ",", 
       RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"v", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
      RowBox[{"Opacity", "[", ".6", "]"}]}], ",", " ", 
     RowBox[{"Mesh", " ", "\[Rule]", " ", "None"}]}], "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5883386948088417`*^9, 3.5883387920834055`*^9}, {
   3.5883388681147547`*^9, 3.588338902323711*^9}, {3.5883389574828663`*^9, 
   3.588338974385833*^9}, 3.5883404603178234`*^9, 3.5883414040037985`*^9}],

Cell["It is the quadric defined by the equation", "Text",
 CellChangeTimes->{{3.5883182455697985`*^9, 3.588318261936735*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"x", "^", "2"}], " ", "+", " ", 
   RowBox[{"y", "^", "2"}], " ", "-", 
   RowBox[{"z", "^", "2"}]}], " ", "\[Equal]", " ", "1"}]], "Input",
 CellChangeTimes->{{3.5883182820748863`*^9, 3.5883183021390343`*^9}, {
  3.5883926010801964`*^9, 3.588392611438615*^9}}],

Cell["The normal vector field is", "Text",
 CellChangeTimes->{{3.5883183493287334`*^9, 3.588318360512373*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"nhyp", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "3", "]"}], "[", "hypsf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", ">", "0"}], ",", 
      RowBox[{"v", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.588318365192641*^9, 3.588318372047033*^9}, {
   3.5883184180426636`*^9, 3.58831842515207*^9}, {3.5883184870836124`*^9, 
   3.5883185219316053`*^9}, {3.5883188504443955`*^9, 3.588318860715983*^9}, 
   3.588392645727475*^9, 3.614861852249527*^9, 3.614917784229748*^9, 
   3.6151813598587375`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"Cos", "[", "u", "]"}], " ", 
     RowBox[{"Cosh", "[", "v", "]"}]}], 
    SqrtBox[
     RowBox[{"Cosh", "[", 
      RowBox[{"2", " ", "v"}], "]"}]]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"Cosh", "[", "v", "]"}], " ", 
     RowBox[{"Sin", "[", "u", "]"}]}], 
    SqrtBox[
     RowBox[{"Cosh", "[", 
      RowBox[{"2", " ", "v"}], "]"}]]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"Sinh", "[", "v", "]"}], 
     SqrtBox[
      RowBox[{"Cosh", "[", 
       RowBox[{"2", " ", "v"}], "]"}]]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5883927173628006`*^9, 3.588414142691103*^9, 3.588487121953766*^9, 
   3.5884990647674503`*^9, 3.588563854563089*^9, 3.5886610931599493`*^9, 
   3.5886739740237007`*^9, 3.588766005100974*^9, 3.588917537272459*^9, 
   3.588918891448437*^9, 3.5889437536861625`*^9, 3.588998600878888*^9, 
   3.5890059407457047`*^9, 3.58908710170723*^9, 3.589169680461894*^9, 
   3.58960853782096*^9, 3.5897728553158183`*^9, 3.5898647231741667`*^9, 
   3.589890506741996*^9, 3.589951883017136*^9, 3.5899536568806515`*^9, 
   3.5899560142585726`*^9, 3.589978296854082*^9, 3.590039009361622*^9, 
   3.5902120096493025`*^9, 3.5904958190292*^9, 3.590640419229368*^9, 
   3.5906714829085894`*^9, 3.590715685901078*^9, 3.5907201701986675`*^9, 
   3.5907340484551435`*^9, 3.5908181808404036`*^9, 3.5909046962673497`*^9, 
   3.5909102117740736`*^9, 3.59098795566062*^9, 3.5911632387169137`*^9, 
   3.5911806678129253`*^9, 3.5912467889784565`*^9, 3.5913394495485816`*^9, 
   3.5914142271536036`*^9, 3.5914415558399916`*^9, 3.5915074104232855`*^9, 
   3.5915923949070916`*^9, 3.5916857047361174`*^9, 3.59176783437414*^9, 
   3.591945364720682*^9, 3.591966126305372*^9, 3.592022566753022*^9, 
   3.592022706856868*^9, 3.5920467433875527`*^9, 3.5921112245996037`*^9, 
   3.592133831297254*^9, 3.5921479176387863`*^9, 3.5922001249572735`*^9, 
   3.5922932528436127`*^9, 3.592305990064765*^9, 3.5923732782217956`*^9, 
   3.592454414313846*^9, 3.5925450422158594`*^9, 3.592632208634556*^9, 
   3.5926559615710554`*^9, 3.592708155074218*^9, 3.592741052837453*^9, 
   3.592799291168187*^9, 3.5929819527022*^9, 3.593008848063084*^9, 
   3.593064294602658*^9, 3.5931467754372807`*^9, 3.593177850218502*^9, 
   3.593321895110676*^9, 3.5933488156525497`*^9, 3.5934050662114897`*^9, 
   3.593413997258376*^9, 3.593434078953621*^9, 3.5935839618749695`*^9, 
   3.593611819411711*^9, 3.5936680948463364`*^9, 3.5938384355603*^9, 
   3.593840951191283*^9, 3.594184573825266*^9, 3.594192204984269*^9, 
   3.5942697019368825`*^9, 3.5942746446376104`*^9, 3.594363575076174*^9, 
   3.594364709260566*^9, 3.5946216262813363`*^9, 3.5947054238432817`*^9, 
   3.594877284631074*^9, 3.594881068152519*^9, 3.594964010478292*^9, 
   3.5950483424160986`*^9, 3.5951338055432606`*^9, 3.5951436419041643`*^9, 
   3.595229679079672*^9, 3.595311850296245*^9, 3.595484800623603*^9, 
   3.5954860406385813`*^9, 3.5954886791648154`*^9, 3.595569166041711*^9, 
   3.595570233841786*^9, 3.595574939984962*^9, 3.5956508713297606`*^9, 
   3.5956595573670387`*^9, 3.5958282756459074`*^9, 3.5959119989545546`*^9, 
   3.596001557471689*^9, 3.5960891869173646`*^9, 3.5962618849923615`*^9, 
   3.596355663625343*^9, 3.5963714658137865`*^9, 3.596436862172959*^9, 
   3.5965212862426786`*^9, 3.5972075182660646`*^9, 3.59729825548633*^9, 
   3.597381841044182*^9, 3.597468084022111*^9, 3.59772929275064*^9, {
   3.5977376740284443`*^9, 3.5977376937365713`*^9}, 3.5977612664868636`*^9, 
   3.597814066519808*^9, 3.5978474280320826`*^9, 3.5979019481623545`*^9, 
   3.5980092598448157`*^9, 3.598074376802319*^9, 3.5983626707952857`*^9, 
   3.59842555952346*^9, 3.5985947296994953`*^9, 3.598625181196543*^9, 
   3.598675580643878*^9, 3.5988608385862045`*^9, 3.598882113060272*^9, 
   3.598940444441946*^9, 3.5990227501377754`*^9, 3.59919714701582*^9, 
   3.599197249318671*^9, 3.599287077864723*^9, 3.5994666436346674`*^9, 
   3.5994872809113026`*^9, 3.599488182842487*^9, 3.5994885258558893`*^9, 
   3.5994888238632126`*^9, 3.5994890863336735`*^9, 3.599550825033957*^9, 
   3.5995512987443895`*^9, 3.599803407887988*^9, 3.6089605889768486`*^9, 
   3.6089613033333035`*^9, 3.608965754972722*^9, 3.6089661900106864`*^9, 
   3.6089673440062785`*^9, 3.608968841091907*^9, 3.6089692244788356`*^9, 
   3.6089694746451445`*^9, 3.608972205915581*^9, 3.6091370381883135`*^9, 
   3.609215116440267*^9, 3.609307927501056*^9, 3.609558825781818*^9, 
   3.609560961818372*^9, 3.609649067724177*^9, 3.609650321553892*^9, 
   3.6096724940126047`*^9, 3.6097310615792084`*^9, 3.609743648388341*^9, 
   3.6097530865017166`*^9, 3.6098148113241096`*^9, 3.609822512116561*^9, 
   3.6098499639440875`*^9, 3.609910388270091*^9, 3.611208391244477*^9, 
   3.61146610370821*^9, 3.6115532996668596`*^9, 3.611558167925308*^9, 
   3.6115582068695354`*^9, 3.611569706955575*^9, 3.6115701075784893`*^9, 
   3.611573547499769*^9, 3.6116341225021305`*^9, 3.6116351934012127`*^9, 
   3.611925017305276*^9, 3.6119969460862007`*^9, 3.6120721300582824`*^9, 
   3.6120900917701087`*^9, 3.6121526129949956`*^9, 3.61226571452258*^9, 
   3.6123237631289635`*^9, 3.6126788786914744`*^9, 3.612754368616638*^9, 
   3.6128459859022427`*^9, 3.613021069667039*^9, 3.6131050226543064`*^9, 
   3.6132198054464135`*^9, 3.6132778677844276`*^9, 3.6134435151046324`*^9, 
   3.6134729045818605`*^9, 3.61354124482926*^9, 3.613560036657508*^9, 
   3.6136190074497643`*^9, 3.6139702755280757`*^9, 3.6139763930840263`*^9, 
   3.6139942761322803`*^9, 3.6139943161931505`*^9, 3.6140533859289365`*^9, 
   3.6141460266340876`*^9, 3.614163986804535*^9, 3.614228816312516*^9, 
   3.614256243541877*^9, 3.6143098849476624`*^9, 3.614328237004467*^9, 
   3.614395967772697*^9, 3.6144295421150923`*^9, 3.6144822833815975`*^9, 
   3.6144905544606905`*^9, 3.6145052559544373`*^9, 3.6145728264073277`*^9, 
   3.6146857534528837`*^9, 3.6146861486684885`*^9, 3.6146877138090096`*^9, 
   3.6146894060878024`*^9, 3.6147492106099424`*^9, 3.614751100038461*^9, 
   3.614751230891491*^9, 3.6147514678559074`*^9, 3.6148608199957137`*^9, 
   3.6148633234881105`*^9, 3.6149174989676466`*^9, 3.6149466467177567`*^9, 
   3.615019714853715*^9, 3.61509779076012*^9, 3.615179962444355*^9, 
   3.615195895735549*^9, 3.6152059474141*^9, 3.615261733622952*^9, 
   3.6153520628101482`*^9, 3.6154344587014813`*^9, 3.6155280164771748`*^9, 
   3.615611423189912*^9, 3.615641839790137*^9, 3.6158945160784883`*^9, 
   3.6159531367108545`*^9, 3.6159583696464453`*^9, 3.6160460079069567`*^9, 
   3.6160647469851785`*^9, 3.6161193210723133`*^9, 3.6161575918005705`*^9, 
   3.6162182460480733`*^9, 3.616297852947647*^9, 3.616383947086277*^9, 
   3.616393930139047*^9, 3.6164204761630907`*^9, 3.6164709793980722`*^9, 
   3.616487090695547*^9, 3.616494755402169*^9, 3.6165019334683084`*^9, 
   3.6165512201608543`*^9, 3.616646615452362*^9, 3.6166687450092325`*^9, 
   3.6167296375964966`*^9, 3.616814477964036*^9, 3.616899535477528*^9, 
   3.6169899353355107`*^9, 3.616992540948087*^9, 3.617075049214074*^9, 
   3.6171683347057056`*^9, 3.6171716058286514`*^9, 3.617198339510583*^9, 
   3.617282746222723*^9, 3.617337038670792*^9, 3.6174260937492247`*^9, 
   3.617453877856944*^9, 3.6175113055549583`*^9, 3.6175272972464557`*^9, 
   3.6175276403222585`*^9, 3.6175445661014185`*^9, 3.617599429196843*^9, 
   3.6176155056360683`*^9, 3.6176246355363774`*^9, 3.6176829157901316`*^9, 
   3.617692809692338*^9, 3.6177012115906534`*^9, 3.6177695964969635`*^9, 
   3.6177762516426525`*^9, 3.6178035020395546`*^9, 3.617804354237851*^9, 
   3.617859532992169*^9, 3.61788899620437*^9, 3.61794022265136*^9, 
   3.6179509918247423`*^9, 3.6179726286473308`*^9, 3.6179750461834974`*^9, 
   3.6180244539782543`*^9, 3.61803228547281*^9, 3.618114539103713*^9, 
   3.61813512730051*^9, 3.6181357256083612`*^9, 3.618139923778535*^9, 
   3.6182087362455196`*^9, 3.6182168911962776`*^9, 3.618235617042833*^9, 
   3.6182938452156396`*^9, 3.6183731647488384`*^9, 3.618465824909399*^9, 
   3.6184683463127403`*^9, 3.6184696196337767`*^9, 3.6184698156949205`*^9, 
   3.6184911633335342`*^9, 3.618546049339672*^9, 3.618580309022361*^9, 
   3.6186338406398644`*^9, 3.6186342108597145`*^9, 3.6186407707419415`*^9, 
   3.618718814434475*^9, 3.618803138354884*^9, 3.6188333620168085`*^9, 
   3.6189112178836713`*^9, 3.6189112850729895`*^9, 3.6189813240776567`*^9, 
   3.6189940898074903`*^9, 3.6201900080334177`*^9, 3.6201958440249653`*^9, 
   3.620195889892174*^9, 3.6201987461493683`*^9, 3.6201987924023438`*^9, 
   3.620199187568752*^9, 3.6205365925154023`*^9}]
}, Open  ]],

Cell["\<\
We fix a point {u,v} and consider the tangent plane of the hyperboloid at \
this point with the variable point vec[x]. Its equation is \
\>", "Text",
 CellChangeTimes->{{3.588318711689459*^9, 3.5883187975213685`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"h", "[", 
   RowBox[{"u_", ",", " ", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"nhyp", "[", 
     RowBox[{"u", ",", " ", "v"}], "]"}], ".", 
    RowBox[{"vec", "[", "x", "]"}]}], " ", "==", " ", 
   RowBox[{
    RowBox[{"nhyp", "[", 
     RowBox[{"u", ",", " ", "v"}], "]"}], ".", 
    RowBox[{"hypsf", "[", 
     RowBox[{"u", ",", " ", "v"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.58833644559929*^9, 3.58833644559929*^9}, {
  3.5883368501704006`*^9, 3.588336863664424*^9}, {3.5883926475838785`*^9, 
  3.588392650391883*^9}}],

Cell["\<\
The intersection of the hyperboloid with the tangent plane at {u,v} = {0,0} \
is the solution of\
\>", "Text",
 CellChangeTimes->{{3.588336386537586*^9, 3.588336413541233*^9}, {
  3.588336480340551*^9, 3.588336555641883*^9}, {3.609822617083565*^9, 
  3.6098226359956465`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"0", ",", "0"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", "1", "]"}], "^", "2"}], " ", "+", " ", 
       RowBox[{
        RowBox[{"x", "[", "2", "]"}], "^", "2"}], " ", "-", 
       RowBox[{
        RowBox[{"x", "[", "3", "]"}], "^", "2"}]}], "\[Equal]", " ", "1"}]}], 
    "}"}], ",", " ", 
   RowBox[{"vec", "[", "x", "]"}], ",", "Reals"}], "]"}]], "Input",
 CellChangeTimes->{{3.5883189765386076`*^9, 3.588319000498978*^9}, {
   3.5883190488517437`*^9, 3.5883191283982935`*^9}, {3.588319186566621*^9, 
   3.588319199897383*^9}, {3.588319458461172*^9, 3.58831946104532*^9}, 
   3.6148618522651267`*^9, 3.614917784245348*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], "\[Equal]", "1"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], "\[Equal]", 
     RowBox[{"-", 
      SqrtBox[
       SuperscriptBox[
        RowBox[{"x", "[", "2", "]"}], "2"]]}]}], "||", 
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], "\[Equal]", 
     SqrtBox[
      SuperscriptBox[
       RowBox[{"x", "[", "2", "]"}], "2"]]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.589625282761124*^9, 3.609822646391241*^9, 
  3.615196006151864*^9, 3.6179511400182185`*^9}]
}, Closed]],

Cell["The solution consists of two lines intersecting in the point", "Text",
 CellChangeTimes->{{3.5883368982808847`*^9, 3.588336928685338*^9}, {
   3.5883370207430906`*^9, 3.5883370393991575`*^9}, 3.615264421498866*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hypsf", "[", 
  RowBox[{"0", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.588337052581912*^9, 3.5883370617754374`*^9}, 
   3.58833711234533*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.615196021270729*^9, 3.617951158732289*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"lines", " ", "=", " ", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "t", ",", "t"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "t", ",", 
         RowBox[{"-", "t"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", " ", 
     RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", "Thick"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Thick"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5883391787715225`*^9, 3.588339406986576*^9}, 
   3.588340016380431*^9, 3.5883400791880236`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tpl", " ", "=", " ", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"u", "+", "v"}], ",", 
       RowBox[{"u", "-", "v"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"v", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Opacity", "[", "0.3", "]"}]}], "}"}]}], ",", " ", 
     RowBox[{"Mesh", "\[Rule]", " ", "False"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5883395599233236`*^9, 3.588339574290145*^9}, {
   3.58833960514691*^9, 3.588339605156911*^9}, {3.588339682473333*^9, 
   3.588339886557006*^9}, 3.5883400673403463`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"pt", " ", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.015", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.588340740746863*^9, 3.5883407765549107`*^9}, {
   3.5883408387954707`*^9, 3.5883408522202387`*^9}, {3.5883409048192472`*^9, 
   3.588341005627013*^9}, {3.5883410445882416`*^9, 3.5883410657394514`*^9}, 
   3.588341104810686*^9, 3.614861852280727*^9, 3.6149177842609477`*^9}],

Cell["\<\
The next figure shows the hyperboloid and the intersection with its tangent \
plane at the point pt:\
\>", "Text",
 CellChangeTimes->{{3.5883405593284864`*^9, 3.5883406616313376`*^9}, {
  3.5883411405207286`*^9, 3.588341154064503*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"hyp", ",", "lines", ",", "tpl", ",", "pt"}], "}"}], ",", " ", 
   RowBox[{"Axes", "\[Rule]", " ", "None"}], ",", 
   RowBox[{"Boxed", "\[Rule]", " ", "False"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5883394200973263`*^9, 3.588339474577442*^9}, {
  3.588339905786106*^9, 3.588339907934229*^9}, {3.588339937962946*^9, 
  3.588339947194474*^9}, {3.588341018018722*^9, 3.5883410194828053`*^9}}],

Cell["\<\
Through any point of hypsf  two lines belong to the surface, for example\
\>", "Text",
 CellChangeTimes->{{3.5883377675518055`*^9, 3.5883378334235735`*^9}, {
  3.5883390557674875`*^9, 3.588339089159397*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", "1", "]"}], "^", "2"}], " ", "+", " ", 
       RowBox[{
        RowBox[{"x", "[", "2", "]"}], "^", "2"}], " ", "-", 
       RowBox[{
        RowBox[{"x", "[", "3", "]"}], "^", "2"}]}], "\[Equal]", " ", "1"}]}], 
    "}"}], ",", " ", 
   RowBox[{"vec", "[", "x", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5883189765386076`*^9, 3.588319000498978*^9}, {
   3.5883190488517437`*^9, 3.5883191283982935`*^9}, {3.588319186566621*^9, 
   3.588319199897383*^9}, {3.588319458461172*^9, 3.58831946104532*^9}, {
   3.588319535468577*^9, 3.58831954670922*^9}, {3.588319614765112*^9, 
   3.588319619853403*^9}, {3.588336590819945*^9, 3.5883366074651737`*^9}, 
   3.5883368036823187`*^9, {3.5883371369567375`*^9, 3.588337149963482*^9}, {
   3.5896249832169914`*^9, 3.5896249944856358`*^9}, {3.58962515837101*^9, 
   3.5896251697996635`*^9}, 3.6148618522963266`*^9, 3.6148646598800583`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Solve", "::", "svars"}], "MessageName"], ":", 
  " ", "\<\"Equations may not give solutions for all \\\"solve\\\" variables. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Solve/svars\\\", \
ButtonNote -> \\\"Solve::svars\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.589625171160741*^9, 3.6098227680241985`*^9, 
  3.615196153054267*^9, 3.617951209465191*^9, 3.617951262094201*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "[", "2", "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"Cosh", "[", "v", "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "u", "]"}], " ", 
         RowBox[{"x", "[", "1", "]"}]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"u", "-", 
           RowBox[{"\[ImaginaryI]", " ", "v"}]}], "]"}], " ", 
         RowBox[{"x", "[", "1", "]"}]}], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"u", "+", 
           RowBox[{"\[ImaginaryI]", " ", "v"}]}], "]"}], " ", 
         RowBox[{"x", "[", "1", "]"}]}]}], 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"Sin", "[", "u", "]"}]}], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"u", "-", 
           RowBox[{"\[ImaginaryI]", " ", "v"}]}], "]"}]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"u", "+", 
           RowBox[{"\[ImaginaryI]", " ", "v"}]}], "]"}]}]}]]}], ",", 
     RowBox[{
      RowBox[{"x", "[", "3", "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", "u", "]"}]}], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"u", "-", 
           RowBox[{"\[ImaginaryI]", " ", "v"}]}], "]"}]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"u", "+", 
           RowBox[{"\[ImaginaryI]", " ", "v"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"Cosh", "[", "v", "]"}], " ", 
         RowBox[{"x", "[", "1", "]"}]}]}], 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", "u", "]"}]}], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"u", "-", 
           RowBox[{"\[ImaginaryI]", " ", "v"}]}], "]"}]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"u", "+", 
           RowBox[{"\[ImaginaryI]", " ", "v"}]}], "]"}]}]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "[", "2", "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"Cosh", "[", "v", "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "u", "]"}], " ", 
         RowBox[{"x", "[", "1", "]"}]}], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"u", "-", 
           RowBox[{"\[ImaginaryI]", " ", "v"}]}], "]"}], " ", 
         RowBox[{"x", "[", "1", "]"}]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"u", "+", 
           RowBox[{"\[ImaginaryI]", " ", "v"}]}], "]"}], " ", 
         RowBox[{"x", "[", "1", "]"}]}]}], 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"Sin", "[", "u", "]"}]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"u", "-", 
           RowBox[{"\[ImaginaryI]", " ", "v"}]}], "]"}]}], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"u", "+", 
           RowBox[{"\[ImaginaryI]", " ", "v"}]}], "]"}]}]}]]}], ",", 
     RowBox[{
      RowBox[{"x", "[", "3", "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", "u", "]"}]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"u", "-", 
           RowBox[{"\[ImaginaryI]", " ", "v"}]}], "]"}]}], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"u", "+", 
           RowBox[{"\[ImaginaryI]", " ", "v"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"Cosh", "[", "v", "]"}], " ", 
         RowBox[{"x", "[", "1", "]"}]}]}], 
       RowBox[{
        RowBox[{"Sin", "[", "u", "]"}], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"u", "-", 
           RowBox[{"\[ImaginaryI]", " ", "v"}]}], "]"}]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"u", "+", 
           RowBox[{"\[ImaginaryI]", " ", "v"}]}], "]"}]}]}]]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.589624927802822*^9, 3.5896249511701584`*^9}, {
   3.5896251494334984`*^9, 3.589625171163741*^9}, 3.609822768032199*^9, 
   3.6151961530602674`*^9, 3.617951209472191*^9, 3.617951262101201*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"v", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5883371576409206`*^9, 3.5883371965681477`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "[", "2", "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"Cosh", "[", "v", "]"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", "u", "]"}], "+", 
           RowBox[{
            RowBox[{"Sin", "[", "u", "]"}], " ", 
            RowBox[{"Sinh", "[", "v", "]"}]}]}], ")"}], " ", 
         RowBox[{"x", "[", "1", "]"}]}]}], 
       RowBox[{
        RowBox[{"Sin", "[", "u", "]"}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", "u", "]"}], " ", 
         RowBox[{"Sinh", "[", "v", "]"}]}]}]]}], ",", 
     RowBox[{
      RowBox[{"x", "[", "3", "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"Cos", "[", "u", "]"}], "+", 
        RowBox[{
         RowBox[{"Sin", "[", "u", "]"}], " ", 
         RowBox[{"Sinh", "[", "v", "]"}]}], "-", 
        RowBox[{
         RowBox[{"Cosh", "[", "v", "]"}], " ", 
         RowBox[{"x", "[", "1", "]"}]}]}], 
       RowBox[{
        RowBox[{"Sin", "[", "u", "]"}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", "u", "]"}], " ", 
         RowBox[{"Sinh", "[", "v", "]"}]}]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "[", "2", "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"Cosh", "[", "v", "]"}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", "u", "]"}], " ", 
         RowBox[{"x", "[", "1", "]"}]}], "+", 
        RowBox[{
         RowBox[{"Sin", "[", "u", "]"}], " ", 
         RowBox[{"Sinh", "[", "v", "]"}], " ", 
         RowBox[{"x", "[", "1", "]"}]}]}], 
       RowBox[{
        RowBox[{"Sin", "[", "u", "]"}], "+", 
        RowBox[{
         RowBox[{"Cos", "[", "u", "]"}], " ", 
         RowBox[{"Sinh", "[", "v", "]"}]}]}]]}], ",", 
     RowBox[{
      RowBox[{"x", "[", "3", "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", "u", "]"}]}], "+", 
        RowBox[{
         RowBox[{"Sin", "[", "u", "]"}], " ", 
         RowBox[{"Sinh", "[", "v", "]"}]}], "+", 
        RowBox[{
         RowBox[{"Cosh", "[", "v", "]"}], " ", 
         RowBox[{"x", "[", "1", "]"}]}]}], 
       RowBox[{
        RowBox[{"Sin", "[", "u", "]"}], "+", 
        RowBox[{
         RowBox[{"Cos", "[", "u", "]"}], " ", 
         RowBox[{"Sinh", "[", "v", "]"}]}]}]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5896251761000233`*^9, 3.6098227776267476`*^9, 
  3.6151961675310946`*^9, 3.617951266244438*^9}]
}, Closed]],

Cell[TextData[{
 "Surfaces being ruled in a twofold way are said to be ",
 StyleBox["doubly ruled",
  FontColor->RGBColor[0, 0, 1]],
 ", see ",
 ButtonBox["MathWorld",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/DoublyRuledSurface.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/DoublyRuledSurface.html"],
 ". The spherical image of the surface hypsf is given by its normal vector \
nhyp[u,v] defined above. We have"
}], "Text",
 CellChangeTimes->{{3.588337859712077*^9, 3.588337952823403*^9}, {
   3.588338081911786*^9, 3.588338171823929*^9}, 3.588338215392421*^9, 
   3.5896254035730343`*^9, {3.589625489598955*^9, 3.589625585046414*^9}, {
   3.609822804716297*^9, 3.609822809275558*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "nhyp", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5896256072246823`*^9, 3.5896256187763433`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"Cosh", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "u", "]"}]}], 
       SqrtBox[
        RowBox[{"Cosh", "[", 
         RowBox[{"2", " ", "v"}], "]"}]]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"Cos", "[", "u", "]"}], " ", 
        RowBox[{"Sinh", "[", "v", "]"}]}], 
       SqrtBox[
        RowBox[{"Cosh", "[", 
         RowBox[{"2", " ", "v"}], "]"}]]], "-", 
      FractionBox[
       RowBox[{
        RowBox[{"Cos", "[", "u", "]"}], " ", 
        RowBox[{"Cosh", "[", "v", "]"}], " ", 
        RowBox[{"Sinh", "[", 
         RowBox[{"2", " ", "v"}], "]"}]}], 
       SuperscriptBox[
        RowBox[{"Cosh", "[", 
         RowBox[{"2", " ", "v"}], "]"}], 
        RowBox[{"3", "/", "2"}]]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"Cos", "[", "u", "]"}], " ", 
       RowBox[{"Cosh", "[", "v", "]"}]}], 
      SqrtBox[
       RowBox[{"Cosh", "[", 
        RowBox[{"2", " ", "v"}], "]"}]]], ",", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"Sin", "[", "u", "]"}], " ", 
        RowBox[{"Sinh", "[", "v", "]"}]}], 
       SqrtBox[
        RowBox[{"Cosh", "[", 
         RowBox[{"2", " ", "v"}], "]"}]]], "-", 
      FractionBox[
       RowBox[{
        RowBox[{"Cosh", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "u", "]"}], " ", 
        RowBox[{"Sinh", "[", 
         RowBox[{"2", " ", "v"}], "]"}]}], 
       SuperscriptBox[
        RowBox[{"Cosh", "[", 
         RowBox[{"2", " ", "v"}], "]"}], 
        RowBox[{"3", "/", "2"}]]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Cosh", "[", "v", "]"}], 
        SqrtBox[
         RowBox[{"Cosh", "[", 
          RowBox[{"2", " ", "v"}], "]"}]]]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"Sinh", "[", "v", "]"}], " ", 
        RowBox[{"Sinh", "[", 
         RowBox[{"2", " ", "v"}], "]"}]}], 
       SuperscriptBox[
        RowBox[{"Cosh", "[", 
         RowBox[{"2", " ", "v"}], "]"}], 
        RowBox[{"3", "/", "2"}]]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5896256247506847`*^9, 3.6098228194771414`*^9, 
  3.615196190120387*^9, 3.6179513157462697`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"u", "\[Rule]", " ", 
     RowBox[{"Random", "[", "]"}]}], ",", 
    RowBox[{"v", "\[Rule]", " ", 
     RowBox[{"Random", "[", "]"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5896256589816427`*^9, 3.58962570072103*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.06946248237960542`"}], ",", 
     RowBox[{"-", "0.23594894740757577`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9572210715643371`", ",", 
     RowBox[{"-", "0.017122063114428203`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "0.8082860827031659`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.589625706470359*^9, 3.6098228255534887`*^9, 
  3.6151961993739157`*^9, 3.6179513245367727`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixRank", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.5896257130727367`*^9, 3.5896257222002587`*^9}}],

Cell[BoxData["2"], "Output",
 CellChangeTimes->{3.5896257276365695`*^9, 3.609822831041803*^9, 
  3.615196204303198*^9, 3.617951328993027*^9}]
}, Closed]],

Cell["\<\
Indeed, the spherical image of the surface covers a whole open region of the \
sphere. Therefore the surface may not be developable; remember that the \
spherical image of a developable surface is a curve or a point only.\
\>", "Text",
 CellChangeTimes->{{3.5896257957964683`*^9, 3.589625951590379*^9}, 
   3.6151962208821464`*^9}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"nhyp", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", " ", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "7"}], ",", "7"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5896259599918594`*^9, 3.589626106817258*^9}, {
  3.5896265303224807`*^9, 3.589626550265621*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"nhyp", "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{"[", "3", "]"}], "]"}], ",", " ", 
   RowBox[{"v", "\[Rule]", " ", 
    RowBox[{"-", "Infinity"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5896261379230366`*^9, 3.589626182777602*^9}, 
   3.589626268130484*^9, {3.615196311548332*^9, 3.6151963255081306`*^9}}],

Cell[BoxData[
 FractionBox["1", 
  SqrtBox["2"]]], "Output",
 CellChangeTimes->{{3.58962617067691*^9, 3.5896261837426577`*^9}, 
   3.5896262696565714`*^9, 3.609822886486974*^9, {3.615196286126878*^9, 
   3.615196326977215*^9}, 3.617951356399595*^9}]
}, Closed]],

Cell[TextData[{
 "Thus the spherical image of the whole hyperboloid hypsf consists of the \
points of the unit sphere whose third coordinate  satisfies -",
 Cell[BoxData[
  FractionBox["1", 
   SqrtBox["2"]]],
  CellChangeTimes->{{3.58962617067691*^9, 3.5896261837426577`*^9}, 
    3.5896262696565714`*^9}],
 "< x[3] < ",
 Cell[BoxData[
  FractionBox["1", 
   SqrtBox["2"]]],
  CellChangeTimes->{{3.58962617067691*^9, 3.5896261837426577`*^9}, 
    3.5896262696565714`*^9}],
 "."
}], "Text",
 CellChangeTimes->{{3.58962632295862*^9, 3.589626485630924*^9}}],

Cell[TextData[{
 "Another doubly ruled surface is the ",
 StyleBox["hyperbolic paraboloid",
  FontColor->RGBColor[0, 0, 1]],
 ", see ",
 ButtonBox["MathWorld",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/HyperbolicParaboloid.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/HyperbolicParaboloid.html"],
 "."
}], "Text",
 CellChangeTimes->{{3.588337859712077*^9, 3.588337952823403*^9}, {
   3.588338081911786*^9, 3.588338171823929*^9}, 3.588338215392421*^9, {
   3.5896254035730343`*^9, 3.589625428646468*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "hyperbolicparaboloid"}]], "Input",
 CellChangeTimes->{3.5883384595453854`*^9}],

Cell[BoxData[
 StyleBox["\<\"{u,v}->hyperbolicparaboloid[u,v] is a parametrization of a \
hyperbolic paraboloid.  To plot try hyperbolicparaboloid[-1,1,-1,1].\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6179513750396605`*^9},
 CellTags->"Info3617958574-5478789"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hyperbolicparaboloid", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.588338474241226*^9, 3.5883384780094414`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"u", ",", "v", ",", 
   RowBox[{"u", " ", "v"}]}], "}"}]], "Output",
 CellChangeTimes->{3.589626800678944*^9, 3.5896269951120653`*^9, 
  3.6098229350987544`*^9, 3.6151963654254136`*^9, 3.61795137973693*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"hyperbolicparaboloid", "[", 
  RowBox[{
   RowBox[{"-", "1"}], ",", "1", ",", 
   RowBox[{"-", "1"}], ",", "1"}], "]"}]], "Input"],

Cell["\<\
As an exercise find  the line families contained in this surface, calculate \
its first fundamental form and plot its spherical image.\
\>", "Text",
 CellChangeTimes->{{3.5896266873664627`*^9, 3.589626792142456*^9}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2. The Gaussian Curvature", "Subsection",
 CellChangeTimes->{{3.5872730558623724`*^9, 3.58727307645455*^9}, {
   3.5883415613617992`*^9, 3.5883415766636744`*^9}, {3.5883416340959597`*^9, 
   3.5883416520479865`*^9}, 3.6151964340823407`*^9, 3.6152119753114877`*^9, 
   3.6179516333704367`*^9, 3.61795637897787*^9}],

Cell[CellGroupData[{

Cell["\<\
2.2.1. Integral Curvature and Curvature Integral. Orientation\
\>", "Subsubsection",
 CellChangeTimes->{{3.589779006964474*^9, 3.5897790435933385`*^9}, {
   3.5897790965554314`*^9, 3.589779110049455*^9}, 3.609823738997735*^9, 
   3.6098312806720943`*^9}],

Cell["Here is the unit sphere:", "Text",
 CellChangeTimes->{{3.588487873500686*^9, 3.5884878829387026`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sph1", " ", "=", " ", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"sphero", "[", "1", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "0", ",", 
       RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"v", ",", 
       RowBox[{
        RowBox[{"-", "Pi"}], "/", "2"}], ",", 
       RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
     RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
      RowBox[{"Opacity", "[", ".4", "]"}]}], ",", " ", 
     RowBox[{"Mesh", "\[Rule]", " ", "False"}]}], "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5884876724319334`*^9, 3.588487820210993*^9}, 
   3.5896342644259577`*^9}],

Cell["The spherical image of the part hyp of the hyperboloid is", "Text",
 CellChangeTimes->{{3.588393319929459*^9, 3.5883933833435707`*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"nhyp", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5883416562532268`*^9, 3.588341656255227*^9}, {
   3.5883416876340218`*^9, 3.588341775107025*^9}, 3.5883418201235995`*^9, 
   3.588392652560287*^9, {3.5883932721777754`*^9, 3.588393273675378*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"sph1", ",", " ", "%"}], "}"}], ",", " ", 
   RowBox[{"Axes", " ", "\[Rule]", " ", "None"}], ",", " ", 
   RowBox[{"Boxed", " ", "\[Rule]", " ", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.588487907992347*^9, 3.588487947772417*^9}}],

Cell[TextData[{
 "The area of the spherical image of a surface region is a measure  for the \
curvature of the surface in this region; it is called its",
 StyleBox[" integral curvature",
  FontColor->RGBColor[0, 0, 1]],
 ". For developable surfaces the integral curvature is zero since the \
spherical image is a point (in case of a plane) or a curve. "
}], "Text",
 CellChangeTimes->{{3.5883934642453127`*^9, 3.588393512823798*^9}, {
   3.5883935504978642`*^9, 3.5883936377488174`*^9}, {3.588393710195345*^9, 
   3.588393869144024*^9}, 3.5883939316533337`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Integrate"}]], "Input",
 CellChangeTimes->{{3.5883419502820444`*^9, 3.5883419756504955`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\!\(\*RowBox[{\\\"Integrate\\\", \\\"[\\\", RowBox[{StyleBox[\
\\\"f\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\"x\\\", \\\"TI\\\"]}], \\\"]\\\
\"}]\) gives the indefinite integral \!\(\*RowBox[{\\\"\[Integral]\\\", \
StyleBox[\\\"f\\\", \\\"TI\\\"], \\\" \\\", StyleBox[\\\"d\\\", \\\"TI\\\"], \
StyleBox[\\\"x\\\", \\\"TI\\\"]}]\). \\n\!\(\*RowBox[{\\\"Integrate\\\", \
\\\"[\\\", RowBox[{StyleBox[\\\"f\\\", \\\"TI\\\"], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{StyleBox[\\\"x\\\", \\\"TI\\\"], \\\",\\\", \
SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"min\\\", \
\\\"TI\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \
StyleBox[\\\"max\\\", \\\"TI\\\"]]}], \\\"}\\\"}]}], \\\"]\\\"}]\) gives the \
definite integral \!\(\*RowBox[{SubsuperscriptBox[\\\"\[Integral]\\\", \
SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"min\\\", \
\\\"TI\\\"]], SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \
StyleBox[\\\"max\\\", \\\"TI\\\"]]], \\\" \\\", StyleBox[\\\"f\\\", \
\\\"TI\\\"], \\\" \\\", StyleBox[\\\"d\\\", \\\"TI\\\"], StyleBox[\\\"x\\\", \
\\\"TI\\\"]}]\). \\n\!\(\*RowBox[{\\\"Integrate\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"f\\\", \\\"TI\\\"], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{StyleBox[\\\"x\\\", \\\"TI\\\"], \\\",\\\", \
SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"min\\\", \
\\\"TI\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \
StyleBox[\\\"max\\\", \\\"TI\\\"]]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\
\", RowBox[{StyleBox[\\\"y\\\", \\\"TI\\\"], \\\",\\\", \
SubscriptBox[StyleBox[\\\"y\\\", \\\"TI\\\"], StyleBox[\\\"min\\\", \
\\\"TI\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"y\\\", \\\"TI\\\"], \
StyleBox[\\\"max\\\", \\\"TI\\\"]]}], \\\"}\\\"}], \\\",\\\", StyleBox[\\\"\
\[Ellipsis]\\\", \\\"TR\\\"]}], \\\"]\\\"}]\) gives the multiple integral \
\!\(\*RowBox[{SubsuperscriptBox[\\\"\[Integral]\\\", SubscriptBox[StyleBox[\\\
\"x\\\", \\\"TI\\\"], StyleBox[\\\"min\\\", \\\"TI\\\"]], \
SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"max\\\", \
\\\"TI\\\"]]], RowBox[{StyleBox[\\\"d\\\", \\\"TI\\\"], StyleBox[\\\"x\\\", \
\\\"TI\\\"], RowBox[{SubsuperscriptBox[\\\"\[Integral]\\\", \
SubscriptBox[StyleBox[\\\"y\\\", \\\"TI\\\"], StyleBox[\\\"min\\\", \
\\\"TI\\\"]], SubscriptBox[StyleBox[\\\"y\\\", \\\"TI\\\"], \
StyleBox[\\\"max\\\", \\\"TI\\\"]]], RowBox[{StyleBox[\\\"d\\\", \\\"TI\\\"], \
\\\"\[InvisibleSpace]\\\", StyleBox[\\\"y\\\", \\\"TI\\\"], \\\" \\\", \\\"\
\[Ellipsis]\\\", \\\" \\\", StyleBox[\\\"f\\\", \\\"TI\\\"]}]}]}]}]\). \"\>", 
   "MSG"], "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Integrate"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.609823843893735*^9},
 CellTags->"Info3609831043-6425210"]
}, Closed]],

Cell["\<\
The integration of the area element of the spherical image nhyp[u,v] yields \
for the region hyp:\
\>", "Text",
 CellChangeTimes->{{3.588394687349861*^9, 3.5883947193611174`*^9}, {
  3.588394751699974*^9, 3.588394762619993*^9}, {3.588394847452942*^9, 
  3.588394860198165*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dA", "[", "nhyp", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.588342032832766*^9, 3.5883420805934973`*^9}, {
   3.5883422997950354`*^9, 3.588342314618883*^9}, 3.588394079635194*^9, {
   3.5883947964096527`*^9, 3.588394797220854*^9}, 3.614861852327527*^9, 
   3.614865446121439*^9}],

Cell[BoxData[
 RowBox[{"4", " ", "\[Pi]", " ", 
  SqrtBox[
   RowBox[{"Sech", "[", "4", "]"}]], " ", 
  RowBox[{"Sinh", "[", "2", "]"}]}]], "Output",
 CellChangeTimes->{3.588394821900097*^9, 3.609823883167981*^9, 
  3.6152106411503444`*^9, 3.6179518546150913`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.588342444491311*^9, 3.5883424563769913`*^9}}],

Cell[BoxData["8.721554642121092`"], "Output",
 CellChangeTimes->{3.588342457654064*^9, 3.5883948681073785`*^9, 
  3.6098238898403625`*^9, 3.6152106509471617`*^9, 3.617951858598319*^9}]
}, Closed]],

Cell["The area of the spherical image of the whole hyperboloid is", "Text",
 CellChangeTimes->{{3.588394955373932*^9, 3.5883949821591787`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"dA", "[", "nhyp", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "0", ",", 
       RowBox[{"2", "*", "Pi"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"v", ",", 
       RowBox[{"-", "x"}], ",", "x"}], "}"}]}], "]"}], ",", " ", 
   RowBox[{"x", "\[Rule]", " ", "Infinity"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5883426748503556`*^9, 3.5883427271728477`*^9}, 
   3.5883940826303988`*^9, {3.5883948978722305`*^9, 3.588394899385433*^9}, 
   3.614861852327527*^9, 3.614865446137039*^9}],

Cell[BoxData[
 RowBox[{"2", " ", 
  SqrtBox["2"], " ", "\[Pi]"}]], "Output",
 CellChangeTimes->{3.5883427332412577`*^9, 3.5883949033478403`*^9, 
  3.609823902121065*^9, 3.615210692708435*^9, 3.617951896151467*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.5883427886993556`*^9, 3.588342798730173*^9}}],

Cell[BoxData["8.885765876316732`"], "Output",
 CellChangeTimes->{3.5883428013977776`*^9, 3.588394924033477*^9, 
  3.609823910323534*^9, 3.6152107149384737`*^9, 3.6179519097132425`*^9}]
}, Closed]],

Cell["\<\
and this is less than the area 4\[DoubledPi] of the whole unit sphere.  \
Indeed, the spherical image is the region on the unit sphere between the two \
limit circles\
\>", "Text",
 CellChangeTimes->{{3.588395009084826*^9, 3.588395145163865*^9}, {
  3.588395195895154*^9, 3.5883951978139577`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{"nhyp", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{"v", "\[Rule]", " ", "Infinity"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.588342841177848*^9, 3.5883428656074905`*^9}, 
   3.58839265435429*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"Cos", "[", "u", "]"}], 
    SqrtBox["2"]], ",", 
   FractionBox[
    RowBox[{"Sin", "[", "u", "]"}], 
    SqrtBox["2"]], ",", 
   RowBox[{"-", 
    FractionBox["1", 
     SqrtBox["2"]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.588342870412299*^9, 3.588395157456687*^9, 
  3.5896340280544376`*^9, 3.6098239256544113`*^9, 3.6152107379797144`*^9, 
  3.617951921919941*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{"nhyp", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{"v", "\[Rule]", " ", 
    RowBox[{"-", "Infinity"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.588342841177848*^9, 3.5883428656074905`*^9}, 
   3.58839265435429*^9, {3.588395162370695*^9, 3.5883951674563046`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"Cos", "[", "u", "]"}], 
    SqrtBox["2"]], ",", 
   FractionBox[
    RowBox[{"Sin", "[", "u", "]"}], 
    SqrtBox["2"]], ",", 
   FractionBox["1", 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{3.588395168673106*^9, 3.589634033230734*^9, 
  3.609823929432627*^9, 3.615210742940523*^9, 3.6179519318005056`*^9}]
}, Closed]],

Cell["\<\
Since the area element of any surface by its definition always is  positive, \
the integral curvature is always non negative. For a finer consideration of \
the curvature the orientation of the spherical image has to be considered, \
and a finer integration on the surface must be introduced, namely the \
integration of alternating biforms.
As has been shown at the end  of subsection 1.4.1 we have the equation 
dA[sf][u,v] ==Det[{\[Sigma][1][sf][u,v], \[Sigma][2][sf][u,v]}]], and this is \
the strict coordinate of the biform 
\[Sigma][1][sf][u,v]\[And]\[Sigma][2][sf][u,v]. The left hand side of this \
equation is always positive, whereas the sign of the right side depends on \
the signs of the basic vectors and on their order. The ordered cobasis 
{\[Sigma][1][sf][u,v], \[Sigma][2][sf][u,v]}], or equivalently the ordered \
basis  {amf[1][sf][u,v], amf[2][sf][u,v]}] represents the orientation of the \
tangent planes; in the natural order this orientation is considered to be \
positive or counter clockwise. \
\>", "Text",
 CellChangeTimes->{{3.5883956383758087`*^9, 3.5883958423764772`*^9}, {
   3.588395877112464*^9, 3.5883959244321704`*^9}, {3.5884149596021376`*^9, 
   3.5884151284880342`*^9}, {3.5884152076581736`*^9, 
   3.5884152696526823`*^9}, {3.588415339525205*^9, 3.5884153419276094`*^9}, {
   3.5884154774918475`*^9, 3.588415512420309*^9}, {3.588415721613336*^9, 
   3.588415786285035*^9}, {3.588415925629005*^9, 3.5884159356215763`*^9}, {
   3.58841620247784*^9, 3.5884162121253915`*^9}, {3.5884162594771*^9, 
   3.588416445276727*^9}, {3.5884236681491313`*^9, 3.5884236686571603`*^9}, {
   3.588488086924661*^9, 3.5884880975326796`*^9}, {3.5884882789641457`*^9, 
   3.588488288460689*^9}, {3.58848868499737*^9, 3.5884886898446465`*^9}, 
   3.609823956908199*^9, 3.6098240272362213`*^9, {3.614861852405527*^9, 
   3.614861852483527*^9}, {3.6149177843389482`*^9, 3.6149177844169483`*^9}, 
   3.6152107773853836`*^9, {3.615210839067892*^9, 3.615210881359566*^9}, 
   3.6152644556048174`*^9}],

Cell["\<\
Consider the sequence of colors (Red, Green, Blue, Black) and the sequence of \
points in the parameter neighborhood of the point {0,0}:\
\>", "Text",
 CellChangeTimes->{{3.5884285649172106`*^9, 3.5884286217354603`*^9}, {
  3.5884286562264333`*^9, 3.5884287192820396`*^9}, {3.588488460204512*^9, 
  3.5884884633086896`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{".3", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", ".3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", ".3"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", ".3"}]}], "}"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.5884287354409637`*^9, 3.5884288748109355`*^9}, {
  3.589634138656764*^9, 3.589634151975526*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.3`", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.3`"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "0.3`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6098241369524965`*^9, 3.6152109200788345`*^9}]
}, Closed]],

Cell["\<\
Running on the hyperboloid through these points in the given order is a \
positive or counter clockwise turn:\
\>", "Text",
 CellChangeTimes->{{3.588428907825824*^9, 3.5884289947457952`*^9}, {
  3.588488794187615*^9, 3.5884888100045195`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"pt1", " ", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"hypsf", "[", 
        RowBox[{".3", ",", "0"}], "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5884290046673627`*^9, 3.5884291367649183`*^9}, 
   3.5884295120143814`*^9, 3.5884883695753284`*^9, 3.6148618524991274`*^9, 
   3.6149177844169483`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"pt2", " ", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Green", ",", 
      RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"hypsf", "[", 
        RowBox[{"0", ",", ".3"}], "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5884290046673627`*^9, 3.58842918871689*^9}, 
   3.5884295183647447`*^9, 3.5884883917355957`*^9, 3.614861852514727*^9, 
   3.614917784432548*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"pt3", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Blue", ",", 
      RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"hypsf", "[", 
        RowBox[{
         RowBox[{"-", ".3"}], ",", "0"}], "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5884290046673627`*^9, 3.5884292509564495`*^9}, 
   3.5884295237650537`*^9, 3.588488417024042*^9, 3.614861852514727*^9, 
   3.614917784432548*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"pt4", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Black", ",", 
      RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"hypsf", "[", 
        RowBox[{"0", ",", 
         RowBox[{"-", ".3"}]}], "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5884290046673627`*^9, 3.5884293145250854`*^9}, 
   3.5884295299654083`*^9, 3.588488430007785*^9, 3.614861852514727*^9, 
   3.614917784448148*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"hyp", ",", "pt1", ",", "pt2", ",", "pt3", ",", "pt4"}], "}"}], 
   ",", 
   RowBox[{"Axes", "\[Rule]", "None"}], ",", 
   RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.58842939432465*^9, 3.5884294656937323`*^9}}],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJyFm3dUFlfzx2kiCsQuxEICqIiKYsEGMje+tigW7D2JFQRfJYrYCyqCDQuo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    "], {
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[2], Opacity[
      0.6], EdgeForm[None], Specularity[
       GrayLevel[1], 3], 
      StyleBox[GraphicsGroup3DBox[Polygon3DBox[CompressedData["
1:eJxNm3n8llP+h+/nGWMYYx3GFlqkyNaqjRZk3yJZk+xkT6KioohQSUpKyb7v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         "]]],
       Lighting->{{"Ambient", 
          RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
         "Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{0, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{2, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}},
    VertexNormals->CompressedData["
1:eJxNW3c8l+/3JrKKikKiQSgqokHJkwilKEpSVoSmlEo0KCOEShkZqYTKjoR6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     "]], 
   {RGBColor[1, 0, 0], PointSize[0.02], 
    Point3DBox[{0.955336489125606, 0.29552020666133955`, 0}]}, 
   {RGBColor[0, 1, 0], PointSize[0.02], 
    Point3DBox[{1.0453385141288605`, 0., 0.3045202934471426}]}, 
   {RGBColor[0, 0, 1], PointSize[0.02], 
    Point3DBox[{0.955336489125606, -0.29552020666133955`, 0}]}, 
   {GrayLevel[0], PointSize[0.02], 
    Point3DBox[{1.0453385141288605`, 0., -0.3045202934471426}]}},
  AutomaticImageSize->True,
  Axes->None,
  Boxed->False,
  DisplayFunction->Identity,
  FaceGridsStyle->Automatic,
  ImageSize->{407.1099311549699, 378.31894122200987`},
  Method->{},
  PlotRange->{{-3.7621946548379537`, 
   3.762194654837575}, {-3.7621946548378586`, 
   3.7621946548378586`}, {-3.626859332934112, 3.626859332934112}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, Automatic, Automatic},
  ViewPoint->{2.709194624050039, -1.2012119943940276`, 1.6332036717881484`},
  ViewVertical->{0.31631513998353933`, 0.28055155392842895`, 
   0.9400358634884747}]], "Output",
 CellChangeTimes->{3.615210951528489*^9}]
}, Closed]],

Cell["Now we consider the spherical images of these points:", "Text",
 CellChangeTimes->{{3.588488839700218*^9, 3.5884888813005977`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"arr1", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"nhyp", "[", 
          RowBox[{"0.3", ",", "0"}], "]"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.588427392477151*^9, 3.5884274494664106`*^9}, {
   3.5884275184193544`*^9, 3.5884275979879055`*^9}, {3.588427688125061*^9, 
   3.5884276984686527`*^9}, {3.588427772996915*^9, 3.58842777378096*^9}, {
   3.5884280016129913`*^9, 3.5884280146927395`*^9}, {3.5884280699088974`*^9, 
   3.5884280748041773`*^9}, 3.588429567725568*^9, 3.588488547303494*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"arr2", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Green", ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"nhyp", "[", 
          RowBox[{"0", ",", "0.3"}], "]"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.588427392477151*^9, 3.5884274494664106`*^9}, {
   3.5884275184193544`*^9, 3.5884275979879055`*^9}, {3.588427688125061*^9, 
   3.5884276984686527`*^9}, {3.588427772996915*^9, 3.58842777378096*^9}, {
   3.5884280016129913`*^9, 3.5884280146927395`*^9}, {3.5884280699088974`*^9, 
   3.588428119556737*^9}, 3.588429575366005*^9, 3.5884885668076096`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"arr3", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Blue", ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"nhyp", "[", 
          RowBox[{
           RowBox[{"-", ".3"}], ",", "0"}], "]"}]}], "}"}], "]"}]}], "}"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.588427392477151*^9, 3.5884274494664106`*^9}, {
   3.5884275184193544`*^9, 3.5884275979879055`*^9}, {3.588427688125061*^9, 
   3.5884276984686527`*^9}, {3.588427772996915*^9, 3.58842777378096*^9}, {
   3.5884280016129913`*^9, 3.5884280146927395`*^9}, {3.5884280699088974`*^9, 
   3.5884281805252247`*^9}, {3.5884282118210144`*^9, 3.588428289323447*^9}, 
   3.588429582853433*^9, 3.5884885870717688`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"arr4", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Black", ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"nhyp", "[", 
          RowBox[{"0", ",", 
           RowBox[{"-", ".3"}]}], "]"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.588427392477151*^9, 3.5884274494664106`*^9}, {
   3.5884275184193544`*^9, 3.5884275979879055`*^9}, {3.588427688125061*^9, 
   3.5884276984686527`*^9}, {3.588427772996915*^9, 3.58842777378096*^9}, {
   3.5884280016129913`*^9, 3.5884280146927395`*^9}, {3.5884280699088974`*^9, 
   3.5884281805252247`*^9}, {3.5884282118210144`*^9, 3.5884283493828826`*^9}, 
   3.588429589597819*^9, 3.588488601991622*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"sph1", ",", "arr1", ",", "arr2", ",", "arr3", ",", "arr4"}], 
    "}"}], ",", " ", 
   RowBox[{"Axes", "\[Rule]", " ", "None"}], ",", " ", 
   RowBox[{"Boxed", " ", "\[Rule]", " ", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5884283602025013`*^9, 3.588428386155986*^9}, {
  3.5884886535505705`*^9, 3.5884886580278273`*^9}, {3.5884889416150475`*^9, 
  3.588488975566989*^9}}],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJx1m3lcz9n3x0N+Zsg6Y5kxDYVkkCWylE4MQtayi6HQNikMRihkq+zMhIhk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    "], {
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[2], Opacity[
      0.4], EdgeForm[None], Specularity[
       GrayLevel[1], 3], 
      StyleBox[GraphicsGroup3DBox[Polygon3DBox[CompressedData["
1:eJxNm3f819Mexz/fYxMapCTtQUpLE/0KmaWhIdGyqTSISoNkZ5P2kNIgWRk3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         "]]],
       Lighting->{{"Ambient", 
          RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
         "Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{0, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{2, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}},
    VertexNormals->CompressedData["
1:eJx1W2lYT93bbUJ5VGgwRCFkDEkifseQJBRlDJVSoVGpkBQhDSJEac5QSEil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     "]], 
   {RGBColor[1, 0, 0], 
    Arrow3DBox[{{0, 0, 0}, {0.955336489125606, 0.29552020666133955`, 0}}]}, 
   {RGBColor[0, 1, 0], 
    Arrow3DBox[{{0, 0, 0}, {0.9600913205580516, 0., -0.2796867107838638}}]}, 
   {RGBColor[0, 0, 1], 
    Arrow3DBox[{{0, 0, 0}, {0.955336489125606, -0.29552020666133955`, 0}}]}, 
   {GrayLevel[0], 
    Arrow3DBox[{{0, 0, 0}, {0.9600913205580516, 0., 0.2796867107838638}}]}},
  AutomaticImageSize->True,
  Axes->None,
  Boxed->False,
  DisplayFunction->Identity,
  FaceGridsStyle->Automatic,
  ImageSize->{369.40208598653146`, 370.23333965559044`},
  Method->{},
  PlotRange->{{-1., 0.9999999999998993}, {-0.9999999999999748, 
   0.9999999999999748}, {-0.9999999999999748, 0.9999999999999748}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, Automatic, Automatic},
  ViewPoint->{3.365253503659903, -0.1259635342426063, 0.33045732575607367`},
  ViewVertical->{0.5269567602826974, 0.29328717721087855`, 
   0.7976836493723889}]], "Output",
 CellChangeTimes->{3.615211029232226*^9}]
}, Closed]],

Cell["\<\
The order of the colors  (Red, Green, Blue, Black)  shows that the sequence \
of the corresponding arrows induce the clockwise, i. e. negative, orientation \
on the unit sphere:  in case of the hyperboloid the Gauss map inverses the \
natural orientations. The reason is that the curvature of the hyperboloid is \
negative, as we shall see now.
The space of alternating biforms on a two-dimensional vector space is \
one-dimensional; the strict coordinate \[CapitalOmega][[1,2]] of the biform \
\[CapitalOmega] serves as a Cartesian coordinate. The integral of the biform \
\[CapitalOmega] is defined to be\
\>", "Text",
 CellChangeTimes->{{3.5884893334124565`*^9, 3.5884893557247334`*^9}, {
  3.588489422220536*^9, 3.5884897365085125`*^9}, {3.588489801484229*^9, 
  3.588489872100268*^9}, {3.5884899097884235`*^9, 3.588489962276426*^9}, {
  3.5884900049308653`*^9, 3.588490046281231*^9}, {3.588490080052162*^9, 
  3.5884900844844155`*^9}, {3.5884901378524685`*^9, 3.5884902140368257`*^9}, {
  3.5884995387898827`*^9, 3.588499554920311*^9}, {3.615211108371165*^9, 
  3.615211113316374*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Integral]", "\[CapitalOmega]"}], " ", ":=", " ", 
  RowBox[{"\[Integral]", 
   RowBox[{
    RowBox[{"\[CapitalOmega]", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}], " ", 
    RowBox[{
     RowBox[{"\[Sigma]", "[", "1", "]"}], "\[Wedge]", 
     RowBox[{"\[Sigma]", "[", "2", "]"}]}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{3.588500380185361*^9}],

Cell["\<\
As in any 1-dimensional vector spaces the ratio of two elements can be \
defined as the ratio of its coordinates with respect to an arbitrary basis, \
e.g.  we have .\
\>", "Text",
 CellChangeTimes->{
  3.5884998191067753`*^9, {3.5884998502368298`*^9, 3.5884999423861914`*^9}, {
   3.588500051430383*^9, 3.588500125826914*^9}, 3.6098243018919306`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalOmega]", " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{"\[CapitalOmega]", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}], " ", 
    RowBox[{
     RowBox[{"\[Sigma]", "[", "1", "]"}], "\[Wedge]", 
     RowBox[{"\[Sigma]", "[", "2", "]"}]}]}]}], ",", " ", 
  RowBox[{
   RowBox[{"or", "  ", 
    RowBox[{"\[CapitalOmega]", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}]}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{"\[CapitalOmega]", "/", 
     RowBox[{"\[Sigma]", "[", "1", "]"}]}], "\[Wedge]", 
    RowBox[{"\[Sigma]", "[", "2", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.5885001751074004`*^9, 3.5885002704079676`*^9}, 
   3.5885003734305487`*^9}],

Cell["\<\
Since dA = \[Sigma][1]\[Wedge]\[Sigma][2]   the integral can be written as a \
surface integral over the ratio, which is a function on the surface\
\>", "Text",
 CellChangeTimes->{{3.5885013705531*^9, 3.5885014825768967`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[Integral]", "\[CapitalOmega]"}], "=", 
   RowBox[{
    RowBox[{"\[Integral]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[CapitalOmega]", "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Sigma]", "[", "1", "]"}], "\[Wedge]", 
          RowBox[{"\[Sigma]", "[", "2", "]"}]}], ")"}]}], ")"}], 
      RowBox[{
       RowBox[{"\[Sigma]", "[", "1", "]"}], "\[Wedge]", 
       RowBox[{"\[Sigma]", "[", "2", "]"}]}]}]}], "  ", "=", " ", 
    RowBox[{"\[Integral]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[CapitalOmega]", "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Sigma]", "[", "1", "]"}], "\[Wedge]", 
          RowBox[{"\[Sigma]", "[", "2", "]"}]}], ")"}]}], ")"}], "dA"}]}]}]}],
   TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{
  3.5885011117954454`*^9, {3.588501145444705*^9, 3.5885011624331346`*^9}, {
   3.588501272460128*^9, 3.588501317419407*^9}}],

Cell[TextData[{
 "Now we apply this to the oriented area element of the spherical image \
amf[3][sf][u,v]. By the third derivation equation this area element is   \
\[CapitalOmega] = \[Omega][1] ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Wedge]", " "}], TraditionalForm]]],
 "\[Omega][2]. The ratio"
}], "Text",
 CellChangeTimes->{{3.5885016075799165`*^9, 3.5885016542863984`*^9}, {
   3.588501705220488*^9, 3.5885019030600357`*^9}, {3.5896350200141745`*^9, 
   3.589635126429261*^9}, 3.6148618526083274`*^9, 3.6149177845261483`*^9, {
   3.615211292326688*^9, 3.615211294042691*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"gauss", "[", "ff_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Omega]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Omega]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}], "/", 
   RowBox[{
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5885019269280777`*^9, 3.5885021178568125`*^9}, {
  3.588502172800109*^9, 3.5885022401922274`*^9}, {3.609673711884263*^9, 
  3.609673712924323*^9}},
 CellTags->"gaussK"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"gauss", "::", "usage"}], " ", "=", " ", 
   "\"\<gauss[f][u,v] is the Gaussian curvature of the surface f[u,v].\>\""}],
   ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6152113763484354`*^9, 3.615211448826163*^9}, {
   3.615211504674261*^9, 3.6152115152822795`*^9}, 3.61521155540555*^9}],

Cell[TextData[{
 "Is named the ",
 StyleBox["Gaussian curvature",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface at the point  ff[u,v].  Remark that the Gaussian curvature \
doesn\[CloseCurlyQuote]t depend on the orientation of the surface: A change \
of the orientation would cause the change of signs of the numerator and the \
denominator in the same way.\nWe will calculate it for our example:"
}], "Text",
 CellChangeTimes->{{3.5885022915319176`*^9, 3.588502353635627*^9}, {
   3.5896344813413644`*^9, 3.5896344946851273`*^9}, {3.5896352910086946`*^9, 
   3.589635419818121*^9}, 3.615264508027816*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"gauss", "[", "hypsf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5885023564748316`*^9, 3.588502394772899*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  SuperscriptBox[
   RowBox[{"Sech", "[", 
    RowBox[{"2", " ", "v"}], "]"}], "2"]}]], "Output",
 CellChangeTimes->{3.5885023972533035`*^9, 3.589634522789735*^9, 
  3.5973300559479504`*^9, 3.5973319731496077`*^9, 3.6098244008405905`*^9, 
  3.6152115777759895`*^9, 3.6179542136430197`*^9}]
}, Closed]],

Cell["\<\
Remember Sech[x] == 1/Cosh[x].  Since hypsf is a surface of revolution the \
Gaussian curvature does not depend on u.  It reflects very well the visual \
impression of the curvature of the hyperboloid:\
\>", "Text",
 CellChangeTimes->{{3.588502593392448*^9, 3.58850274255991*^9}, 
   3.615264540124651*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     RowBox[{"Sech", "[", 
      RowBox[{"2", " ", "v"}], "]"}], "^", "2"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5884250453039*^9, 3.5884250954547687`*^9}, 
   3.588425134172983*^9, 3.588502546139965*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV1nk01P0XB3CptGiRSlkiqqkeQraiuG2PqJAwQzFZQrLEU9mSDFFaEFnK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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{0, 2}, {-0.9999999999999933, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.5884250967188406`*^9, 3.588425138067206*^9, 
  3.588502550882373*^9, 3.589634541163786*^9, 3.6098244322113843`*^9, 
  3.615211620941265*^9}]
}, Closed]],

Cell["\<\
Mathematica also calculates the Gaussian curvature for a general surface:\
\>", "Text",
 CellChangeTimes->{{3.588502870776535*^9, 3.5885029205094223`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"gauss", "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.588502749330322*^9, 3.5885027917311964`*^9}, {
  3.609825995110777*^9, 3.609825999670038*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "3"]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "3"]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "3"]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "3"]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "3"]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "3"]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}], "-", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}], "-", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}], "-", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], ")"}], 
        RowBox[{"3", "/", "2"}]]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}], "-", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}], "-", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}], "-", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], ")"}], 
        RowBox[{"3", "/", "2"}]]}], ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"\[Sqrt]", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.6098259872963305`*^9, 3.6098260205972347`*^9, 
  3.609850308595493*^9, 3.615211703949011*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6098262724436398`*^9, 3.6098262802690873`*^9}, {
   3.6098268413811812`*^9, 3.6098268828225517`*^9}, 3.6098309235986705`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], "-", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"2", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"2", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"2", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], "-", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"2", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], "-", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"2", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"2", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"2", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], "-", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"2", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], "-", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"2", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"2", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"2", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], "-", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"2", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"2", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"2", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], "-", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"2", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "2"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"2", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "2"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"2", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "2"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"2", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "2"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"2", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], "2"], "-", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "-", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "-", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], "-", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "2"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"2", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}], "-", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "2"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"2", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}], "-", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "2"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"2", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}]}], ")"}], "/", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}], 
   "2"]}]], "Output",
 CellChangeTimes->{3.6098268333997245`*^9, 3.6098309132800803`*^9, 
  3.6098557502126503`*^9}]
}, Closed]],

Cell["\<\
after waiting 59 min for a result.  We shall give simpler expression for the \
Gaussian curvature later.\
\>", "Text",
 CellChangeTimes->{{3.6098309366054144`*^9, 3.6098310648917522`*^9}, 
   3.615211712373026*^9}],

Cell[TextData[{
 "We define the ",
 StyleBox["curvature integral ",
  FontColor->RGBColor[0, 0, 1]],
 "as the integral of K(u,v)*dA[sf][u,v]  (K[u,v]== Gaussian Curvature); for \
surfaces with K(u,v)\[NotEqual]0  it coincides up to sign with the integral \
curvature. "
}], "Text",
 CellChangeTimes->{{3.588502989586344*^9, 3.5885031522946296`*^9}, {
   3.588503185959489*^9, 3.5885032187663465`*^9}, {3.6098311102523465`*^9, 
   3.6098311450603375`*^9}, 3.615264590355524*^9, {3.617954311481616*^9, 
   3.6179544126024*^9}}],

Cell["\<\
The Gaussian curvature of any developable surface is zero. Examples:\
\>", "Text",
 CellChangeTimes->{{3.5885081700865965`*^9, 3.5885082334071083`*^9}, 
   3.588508375289357*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "plane"}]], "Input",
 CellChangeTimes->{{3.5899584114106817`*^9, 3.589958414279846*^9}, {
  3.615211799577179*^9, 3.615211819997615*^9}}],

Cell[BoxData[
 StyleBox["\<\"{u,v}->plane[a1,a2,b1,b2,c1,c2][u,v] is a parametrization of a \
plane in R^3.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.615211821136417*^9},
 CellTags->"Info3615219021-6377691"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"pl", "[", 
   RowBox[{"u_", ",", "v_"}], " ", "]"}], "=", " ", 
  RowBox[{
   RowBox[{"plane", "[", 
    RowBox[{"1", ",", "0", ",", "0", ",", "1", ",", "0", ",", "0"}], "]"}], 
   "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5899581112285123`*^9, 3.589958113401637*^9}, {
   3.5899581556930556`*^9, 3.5899582483363543`*^9}, {3.589958278543082*^9, 
   3.589958359030686*^9}, 3.6148618527175274`*^9, 3.614862652983333*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"u", ",", "v", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5899582499984493`*^9, {3.5899582852784677`*^9, 3.589958328573944*^9}, 
   3.5899583611578074`*^9, 3.609831174458019*^9, 3.6152117851003537`*^9, 
   3.6179545297390995`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"gauss", "[", "pl", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.589958375121606*^9, 3.589958385221184*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.589958386345248*^9, 3.60983117448602*^9, 3.6152118317756357`*^9, {
   3.617954520366563*^9, 3.6179545333483057`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"gauss", "[", 
    RowBox[{"tangsf", "[", "curve", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.588502749330322*^9, 3.5885027917311964`*^9}, {
  3.5885080347251587`*^9, 3.588508057048798*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5885081252677183`*^9, 3.589635559297966*^9, 
  3.609831188061797*^9, 3.615211869574502*^9, 3.617954573384596*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"gauss", "[", 
    RowBox[{"conesf", "[", "y", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.588502749330322*^9, 3.5885027917311964`*^9}, {
   3.5885080347251587`*^9, 3.588508057048798*^9}, 3.5885082818295927`*^9, {
   3.588508346647707*^9, 3.588508358332127*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.588508363308536*^9, 3.5896355667859793`*^9, 
  3.6098311983233843`*^9, 3.615211909619772*^9, 3.617954624247505*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"gauss", "[", 
    RowBox[{"cylindersf", "[", 
     RowBox[{"c", ",", "y"}], "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.588502749330322*^9, 3.5885027917311964`*^9}, {
   3.5885080347251587`*^9, 3.588508057048798*^9}, 3.5885082818295927`*^9, {
   3.588508346647707*^9, 3.5885083677857437`*^9}, {3.5885084318706565`*^9, 
   3.588508443430277*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.588508445848281*^9, 3.5896355726515894`*^9, 
  3.609831198377387*^9, 3.615211916998585*^9, 3.6179546324049716`*^9}]
}, Closed]],

Cell[TextData[{
 "The Gaussian curvature of a sphere of radius r equals ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    SuperscriptBox["r", "2"]], TraditionalForm]]],
 ":"
}], "Text",
 CellChangeTimes->{{3.5885086629246006`*^9, 3.588508697213562*^9}, {
   3.588508729758423*^9, 3.5885088016285343`*^9}, 3.615264594986789*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"gauss", "[", 
    RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.588502749330322*^9, 3.5885027917311964`*^9}, {
   3.5885080347251587`*^9, 3.588508057048798*^9}, 3.5885082818295927`*^9, {
   3.588508346647707*^9, 3.5885083677857437`*^9}, {3.5885084318706565`*^9, 
   3.588508443430277*^9}, {3.5885088284560685`*^9, 3.5885088477761736`*^9}}],

Cell[BoxData[
 FractionBox["1", 
  SuperscriptBox["r", "2"]]], "Output",
 CellChangeTimes->{3.588508849861293*^9, 3.5896355810912046`*^9, 
  3.6098311991364307`*^9, 3.6152119251261997`*^9, 3.617954640912458*^9}]
}, Closed]],

Cell["\<\
Clearly, for the unit sphere the Gauss map is the identity; it is orientation \
preserving, and the Gaussian curvature is positive.\
\>", "Text",
 CellChangeTimes->{{3.5885090527488976`*^9, 3.5885091182126417`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["2.2.2. Theorema Egregium", "Subsubsection",
 CellChangeTimes->{{3.5897791459451184`*^9, 3.5897791554299345`*^9}, {
   3.589779201169215*^9, 3.5897792115588336`*^9}, 3.609831296628007*^9, 
   3.6112105016421847`*^9, 3.6152119829399014`*^9, 3.615212872250663*^9, 
   3.6179564158099766`*^9, 3.617965383514293*^9}],

Cell["\<\
The Gaussian curvature has been defined by the normal vector and the \
spherical image  of the surface. This is a construction using the embedding \
of the surface into the Euclidean space. It is an surprising result, found by \
Gauss in the year 1816,  that this curvature doesn\[CloseCurlyQuote]t depend \
on the embedding but on the metric of the surface only. Gauss named this \
result the\
\>", "Text",
 CellChangeTimes->{{3.589779294238979*^9, 3.589779629748768*^9}, {
   3.589780134955655*^9, 3.5897801705861177`*^9}, {3.5898648454159813`*^9, 
   3.589864846336383*^9}, 3.589864883526848*^9}],

Cell[TextData[{
 StyleBox["Theorema egregium",
  FontColor->RGBColor[0, 0, 1]],
 ". If F[sf[u,v]] = sh[f[u,v]] is an isometry then the Gaussian curvatures at \
corresponding points coincide:"
}], "Text",
 CellChangeTimes->{{3.589779644319194*^9, 3.5897796537572103`*^9}, {
  3.58977983591873*^9, 3.589779957817344*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"gauss", "[", 
    RowBox[{"sh", "[", "f", "]"}], "]"}], "[", 
   RowBox[{"u", ",", " ", "v"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"gauss", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.589779962700153*^9, 3.5897800217150564`*^9}, {
  3.61795650503608*^9, 3.6179565144676194`*^9}, {3.6179565867477536`*^9, 
  3.6179565931711206`*^9}}],

Cell[TextData[{
 StyleBox["Proof",
  FontColor->RGBColor[0, 0, 1]],
 ".  In subsection 1.4.1, 2. we expressed the first fundamental form as the \
sum of the squares of the basis forms \[Sigma][1], \[Sigma][2]. Therefore it \
suffices to show that the Gaussian curvature may be expressed through these \
basis forms and their exterior derivatives. From the last integrability \
condition ",
 ButtonBox["1.5.1",
  BaseStyle->"Hyperlink",
  ButtonData->"intcond"],
 " it follows"
}], "Text",
 CellChangeTimes->{{3.5897802415506425`*^9, 3.589780247556653*^9}, {
   3.589781031988431*^9, 3.5897811125001726`*^9}, {3.589781144308628*^9, 
   3.5897811764446845`*^9}, {3.5897813023213053`*^9, 3.589781390586261*^9}, {
   3.5898649435557537`*^9, 3.589864944928556*^9}, {3.589865042054326*^9, 
   3.589865062708763*^9}, {3.589865161098136*^9, 3.589865165263343*^9}, {
   3.5898652061666145`*^9, 3.589865238209071*^9}, 3.589868621090613*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"gauss", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", "+", 
     RowBox[{
      RowBox[{
       RowBox[{"dd", "[", 
        RowBox[{
         RowBox[{"\[Omega]", "[", "3", "]"}], "[", "sf", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "/", 
      RowBox[{
       RowBox[{"extprod", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], ")"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", " ", "Reals"}], ",", " ", 
     RowBox[{"v", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5898653290948305`*^9, 3.5898654271098027`*^9}, {
   3.589865496529925*^9, 3.5898655792100697`*^9}, 3.589865737519148*^9, {
   3.5898682853312235`*^9, 3.589868290292032*^9}, {3.5898683717241745`*^9, 
   3.589868393626613*^9}, {3.58986851160962*^9, 3.5898685574737015`*^9}, 
   3.6096737157884865`*^9, 3.6099111290994644`*^9, 3.609911671609494*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5898683096984663`*^9, 3.589868403891431*^9, 
  3.589868570312524*^9, 3.6098340114114246`*^9, 3.6099116559826*^9, 
  3.6099117050344057`*^9, 3.611208501652792*^9, 3.6152121688298273`*^9, 
  3.617956698443142*^9}]
}, Closed]],

Cell["\<\
Thus it suffices to show that  \[Omega][3] may be expressed by \[Sigma][1], \
\[Sigma][2]. This follows from the first two integrability conditions. \
Indeed, inserting for the basis representation of  \[Omega][3]:\
\>", "Text",
 CellChangeTimes->{{3.589865870649782*^9, 3.589866048770895*^9}, {
   3.589866265190075*^9, 3.589866267186878*^9}, 3.6152646117317467`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Omega]", "[", "3", "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"cg", "[", "1", "]"}], "*", 
    RowBox[{"\[Sigma]", "[", "1", "]"}]}], " ", "+", "  ", 
   RowBox[{
    RowBox[{"cg", "[", "2", "]"}], "*", 
    RowBox[{"\[Sigma]", "[", "2", "]"}], " "}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.589866097895381*^9, 3.589866168033104*^9}, {
  3.6179744737467556`*^9, 3.6179744768909354`*^9}}],

Cell[TextData[{
 "into the integrability conditions we obtain the formulas ",
 ButtonBox["[B-R]",
  BaseStyle->"Hyperlink",
  ButtonData->"B-R"],
 ", (46.5-8)"
}], "Text",
 CellChangeTimes->{{3.5898662781068974`*^9, 3.589866329103387*^9}, {
  3.5898673198299274`*^9, 3.5898673426683674`*^9}, {3.589867391465253*^9, 
  3.589867431931724*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cg", "[", "1", "]"}], "[", "ff_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"dd", "[", 
     RowBox[{
      RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "ff", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "/", 
   RowBox[{
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5898663353121977`*^9, 3.5898664498007994`*^9}, {
   3.589866942293664*^9, 3.5898669583616924`*^9}, {3.5898669907161493`*^9, 
   3.589867004756174*^9}, 3.5898681119369183`*^9, {3.5898682177831044`*^9, 
   3.589868228796724*^9}, 3.6096737250530167`*^9, 3.6179744789150515`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cg", "[", "2", "]"}], "[", "ff_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"dd", "[", 
     RowBox[{
      RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "ff", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "/", 
   RowBox[{
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.589866492544874*^9, 3.5898665075833006`*^9}, {
   3.589866902544794*^9, 3.5898669300476427`*^9}, 3.5898689735732317`*^9, {
   3.589869375273937*^9, 3.58986938255915*^9}, 3.609911786091042*^9, 
   3.609911905885894*^9, 3.6179744802981305`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"cg", "::", "usage"}], "=", " ", 
  "\"\<cg[i][f][u,v], i = 1,2, are the coefficients in the decomposition of \
\[Omega][3][f][u,v] with respect to the cobasis \
{\[Sigma][i][f][u,v]}.\>\""}]], "Input",
 CellChangeTimes->{{3.6179750758591948`*^9, 3.617975187419575*^9}, {
   3.6179752579396086`*^9, 3.617975284484127*^9}, 3.6179754698357286`*^9, 
   3.617976052148035*^9, {3.6179762354295177`*^9, 3.6179763154430943`*^9}, 
   3.617976361330719*^9}],

Cell["and this shows", "Text",
 CellChangeTimes->{{3.5898665879858418`*^9, 3.589866602790268*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Omega]", "[", "3", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", "-", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"cg", "[", "1", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "*", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], " ", "-", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"cg", "[", "2", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "*", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", " ", "Reals"}], ",", " ", 
     RowBox[{"v", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.589866608874278*^9, 3.5898667830485845`*^9}, {
   3.589867075549098*^9, 3.5898671069051533`*^9}, {3.5898676092260356`*^9, 
   3.5898676576329203`*^9}, {3.589869404633189*^9, 3.5898694693577027`*^9}, 
   3.609911828578472*^9, {3.617974482131235*^9, 3.6179744835703173`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.589866791488199*^9, 3.5898670346458263`*^9, 
  3.5898671133479643`*^9, 3.589867660160125*^9, 3.589868722537591*^9, 
  3.589868984789652*^9, 3.5898693936039696`*^9, 3.589869475628914*^9, 
  3.6099119937009163`*^9, 3.611208613588194*^9, 3.6152123512409477`*^9, 
  3.6179573178875723`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"dd", "[", 
        RowBox[{
         RowBox[{"\[Omega]", "[", "3", "]"}], "[", "sf", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "/", 
      RowBox[{
       RowBox[{"extprod", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "+", " ", 
     RowBox[{
      RowBox[{"gauss", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "\[Element]", " ", "Reals"}], ",", " ", 
      RowBox[{"v", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}], 
  " "}]], "Input",
 CellChangeTimes->{
  3.589893961196463*^9, 3.6179587350616302`*^9, {3.617958812949085*^9, 
   3.617958909461605*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.589893970150879*^9, 3.611208996426091*^9, 
  3.617958705963966*^9, 3.6179589666238747`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"gauss", "[", "hypsf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", "\[Equal]", " ", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       RowBox[{"dd", "[", 
        RowBox[{
         RowBox[{"\[Omega]", "[", "3", "]"}], "[", "hypsf", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "/", 
     RowBox[{
      RowBox[{"extprod", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "hypsf", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "hypsf", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", " ", "Reals"}], ",", " ", 
     RowBox[{"v", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.5898707934412284`*^9, {3.5898708344381003`*^9, 3.5898708579785414`*^9}, {
   3.5898940993971057`*^9, 3.5898941417199802`*^9}, 3.609911786284053*^9, 
   3.6099119062469144`*^9, {3.617964848782708*^9, 3.617964872742079*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.6179648750162086`*^9}]
}, Closed]],

Cell[TextData[{
 "In the next cell the  exterior differential is not evaluated since the form \
has not the required shape,\n",
 StyleBox["Example.",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.5898948034575424`*^9, 3.589894888103291*^9}, {
   3.589894946556594*^9, 3.5898949593954163`*^9}, {3.6112105679579773`*^9, 
   3.61121057848958*^9}, 3.615264617043051*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"gauss", "[", "hypsf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", "\[Equal]", " ", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"dd", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"cg", "[", "1", "]"}], "[", "hypsf", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "*", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "hypsf", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"cg", "[", "2", "]"}], "[", "hypsf", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "*", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "hypsf", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}]}], "]"}]}], "/", 
     RowBox[{
      RowBox[{"extprod", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "hypsf", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "hypsf", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", " ", "Reals"}], ",", " ", 
     RowBox[{"v", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.5898707934412284`*^9, {3.5898708344381003`*^9, 3.5898708579785414`*^9}, 
   3.5898940592114353`*^9, 3.609911786460063*^9, 3.609911906411924*^9, {
   3.617964938630847*^9, 3.6179649565028696`*^9}, {3.61797448518841*^9, 
   3.6179744866124916`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"Cosh", "[", 
     RowBox[{"2", " ", "v"}], "]"}], 
    RowBox[{"3", "/", "2"}]], " ", 
   RowBox[{"dd", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Sinh", "[", "v", "]"}], 
        SqrtBox[
         RowBox[{"Cosh", "[", 
          RowBox[{"2", " ", "v"}], "]"}]]]}], ",", "0"}], "}"}], "]"}], " ", 
   RowBox[{"Sech", "[", "v", "]"}]}], "\[Equal]", "1"}]], "Output",
 CellChangeTimes->{3.589894769106282*^9, 3.6112101142450266`*^9, 
  3.615212698060757*^9, 3.6179649250170684`*^9, 3.6179649599810686`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", " ", "Reals"}], ",", " ", 
     RowBox[{"v", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5898696428144073`*^9, 3.589869668273652*^9}, {
   3.5898697017045107`*^9, 3.589869703092913*^9}, {3.5898697499865956`*^9, 
   3.589869777146243*^9}, {3.5898698277995324`*^9, 3.5898698602631893`*^9}, 
   3.5898700446243134`*^9, {3.5898700755903673`*^9, 3.5898700919703965`*^9}, {
   3.589870131500866*^9, 3.589870151484501*^9}, {3.5898702559422846`*^9, 
   3.5898702595770903`*^9}, 3.589870338404029*^9, {3.589870368465282*^9, 
   3.5898704075121503`*^9}, 3.589870464873451*^9, {3.5898705796740527`*^9, 
   3.589870626879736*^9}, 3.5898707377647305`*^9, 3.5898708705053635`*^9, {
   3.61121026378858*^9, 3.611210293877301*^9}, 3.6112103255881147`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"Cosh", "[", 
     RowBox[{"2", " ", "v"}], "]"}], 
    RowBox[{"3", "/", "2"}]], " ", 
   RowBox[{"dd", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Sinh", "[", "v", "]"}], 
        SqrtBox[
         RowBox[{"Cosh", "[", 
          RowBox[{"2", " ", "v"}], "]"}]]]}], ",", "0"}], "}"}], "]"}], " ", 
   RowBox[{"Sech", "[", "v", "]"}]}], "\[Equal]", "1"}]], "Output",
 CellChangeTimes->{3.61121012217148*^9, 3.611210301502737*^9, 
  3.6152127074207735`*^9, 3.6179649149144907`*^9, 3.61796500319254*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"Cosh", "[", 
     RowBox[{"2", " ", "v"}], "]"}], 
    RowBox[{"3", "/", "2"}]], " ", 
   RowBox[{"dd", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SqrtBox[
         RowBox[{"Sech", "[", 
          RowBox[{"2", " ", "v"}], "]"}]]}], " ", 
       RowBox[{"Sinh", "[", "v", "]"}]}], ",", "0"}], "}"}], "]"}], " ", 
   RowBox[{"Sech", "[", "v", "]"}]}], "\[Equal]", "1"}]], "Input",
 CellChangeTimes->{{3.5899563725630665`*^9, 3.5899563808245387`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"Cosh", "[", 
     RowBox[{"2", " ", "v"}], "]"}], 
    RowBox[{"3", "/", "2"}]], " ", 
   RowBox[{"dd", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SqrtBox[
         RowBox[{"Sech", "[", 
          RowBox[{"2", " ", "v"}], "]"}]]}], " ", 
       RowBox[{"Sinh", "[", "v", "]"}]}], ",", "0"}], "}"}], "]"}], " ", 
   RowBox[{"Sech", "[", "v", "]"}]}], "\[Equal]", "1"}]], "Output",
 CellChangeTimes->{3.6112103567558975`*^9}]
}, Closed]],

Cell["\<\
Now we define the differential form corresponding to the unevaluated by dd \
expression:\
\>", "Text",
 CellChangeTimes->{{3.5899566907632666`*^9, 3.5899567449393654`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"w1", "[", 
   RowBox[{"u_", ",", " ", "v_"}], "]"}], " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"-", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"Sech", "[", 
         RowBox[{"2", "*", "v"}], "]"}], "]"}]}], ")"}], "*", "\n", "    ", 
     RowBox[{"Sinh", "[", "v", "]"}]}], ",", " ", "0"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5899562031123743`*^9, 3.589956248807988*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SqrtBox[
      RowBox[{"Sech", "[", 
       RowBox[{"2", " ", "v"}], "]"}]]}], " ", 
    RowBox[{"Sinh", "[", "v", "]"}]}], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.5899562577094975`*^9, 3.611210179407754*^9, 
  3.6112103776080904`*^9, 3.615212777589697*^9, 3.617965217405792*^9}]
}, Closed]],

Cell["The evaluation yields", "Text",
 CellChangeTimes->{{3.589956767523657*^9, 3.5899567761071477`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", "w1", "]"}], "[", 
  RowBox[{"u", ",", "v"}], " ", "]"}]], "Input",
 CellChangeTimes->{{3.589956265578947*^9, 3.5899562755165157`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Cosh", "[", "v", "]"}], " ", 
   SqrtBox[
    RowBox[{"Sech", "[", 
     RowBox[{"2", " ", "v"}], "]"}]]}], "-", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"Sech", "[", 
     RowBox[{"2", " ", "v"}], "]"}], 
    RowBox[{"3", "/", "2"}]], " ", 
   RowBox[{"Sinh", "[", "v", "]"}], " ", 
   RowBox[{"Sinh", "[", 
    RowBox[{"2", " ", "v"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.615212783439707*^9, 3.6179652426032333`*^9}]
}, Closed]],

Cell["and the expected result", "Text",
 CellChangeTimes->{{3.5899567855976906`*^9, 3.589956817331506*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"Cosh", "[", 
       RowBox[{"2", " ", "v"}], "]"}], 
      RowBox[{"3", "/", "2"}]], "*", "%", "*", 
     RowBox[{"Sech", "[", "v", "]"}]}], "\[Equal]", "1"}], ",", " ", 
   RowBox[{"v", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5899563376110673`*^9, 3.589956357044179*^9}, {
  3.589956388894*^9, 3.5899564536937065`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.589956455895833*^9, 3.611210193448557*^9, 
  3.6152128103809547`*^9, 3.617965259609206*^9}]
}, Closed]],

Cell["", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.2.3. Developable Surfaces 2", "Subsubsection",
 CellChangeTimes->{{3.58995791782845*^9, 3.5899579288990836`*^9}, {
   3.58995796082791*^9, 3.589957970067438*^9}, {3.5900391023377857`*^9, 
   3.5900391053953905`*^9}, 3.611210506158443*^9, 3.6112125836092663`*^9, 
   3.6152128786622744`*^9, 3.615263576317348*^9, 3.6179654195943565`*^9, 
   3.617973709425148*^9}],

Cell["\<\
In subsection 2.2.1 we have seen that all developable surfaces have Gaussian \
curvature zero. From the theorema egregium it follows that any surface \
isometric to the plane has this property. Now we will prove the converse: \
\>", "Text",
 CellChangeTimes->{{3.5899580312989407`*^9, 3.5899580758994913`*^9}, {
  3.5899585563559723`*^9, 3.5899586364995565`*^9}, {3.589958678715971*^9, 
  3.589958706467558*^9}, {3.589978337180153*^9, 3.5899783553853855`*^9}, {
  3.590039159901887*^9, 3.590039159901887*^9}, {3.590039354761829*^9, 
  3.590039368786254*^9}}],

Cell[TextData[{
 StyleBox["Proposition",
  FontColor->RGBColor[0, 0, 1]],
 ". Let sf[u,v] be a surface with Gaussian curvature zero. Then the rank \
rk[u,v] of the differential of the Gauss map  d[",
 "amf[",
 "3][sf]][u,v] is less than 2. If the rank for all points sf[u,v] equals \
zero, the surface is a part of a plane. If the rank  for all points sf[u,v] \
equals one, the surface is developable."
}], "Text",
 CellChangeTimes->{{3.5899587166831427`*^9, 3.5899587244515867`*^9}, {
   3.5899588196920342`*^9, 3.589958880251498*^9}, {3.589958924227013*^9, 
   3.589958945747244*^9}, {3.5899589894277425`*^9, 3.5899590581636744`*^9}, {
   3.5899590896194735`*^9, 3.5899591359231215`*^9}, 3.589978431482319*^9, {
   3.589979743507023*^9, 3.589979771041072*^9}, {3.5899800276459227`*^9, 
   3.5899800708423977`*^9}, 3.614861852826728*^9, 3.6149177846821485`*^9, 
   3.615261926990012*^9}],

Cell[TextData[{
 StyleBox["Proof",
  FontColor->RGBColor[0, 0, 1]],
 ".  The differential of the Gauss map is d[amf[3] ]== amf[1] \[Omega][2] -  \
amf[2] \[Omega][1]. The rank  rk[u,v] of this map at a point sf[u,v] is less \
than 2 iff \[Omega][1] ",
 Cell[BoxData[
  FormBox["\[And]", TraditionalForm]]],
 " \[Omega][2] == 0, and this is the case iff gauss[sf][u,v]== 0. If the rank \
equals 0 for the whole connected surface  the normal vector amf[3] is \
constant, and the statement follows from",
 ButtonBox[" Lemma 2.1.1",
  BaseStyle->"Hyperlink",
  ButtonData->"lem2.1.1"],
 ".  If the rank of the Gauss map is less than two then the set of all points \
sf[u,v] of the surface with rk[u,v] = 1 is open. We assume that rk[u,v] == 1 \
for all points of the surface. Then the kernel of d[amf[3][sf]][u,v]  is \
one-dimensional. We put the vector amf[1][sf][u,v] into the kernel. Then the \
frame is uniquely defined since amf[2] == amf[3] \[Times] amf[1]. The \
integral curves of the Pfaffian equation \[Sigma][2] == 0 have the tangent \
vector amf[1]=d[sf][u, v].vt, where vt is the corresponding vector in the \
parameter space. Thus d[amf[3][sf]][u, v].vt== 0, and the normal vector is \
constant along the integral curves. We will show that also amf[1] is constant \
along these curves: d[amf[1][sf]][u,v].vt == 0 if \[Sigma][2](vt) = 0. To \
this aim we consider the basis decompositions of \[Omega][1], \[Omega][2] \
with the notations [B-R] (61.9) p. 87:"
}], "Text",
 CellChangeTimes->{{3.589978656980715*^9, 3.589978703499996*^9}, {
   3.5899787359636536`*^9, 3.589978816974596*^9}, {3.5899788639306784`*^9, 
   3.589979198488866*^9}, {3.5899796086915865`*^9, 3.589979638050838*^9}, {
   3.589979676146105*^9, 3.5899797209025836`*^9}, 3.5899800551799707`*^9, {
   3.589980091294034*^9, 3.5899801718057756`*^9}, {3.589980202428629*^9, 
   3.5899802665915422`*^9}, {3.5899803831008573`*^9, 
   3.5899805423809676`*^9}, {3.5899805879755754`*^9, 
   3.5899807208211737`*^9}, {3.589980760477442*^9, 3.58998077250113*^9}, {
   3.589980874364956*^9, 3.5899809564446507`*^9}, 3.5899811643895445`*^9, 
   3.589981878013362*^9, {3.589981948653402*^9, 3.589981996293127*^9}, {
   3.589982186453003*^9, 3.589982221292996*^9}, {3.5899822553059416`*^9, 
   3.5899823342284555`*^9}, {3.590039496051277*^9, 3.5900394960668774`*^9}, {
   3.590039566969002*^9, 3.590039575065416*^9}, {3.590039605189069*^9, 
   3.590039677604396*^9}, 3.59003973123729*^9, {3.5900397746677666`*^9, 
   3.5900397784741735`*^9}, {3.5900398450082903`*^9, 3.590039878158348*^9}, {
   3.5900399682641068`*^9, 3.590040111987159*^9}, {3.5900407431174674`*^9, 
   3.59004083581283*^9}, {3.590040875140499*^9, 3.590040965620658*^9}, {
   3.59004100086112*^9, 3.590041048722004*^9}, {3.614861853481929*^9, 
   3.6148618583803377`*^9}, {3.6149177853529496`*^9, 
   3.6149177902357583`*^9}, {3.6152619289561243`*^9, 3.615261948601248*^9}, {
   3.615262603651715*^9, 3.615262646526167*^9}, {3.615262816362881*^9, 
   3.6152628196860714`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", " ", 
    RowBox[{"\[Omega]", "[", "1", "]"}]}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "*", 
     RowBox[{"\[Sigma]", "[", "1", "]"}]}], " ", "+", "  ", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "2"}], "]"}], "*", 
     RowBox[{"\[Sigma]", "[", "2", "]"}]}]}]}], ";", " ", 
  RowBox[{
   RowBox[{"\[Omega]", "[", "2", "]"}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "1"}], "]"}], "*", 
     RowBox[{"\[Sigma]", "[", "1", "]"}]}], " ", "+", "  ", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "*", 
     RowBox[{"\[Sigma]", "[", "2", "]"}]}]}]}], ";"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5899823839693003`*^9, 3.589982562800529*^9}}],

Cell[TextData[{
 "leading to the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " definitions"
}], "Text",
 CellChangeTimes->{{3.589982622308933*^9, 3.5899826449002247`*^9}},
 CellTags->"cij"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cf", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "[", "ff_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     RowBox[{"extprod", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Omega]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "/", 
   RowBox[{
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5899830368256416`*^9, 3.589983216612925*^9}, 
   3.589983350955609*^9, 3.589983976627395*^9, {3.59221330302858*^9, 
   3.5922133147682514`*^9}, 3.592315502531618*^9, {3.609911786486065*^9, 
   3.609911786498065*^9}, {3.609911906425925*^9, 3.6099119064319253`*^9}, 
   3.6179720239937468`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"cf", "[", 
       RowBox[{"2", ",", "2"}], "]"}], "[", "ff_", "]"}], "[", 
     RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
    RowBox[{
     RowBox[{"+", 
      RowBox[{
       RowBox[{"extprod", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"\[Omega]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "/", 
     RowBox[{
      RowBox[{"extprod", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"cf", "[", 
       RowBox[{"1", ",", "1"}], "]"}], "[", "ff_", "]"}], "[", 
     RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"extprod", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Omega]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}], "/", 
     RowBox[{
      RowBox[{"extprod", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"cf", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "[", "ff_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"extprod", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Omega]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}], "/", 
    RowBox[{
     RowBox[{"extprod", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5899830368256416`*^9, 3.589983216612925*^9}, {
   3.5899832812556224`*^9, 3.5899832887070484`*^9}, 3.589984012651456*^9, 
   3.590497429810029*^9, {3.609911786509066*^9, 3.6099117865160666`*^9}, {
   3.609911906443926*^9, 3.6099119064499264`*^9}, 3.6179720269479156`*^9, 
   3.618024581851679*^9, {3.6180246142061357`*^9, 3.6180246441269884`*^9}}],

Cell["For this coefficients one has ", "Text",
 CellChangeTimes->{{3.5900401716884637`*^9, 3.590040188489693*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"cf", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "==", 
   RowBox[{
    RowBox[{
     RowBox[{"cf", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5899837285372057`*^9, 3.589983810223878*^9}, {
  3.5900402150409403`*^9, 3.5900402169441433`*^9}, {3.617972032119211*^9, 
  3.6179720334632883`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.589983811229935*^9, 3.589983959820434*^9, 
  3.58998409437613*^9, 3.5900402260389595`*^9, 3.6112110570099497`*^9, 
  3.6152632142706404`*^9, 3.617972753835491*^9}]
}, Closed]],

Cell["\<\
 for all surfaces; it is a consequence of the third integrability condition. \
We conclude, since \[Sigma][1][sf][u,v][vt] ==1 and \[Sigma][2][sf][u,v][vt] \
== 0,\
\>", "Text",
 CellChangeTimes->{{3.589984123908819*^9, 3.589984178348933*^9}, {
   3.589984231596979*^9, 3.5899843220211506`*^9}, {3.5899843621814475`*^9, 
   3.5899843678207703`*^9}, {3.5899843991745634`*^9, 3.5899844344285803`*^9}, 
   3.590040616492045*^9, {3.5900406549929123`*^9, 3.590040669547738*^9}, 
   3.5900411030413*^9, {3.590041232427927*^9, 3.5900412522711616`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{
      RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], 
   RowBox[{"(", "vt", ")"}]}], " ", "\[Equal]", " ", "0", " ", "\[Equal]", 
  " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", "*", 
    RowBox[{"cf", "[", 
     RowBox[{"1", ",", "1"}], "]"}]}], " ", "+", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", "*", 
    RowBox[{"cf", "[", 
     RowBox[{"2", ",", "1"}], "]"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.589984447519329*^9, 3.5899845634239583`*^9}, {
   3.589984611100685*^9, 3.589984633600972*^9}, {3.589984668727981*^9, 
   3.589984696433566*^9}, 3.589984851882457*^9, 3.5899848983511147`*^9, {
   3.6148618584115376`*^9, 3.6148618584271374`*^9}, {3.6149177902513585`*^9, 
   3.614917790266958*^9}, {3.61526194986032*^9, 3.615261953404523*^9}, {
   3.6179720352323895`*^9, 3.617972036935487*^9}}],

Cell["\<\
We conclude cf[1,1] == cf[2,1] ==cf[1,2] ==0, and therefore \
\[Omega][2][sf][u,v] == 0 is the null form. Furthermore we have that the \
assumption implies \
\>", "Text",
 CellChangeTimes->{{3.589984961956753*^9, 3.589984971221283*^9}, {
  3.589985019637052*^9, 3.5899851567168922`*^9}, {3.5899852224376516`*^9, 
  3.5899852821410666`*^9}, {3.61797203839657*^9, 3.617972045323967*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Omega]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     RowBox[{
      RowBox[{"cf", "[", 
       RowBox[{"2", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "*", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5899852947197857`*^9, 3.5899853374092274`*^9}, {
   3.5899853776785307`*^9, 3.589985379710647*^9}, {3.589985414166618*^9, 
   3.5899855089280376`*^9}, 3.617972047079067*^9}],

Cell["We conclude from the derivation equations", "Text",
 CellChangeTimes->{{3.5899857875329733`*^9, 3.589985865828451*^9}, 
   3.5899859187814803`*^9, {3.5899859747406807`*^9, 3.5899859794209485`*^9}, {
   3.5900414890483775`*^9, 3.5900415027764015`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{
      RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], 
   RowBox[{"(", "vt", ")"}]}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "*", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", "3", "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], 
   RowBox[{"(", "vt", ")"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.589985616280178*^9, 3.5899857305607147`*^9}, {
  3.6148618584271374`*^9, 3.6148618584427376`*^9}, {3.6149177902825584`*^9, 
  3.6149177902825584`*^9}, {3.615261954652594*^9, 3.6152619562126837`*^9}}],

Cell["\<\
since \[Omega][2] == 0. The last equation implies. since \[Sigma][1][vt]== 1, \
\[Sigma][2][vt]==0:\
\>", "Text",
 CellChangeTimes->{
  3.589985928237021*^9, {3.5899860674129815`*^9, 3.5899861255893087`*^9}, 
   3.590041447006304*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{
      RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], 
   RowBox[{"(", "vt", ")"}]}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "*", 
   RowBox[{
    RowBox[{
     RowBox[{"cg", "[", "1", "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5899860290237856`*^9, 3.589986048991928*^9}, {
   3.6148618584427376`*^9, 3.6148618584427376`*^9}, {3.6149177902825584`*^9, 
   3.6149177902981586`*^9}, {3.6152619573567486`*^9, 3.6152619587168264`*^9}, 
   3.6179744883795924`*^9}],

Cell["Now we apply the fifth integrability condition :", "Text",
 CellChangeTimes->{{3.5899861640295076`*^9, 3.5899861937332067`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"dd", "[", 
     RowBox[{"\[Omega]", "[", "2", "]"}], "]"}], " ", "\[Equal]", " ", 
    RowBox[{"-", " ", 
     RowBox[{"\[Omega]", "[", "3", "]"}]}]}], "\[And]", " ", 
   RowBox[{"\[Omega]", "[", "1", "]"}]}], " ", "=", " ", 
  RowBox[{"0", " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"cg", "[", "1", "]"}], "*", " ", 
     RowBox[{"cf", "[", 
      RowBox[{"2", ",", "2"}], "]"}], "*", 
     RowBox[{"\[Sigma]", "[", "1", "]"}]}], "\[And]", 
    RowBox[{
     RowBox[{"\[Sigma]", "[", "2", "]"}], "."}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.589986244895133*^9, 3.5899863882873344`*^9}, {
   3.5899864285356364`*^9, 3.589986483231765*^9}, {3.5899865213349447`*^9, 
   3.589986633432356*^9}, 3.6179720482881365`*^9, 3.617974492023801*^9}],

Cell["\<\
Since MatrixRank[{\[Omega][1], \[Omega][2]}] == 1 we have \
cf[2,2]\[NotEqual]0, and thus cg[1] == 0. It follows\
\>", "Text",
 CellChangeTimes->{{3.5899866745767093`*^9, 3.589986807629319*^9}, {
   3.589986839149122*^9, 3.5899868475086*^9}, 3.61797204974422*^9, 
   3.617974494186925*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{
      RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], 
   RowBox[{"(", "vt", ")"}]}], " ", "\[Equal]", " ", "0"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5899868535589466`*^9, 3.589986858447226*^9}, 
   3.6148618584427376`*^9, 3.6149177902981586`*^9, 3.6152619598278904`*^9}],

Cell["\<\
amf[1] is constant along the integral curves of \[Sigma][2]== 0, and thus \
these curves must be lines. Since the normal vector of the surface is also \
constant along these lines, the surface is developable. \[FilledSquare]\
\>", "Text",
 CellChangeTimes->{{3.5899869117332735`*^9, 3.5899870684532375`*^9}, 
   3.6148618584739375`*^9, 3.614917790329358*^9, 3.615261961097963*^9, {
   3.6152634663810596`*^9, 3.6152634704812946`*^9}, {3.617972839882413*^9, 
   3.617972846952817*^9}}],

Cell[TextData[{
 StyleBox["Remark",
  FontColor->RGBColor[0, 0, 1]],
 ". Generally, a surface may have singularities. Furthermore, the subset of \
points at which the rank of the Gauss map is zero, is a closed set. The \
points of the last set not being interior points of the set are not \
considered in the proposition.  Having in mind this, one often formulates - \
with a grain of salt:\n",
 StyleBox["Corollary",
  FontColor->RGBColor[0, 0, 1]],
 ". A surface in the Euclidean 3-space is locally isometric to an Euclidean \
plane iff its Gauss curvature is zero."
}], "Text",
 CellChangeTimes->{{3.589959160829546*^9, 3.5899591830038147`*^9}, {
   3.5899592232671175`*^9, 3.5899593889235926`*^9}, {3.5899594189633102`*^9, 
   3.58995943381116*^9}, {3.589959612019353*^9, 3.589959622683963*^9}, 
   3.5899785101376567`*^9, {3.5900420955373964`*^9, 3.590042246961057*^9}, 
   3.617972882304839*^9}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. The Second Fundamental Form", "Section",
 CellChangeTimes->{{3.590213457675046*^9, 3.5902135002631207`*^9}, 
   3.5902137672731895`*^9, {3.5905025808142767`*^9, 3.5905025824834795`*^9}, 
   3.5907394960471115`*^9, {3.6112125916717277`*^9, 3.6112126039264283`*^9}, {
   3.611212757083188*^9, 3.6112127596153336`*^9}, 3.6152635866689405`*^9, 
   3.61527332575016*^9}],

Cell[CellGroupData[{

Cell["3.1. The Definition ", "Subsection",
 CellChangeTimes->{{3.5906466020506277`*^9, 3.590646615061051*^9}, {
   3.5906466475091076`*^9, 3.5906466547319202`*^9}, {3.6112127683308315`*^9, 
   3.6112127708729773`*^9}, 3.611213166180588*^9, {3.6179741428428288`*^9, 
   3.617974156080586*^9}, 3.6180341576632977`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";"}]], "Input",
 CellChangeTimes->{{3.6180338973768406`*^9, 3.6180339102624636`*^9}}],

Cell[TextData[{
 "Following ",
 ButtonBox["[B-R]",
  BaseStyle->"Hyperlink",
  ButtonData->"B-R"],
 ",(61..8) we introduce now the ",
 StyleBox["second fundamental form",
  FontColor->RGBColor[0, 0, 1]],
 ":"
}], "Text",
 CellChangeTimes->{{3.5906404910830946`*^9, 3.590640514810736*^9}, {
  3.5906405514552007`*^9, 3.590640594776477*^9}, {3.5906406796562257`*^9, 
  3.5906406796562257`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"fund2", ",", "ff"}], "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", "ff_", "]"}], "[", 
     RowBox[{"u_", ",", "v_"}], "]"}], "[", 
    RowBox[{"x_List", ",", "y_List"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", "ff", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ".", "x"}], ")"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{
         RowBox[{"amf", "[", "3", "]"}], "[", "ff", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ".", "y"}], ")"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.590214197740346*^9, 3.590214224307193*^9}, {
   3.5902142903889084`*^9, 3.590214400400302*^9}, {3.590218010839443*^9, 
   3.590218051961116*^9}, {3.5902180860783753`*^9, 3.5902181389780684`*^9}, {
   3.5904956764293494`*^9, 3.5904956764293494`*^9}, {3.5905011101060934`*^9, 
   3.5905011431313515`*^9}, {3.5907157938532677`*^9, 3.59071579522607*^9}, 
   3.6148618585051374`*^9, 3.6149177903449583`*^9, 3.6152619715185585`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fund2", "::", "usage"}], "=", " ", 
   "\"\<fund2[f][u,v][xx,yy] is the value of the second fundamental form of \
the surface f[u,v] for the tangent vectors xx,yy.\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.618026345918378*^9, 3.618026378569235*^9}, {
   3.6180264185365047`*^9, 3.6180265050698566`*^9}, 3.618026535786311*^9, {
   3.618026569950371*^9, 3.618026638153691*^9}}],

Cell[TextData[{
 "Clearly, fund2 is invariant with respect to orientation preserving \
Euclidean motions. It changes the sign if the orientation of the space or the \
orientation of the surface (sign of amf[3][sf])  changes.  It is a field of \
bilinear forms with  bilinear linear transformation under parameter \
transformations. Thus, as well as the first fundamental form, it defines a \
field of twofold covariant tensors on the surface. The coordinates of this \
tensor with respect to the local cobasis \[Sigma][1], \[Sigma][2]  are the \
coefficients cf[i,j], defined in subsection ",
 ButtonBox["2.2.3",
  BaseStyle->"Hyperlink",
  ButtonData->"cij"],
 ":"
}], "Text",
 CellChangeTimes->{{3.590640970830737*^9, 3.5906414247915344`*^9}, {
   3.5906420395730143`*^9, 3.590642063846657*^9}, {3.5907159302287073`*^9, 
   3.5907160598961353`*^9}, {3.5907161361179314`*^9, 3.5907161917331123`*^9}, 
   3.6112129366894617`*^9, 3.6148618585987377`*^9, 3.6149177904385586`*^9, 
   3.6152619732326565`*^9, {3.61526726018423*^9, 3.615267267071624*^9}, 
   3.617972051489319*^9, 3.6180344092752137`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"xx", "=", " ", 
   RowBox[{"{", 
    RowBox[{"s1", ",", "s2"}], "}"}]}], ";", " ", 
  RowBox[{"yy", "=", 
   RowBox[{"{", 
    RowBox[{"t1", ",", "t2"}], "}"}]}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fund2", "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{"xx", ",", "yy"}], "]"}], "-", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"cf", "[", 
           RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"\[Sigma]", "[", "i", "]"}], "[", "sf", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], ".", "xx"}], ")"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"\[Sigma]", "[", "j", "]"}], "[", "sf", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], ".", "yy"}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "2"}], "}"}]}], "]"}]}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "\[Element]", " ", "Reals"}], ",", 
      RowBox[{"v", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5902162888928185`*^9, 3.5902165073244023`*^9}, {
   3.5902167767524757`*^9, 3.590216796829711*^9}, {3.590217454916867*^9, 
   3.590217511061365*^9}, {3.5902175775954823`*^9, 3.5902176033823276`*^9}, 
   3.5902178500811605`*^9, {3.590218591566063*^9, 3.590218738206321*^9}, 
   3.5902188211048665`*^9, 3.5902198527502785`*^9, 3.590220631597246*^9, 
   3.59049567686615*^9, {3.5904994302171426`*^9, 3.5904995144260902`*^9}, {
   3.5904995882298203`*^9, 3.5904996219258795`*^9}, {3.5904996601615467`*^9, 
   3.5904996603643465`*^9}, {3.5904997007840176`*^9, 3.590499704403224*^9}, 
   3.5905023971551538`*^9, {3.590502450304447*^9, 3.590502485420109*^9}, {
   3.5906415477197504`*^9, 3.5906415910566263`*^9}, {3.590818432344045*^9, 
   3.5908184468832707`*^9}, 3.6179720537374477`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5906416219134808`*^9, 3.590641698010414*^9, 
  3.5907381034950657`*^9, 3.611213036980198*^9, 3.6114692218585577`*^9, 
  3.615273260044402*^9, 3.6180256848360167`*^9, 3.6180340857471714`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cf", "::", "usage"}], " ", "=", " ", 
   "\"\<cf[i,j][f][u,v] are the coefficients  of the second fundamental form \
wit respect to the cobasis {\[Sigma][i][f][u,v]} of the surface f[u,v] in the \
Euclidean 3-space.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.618025654634363*^9, 3.6180258392138877`*^9}, 
   3.6180258780423555`*^9}],

Cell[TextData[{
 "The bilinear form fund2 is ",
 StyleBox["symmetric",
  FontColor->RGBColor[0, 0, 1]],
 ":"
}], "Text",
 CellChangeTimes->{{3.5906417309108725`*^9, 3.590641761923727*^9}, 
   3.5906418653519087`*^9, 3.5907162291482525`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"fund2", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "[", 
     RowBox[{"xx", ",", "yy"}], "]"}], "-", 
    RowBox[{
     RowBox[{
      RowBox[{"fund2", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "[", 
     RowBox[{"yy", ",", "xx"}], "]"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{"v", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.590214680093193*^9, 3.5902147816961718`*^9}, {
  3.5904956764449496`*^9, 3.5904956764449496`*^9}, {3.590641834853855*^9, 
  3.5906418500950813`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.590214783536975*^9, 3.59049593854101*^9, 
  3.590499278491276*^9, 3.59064185491549*^9, 3.611213066552889*^9, 
  3.61527286871902*^9, 3.6152731514021883`*^9, 3.6180341269780445`*^9}]
}, Closed]],

Cell[TextData[{
 "We remark that very often the second fundamental form is defined with the \
opposite sign, see e.g. Alfred  Gray [",
 ButtonBox["G06",
  BaseStyle->"Hyperlink",
  ButtonData->"Gray"],
 "], or Erwin Kreyszig [",
 ButtonBox["Kr",
  BaseStyle->"Hyperlink",
  ButtonData->"Kr"],
 "], formula (38.6), p 146."
}], "Text",
 CellChangeTimes->{{3.590642754147869*^9, 3.59064281138437*^9}, {
   3.590643336512492*^9, 3.5906434798299437`*^9}, {3.5906435852705293`*^9, 
   3.590643647140238*^9}, 3.590644042975333*^9, {3.5991973443311057`*^9, 
   3.5991973496114078`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["3.2. Gaussian Curvature and Second Fundamental Form", "Subsection",
 CellChangeTimes->{{3.5906466724535513`*^9, 3.5906467470684824`*^9}, 
   3.590671674118125*^9, 3.6112131733619986`*^9, 3.6114693957095017`*^9, 
   3.6152733312304735`*^9, 3.6152757102455454`*^9, 3.6180344955531483`*^9, 
   3.6180373458971786`*^9}],

Cell["\<\
For the Gaussian curvature we obtain the formula, see [B-R], (61.12):\
\>", "Text",
 CellChangeTimes->{{3.590644144063511*^9, 3.5906441679783525`*^9}, {
  3.5906444821005044`*^9, 3.590644503784542*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"gauss", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", "-", " ", 
    RowBox[{"Det", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"cf", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{"v", "\[Element]", " ", "Reals"}]}], "}"}], ",", 
   RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5906441721591597`*^9, 3.59064420053561*^9}, {
   3.590644236665273*^9, 3.5906442773657446`*^9}, 3.5906443350702457`*^9, {
   3.6114672135436893`*^9, 3.611467262235474*^9}, 3.614861858629938*^9, 
   3.6148635015936236`*^9, 3.617972055328539*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.590644357643486*^9, 3.611467253176956*^9, 
  3.61146756235264*^9, 3.615273887073266*^9, 3.618035108663216*^9}]
}, Closed]],

Cell[TextData[{
 "Remember that the definition of the Gaussian curvature is the ratio of two \
alternating biforms, invariant under Euclidean motions and parameter \
transformations. In the local basis \[Sigma][1], \[Sigma][2] the strict \
coordinate of  \[Sigma][1] \[And] \[Sigma][2] is 1, and the formula just \
calculated follows immediately from the ",
 ButtonBox["definition",
  BaseStyle->"Hyperlink",
  ButtonData->"gaussK"],
 "."
}], "Text",
 CellChangeTimes->{{3.590738951294155*^9, 3.5907390645503535`*^9}, {
   3.59073910233362*^9, 3.590739262452301*^9}, {3.590739416346572*^9, 
   3.5907394544574385`*^9}, {3.618034565778165*^9, 3.6180345719545183`*^9}, 
   3.6180373847834024`*^9}],

Cell[TextData[{
 "The coordinates of the second fundamental form with respect to the local ",
 "cobasis",
 " ",
 ButtonBox["du, dv",
  BaseStyle->"Hyperlink",
  ButtonData->"dudv"],
 " are"
}], "Text",
 CellChangeTimes->{{3.5907165401090384`*^9, 3.5907165927970514`*^9}, {
   3.5907167704052105`*^9, 3.5907168262464046`*^9}, 3.618034459904109*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fd2", "[", 
      RowBox[{"1", ",", "1"}], "]"}], "[", "ff_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", "ff", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fd2", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "[", "ff_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", "ff", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fd2", "[", 
      RowBox[{"2", ",", "2"}], "]"}], "[", "ff_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", "ff", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fd2", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "[", "ff_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", "ff", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5906718894921036`*^9, 3.5906720131535206`*^9}, {
   3.590719635842104*^9, 3.590719636032115*^9}, 3.5907196778325057`*^9, 
   3.618035398484793*^9, 3.6180354370499988`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fd2", "::", "usage"}], " ", "=", " ", 
   "\"\<{fd2[i,j][f][u,v], i,j = 1, 2} is the matrix of the coefficients  \
with respect to the local standard basis {du,dv} of the second fundamental \
form of the surface f[u,v] in the Euclidean space.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6180354694598527`*^9, 3.6180357108316584`*^9}, 
   3.6180359090899982`*^9}],

Cell[TextData[StyleBox["The determinant of the matrix {fd2[i,j]} is the \
product of determinants",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.590716987076603*^9, 3.590717076748732*^9}, {
  3.592113156600597*^9, 3.5921131570841975`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Det", "[", 
   RowBox[{"{", 
    RowBox[{"fd2", "[", 
     RowBox[{"i", ",", "j"}], "]"}], "}"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"Det", "[", 
    RowBox[{"{", 
     RowBox[{"cf", "[", 
      RowBox[{"i", ",", "j"}], "]"}], "}"}], "]"}], "*", 
   RowBox[{"Det", "[", 
    RowBox[{"{", 
     RowBox[{"rgT", "[", 
      RowBox[{"i", ",", "j"}], "]"}], "}"}], "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5907170998510537`*^9, 3.5907171567763095`*^9}, {
   3.590719718049806*^9, 3.5907197185128326`*^9}, 3.617628080916442*^9, 
   3.6179720574146585`*^9}],

Cell[TextData[{
 StyleBox["Proof",
  FontColor->RGBColor[0, 0, 1]],
 ":"
}], "Text",
 CellChangeTimes->{{3.5907172529178085`*^9, 3.5907172560609884`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Det", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"fd2", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "==", 
   RowBox[{
    RowBox[{"Det", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"cf", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "*", 
    RowBox[{"Det", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5906723438117013`*^9, 3.5906724411714725`*^9}, {
   3.590672471809926*^9, 3.5906725129315987`*^9}, {3.59071972720533*^9, 
   3.59071972808438*^9}, {3.5907368705001*^9, 3.5907368707185*^9}, {
   3.614861858629938*^9, 3.6148618586455383`*^9}, {3.6148635016092234`*^9, 
   3.6148635016092234`*^9}, 3.6176280830785656`*^9, 3.617972058857741*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.590672534272436*^9, 3.590720247280076*^9, 
  3.5907369018561554`*^9, 3.590738034574145*^9, 3.6114678073266516`*^9, 
  3.615274872125608*^9, 3.6180361504588037`*^9}]
}, Closed]],

Cell["Thus it follows the general formula, see [B-R], (61.12)", "Text",
 CellChangeTimes->{{3.5909099752525454`*^9, 3.590909987588251*^9}, {
   3.5909888126325254`*^9, 3.590988812960126*^9}, {3.5909889041422863`*^9, 
   3.59098893481194*^9}, 3.5909890097856717`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "-", 
   RowBox[{
    RowBox[{"Det", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"fd2", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "/", 
    RowBox[{"Det", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.59091000400919*^9, 3.590910046910644*^9}, {
   3.590910117662691*^9, 3.5909101521126614`*^9}, 3.6114690139486666`*^9, {
   3.6148618586455383`*^9, 3.614861858661138*^9}, {3.614863501640424*^9, 
   3.614863501640424*^9}, 3.617628084765662*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.59091017884019*^9, 3.5909102448319645`*^9, 
  3.6114690049301505`*^9, 3.6114690378200316`*^9, 3.6152752397366343`*^9, 
  3.6180366795480657`*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example",
  FontColor->RGBColor[0, 0, 1]],
 ". ",
 StyleBox["The sphere of radius r",
  FontColor->RGBColor[0, 0, 1]],
 ":"
}], "Text",
 CellChangeTimes->{{3.590645549360779*^9, 3.5906455664584093`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Det", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"fd2", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", 
        RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "-", 
   RowBox[{
    RowBox[{"Det", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"cf", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", 
         RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "*", 
    RowBox[{"Det", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", 
         RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5906723438117013`*^9, 3.5906724411714725`*^9}, {
   3.590672471809926*^9, 3.5906725129315987`*^9}, {3.5906725949253426`*^9, 
   3.5906726627230616`*^9}, {3.590673581970276*^9, 3.5906735987247057`*^9}, {
   3.5907197413651395`*^9, 3.5907197418371663`*^9}, {3.5907368468192587`*^9, 
   3.5907368597516813`*^9}, {3.590738130810714*^9, 3.5907381619795685`*^9}, {
   3.614861858661138*^9, 3.614861858661138*^9}, {3.614863501656024*^9, 
   3.6148635016716237`*^9}, 3.6176280865107617`*^9, 3.617972060681845*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.590673556058631*^9, 3.590673601829111*^9, 
  3.590738165707975*^9, 3.6114690704768996`*^9, 3.6152755758698597`*^9, 
  3.6180372476835613`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"cf", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "[", 
       RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "2"}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", ">", "0"}], ",", " ", 
     RowBox[{
      RowBox[{"Cos", "[", "v", "]"}], ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5906720266943445`*^9, 3.5906720991096716`*^9}, {
   3.5906721323533297`*^9, 3.590672139934943*^9}, 3.5906722123658705`*^9, {
   3.5907382355024977`*^9, 3.590738290320994*^9}, 3.614861858676738*^9, 
   3.614863501687224*^9, 3.6179720618959146`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "r"], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox["1", "r"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.590672144895752*^9, 3.5906722142534738`*^9, 
  3.5907382930509987`*^9, 3.611469089331978*^9, 3.6152755878115425`*^9, 
  3.6180372667196503`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", 
      RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{"xx", ",", "xx"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{"v", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{
      RowBox[{"Cos", "[", "v", "]"}], ">", "0"}], ",", 
     RowBox[{"r", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.590220048343422*^9, 3.5902200805418787`*^9}, {
   3.590220507904629*^9, 3.590220528902266*^9}, 3.5902205880731697`*^9, {
   3.5902221438171024`*^9, 3.5902221985575986`*^9}, 3.5904956768973503`*^9, 
   3.5906439031210876`*^9, 3.5906439367703466`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", "r", " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["s1", "2"], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["s2", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["s1", "2"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "v"}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.590222207309214*^9, 3.5905025445754128`*^9, 
  3.5906439425423565`*^9, 3.611469113916384*^9, 3.611469242259725*^9, 
  3.615275600115247*^9, 3.618037278212307*^9}]
}, Closed]],

Cell["Thus we see", "Text",
 CellChangeTimes->{{3.5906455044951*^9, 3.59064551025151*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"fund2", "[", 
       RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "[", 
     RowBox[{"xx", ",", "xx"}], "]"}], "\[Equal]", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "r"}], ")"}], "*", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"fund1", "[", 
        RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{"xx", ",", "xx"}], "]"}]}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{"v", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{
      RowBox[{"Cos", "[", "v", "]"}], ">", "0"}], ",", 
     RowBox[{"r", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.590220048343422*^9, 3.5902200805418787`*^9}, {
   3.590220507904629*^9, 3.590220528902266*^9}, 3.5902205880731697`*^9, {
   3.5902221438171024`*^9, 3.5902221985575986`*^9}, 3.5904956768973503`*^9, 
   3.5906439031210876`*^9, 3.5906439367703466`*^9, {3.5906453634084525`*^9, 
   3.590645369289663*^9}, {3.590645419552951*^9, 3.590645467944236*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5906453767464757`*^9, 3.590645485057466*^9, 
  3.5907380645261974`*^9, 3.590738371628337*^9, 3.611469271826416*^9, 
  3.6152756292429123`*^9, 3.6180372886029015`*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example",
  FontColor->RGBColor[0, 0, 1]],
 ". The second fundamental forms for all ",
 StyleBox["developable surfaces",
  FontColor->RGBColor[0, 0, 1]],
 " degenerate. For the ",
 StyleBox["circular cones",
  FontColor->RGBColor[0, 0, 1]],
 " we have"
}], "Text",
 CellChangeTimes->{{3.5906456117920885`*^9, 3.590645688778224*^9}, {
  3.5906459738999243`*^9, 3.5906459850383444`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", 
      RowBox[{"cone", "[", "a", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t1", ",", "t2"}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"a", "/", "2"}], "]"}], ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.590214476700036*^9, 3.590214562578187*^9}, 
   3.5904956764449496`*^9, {3.5904958754076986`*^9, 3.590495889354123*^9}, {
   3.5906437534388247`*^9, 3.590643762767641*^9}, {3.5906447896394444`*^9, 
   3.5906448165806923`*^9}, {3.590644867826782*^9, 3.590644932863296*^9}, 
   3.614861858676738*^9, 3.6148647317181845`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "2"]}], " ", "s2", " ", "t2", " ", "u", " ", 
  RowBox[{"Sin", "[", "a", "]"}]}]], "Output",
 CellChangeTimes->{3.5906448175634937`*^9, 3.590644886141214*^9, 
  3.5906449383701057`*^9, 3.5907386499484253`*^9, 3.611469289974454*^9, 
  3.615275651087162*^9, 3.6180373069439507`*^9}]
}, Closed]],

Cell["For the plane we have ", "Text",
 CellChangeTimes->{{3.5907384391608553`*^9, 3.590738465088101*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"pl", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", 
  RowBox[{
   RowBox[{"plane", "[", 
    RowBox[{"a1", ",", "a2", ",", "b1", ",", "b2", ",", "c1", ",", "c2"}], 
    "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.5907384667573037`*^9, 3.5907384667573037`*^9}, {
   3.5907385125277843`*^9, 3.5907385253198066`*^9}, 3.590738675891271*^9, 
   3.614861858692338*^9, 3.6148626542469354`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fund2", "[", "pl", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"s1", ",", "s2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t1", ",", "t2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5907385438214393`*^9, 3.5907385878915167`*^9}, 
   3.5907386904304967`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5907385897791195`*^9, 3.5907386932697015`*^9, 
  3.611469335868079*^9, 3.615275673238429*^9, 3.618037320868747*^9}]
}, Closed]],

Cell["\<\
Since the plane and the cones are locally isometric surfaces it is clear that \
the second fundamental form is not invariant under isometries; it doesn\
\[CloseCurlyQuote]t belong to the inner geometry of the surfaces.\
\>", "Text",
 CellChangeTimes->{{3.590738712442135*^9, 3.590738740100984*^9}, {
  3.590738784498662*^9, 3.5907388582555914`*^9}, {3.611469357789333*^9, 
  3.611469360549491*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
3.3.  An Equivalent Definition of the Second Fundamental Form\
\>", "Subsection",
 CellChangeTimes->{{3.590818296109006*^9, 3.590818381035555*^9}, 
   3.590910415997754*^9, 3.611469400327766*^9, 3.611471134269942*^9, 
   3.615275717765976*^9, 3.615276391918535*^9, 3.618037428649912*^9, 
   3.6180379274334407`*^9}],

Cell["\<\
The following definition is often used as the primary. We start with the  \
identity\
\>", "Text",
 CellChangeTimes->{{3.590818477116124*^9, 3.590818522715004*^9}, {
  3.590818558439067*^9, 3.590818570607088*^9}, {3.5908187338572936`*^9, 
  3.5908187527853765`*^9}, {3.590820605355337*^9, 3.590820657793337*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"xx", "=", " ", 
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}]}], ";", " ", 
   RowBox[{"yy", "=", 
    RowBox[{"{", 
     RowBox[{"u1", ",", "u2"}], "}"}]}], ";", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"d", "[", "sf", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ".", "xx"}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"d", "[", 
          RowBox[{
           RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ".", "yy"}], ")"}]}], "\[Equal]", 
     " ", 
     RowBox[{"-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"d", "[", 
             RowBox[{"d", "[", "sf", "]"}], "]"}], "[", 
            RowBox[{"u", ",", "v"}], "]"}], ".", "xx"}], ")"}], ".", "yy"}], 
        ")"}], ".", 
       RowBox[{
        RowBox[{
         RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}]}], "]"}]}], "\n"}]], "Input",
 CellChangeTimes->{{3.6152760579194317`*^9, 3.6152760614466333`*^9}, {
  3.6180375677928705`*^9, 3.6180375998537045`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.618037609036229*^9}]
}, Closed]],

Cell["\<\
and it follows the new expression for the second fundamental form\
\>", "Text",
 CellChangeTimes->{{3.5909086612622857`*^9, 3.5909086901379366`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{"xx", ",", "yy"}], "]"}], " ", "\[Equal]", " ", 
   RowBox[{"-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"d", "[", "sf", "]"}], "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], ".", "xx"}], ")"}], ".", "yy"}], 
      ")"}], ".", 
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5908231690709734`*^9, 3.590823267325593*^9}, 
   3.590823302446602*^9, {3.5908233571987333`*^9, 3.5908233692144213`*^9}, {
   3.590823756951598*^9, 3.590823799359024*^9}, {3.5908238384552603`*^9, 
   3.590823914906633*^9}, {3.590905864085401*^9, 3.5909059654855795`*^9}, {
   3.5909082182371073`*^9, 3.590908268110395*^9}, {3.590908312008872*^9, 
   3.5909083780749884`*^9}, 3.614861858707938*^9, 3.6149177904853587`*^9, 
   3.6152622106372356`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.590908258843979*^9, 3.59090827662801*^9}, 
   3.5909083827549963`*^9, 3.6114701002848015`*^9, 3.6152761154547224`*^9, 
   3.6180376809153404`*^9}]
}, Closed]],

Cell["For the coefficients fd2[i,j][sf][u,v] we obtain", "Text",
 CellChangeTimes->{{3.5909087665624704`*^9, 3.590908833970189*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"sf", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"u", ",", "2"}], "}"}]}], "]"}], ".", 
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "\[Equal]", " ", 
   RowBox[{"-", 
    RowBox[{
     RowBox[{
      RowBox[{"fd2", "[", 
       RowBox[{"1", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.590837626280514*^9, 3.5908376661217923`*^9}, {
   3.5908379583135047`*^9, 3.5908380325077486`*^9}, 3.614861858707938*^9, 
   3.6149177905009584`*^9, 3.6152622119333096`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5908376682959166`*^9, 3.590838040856226*^9, 
  3.5909088462630105`*^9, 3.6114702396497726`*^9, 3.6152761432753134`*^9, 
  3.618037697206272*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"sf", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", "u", ",", "v"}], "]"}], ".", 
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "\[Equal]", " ", 
   RowBox[{"-", 
    RowBox[{
     RowBox[{
      RowBox[{"fd2", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.590837626280514*^9, 3.5908376661217923`*^9}, {
   3.5908379583135047`*^9, 3.5908380517038465`*^9}, {3.5908381960561028`*^9, 
   3.5908382285549617`*^9}, 3.614861858723538*^9, 3.6149177905165586`*^9, 
   3.6152622130683746`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5908382354213543`*^9, 3.590908846403411*^9, 
  3.6114702593789005`*^9, 3.6152761435623302`*^9, 3.618037697495289*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"sf", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", "v", ",", "u"}], "]"}], ".", 
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "\[Equal]", " ", 
   RowBox[{"-", 
    RowBox[{
     RowBox[{
      RowBox[{"fd2", "[", 
       RowBox[{"2", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.590837626280514*^9, 3.5908376661217923`*^9}, {
   3.5908379583135047`*^9, 3.5908380517038465`*^9}, {3.5908381960561028`*^9, 
   3.590838288707402*^9}, 3.614861858723538*^9, 3.6149177905165586`*^9, 
   3.6152622141574373`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5908382912455473`*^9, 3.590908846465811*^9, 
  3.6114702695814843`*^9, 3.615276143680337*^9, 3.6180376976132956`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"sf", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"v", ",", "2"}], "}"}]}], "]"}], ".", 
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "\[Equal]", " ", 
   RowBox[{"-", 
    RowBox[{
     RowBox[{
      RowBox[{"fd2", "[", 
       RowBox[{"2", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.590837626280514*^9, 3.5908376661217923`*^9}, {
   3.5908379583135047`*^9, 3.5908380517038465`*^9}, {3.5908381960561028`*^9, 
   3.5908383295867405`*^9}, 3.614861858723538*^9, 3.614917790532159*^9, 
   3.6152622154055085`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5908383412114053`*^9, 3.5909088465750113`*^9, 
  3.6114702747567806`*^9, 3.61527614391035*^9, 3.6180376978383083`*^9}]
}, Closed]],

Cell["Using the cobasis du, dv we may write", "Text",
 CellChangeTimes->{{3.590909029266932*^9, 3.590909052214572*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"sf", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", "u", ",", "u"}], "]"}], ".", 
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "*", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"u", ",", "u", ",", "v"}], "]"}], "[", "xx", "]"}], "*", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"u", ",", "u", ",", "v"}], "]"}], "[", "yy", "]"}]}], "+", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"sf", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", "u", ",", "v"}], "]"}], ".", 
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "*", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"u", ",", "u", ",", "v"}], "]"}], "[", "xx", "]"}], "*", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"v", ",", "u", ",", "v"}], "]"}], "[", "yy", "]"}]}], "+", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"sf", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", "v", ",", "u"}], "]"}], ".", 
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "*", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"v", ",", "u", ",", "v"}], "]"}], "[", "xx", "]"}], "*", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"u", ",", "u", ",", "v"}], "]"}], "[", "yy", "]"}]}], "+", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"sf", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", "v", ",", "v"}], "]"}], ".", 
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "*", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"v", ",", "u", ",", "v"}], "]"}], "[", "xx", "]"}], "*", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"v", ",", "u", ",", "v"}], "]"}], "[", "yy", "]"}]}], "+", 
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{"xx", ",", "yy"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.590838820986847*^9, 3.5908389558845625`*^9}, {
   3.590838990723555*^9, 3.5908390265996075`*^9}, {3.5908390586154385`*^9, 
   3.5908390676709566`*^9}, {3.5908391213030243`*^9, 
   3.5908391710558696`*^9}, {3.5908392565527596`*^9, 3.590839257639822*^9}, {
   3.590839445520568*^9, 3.59083947264812*^9}, 3.5908415910502853`*^9, {
   3.611470519818797*^9, 3.61147052284297*^9}, {3.611470586316601*^9, 
   3.6114705918189154`*^9}, {3.6114708904849977`*^9, 
   3.6114708942192116`*^9}, {3.611470943300019*^9, 3.6114709523105345`*^9}, {
   3.6148618587391376`*^9, 3.614861858754738*^9}, {3.614917790547759*^9, 
   3.614917790563359*^9}, {3.615262216609577*^9, 3.615262220241785*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.5908391813724594`*^9, 3.5908392620350733`*^9, {3.590839448234723*^9, 
   3.590839476571344*^9}, 3.590839656507636*^9, 3.590841592678378*^9, 
   3.611470301184292*^9, 3.611470603805601*^9, 3.6114709586258955`*^9, 
   3.6152761591522217`*^9, 3.618037714807279*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{"xx", ",", "yy"}], "]"}], " ", "-", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"fd2", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "*", 
      RowBox[{"xx", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "*", 
      RowBox[{"yy", "[", 
       RowBox[{"[", "j", "]"}], "]"}]}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "2"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5908401746002693`*^9, 3.5908402249931517`*^9}, {
   3.5908402920429864`*^9, 3.5908403707404876`*^9}, {3.5908404013022356`*^9, 
   3.5908404929334764`*^9}, 3.590840842709483*^9, 3.5908409435162487`*^9, {
   3.5908411319660273`*^9, 3.59084131367642*^9}, {3.590841362764228*^9, 
   3.590841376276001*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.5908408449406104`*^9, 3.590840948740547*^9, {3.590841296236423*^9, 
   3.5908413156165314`*^9}, 3.590841377976098*^9, 3.611471018833339*^9, 
   3.615276179081362*^9, 3.618037735741476*^9}]
}, Closed]],

Cell["For possible future applications we define", "Text",
 CellChangeTimes->{{3.5909091109174757`*^9, 3.590909168762377*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "fund2a", "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund2a", "[", "ff_", "]"}], "[", 
     RowBox[{"u_", ",", "v_"}], "]"}], "[", 
    RowBox[{"x_List", ",", "y_List"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"d", "[", 
            RowBox[{"d", "[", "ff", "]"}], "]"}], "[", 
           RowBox[{"u1", ",", "v1"}], "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"u1", "\[Rule]", "u"}], ",", 
            RowBox[{"v1", "\[Rule]", "v"}]}], "}"}]}], ")"}], ".", "x"}], 
       ")"}], ".", "y"}], ")"}], ".", 
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "3", "]"}], "[", "ff", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5908418218494864`*^9, 3.590841851618189*^9}, {
   3.590845349630325*^9, 3.590845703112543*^9}, {3.590907786584349*^9, 
   3.590907800437174*^9}, {3.590907905596958*^9, 3.5909079379046154`*^9}, {
   3.614057154177955*^9, 3.6140572705541596`*^9}, 3.614861858754738*^9, 
   3.6149177905789585`*^9, 3.615262223526973*^9}],

Cell["Regard that fund2 and fund2a differ by the sign only:", "Text",
 CellChangeTimes->{{3.5909093606603928`*^9, 3.590909391316146*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund2a", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", " ", "v"}], "]"}], "[", 
    RowBox[{"xx", ",", "yy"}], "]"}], " ", "+", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", " ", "v"}], "]"}], "[", 
    RowBox[{"xx", ",", "yy"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5908457241747475`*^9, 3.5908458264865994`*^9}, {
   3.5908458587194433`*^9, 3.59084586740694*^9}, 3.590846092119793*^9, {
   3.5908461398635235`*^9, 3.590846173752462*^9}, {3.59090782689482*^9, 
   3.5909078458800535`*^9}, 3.590907989353505*^9, 3.61803783090792*^9, 
   3.6180378859720693`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5909079902739067`*^9, 3.6114710534603195`*^9, 
  3.6140573009742126`*^9, 3.6152762828302956`*^9, 3.618037890918352*^9}]
}, Closed]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{3.5902202412377605`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["3.4. Normal and Principal Curvatures", "Subsection",
 CellChangeTimes->{{3.5911636991239314`*^9, 3.591163726106475*^9}, 
   3.6114711409343233`*^9, 3.611640870360384*^9, 3.615276399973996*^9, 
   3.615434797034876*^9, 3.618037933137767*^9, 3.618406755097189*^9}],

Cell["\<\
Consider a general curve on the surface (or a two-dimensional manifold) with \
parameter s\
\>", "Text",
 CellChangeTimes->{{3.591163790323148*^9, 3.5911637979785852`*^9}, {
   3.5911638677065735`*^9, 3.591163893043023*^9}, 3.615276463125608*^9, {
   3.618293875822893*^9, 3.6182939377394023`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Gamma]", "[", "s_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"hu", "[", "s", "]"}], ",", 
    RowBox[{"hv", "[", "s", "]"}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5911640806537533`*^9, 3.5911641202370176`*^9}}],

Cell["Such a curve on the surface ff[u,v] is given by", "Text",
 CellChangeTimes->{{3.6182945196204243`*^9, 3.6182945562960887`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cxx", "[", "ff_", "]"}], "[", "s_", "]"}], " ", ":=", 
  RowBox[{"ff", "[", 
   RowBox[{
    RowBox[{"u", "[", "s", "]"}], ",", 
    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.618294110182105*^9, 3.6182941903194456`*^9}, 
   3.618294366069354*^9}],

Cell["For the non specified general surface we set", "Text",
 CellChangeTimes->{{3.618294651565456*^9, 3.618294677352301*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"cx", "[", "s_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"cxx", "[", "sf", "]"}], "[", "s", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5911639056057415`*^9, 3.5911639586847773`*^9}, 
   3.5911644865179677`*^9, 3.611471276833096*^9, {3.6182942572903633`*^9, 
   3.6182943057128487`*^9}, 3.618294381731782*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cx", "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.6182943281612883`*^9, 3.6182943327788963`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "1", "]"}], "[", 
    RowBox[{
     RowBox[{"u", "[", "s", "]"}], ",", 
     RowBox[{"hv", "[", "s", "]"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "2", "]"}], "[", 
    RowBox[{
     RowBox[{"u", "[", "s", "]"}], ",", 
     RowBox[{"hv", "[", "s", "]"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "3", "]"}], "[", 
    RowBox[{
     RowBox[{"u", "[", "s", "]"}], ",", 
     RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.618294334635299*^9, 3.618294389204195*^9}]
}, Closed]],

Cell["\<\
A parameter s is  the arc length parameter if the following condition is \
satisfied\
\>", "Text",
 CellChangeTimes->{{3.5911640248865643`*^9, 3.5911640470268307`*^9}, {
  3.6152764886770697`*^9, 3.615276498893654*^9}, {3.618294718099573*^9, 
  3.618294723200782*^9}, {3.6182948073161297`*^9, 3.6182949029754972`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"cx", "'"}], "[", "s", "]"}], ".", 
    RowBox[{
     RowBox[{"cx", "'"}], "[", "s", "]"}]}], " ", "==", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", "sf", "]"}], "[", 
     RowBox[{
      RowBox[{"hu", "[", "s", "]"}], ",", 
      RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
     RowBox[{
      RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591164184167674*^9, 3.5911642643002577`*^9}, {
   3.5911643068696923`*^9, 3.591164405895356*^9}, 3.5911644724711647`*^9, {
   3.5911646118721375`*^9, 3.5911646213996825`*^9}, {3.5911647404074893`*^9, 
   3.59116474548778*^9}, {3.611471280412301*^9, 3.611471281483362*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["hv", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"u", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox["u", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"u", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], "2"], "+", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["hv", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"u", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox["u", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"u", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], "2"], "+", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["hv", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"u", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox["u", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"u", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], "2"]}], 
  "\[Equal]", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["hv", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}], "+", 
   RowBox[{"2", " ", 
    RowBox[{
     SuperscriptBox["hu", "\[Prime]",
      MultilineFunction->None], "[", "s", "]"}], " ", 
    RowBox[{
     SuperscriptBox["hv", "\[Prime]",
      MultilineFunction->None], "[", "s", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["hu", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], 
     ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.591164410118598*^9, 3.5911644376651735`*^9}, {
   3.59116447536633*^9, 3.591164492284298*^9}, 3.5911647583315144`*^9, 
   3.591415055427568*^9, 3.598365664084193*^9, 3.598426545694792*^9, 
   3.611471450836048*^9, 3.6116353342538605`*^9, 3.6152765163216505`*^9, 
   3.618038545415787*^9, 3.618043802877192*^9, 3.6182169133639164`*^9, 
   3.6182949095743093`*^9}]
}, Closed]],

Cell["The arc length condition is", "Text",
 CellChangeTimes->{{3.5911647999228935`*^9, 3.591164817426895*^9}, 
   3.61719839476588*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "scond", "]"}], ";", " ", 
  RowBox[{
   RowBox[{"scond", "[", "ff_", "]"}], " ", ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fund1", "[", "ff", "]"}], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], "\[Equal]", 
     "1"}], " ", ")"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5911648479476404`*^9, 3.5911649300543365`*^9}, 
   3.5911649671824603`*^9, {3.6136198879621105`*^9, 3.6136199074309444`*^9}, {
   3.6136204685483303`*^9, 3.613620472947538*^9}, {3.6180438506689253`*^9, 
   3.6180438890771227`*^9}, {3.6182094587451887`*^9, 3.6182094648291993`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"scond", "[", 
   RowBox[{"sphero", "[", "1", "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.598944128504306*^9, 3.5989441321885166`*^9}, {
  3.6136199311429863`*^9, 3.613619945604212*^9}, {3.613620401281012*^9, 
  3.6136204109530287`*^9}, {3.61728282398886*^9, 3.617282859771202*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"Cos", "[", 
      RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["hu", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], "2"]}], "+", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["hv", "\[Prime]",
      MultilineFunction->None], "[", "s", "]"}], "2"]}], "\[Equal]", 
  "1"}]], "Output",
 CellChangeTimes->{3.6172828616900053`*^9, 3.6180438982616477`*^9, 
  3.6181145972918153`*^9, 3.618209485062435*^9, 3.6182169936104574`*^9, 
  3.618294964236805*^9}]
}, Closed]],

Cell[TextData[{
 "Now the derivation of this equation must be zero; this is an analytic \
consequence not recognized automatically by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ":"
}], "Text",
 CellChangeTimes->{{3.599025515164632*^9, 3.5990256061127915`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fund1", "[", 
        RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], ",", "s"}], 
    "]"}], ",", 
   RowBox[{"scond", "[", 
    RowBox[{"sphero", "[", "1", "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5989442396766644`*^9, 3.5989442862613287`*^9}, {
   3.6136206379490275`*^9, 3.6136206408506327`*^9}, {3.617282881985641*^9, 
   3.617282884887246*^9}, {3.618217879816814*^9, 3.6182178831708198`*^9}, 
   3.618218489091484*^9, {3.618295111095543*^9, 3.6182951433683887`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", 
      RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["hu", "\[Prime]",
      MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["hv", "\[Prime]",
     MultilineFunction->None], "[", "s", "]"}]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", 
     RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["hu", "\[Prime]",
     MultilineFunction->None], "[", "s", "]"}], " ", 
   RowBox[{
    SuperscriptBox["hu", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "s", "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{
    SuperscriptBox["hv", "\[Prime]",
     MultilineFunction->None], "[", "s", "]"}], " ", 
   RowBox[{
    SuperscriptBox["hv", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "s", "]"}]}]}]], "Output",
 CellChangeTimes->{3.61422885833899*^9, 3.61719845708799*^9, 
  3.6180439233460827`*^9, 3.6182088016252346`*^9, 3.618209543843338*^9, 
  3.618217034513729*^9, 3.6182178907212334`*^9, 3.6182184956278954`*^9, 
  3.6182951463775606`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fund1", "[", "sf", "]"}], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], ",", "s"}], 
    "]"}], ",", 
   RowBox[{"scond", "[", 
    RowBox[{"sphero", "[", "1", "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5989442396766644`*^9, 3.5989442862613287`*^9}, {
   3.6136206379490275`*^9, 3.6136206408506327`*^9}, {3.617282881985641*^9, 
   3.617282884887246*^9}, {3.618217879816814*^9, 3.6182178831708198`*^9}, 
   3.618218489091484*^9, {3.618295111095543*^9, 3.6182951433683887`*^9}, {
   3.618295278430114*^9, 3.6182952966481557`*^9}}],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["hv", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["hv", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["hv", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "s", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["hu", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "s", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], ")"}]}], 
    "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["hu", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["hv", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "s", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["hu", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "s", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
      ")"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["hu", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["hv", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["hu", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox["hv", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["hu", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.6182953048986273`*^9}]
}, Closed]],

Cell["Therefore we have to assume it explicitly:", "Text",
 CellChangeTimes->{{3.5990256677016993`*^9, 3.599025684378129*^9}, 
   3.61728290995649*^9, 3.617441777844398*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", "scond2", "]"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{"scond2", "[", "ff_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"scond", "[", "ff", "]"}], ",", " ", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"fund1", "[", "ff", "]"}], "[", 
            RowBox[{
             RowBox[{"hu", "[", "t", "]"}], ",", 
             RowBox[{"hv", "[", "t", "]"}]}], "]"}], "[", 
           RowBox[{
            RowBox[{
             RowBox[{"\[Gamma]", "'"}], "[", "t", "]"}], ",", 
            RowBox[{
             RowBox[{"\[Gamma]", "'"}], "[", "t", "]"}]}], "]"}], ",", "t"}], 
         "]"}], "/.", 
        RowBox[{"t", "->", "s"}]}], " ", "]"}], ")"}], "==", " ", "0"}]}], 
   "}"}]}], "\n", 
 RowBox[{"  "}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5989444311036134`*^9, 3.598944452091814*^9}, {
   3.598944491622075*^9, 3.5989445892626595`*^9}, {3.613620483305956*^9, 
   3.613620520215621*^9}, {3.6136205570784855`*^9, 3.6136205617428937`*^9}, {
   3.6173372915542564`*^9, 3.6173373145675726`*^9}, 3.618208860062937*^9, {
   3.6182090179508142`*^9, 3.6182090390576515`*^9}, {3.618209092534545*^9, 
   3.6182090956701508`*^9}, 3.6182091600046635`*^9, {3.6182091936227226`*^9, 
   3.6182092224515734`*^9}, {3.61820972123125*^9, 3.618209830852642*^9}, {
   3.6182099255604086`*^9, 3.618209961814872*^9}, {3.618211324789266*^9, 
   3.6182113780477595`*^9}, {3.6182114114942183`*^9, 3.618211437405864*^9}, 
   3.618211471148723*^9, {3.6182164338814745`*^9, 3.618216468357535*^9}, {
   3.6182165257656355`*^9, 3.618216533191249*^9}, {3.6182185538627977`*^9, 
   3.618218577262839*^9}, 3.6182186344057393`*^9, {3.618218786227606*^9, 
   3.6182187922804165`*^9}, {3.6182217002815247`*^9, 
   3.6182217279247727`*^9}, {3.618221842928175*^9, 3.6182218524753914`*^9}}],

Cell["Now we obtain the expected result:", "Text",
 CellChangeTimes->{{3.6180604278910885`*^9, 3.618060462419063*^9}, {
   3.6182196402511063`*^9, 3.6182196579103374`*^9}, {3.61829593994195*^9, 
   3.6182959707107096`*^9}, 3.6184068236311083`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fund1", "[", "sf", "]"}], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], ",", "s"}], 
    "]"}], ",", 
   RowBox[{"scond2", "[", "sf", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5989442396766644`*^9, 3.5989442862613287`*^9}, {
  3.6136206379490275`*^9, 3.6136206408506327`*^9}, {3.617282881985641*^9, 
  3.617282884887246*^9}, {3.618059910127474*^9, 3.618059926725423*^9}, {
  3.6182186201629143`*^9, 3.6182186312857337`*^9}, {3.6182187056510644`*^9, 
  3.618218714121879*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.618059953714967*^9, 3.618208889874589*^9, {3.6182090470292654`*^9, 
   3.618209074625714*^9}, 3.6182091178377895`*^9, 3.618209250765623*^9, 
   3.618209974154494*^9, 3.618210010315357*^9, 3.6182100459146194`*^9, 
   3.6182115016779766`*^9, 3.61821658506134*^9, 3.6182172521029115`*^9, 
   3.618218535688766*^9, 3.6182185883544583`*^9, 3.618218654186574*^9, 
   3.618218720580291*^9, 3.61821882246647*^9, 3.618221744850803*^9, 
   3.6182217952232914`*^9, 3.6182218820686436`*^9, 3.618295361291853*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example",
  FontColor->RGBColor[0, 0, 1]],
 ". The unit sphere"
}], "Text",
 CellChangeTimes->{{3.6180604278910885`*^9, 3.618060462419063*^9}, {
  3.6182196402511063`*^9, 3.6182196579103374`*^9}, {3.61829593994195*^9, 
  3.618296005188682*^9}, {3.618296062100937*^9, 3.6182960712054577`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fund1", "[", 
     RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
    RowBox[{
     RowBox[{"hu", "[", "s", "]"}], ",", 
     RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
    RowBox[{
     RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.618220361128372*^9, 3.6182203959788337`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"Cos", "[", 
     RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["hu", "\[Prime]",
      MultilineFunction->None], "[", "s", "]"}], "2"]}], "+", 
  SuperscriptBox[
   RowBox[{
    SuperscriptBox["hv", "\[Prime]",
     MultilineFunction->None], "[", "s", "]"}], "2"]}]], "Output",
 CellChangeTimes->{3.6182203623919744`*^9, 3.6182203971020355`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{"%", ",", "s"}], "]"}]], "Input",
 CellChangeTimes->{{3.618220420798477*^9, 3.618220429269292*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["hu", "\[Prime]",
      MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["hv", "\[Prime]",
     MultilineFunction->None], "[", "s", "]"}]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", 
     RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["hu", "\[Prime]",
     MultilineFunction->None], "[", "s", "]"}], " ", 
   RowBox[{
    SuperscriptBox["hu", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "s", "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{
    SuperscriptBox["hv", "\[Prime]",
     MultilineFunction->None], "[", "s", "]"}], " ", 
   RowBox[{
    SuperscriptBox["hv", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "s", "]"}]}]}]], "Output",
 CellChangeTimes->{3.6182204302676935`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fund1", "[", 
        RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], ",", "s"}], 
    "]"}], ",", 
   RowBox[{"scond2", "[", 
    RowBox[{"sphero", "[", "1", "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5989442396766644`*^9, 3.5989442862613287`*^9}, {
   3.6136206379490275`*^9, 3.6136206408506327`*^9}, {3.617282881985641*^9, 
   3.617282884887246*^9}, {3.6182102141921153`*^9, 3.618210263519402*^9}, 
   3.6182116456038294`*^9, 3.618220220603326*^9, {3.6182360303187585`*^9, 
   3.618236096026074*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", 
      RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["hu", "\[Prime]",
      MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["hv", "\[Prime]",
     MultilineFunction->None], "[", "s", "]"}]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", 
     RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["hu", "\[Prime]",
     MultilineFunction->None], "[", "s", "]"}], " ", 
   RowBox[{
    SuperscriptBox["hu", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "s", "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{
    SuperscriptBox["hv", "\[Prime]",
     MultilineFunction->None], "[", "s", "]"}], " ", 
   RowBox[{
    SuperscriptBox["hv", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "s", "]"}]}]}]], "Output",
 CellChangeTimes->{3.6182361039976883`*^9, 3.618296111134742*^9}]
}, Closed]],

Cell["\<\
Unexpectedly, scond2[sphero[1]] has not been applied. 
First we have to evaluate and to simplify the specialized condition:\
\>", "Text",
 CellChangeTimes->{{3.618236148270566*^9, 3.6182362271599045`*^9}, {
  3.618296137309239*^9, 3.6182961587914677`*^9}, {3.618296206613203*^9, 
  3.6182962413651905`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Evaluate", "[", 
   RowBox[{"scond2", "[", 
    RowBox[{"sphero", "[", "1", "]"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6182358571116543`*^9, 3.6182358646152678`*^9}, {
  3.61823632717168*^9, 3.6182363467965145`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["hu", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], "2"]}], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["hv", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"]}], "\[Equal]", "1"}], 
   ",", 
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["hu", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox["hv", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}]}], "\[Equal]", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["hu", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox["hu", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "s", "]"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["hv", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox["hv", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "s", "]"}]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6182358659724703`*^9, 3.618236365142147*^9, 
  3.618296256531058*^9}]
}, Closed]],

Cell["Now we get the expected result:", "Text",
 CellChangeTimes->{{3.618236269311178*^9, 3.6182362919936185`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{"%", ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"fund1", "[", 
         RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], ",", "s"}], 
     "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.618217765187813*^9, 3.618217802393878*^9}, {
   3.6182179873790026`*^9, 3.6182180275178733`*^9}, 3.6182181114772205`*^9, 
   3.6182182611126833`*^9, 3.6182183126707745`*^9, 3.6182188601405363`*^9, {
   3.6182200229821787`*^9, 3.6182200436834145`*^9}, {3.618235708989394*^9, 
   3.6182357770055137`*^9}, 3.61823583762722*^9, {3.6182358763308883`*^9, 
   3.618235921149767*^9}, {3.61823636102374*^9, 3.618236386326984*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6182363898369904`*^9, 3.6182962740700607`*^9}]
}, Closed]],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.61822320072336*^9, 3.61822320072336*^9}}],

Cell[TextData[{
 StyleBox["Example",
  FontColor->RGBColor[0, 0, 1]],
 ". The  hyperboloid"
}], "Text",
 CellChangeTimes->{{3.6182368296017623`*^9, 3.618236847713394*^9}}],

Cell["\<\
The same situation we meet with other explicitly given surfaces, e. g.\
\>", "Text",
 CellChangeTimes->{{3.61829635272456*^9, 3.618296403549467*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hypsf", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.618236856090609*^9, 3.618236874139841*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", "u", "]"}], " ", 
    RowBox[{"Cosh", "[", "v", "]"}]}], ",", 
   RowBox[{
    RowBox[{"Cosh", "[", "v", "]"}], " ", 
    RowBox[{"Sin", "[", "u", "]"}]}], ",", 
   RowBox[{"Sinh", "[", "v", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6182368758714437`*^9, 3.6182962869958005`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"fund1", "[", "hypsf", "]"}], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
      RowBox[{
       RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], ",", "s"}], "]"}],
   "]"}]], "Input",
 CellChangeTimes->{3.618296326096037*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Sinh", "[", 
    RowBox[{"2", " ", 
     RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["hu", "\[Prime]",
      MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["hv", "\[Prime]",
     MultilineFunction->None], "[", "s", "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Sinh", "[", 
    RowBox[{"2", " ", 
     RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["hv", "\[Prime]",
      MultilineFunction->None], "[", "s", "]"}], "3"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox[
    RowBox[{"Cosh", "[", 
     RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["hu", "\[Prime]",
     MultilineFunction->None], "[", "s", "]"}], " ", 
   RowBox[{
    SuperscriptBox["hu", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "s", "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cosh", "[", 
    RowBox[{"2", " ", 
     RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["hv", "\[Prime]",
     MultilineFunction->None], "[", "s", "]"}], " ", 
   RowBox[{
    SuperscriptBox["hv", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "s", "]"}]}]}]], "Output",
 CellChangeTimes->{3.6182963278401365`*^9, 3.6182964479444027`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"Evaluate", "[", 
     RowBox[{"scond2", "[", "hypsf", "]"}], "]"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"fund1", "[", "hypsf", "]"}], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], ",", "s"}], 
     "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.618217765187813*^9, 3.618217802393878*^9}, {
   3.6182179873790026`*^9, 3.6182180275178733`*^9}, 3.6182181114772205`*^9, 
   3.6182182611126833`*^9, 3.6182183126707745`*^9, 3.6182188601405363`*^9, {
   3.6182200229821787`*^9, 3.6182200436834145`*^9}, {3.618235708989394*^9, 
   3.6182357770055137`*^9}, 3.61823583762722*^9, {3.6182358763308883`*^9, 
   3.618235921149767*^9}, {3.61823636102374*^9, 3.618236386326984*^9}, {
   3.6182369218915243`*^9, 3.6182369801108265`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.618236954136781*^9, 3.6182369942444515`*^9, 
  3.6182963352695613`*^9, 3.618296452841683*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "hypsf", "]"}], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], ".", 
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], ")"}], "^", "2"}], " ", 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "hypsf", "]"}], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], ".", 
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], ")"}], "^", "2"}]}], 
   ",", 
   RowBox[{"scond2", "[", "hypsf", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6182370761445956`*^9, 3.6182371296214895`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"Cosh", "[", 
     RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["hu", "\[Prime]",
      MultilineFunction->None], "[", "s", "]"}], "2"]}], "+", 
  RowBox[{
   RowBox[{"Cosh", "[", 
    RowBox[{"2", " ", 
     RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["hv", "\[Prime]",
      MultilineFunction->None], "[", "s", "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{3.6182371331002955`*^9, 3.618296462099212*^9}]
}, Closed]],

Cell["\<\
The same as before: First evaluate and simplify the specialized condition:\
\>", "Text",
 CellChangeTimes->{{3.6182372867293653`*^9, 3.618237333201847*^9}, {
  3.6182964786051564`*^9, 3.618296480141244*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"Evaluate", "[", 
     RowBox[{"scond2", "[", "hypsf", "]"}], "]"}], "]"}], ",", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "hypsf", "]"}], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}], ".", 
        RowBox[{
         RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], ")"}], "^", "2"}], " ",
      "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "hypsf", "]"}], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}], ".", 
        RowBox[{
         RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], ")"}], "^", "2"}]}], 
    "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6182370761445956`*^9, 3.6182371296214895`*^9}, {
   3.6182371678259563`*^9, 3.6182371946892037`*^9}, 3.618237242128887*^9}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.61823722663806*^9, 3.618237250599702*^9}, 
   3.6182965003844023`*^9}]
}, Closed]],

Cell["\<\
\[FilledSquare]

The general formula is obtained directly:\
\>", "Text",
 CellChangeTimes->{{3.6182373795027285`*^9, 3.6182374399996347`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], ".", 
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], ")"}], "^", "2"}], " ", 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], ".", 
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], ")"}], "^", "2"}]}], 
   ",", 
   RowBox[{"scond2", "[", "sf", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591164978147087*^9, 3.59116512593254*^9}, 
   3.6180441542132874`*^9}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.591165132469914*^9, 3.591339491060254*^9, 
  3.5983656035597315`*^9, 3.598365676023876*^9, 3.598426577628048*^9, 
  3.611471478927655*^9, 3.6114736801825595`*^9, 3.6116353914903607`*^9, 
  3.6152765745349803`*^9, 3.6180385830079374`*^9, 3.6180442395561686`*^9, 
  3.6180605013072877`*^9, 3.61811471934643*^9, 3.6182195412689323`*^9, 
  3.618296529619074*^9}]
}, Closed]],

Cell[TextData[{
 "There exists a uniquely defined ",
 StyleBox["angle",
  FontColor->RGBColor[0, 0, 1]],
 " \[Tau] between two tangent vectors  with coordinates {s1,s2}, {t1,t2} \
defined by"
}], "Text",
 CellChangeTimes->{{3.591165792643674*^9, 3.591165861738626*^9}, {
   3.5911660657072926`*^9, 3.5911660947709546`*^9}, 3.618296655345346*^9, {
   3.6182972690779467`*^9, 3.6182973948131385`*^9}, 3.618298044670308*^9, {
   3.618298078357235*^9, 3.6182980826774817`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"angle", "[", "ff_", "]"}], "[", 
    RowBox[{"u_", ",", " ", "v_"}], "]"}], "[", 
   RowBox[{"s_List", ",", " ", "t_List"}], "]"}], " ", ":=", " ", 
  RowBox[{"ArcCos", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"fund1", "[", "ff", "]"}], "[", 
      RowBox[{"u", ",", " ", "v"}], "]"}], "[", 
     RowBox[{"s", ",", " ", "t"}], "]"}], "/", " ", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"fund1", "[", "ff", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}], "[", 
       RowBox[{"s", ",", " ", "s"}], "]"}], "*", 
      RowBox[{
       RowBox[{
        RowBox[{"fund1", "[", "ff", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}], "[", 
       RowBox[{"t", ",", " ", "t"}], "]"}]}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6182985837181396`*^9, 3.61829858371914*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"angle", "[", 
    RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"s1", ",", "s2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t1", ",", "t2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6183113497195683`*^9, 3.6183114408887825`*^9}}],

Cell[BoxData[
 RowBox[{"ArcCos", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"s1", " ", "t1", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "v", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "u", "]"}], "2"]}]}], ")"}]}], "+", 
     RowBox[{"s2", " ", "t2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "2"], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "v", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Sin", "[", "u", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "v", "]"}], "2"]}]}], ")"}]}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"\[Sqrt]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["s1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", "v", "]"}], "2"]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", "u", "]"}], "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["s2", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Cos", "[", "v", "]"}], "2"], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", "v", "]"}], "2"]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"Sin", "[", "u", "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", "v", "]"}], "2"]}]}], ")"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["t1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", "v", "]"}], "2"]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", "u", "]"}], "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["t2", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Cos", "[", "v", "]"}], "2"], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", "v", "]"}], "2"]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"Sin", "[", "u", "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", "v", "]"}], "2"]}]}], ")"}]}]}], ")"}]}], 
      ")"}]}], ")"}]}], "]"}]], "Output",
 CellChangeTimes->{3.6183114450960236`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.6183114751387415`*^9, 3.618311485000306*^9}}],

Cell[BoxData[
 RowBox[{"ArcCos", "[", 
  FractionBox[
   RowBox[{
    RowBox[{"s1", " ", "t1"}], "+", 
    RowBox[{"2", " ", "s2", " ", "t2"}], "+", 
    RowBox[{"s1", " ", "t1", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "v"}], "]"}]}]}], 
   SqrtBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["s1", "2"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["s2", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["s1", "2"], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "v"}], "]"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["t1", "2"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["t2", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["t1", "2"], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "v"}], "]"}]}]}], ")"}]}]]], "]"}]], "Output",
 CellChangeTimes->{3.618312674508342*^9}]
}, Closed]],

Cell["\<\
The direction angle between the tangent vector of a curve on the surface with \
the tangent   vector amf[1]{ff][u,v] of the surface is defined as the \
solution of the equations\
\>", "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.6182974023185673`*^9, 3.618297482128133*^9}, {
   3.6182975428396053`*^9, 3.6182977356406326`*^9}, {3.618297912209732*^9, 
   3.618297956537267*^9}, {3.6182979883630877`*^9, 3.6182979985366697`*^9}, {
   3.6182980955372176`*^9, 3.61829810676186*^9}, {3.6182981910096784`*^9, 
   3.6182982298669004`*^9}, {3.618298282223895*^9, 3.6182983847377586`*^9}, 
   3.6182984255310917`*^9, 3.6182985196004725`*^9, {3.6182985972059116`*^9, 
   3.618298654213172*^9}, {3.6182986943974705`*^9, 3.618298766141574*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dirangle", "[", "ff_", "]"}], "[", "s_", "]"}], " ", ":=", " ", 
  RowBox[{"Assuming", "[", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"Evaluate", "[", 
      RowBox[{"scond2", "[", "ff", "]"}], "]"}], "]"}], ",", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "\[Tau]", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}], ".", 
         RowBox[{
          RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}]}], ",", " ", 
       RowBox[{
        RowBox[{"Sin", "[", "\[Tau]", "]"}], " ", "\[Equal]", " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}], ".", 
         RowBox[{
          RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"0", "\[LessEqual]", " ", "\[Tau]"}], ",", " ", 
       RowBox[{"\[Tau]", " ", "<", " ", 
        RowBox[{"2", "*", "Pi"}]}]}], "}"}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5911658904282665`*^9, 3.591166056496765*^9}, {
   3.5911664298171177`*^9, 3.591166476456786*^9}, {3.5911665164810753`*^9, 
   3.5911665297628345`*^9}, 3.5911673587612505`*^9, 3.6148618587859383`*^9, 
   3.614917790610159*^9, {3.615262227734214*^9, 3.6152622420480323`*^9}, 
   3.6152757802705507`*^9, {3.6152765968182545`*^9, 3.6152765992253923`*^9}, {
   3.6181181173599977`*^9, 3.618118117952799*^9}, {3.6182375175941706`*^9, 
   3.6182376369811807`*^9}, {3.618298818994597*^9, 3.618298822635805*^9}}],

Cell["It is the angle ", "Text",
 CellChangeTimes->{{3.618296717043454*^9, 3.6182967229246645`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dirangle", "[", 
   RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.6116354915177364`*^9, 3.6116355074453645`*^9}, {
   3.611635948395739*^9, 3.611635961468562*^9}, 3.6148618587859383`*^9, 
   3.614917790610159*^9, {3.6180442929732237`*^9, 3.618044310582231*^9}, 
   3.61804546640534*^9, {3.6180605496920547`*^9, 3.61806057566054*^9}, 
   3.61811479371176*^9, {3.618117354035057*^9, 3.6181173736598916`*^9}, {
   3.6181174175271683`*^9, 3.618117436574802*^9}, {3.618118143271643*^9, 
   3.618118149449254*^9}, {3.618237684498864*^9, 3.6182376950132823`*^9}, {
   3.6183189630340247`*^9, 3.618319022601432*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", "\[Tau]", "]"}], "\[Equal]", 
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}]], " ", 
     RowBox[{
      SuperscriptBox["hu", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"Sin", "[", "\[Tau]", "]"}], "\[Equal]", 
    FractionBox[
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}]], " ", 
      RowBox[{
       SuperscriptBox["hv", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}]}], 
     SqrtBox[
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}]]]}], ",", 
   RowBox[{"\[Tau]", "\[GreaterEqual]", "0"}], ",", 
   RowBox[{"\[Tau]", "<", 
    RowBox[{"2", " ", "\[Pi]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.611635512702574*^9, 3.611635965259369*^9, 3.615276621064642*^9, 
   3.6180386397371817`*^9, 3.6180454348265343`*^9, 3.6180454711076093`*^9, 
   3.618063769732231*^9, 3.618114927201195*^9, 3.618117454702034*^9, 
   3.61811815266286*^9, 3.6181196685799227`*^9, 3.618237721470929*^9, 
   3.618318983022168*^9, 3.6183190323369884`*^9, {3.61837515290993*^9, 
   3.618375174796769*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{"r", "\[Rule]", "1"}]}], ",", "\[Tau]", ",", "Reals"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.611635580391093*^9, 3.611635587114704*^9}, {
   3.6116356236031685`*^9, 3.6116356431344028`*^9}, 3.6148618588015385`*^9, 
   3.6149177906413593`*^9, {3.618119717361208*^9, 3.618119726877225*^9}, {
   3.618320086843303*^9, 3.618320092458624*^9}, 3.618375224935257*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"hv", "[", "s", "]"}], "]"}], "\[Equal]", "0"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], "\[Equal]", 
         RowBox[{"-", "1"}]}], "&&", 
        RowBox[{"\[Tau]", "\[Equal]", 
         FractionBox[
          RowBox[{"3", " ", "\[Pi]"}], "2"]}]}], ")"}], "||", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], "\[Equal]", "1"}], "&&", 
        RowBox[{"\[Tau]", "\[Equal]", 
         FractionBox["\[Pi]", "2"]}]}], ")"}]}], ")"}]}], ")"}], "||", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"hv", "[", "s", "]"}], "]"}], ">", "0"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sec", "[", 
           RowBox[{"hv", "[", "s", "]"}], "]"}]}], "<", 
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], "<", 
         RowBox[{"Sec", "[", 
          RowBox[{"hv", "[", "s", "]"}], "]"}]}], "&&", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["hv", "\[Prime]",
               MultilineFunction->None], "[", "s", "]"}], "\[Equal]", 
             RowBox[{"-", 
              SqrtBox[
               RowBox[{"1", "-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"]}]}]]}]}], 
            "&&", 
            RowBox[{"\[Tau]", "\[Equal]", 
             RowBox[{
              RowBox[{"2", " ", "\[Pi]"}], "-", 
              RowBox[{"2", " ", 
               RowBox[{"ArcTan", "[", 
                SqrtBox[
                 FractionBox[
                  RowBox[{"1", "-", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}]}]}], 
                  RowBox[{"1", "+", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}]}]}]]], 
                "]"}]}]}]}]}], ")"}], "||", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["hv", "\[Prime]",
               MultilineFunction->None], "[", "s", "]"}], "\[Equal]", 
             SqrtBox[
              RowBox[{"1", "-", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"]}]}]]}], "&&", 
            RowBox[{"\[Tau]", "\[Equal]", 
             RowBox[{"2", " ", 
              RowBox[{"ArcTan", "[", 
               SqrtBox[
                FractionBox[
                 RowBox[{"1", "-", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}]}]}], 
                 RowBox[{"1", "+", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}]}]}]]], 
               "]"}]}]}]}], ")"}]}], ")"}]}], ")"}], "||", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], "\[Equal]", 
         RowBox[{"Sec", "[", 
          RowBox[{"hv", "[", "s", "]"}], "]"}]}], "&&", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], "\[Equal]", "0"}], "&&", 
        RowBox[{"\[Tau]", "\[Equal]", "0"}]}], ")"}], "||", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], "\[Equal]", 
         RowBox[{"-", 
          RowBox[{"Sec", "[", 
           RowBox[{"hv", "[", "s", "]"}], "]"}]}]}], "&&", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], "\[Equal]", "0"}], "&&", 
        RowBox[{"\[Tau]", "\[Equal]", "\[Pi]"}]}], ")"}]}], ")"}]}], ")"}], "||", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"hv", "[", "s", "]"}], "]"}], "<", "0"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Sec", "[", 
          RowBox[{"hv", "[", "s", "]"}], "]"}], "<", 
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], "<", 
         RowBox[{"-", 
          RowBox[{"Sec", "[", 
           RowBox[{"hv", "[", "s", "]"}], "]"}]}]}], "&&", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["hv", "\[Prime]",
               MultilineFunction->None], "[", "s", "]"}], "\[Equal]", 
             RowBox[{"-", 
              SqrtBox[
               RowBox[{"1", "-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"]}]}]]}]}], 
            "&&", 
            RowBox[{"\[Tau]", "\[Equal]", 
             RowBox[{
              RowBox[{"2", " ", "\[Pi]"}], "-", 
              RowBox[{"2", " ", 
               RowBox[{"ArcTan", "[", 
                SqrtBox[
                 FractionBox[
                  RowBox[{
                   RowBox[{"-", "1"}], "-", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}]}]}], 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}]}]}]]], 
                "]"}]}]}]}]}], ")"}], "||", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["hv", "\[Prime]",
               MultilineFunction->None], "[", "s", "]"}], "\[Equal]", 
             SqrtBox[
              RowBox[{"1", "-", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"]}]}]]}], "&&", 
            RowBox[{"\[Tau]", "\[Equal]", 
             RowBox[{"2", " ", 
              RowBox[{"ArcTan", "[", 
               SqrtBox[
                FractionBox[
                 RowBox[{
                  RowBox[{"-", "1"}], "-", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}]}]}], 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}]}]}]]], 
               "]"}]}]}]}], ")"}]}], ")"}]}], ")"}], "||", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], "\[Equal]", 
         RowBox[{"-", 
          RowBox[{"Sec", "[", 
           RowBox[{"hv", "[", "s", "]"}], "]"}]}]}], "&&", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], "\[Equal]", "0"}], "&&", 
        RowBox[{"\[Tau]", "\[Equal]", "0"}]}], ")"}], "||", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], "\[Equal]", 
         RowBox[{"Sec", "[", 
          RowBox[{"hv", "[", "s", "]"}], "]"}]}], "&&", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], "\[Equal]", "0"}], "&&", 
        RowBox[{"\[Tau]", "\[Equal]", "\[Pi]"}]}], ")"}]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.6181182596790476`*^9, 3.6181197331484356`*^9, 
  3.618237737273757*^9, 3.618319090529317*^9, 3.6183200958948207`*^9, 
  3.618375179913578*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solangle", " ", "=", 
  RowBox[{"Assuming", "[", 
   RowBox[{
    RowBox[{"scond2", "[", 
     RowBox[{"sphero", "[", "1", "]"}], "]"}], ",", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{"%", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], "\[Element]", " ", "Reals"}], ",", 
        RowBox[{
         RowBox[{"hv", "[", "s", "]"}], "\[Element]", " ", "Reals"}]}], 
       "}"}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6183191347148447`*^9, 3.6183191944412603`*^9}, 
   3.618319228977236*^9, {3.6183193357953453`*^9, 3.6183193716903987`*^9}, {
   3.6183194292416906`*^9, 3.61831947505031*^9}, 3.61837523803928*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["hv", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], "\[Equal]", "0"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Tau]", "\[Equal]", "0"}], "&&", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Sec", "[", 
              RowBox[{"hv", "[", "s", "]"}], "]"}], "\[Equal]", 
             RowBox[{
              SuperscriptBox["hu", "\[Prime]",
               MultilineFunction->None], "[", "s", "]"}]}], "&&", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"hv", "[", "s", "]"}], "]"}], ">", "0"}]}], ")"}], "||", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Sec", "[", 
               RowBox[{"hv", "[", "s", "]"}], "]"}], "+", 
              RowBox[{
               SuperscriptBox["hu", "\[Prime]",
                MultilineFunction->None], "[", "s", "]"}]}], "\[Equal]", 
             "0"}], "&&", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"hv", "[", "s", "]"}], "]"}], "<", "0"}]}], ")"}]}], 
         ")"}]}], ")"}], "||", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Tau]", "\[Equal]", "\[Pi]"}], "&&", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Sec", "[", 
              RowBox[{"hv", "[", "s", "]"}], "]"}], "\[Equal]", 
             RowBox[{
              SuperscriptBox["hu", "\[Prime]",
               MultilineFunction->None], "[", "s", "]"}]}], "&&", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"hv", "[", "s", "]"}], "]"}], "<", "0"}]}], ")"}], "||", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Sec", "[", 
               RowBox[{"hv", "[", "s", "]"}], "]"}], "+", 
              RowBox[{
               SuperscriptBox["hu", "\[Prime]",
                MultilineFunction->None], "[", "s", "]"}]}], "\[Equal]", 
             "0"}], "&&", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"hv", "[", "s", "]"}], "]"}], ">", "0"}]}], ")"}]}], 
         ")"}]}], ")"}]}], ")"}]}], ")"}], "||", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{"1", "-", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], "2"]}]}]], "\[Equal]", 
     RowBox[{
      SuperscriptBox["hv", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}]}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Tau]", "\[Equal]", 
         RowBox[{"2", " ", 
          RowBox[{"ArcTan", "[", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             FractionBox["2", 
              RowBox[{"1", "+", 
               RowBox[{
                RowBox[{"Cos", "[", 
                 RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}]}]}]]}]], 
           "]"}]}]}], "&&", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"hv", "[", "s", "]"}], "]"}], ">", "0"}], "&&", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sec", "[", 
           RowBox[{"hv", "[", "s", "]"}], "]"}]}], "<", 
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], "<", 
         RowBox[{"Sec", "[", 
          RowBox[{"hv", "[", "s", "]"}], "]"}]}]}], ")"}], "||", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Tau]", "\[Equal]", 
         RowBox[{"2", " ", 
          RowBox[{"ArcTan", "[", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "1"}], "-", 
             FractionBox["2", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{
                RowBox[{"Cos", "[", 
                 RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}]}]}]]}]], 
           "]"}]}]}], "&&", 
        RowBox[{
         RowBox[{"Sec", "[", 
          RowBox[{"hv", "[", "s", "]"}], "]"}], "<", 
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], "<", 
         RowBox[{"-", 
          RowBox[{"Sec", "[", 
           RowBox[{"hv", "[", "s", "]"}], "]"}]}]}], "&&", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"hv", "[", "s", "]"}], "]"}], "<", "0"}]}], ")"}]}], 
     ")"}]}], ")"}], "||", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"hv", "[", "s", "]"}], "]"}], "\[Equal]", "0"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"2", " ", "\[Tau]"}], "\[Equal]", "\[Pi]"}], "&&", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], "\[Equal]", "1"}]}], 
       ")"}], "||", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"2", " ", "\[Tau]"}], "\[Equal]", 
         RowBox[{"3", " ", "\[Pi]"}]}], "&&", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], "\[Equal]", 
         RowBox[{"-", "1"}]}]}], ")"}]}], ")"}]}], ")"}], "||", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      SqrtBox[
       RowBox[{"1", "-", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["hu", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], "2"]}]}]], "+", 
      RowBox[{
       SuperscriptBox["hv", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}]}], "\[Equal]", "0"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", " ", 
           RowBox[{"ArcTan", "[", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              FractionBox["2", 
               RowBox[{"1", "+", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}]}]}]]}]], 
            "]"}]}]}], "\[Equal]", 
         RowBox[{"2", " ", "\[Pi]"}]}], "&&", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"hv", "[", "s", "]"}], "]"}], ">", "0"}], "&&", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sec", "[", 
           RowBox[{"hv", "[", "s", "]"}], "]"}]}], "<", 
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], "<", 
         RowBox[{"Sec", "[", 
          RowBox[{"hv", "[", "s", "]"}], "]"}]}]}], ")"}], "||", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Tau]", "+", 
          RowBox[{"2", " ", 
           RowBox[{"ArcTan", "[", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "1"}], "-", 
              FractionBox["2", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}]}]}]]}]], 
            "]"}]}]}], "\[Equal]", 
         RowBox[{"2", " ", "\[Pi]"}]}], "&&", 
        RowBox[{
         RowBox[{"Sec", "[", 
          RowBox[{"hv", "[", "s", "]"}], "]"}], "<", 
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], "<", 
         RowBox[{"-", 
          RowBox[{"Sec", "[", 
           RowBox[{"hv", "[", "s", "]"}], "]"}]}]}], "&&", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"hv", "[", "s", "]"}], "]"}], "<", "0"}]}], ")"}]}], 
     ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.618319612998201*^9, 3.618375356521488*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solangle", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"hv", "[", "s", "]"}], " ", "\[Rule]", " ", "0"}], ",", 
    RowBox[{
     RowBox[{"hu", "[", "s", "]"}], " ", "\[Rule]", " ", 
     RowBox[{"1", "+", "s"}]}], ",", 
    RowBox[{
     RowBox[{
      SuperscriptBox["hv", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], "\[Rule]", " ", "0"}], ",", 
    RowBox[{
     RowBox[{
      SuperscriptBox["hu", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], "\[Rule]", "1"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.611635580391093*^9, 3.611635587114704*^9}, {
   3.6116356236031685`*^9, 3.6116356431344028`*^9}, 3.6148618588015385`*^9, 
   3.6149177906413593`*^9, 3.618118629384097*^9, {3.61811879586759*^9, 
   3.618118838892465*^9}, {3.618119433066309*^9, 3.618119489522808*^9}, {
   3.6181195503005147`*^9, 3.618119577226162*^9}, 3.61811986070986*^9, {
   3.6181199797380686`*^9, 3.618120032622162*^9}, 3.6182378003914676`*^9, {
   3.618320127722641*^9, 3.618320133946997*^9}, {3.618320467129054*^9, 
   3.6183204861621428`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Power", "::", "infy"}], "MessageName"], ":", 
  " ", "\<\"Infinite expression \[NoBreak]\\!\\(1\\/0\\)\[NoBreak] \
encountered. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/infy\\\", ButtonNote -> \
\\\"Power::infy\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6183759388081107`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Power", "::", "infy"}], "MessageName"], ":", 
  " ", "\<\"Infinite expression \[NoBreak]\\!\\(1\\/0\\)\[NoBreak] \
encountered. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/infy\\\", ButtonNote -> \
\\\"Power::infy\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.618375938854911*^9}],

Cell[BoxData[
 RowBox[{"\[Tau]", "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.618320487968246*^9, 3.618375938854911*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Reduce", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"dirangle", "[", 
       RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", "s", "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["hv", "\[Prime]",
          MultilineFunction->None], "[", "s", "]"}], "\[Rule]", " ", 
        RowBox[{"1", "/", 
         RowBox[{"Sqrt", "[", "2", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["hu", "\[Prime]",
          MultilineFunction->None], "[", "s", "]"}], "\[Rule]", 
        RowBox[{"1", "/", 
         RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], "}"}]}], ",", "\[Tau]", ",", 
    "Reals"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.611635580391093*^9, 3.611635587114704*^9}, {
   3.6116356236031685`*^9, 3.6116356431344028`*^9}, 3.6148618588015385`*^9, 
   3.6149177906413593`*^9, 3.618118629384097*^9, {3.61811879586759*^9, 
   3.618118838892465*^9}, {3.618119433066309*^9, 3.618119489522808*^9}, {
   3.6181195503005147`*^9, 3.618119577226162*^9}, 3.61811986070986*^9, 
   3.618119948070013*^9, 3.618120040656176*^9, {3.618120115208707*^9, 
   3.6181201569699802`*^9}, 3.618237828970718*^9, {3.6183201627306433`*^9, 
   3.618320166970886*^9}, {3.618320507146343*^9, 3.6183205123936434`*^9}, {
   3.6183206598570776`*^9, 3.6183207264948893`*^9}, {3.618320972341951*^9, 
   3.6183209890159044`*^9}, {3.618321068420446*^9, 3.6183210771309443`*^9}, 
   3.618321121093459*^9, {3.618321162740841*^9, 3.6183211834050226`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"4", " ", "\[Tau]"}], "\[Equal]", "\[Pi]"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"hv", "[", "s", "]"}], "]"}], "\[Equal]", 
     RowBox[{"-", "1"}]}], "||", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"hv", "[", "s", "]"}], "]"}], "\[Equal]", "1"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.6183211244376497`*^9, 3.6183211878662777`*^9, 
  3.6183760023626223`*^9}]
}, Closed]],

Cell["Clearly, the solution is \[Tau] = Pi/4.", "Text",
 CellChangeTimes->{{3.591168964923118*^9, 3.5911689898665447`*^9}, {
   3.598367986622035*^9, 3.5983680078382483`*^9}, 3.611471327168975*^9, {
   3.611636294653947*^9, 3.6116363786600947`*^9}, {3.6181209493889723`*^9, 
   3.618120953039378*^9}, {3.6181215261999855`*^9, 3.61812154033361*^9}, {
   3.6182378794368067`*^9, 3.6182379036012487`*^9}}],

Cell["\<\

We consider the curvature vector of the curve cx[s] under the conditions\
\>", "Text",
 CellChangeTimes->{{3.591168964923118*^9, 3.5911689898665447`*^9}, {
   3.598367986622035*^9, 3.5983680078382483`*^9}, 3.611471327168975*^9, {
   3.611636294653947*^9, 3.6116363786600947`*^9}, {3.6181209493889723`*^9, 
   3.618120953039378*^9}, {3.6181215261999855`*^9, 3.61812154033361*^9}, {
   3.6182378794368067`*^9, 3.6182379036012487`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "assu"}]], "Input",
 CellChangeTimes->{{3.591174076491518*^9, 3.591174077960602*^9}}],

Cell[BoxData[
 StyleBox["\<\"assu[c][s] is a set of assumptions in the first four \
derivatives of the \\nparameter representation c[s] of a smooth curve in the \
n-dimensional Euclidean space \\ngiving True if s is the Euclidean arc length \
of the curve.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.618038730909397*^9},
 CellTags->"Info3618045930-7228279"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"assu", "[", "cx", "]"}], "[", "s", "]"}], ",", " ", 
   RowBox[{"scond2", "[", "sf", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.598428016364175*^9, 3.598428062821057*^9}, 
   3.611471341193777*^9, 3.611636845693715*^9, 3.6116369060502214`*^9, 
   3.6180441561984005`*^9}],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.5984384030450983`*^9, 3.6114715917451077`*^9, 
  3.611473708873201*^9, 3.6116368878449893`*^9, 3.615276733041046*^9, 
  3.618038778029092*^9, 3.6181240214087677`*^9, 3.618321704598833*^9}]
}, Closed]],

Cell["\<\
Aborted without result after more than 2 h. The first and the second assu \
conditions are confirmed immediately:\
\>", "Text",
 CellChangeTimes->{{3.5984384164455223`*^9, 3.5984384360235567`*^9}, {
  3.59843866032075*^9, 3.5984386991024184`*^9}, {3.618323281095004*^9, 
  3.6183233051033773`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"assu", "[", "cx", "]"}], "[", "s", "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "&&", 
    RowBox[{
     RowBox[{
      RowBox[{"assu", "[", "cx", "]"}], "[", "s", "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], ",", " ", 
   RowBox[{"scond2", "[", "sf", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.598428016364175*^9, 3.598428062821057*^9}, {
   3.5984384649148073`*^9, 3.598438474914425*^9}, 3.6114713433619013`*^9, 
   3.618044157163456*^9, {3.6181240460568113`*^9, 3.61812408535328*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.61812412514895*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "assus", "]"}], ";", 
  RowBox[{"assus", " ", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"assu", "[", "cx", "]"}], "[", "s", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"assu", "[", "cx", "]"}], "[", "s", "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5911689961229024`*^9, 3.591169051093046*^9}, {
   3.5911691093823805`*^9, 3.5911691751901445`*^9}, {3.591169252847586*^9, 
   3.591169263705207*^9}, {3.591169836602975*^9, 3.5911699178166203`*^9}, 
   3.5911700071127276`*^9, {3.5911705231692443`*^9, 3.5911705358059673`*^9}, {
   3.5913395259107156`*^9, 3.5913395324003267`*^9}, {3.5913398016568003`*^9, 
   3.591339809987214*^9}, {3.5913398788457355`*^9, 3.591339883354143*^9}, 
   3.591339948439858*^9, {3.598366907262299*^9, 3.5983669440114007`*^9}, 
   3.598367075362914*^9, 3.5983678274109287`*^9, {3.598367858545709*^9, 
   3.598367861345869*^9}, {3.5984266150837135`*^9, 3.5984266177513185`*^9}, {
   3.5984266931306505`*^9, 3.59842674964955*^9}, {3.6114713463390713`*^9, 
   3.61147134754714*^9}, {3.6114819710020685`*^9, 3.61148197453127*^9}, 
   3.611482035668767*^9, 3.611483426397312*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], "2"]}], 
    "\[Equal]", "1"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["hv", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["u", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["u", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"2", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["hv", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["u", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["u", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"2", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["hv", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["u", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["u", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"2", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"u", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], "\[Equal]", 
    "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6114820501315947`*^9, 3.611483459213189*^9, 
  3.6116370115064063`*^9, 3.615276779764719*^9, 3.6153522650107136`*^9, 
  3.6180388455649548`*^9, 3.6181246894019413`*^9, 3.6183239062737617`*^9, 
  3.618376049505905*^9, 3.6184658255334005`*^9, 3.618468346843141*^9, 
  3.6184696201797776`*^9, 3.618469816240922*^9, 3.618491163895135*^9, 
  3.6185460498076735`*^9, 3.6185803094903617`*^9, 3.6186338411078653`*^9, 
  3.6186342113121157`*^9, 3.6186407712329693`*^9, 3.6187188149024754`*^9, 
  3.6188031388228846`*^9, 3.6188333624536085`*^9, 3.618911218351672*^9, 
  3.6189112855253897`*^9, 3.618981324530058*^9, 3.6189940903690915`*^9, 
  3.620190008595019*^9, 3.620195844524166*^9, 3.620195890344575*^9, 
  3.6201987464233847`*^9, 3.6201987928391447`*^9, 3.6201991881787863`*^9, 
  3.6205365929944296`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"cx", "[", "t", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "2"}], "}"}]}], "]"}], "/.", 
   RowBox[{"t", "\[Rule]", "s"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6181248056065454`*^9, 3.618124897194306*^9}, 
   3.6181281288816905`*^9, {3.6183761140744185`*^9, 3.618376153105687*^9}, {
   3.618377620210264*^9, 3.618377645170308*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["hv", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["hv", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["u", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["hv", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox["u", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["hv", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["hv", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["u", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["hv", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox["u", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["hv", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["hv", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["u", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["hv", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox["u", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.6181281049824486`*^9, 3.618128130114093*^9}, 
   3.6183239311831865`*^9, 3.6183760705347424`*^9, 3.618377608401043*^9, 
   3.61837764634031*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"scond2", "[", "sf", "]"}], ",", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"%", "-", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"frenet", "[", "cx", "]"}], "[", "s", "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], "*", 
       RowBox[{
        RowBox[{
         RowBox[{"curvatures", "[", "cx", "]"}], "[", "s", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}]}], ",", 
     RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5911689961229024`*^9, 3.591169051093046*^9}, {
   3.5911691093823805`*^9, 3.5911691751901445`*^9}, {3.591169252847586*^9, 
   3.591169263705207*^9}, {3.591169836602975*^9, 3.5911699178166203`*^9}, 
   3.5911700071127276`*^9, {3.5911705231692443`*^9, 3.5911705358059673`*^9}, {
   3.5913395259107156`*^9, 3.5913395324003267`*^9}, {3.5913398016568003`*^9, 
   3.591339809987214*^9}, {3.5913398788457355`*^9, 3.591339883354143*^9}, 
   3.591339948439858*^9, {3.598367880602971*^9, 3.598367881796039*^9}, {
   3.598368242418666*^9, 3.5983683037791753`*^9}, {3.5984267984152355`*^9, 
   3.598426833889698*^9}, {3.5984268671021566`*^9, 3.5984269033878202`*^9}, {
   3.611471352307413*^9, 3.6114713546995497`*^9}, {3.6114769096505756`*^9, 
   3.6114769636746655`*^9}, {3.6114821106850576`*^9, 3.611482133509363*^9}, {
   3.6114835231578465`*^9, 3.6114835333484297`*^9}, {3.6181281527029324`*^9, 
   3.6181281603001456`*^9}, {3.618377680972371*^9, 3.618377700004404*^9}, {
   3.61837880231794*^9, 3.6183788427064114`*^9}}],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.6183787850331097`*^9, 3.6183800908178034`*^9}]
}, Closed]],

Cell["Aborted after waiting a long time.", "Text",
 CellChangeTimes->{{3.598427686376796*^9, 3.5984277110872393`*^9}, {
  3.6114717129820423`*^9, 3.611471715070162*^9}, {3.6114831334805584`*^9, 
  3.6114831398959255`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"frenet", "[", "cx", "]"}], "[", "s", "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], "*", 
    RowBox[{
     RowBox[{
      RowBox[{"curvatures", "[", "cx", "]"}], "[", "s", "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ",", "assus", ",", 
   RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.5983684150655403`*^9, {3.611471358282755*^9, 3.6114713598908463`*^9}, {
   3.61147376236126*^9, 3.611473789919836*^9}, {3.611477071370826*^9, 
   3.6114770742179885`*^9}, {3.6181290507857103`*^9, 3.618129058819724*^9}, {
   3.6181309876539125`*^9, 3.6181309895883155`*^9}, {3.618323987210391*^9, 
   3.618323997915004*^9}, {3.618380132688277*^9, 3.61838013449788*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Simplify", "::", "time"}], "MessageName"], ":", 
  " ", "\<\"Time spent on a transformation exceeded \[NoBreak]\\!\\(300.`\\)\
\[NoBreak] seconds, and the transformation was aborted. Increasing the value \
of TimeConstraint option may improve the result of simplification. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Simplify/time\\\", \
ButtonNote -> \\\"Simplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6183243105898876`*^9, 3.6183804457808266`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Simplify", "::", "time"}], "MessageName"], ":", 
  " ", "\<\"Time spent on a transformation exceeded \[NoBreak]\\!\\(300.`\\)\
\[NoBreak] seconds, and the transformation was aborted. Increasing the value \
of TimeConstraint option may improve the result of simplification. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Simplify/time\\\", \
ButtonNote -> \\\"Simplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6183243105898876`*^9, 3.618380747641357*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Simplify", "::", "time"}], "MessageName"], ":", 
  " ", "\<\"Time spent on a transformation exceeded \[NoBreak]\\!\\(300.`\\)\
\[NoBreak] seconds, and the transformation was aborted. Increasing the value \
of TimeConstraint option may improve the result of simplification. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Simplify/time\\\", \
ButtonNote -> \\\"Simplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6183243105898876`*^9, 3.618381047754684*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], ":", 
  " ", "\<\"Further output of \[NoBreak]\\!\\(\\*StyleBox[\\(Simplify :: time\
\\), \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6183243105898876`*^9, 3.6183810478170843`*^9}],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.611471820954218*^9, 3.611473755960894*^9, 
  3.611476514845994*^9, 3.6114820135325007`*^9, 3.618130948887844*^9, 
  3.618324943517089*^9, 3.6183819395850506`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"frenet", "[", "cx", "]"}], "[", "s", "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], "*", 
    RowBox[{
     RowBox[{
      RowBox[{"curvatures", "[", "cx", "]"}], "[", "s", "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ",", 
   RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.5983684150655403`*^9, {3.611471358282755*^9, 3.6114713598908463`*^9}, {
   3.61147376236126*^9, 3.611473789919836*^9}, {3.611477071370826*^9, 
   3.6114770742179885`*^9}, {3.6181290507857103`*^9, 3.618129058819724*^9}, {
   3.6181309876539125`*^9, 3.6181310215527716`*^9}, {3.6188311171135707`*^9, 
   3.6188311289052453`*^9}}],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.618132285420192*^9}]
}, Closed]],

Cell["\<\
The result of this simplification, after a long time of processing, is \
contained in the following definition:\
\>", "Text",
 CellChangeTimes->{{3.5984277365620832`*^9, 3.5984278193202295`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ccc", "[", "s_", "]"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["hv", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
          ")"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["hv", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
          ")"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["hv", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["hu", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}], "-", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["hu", "\[Prime]",
               MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}], 
              "-", 
              RowBox[{"4", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{"4", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
          ")"}]}], "-", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["hv", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            RowBox[{
             SuperscriptBox["hu", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}]}],
              ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["hu", "\[Prime]",
               MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["hu", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["hv", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}]}],
              ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["hu", "\[Prime]",
               MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}]}], ")"}], "/", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["hv", "\[Prime]",
             MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["hu", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], " ", 
          RowBox[{
           SuperscriptBox["hv", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["hu", "\[Prime]",
             MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
        ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["hv", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
          ")"}]}], "-", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["hv", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
          ")"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["hv", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["hu", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["hu", "\[Prime]",
               MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}], 
              "-", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{"4", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{"4", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
          ")"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["hv", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            RowBox[{
             SuperscriptBox["hu", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}]}],
              ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["hu", "\[Prime]",
               MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["hu", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["hv", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}]}],
              ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["hu", "\[Prime]",
               MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}]}], ")"}], "/", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["hv", "\[Prime]",
             MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["hu", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], " ", 
          RowBox[{
           SuperscriptBox["hv", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["hu", "\[Prime]",
             MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
        ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["hv", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
          ")"}]}], "-", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["hv", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
          ")"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["hv", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["hu", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["hu", "\[Prime]",
               MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}], 
              "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{"4", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{"4", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
          ")"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["hu", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}], 
              "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{
             SuperscriptBox["hv", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["hu", "\[Prime]",
               MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["hu", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["hv", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}], 
              "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["hu", "\[Prime]",
               MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}]}], ")"}], "/", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["hv", "\[Prime]",
             MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["hu", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], " ", 
          RowBox[{
           SuperscriptBox["hv", "\[Prime]",
            MultilineFunction->None], "[", "s", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["hu", "\[Prime]",
             MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
        ")"}], "2"]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5984272947301073`*^9, 3.5984273090977325`*^9}, {
  3.5989451988455257`*^9, 3.598945202623742*^9}},
 CellTags->"ccc"],

Cell["Now we simplify", "Text",
 CellChangeTimes->{{3.5984278441866727`*^9, 3.5984278488354807`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"cx", "''"}], "[", "s", "]"}], ",", 
   RowBox[{"scond2", "[", "sf", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5911689961229024`*^9, 3.591169051093046*^9}, {
   3.5911691093823805`*^9, 3.5911691751901445`*^9}, {3.591169252847586*^9, 
   3.591169263705207*^9}, {3.591169836602975*^9, 3.5911699178166203`*^9}, 
   3.5911700071127276`*^9, {3.5911705231692443`*^9, 3.5911705358059673`*^9}, {
   3.5913395259107156`*^9, 3.5913395324003267`*^9}, {3.5913398016568003`*^9, 
   3.591339809987214*^9}, {3.5913398788457355`*^9, 3.591339883354143*^9}, 
   3.591339948439858*^9, {3.598367880602971*^9, 3.598367881796039*^9}, {
   3.5983680672866488`*^9, 3.5983680799763746`*^9}, 3.598368123512864*^9, 
   3.611471369073372*^9, {3.615352303220899*^9, 3.615352305526031*^9}, {
   3.615352369396684*^9, 3.615352371437801*^9}, 3.618044161330694*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["hv", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["hv", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["u", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["hv", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox["u", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["hv", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["hv", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["u", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["hv", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox["u", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["hv", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["hv", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["u", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["hv", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox["u", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.5983681109871483`*^9, 3.598368124799938*^9}, 
   3.5983765605010023`*^9, 3.5984275852574177`*^9, 3.6114718500768833`*^9, 
   3.611476585566039*^9, 3.6116371112217817`*^9, 3.615279903713046*^9, 
   3.6153522150588565`*^9, 3.6153522910392027`*^9, {3.615352357759019*^9, 
   3.6153523732689056`*^9}, 3.6183854576096296`*^9}]
}, Closed]],

Cell["and obtain the expected result:", "Text",
 CellChangeTimes->{{3.5984278647943087`*^9, 3.598427883795142*^9}, 
   3.5984389037123775`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"scond2", "[", "sf", "]"}], ",", " ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Out", "[", "155", "]"}], "-", 
      RowBox[{"ccc", "[", "s", "]"}]}], ",", " ", 
     RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.598376578404026*^9, 3.5983765980811515`*^9}, 
   3.598427178650304*^9, {3.5984274840912404`*^9, 3.5984274895668497`*^9}, {
   3.611472263400524*^9, 3.6114722818085775`*^9}, 3.6153522296746926`*^9, {
   3.618391134115942*^9, 3.618391214237683*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.611473629049635*^9, 3.6114771583888025`*^9, 
  3.611637144980241*^9}]
}, Closed]],

Cell[TextData[{
 "The projection of the curvature vector  cx\[CloseCurlyQuote]\
\[CloseCurlyQuote][s] to the normal amf[3][sf] of the surface is cx\
\[CloseCurlyQuote]\[CloseCurlyQuote][s].",
 "amf[",
 "3][sf][hu[s],hv[s]]; it is named the",
 StyleBox[" normal curvature",
  FontColor->RGBColor[0, 0, 1]],
 " of the curve cx at s. We calculate"
}], "Text",
 CellChangeTimes->{{3.5911693709623423`*^9, 3.591169391610523*^9}, {
  3.591169517170705*^9, 3.5911695922760005`*^9}, {3.5911696364265256`*^9, 
  3.591169668898383*^9}, {3.5911697216343994`*^9, 3.591169744562711*^9}, {
  3.591170067107159*^9, 3.591170090754512*^9}, {3.5984429099982295`*^9, 
  3.598442975261962*^9}, {3.611471370417449*^9, 3.611471374529684*^9}, {
  3.6148618589419384`*^9, 3.6148618589575386`*^9}, {3.614917790766159*^9, 
  3.6149177907973595`*^9}, {3.6152622605120883`*^9, 3.6152622647073283`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"cx", "''"}], "[", "s", "]"}], ".", 
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"fund2a", "[", "sf", "]"}], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
      RowBox[{
       RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}]}], ",", 
   RowBox[{"scond2", "[", "sf", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591167006058077*^9, 3.591167099582426*^9}, {
   3.5911671805020547`*^9, 3.5911672617777033`*^9}, 3.6114713759407644`*^9, 
   3.6148618589731383`*^9, 3.6149177907973595`*^9, 3.615262266573435*^9, 
   3.6180441624927607`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.591167268978115*^9, 3.598443004907658*^9, 
  3.611637650109128*^9, 3.615280994636443*^9, 3.6153597237053266`*^9}]
}, Closed]],

Cell[TextData[{
 "and conclude\n",
 StyleBox["Proposition",
  FontColor->RGBColor[0, 0, 1]],
 ". ",
 StyleBox["All curves ",
  FontSlant->"Italic"],
 "cx",
 StyleBox[" on the surface through the point sf[u,v] with the same tangent  \
at this point have the same normal curvature given by",
  FontSlant->"Italic"],
 " fund2a[sf][u,v][\[Gamma]\[CloseCurlyQuote][s],\[Gamma]\[CloseCurlyQuote][s]\
], s  ",
 StyleBox["the arc length of the curve.  ",
  FontSlant->"Italic"],
 "\[FilledRectangle]"
}], "Text",
 CellChangeTimes->{{3.59117015034192*^9, 3.591170175986387*^9}, {
   3.5911702324906187`*^9, 3.5911703699304795`*^9}, {3.591170402012315*^9, 
   3.591170414571033*^9}, {3.5983664215985203`*^9, 3.598366434774274*^9}, {
   3.598428209586115*^9, 3.5984282141101227`*^9}, {3.5984287710467005`*^9, 
   3.5984287755863085`*^9}, {3.598443070436406*^9, 3.598443070450407*^9}, 
   3.6114713772008367`*^9, 3.6152810347747393`*^9}],

Cell["\<\
Thus, we can define the normal curvature for a curve {h1[t],h2[t]}  with an \
arbitrary parameter t on the surface ff[u,v] by\
\>", "Text",
 CellChangeTimes->{{3.614310317474022*^9, 3.6143103199232264`*^9}, {
   3.6143104210818157`*^9, 3.6143106065544243`*^9}, 3.6152810492845693`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"normalcurvature", "[", 
    RowBox[{"ff_", ",", "h1_", ",", "h2_"}], "]"}], "[", "t_", "]"}], ":=", 
  " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"cvx", ",", "tt", ",", "vt", ",", "tx", ",", "aa", ",", "bb"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"cvx", "[", "tt_", "]"}], " ", ":=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"h1", "[", "tt", "]"}], ",", 
        RowBox[{"h2", "[", "tt", "]"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"vt", "[", "tt_", "]"}], " ", ":=", " ", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"cvx", "[", "tx", "]"}], ",", "tx"}], "]"}], "/.", 
       RowBox[{"tx", "\[Rule]", "tt"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"aa", " ", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         RowBox[{
          RowBox[{"fund2", "[", "ff", "]"}], "[", 
          RowBox[{
           RowBox[{"h1", "[", "tt", "]"}], ",", 
           RowBox[{"h2", "[", "tt", "]"}]}], "]"}], "[", 
         RowBox[{
          RowBox[{"vt", "[", "tt", "]"}], ",", 
          RowBox[{"vt", "[", "tt", "]"}]}], "]"}]}], "/.", 
       RowBox[{"tt", "\[Rule]", "t"}]}]}], ";", 
     RowBox[{"bb", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"fund1", "[", "ff", "]"}], "[", 
         RowBox[{
          RowBox[{"h1", "[", "tt", "]"}], ",", 
          RowBox[{"h2", "[", "tt", "]"}]}], "]"}], "[", 
        RowBox[{
         RowBox[{"vt", "[", "tt", "]"}], ",", 
         RowBox[{"vt", "[", "tt", "]"}]}], "]"}], "/.", 
       RowBox[{"tt", "\[Rule]", "t"}]}]}], ";", 
     RowBox[{"aa", "/", "bb"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6143106214582767`*^9, 3.614310705541086*^9}, {
   3.6143107438282757`*^9, 3.6143107815564337`*^9}, {3.614310816436429*^9, 
   3.614310915165076*^9}, {3.614310967790086*^9, 3.614311041454299*^9}, {
   3.614311075774262*^9, 3.614311217126347*^9}, {3.6143112637990165`*^9, 
   3.6143112898545065`*^9}, {3.614311337239217*^9, 3.6143113487278743`*^9}, {
   3.614311448903604*^9, 3.614311576977929*^9}, {3.6148618589731383`*^9, 
   3.6148618589731383`*^9}, 3.6148631365217824`*^9, 3.614917790812959*^9, {
   3.618395996020481*^9, 3.6183960036020947`*^9}, {3.618396341607888*^9, 
   3.6183963564903145`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"normalcurvature", "::", "usage"}], " ", "=", " ", 
   "\"\<normalcurvature[ff,hu,hv][t]is the normal curvature of the curve \
ff[hu[t],hv[t]], t an arbitrary parameter.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6152814833563967`*^9, 3.615281525013779*^9}, {
   3.6152816554642406`*^9, 3.615281655654251*^9}, {3.61528170335898*^9, 
   3.615281820294668*^9}, 3.615281862400077*^9}],

Cell["\<\
Indeed, this expression is invariant under a parameter transformation, and it \
coincides with the result of the proposition if t = s is the arc length \
parameter.\
\>", "Text",
 CellChangeTimes->{{3.6143128012499533`*^9, 3.6143129209067974`*^9}, 
   3.615281888172551*^9, 3.6184068592621465`*^9}],

Cell[TextData[{
 StyleBox["Example.",
  FontColor->RGBColor[0, 0, 1]],
 " Normal curvature of a general curve on the sphere of radius r"
}], "Text",
 CellChangeTimes->{{3.61431205516628*^9, 3.6143121144266696`*^9}, {
   3.6143125946581373`*^9, 3.614312626209942*^9}, 3.615281900524257*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"normalcurvature", "[", 
     RowBox[{
      RowBox[{"sphero", "[", "r", "]"}], ",", "hu", ",", "hv"}], "]"}], "[", 
    "t", "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"hu", "[", "t", "]"}], "\[Element]", "Reals"}], ",", 
     RowBox[{
      RowBox[{"hv", "[", "t", "]"}], "\[Element]", "Reals"}], ",", 
     RowBox[{"r", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.614311584076335*^9, 3.614311620931443*^9}, {
   3.614312164300522*^9, 3.6143122685814867`*^9}, 3.6148618589887385`*^9, 
   3.614863136537382*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"Abs", "[", 
     RowBox[{"Sec", "[", 
      RowBox[{"hv", "[", "t", "]"}], "]"}], "]"}], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"hv", "[", "t", "]"}], "]"}]}], "r"]}]], "Output",
 CellChangeTimes->{
  3.614311626393756*^9, {3.614312209095084*^9, 3.6143122360556264`*^9}, 
   3.6143122701335754`*^9, 3.6152814196587534`*^9, 3.618397203462602*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"%", "\[Equal]", " ", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Sign", "[", 
       RowBox[{"Cos", "[", 
        RowBox[{"hv", "[", "t", "]"}], "]"}], "]"}]}], "/", "r"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", ">", "0"}], ",", 
     RowBox[{
      RowBox[{"hv", "[", "t", "]"}], "\[Element]", "Reals"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6143116405155635`*^9, 3.614311725388418*^9}, {
  3.614312338661495*^9, 3.614312447581725*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.61431192491583*^9, 3.61431245291603*^9, 
  3.6152814272961903`*^9, 3.6183972295770483`*^9}]
}, Closed]],

Cell[TextData[{
 "All curves through  a given point of the sphere have at this point the same \
normal curvature! Such points are named ",
 StyleBox["umbilic",
  FontColor->RGBColor[0, 0, 1]],
 "."
}], "Text",
 CellChangeTimes->{{3.6183972736471252`*^9, 3.618397349026458*^9}, {
  3.6183975386560383`*^9, 3.6183975462724743`*^9}}],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.614312497097557*^9, 3.614312497099557*^9}}],

Cell["\<\
Now we consider the normal plane of the curve at the point cx[s]. It can be \
spanned by the normal vector of the curve belonging to the tangent plane of \
the surface:\
\>", "Text",
 CellChangeTimes->{{3.591182851545838*^9, 3.5911830541589937`*^9}, {
   3.5913402274775476`*^9, 3.5913402300671525`*^9}, 3.6114713785929165`*^9, 
   3.6116379545436625`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", "[", "2", "]"}], " ", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "  ", 
     RowBox[{
      RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}]}], "*", 
    RowBox[{"Sin", "[", "\[Tau]", "]"}]}], " ", "+", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "*", 
    RowBox[{"Cos", "[", "\[Tau]", "]"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5911830364997625`*^9, 3.5911830411173706`*^9}, {
  3.591183096435068*^9, 3.5911832179904814`*^9}, {3.6148618589887385`*^9, 
  3.6148618589887385`*^9}, {3.614917790828559*^9, 3.614917790828559*^9}, {
  3.6152622786691265`*^9, 3.615262279580179*^9}}],

Cell["\<\
and the normal vector amf[3][sf] of the surface. We decompose the curvature \
vector cx\[CloseCurlyQuote]\[CloseCurlyQuote][s]  lying in the normal plane \
into its normal and its tangential components:\
\>", "Text",
 CellChangeTimes->{{3.5911833479543095`*^9, 3.591183380074766*^9}, {
   3.59118341636043*^9, 3.591183463690913*^9}, {3.591183535118173*^9, 
   3.5911835543982763`*^9}, {3.591415122160385*^9, 3.591415157112384*^9}, 
   3.611471379982996*^9, 3.6148618590199385`*^9, 3.6149177908597593`*^9, 
   3.6152622808812532`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cx", "''"}], "[", "s", "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["k", "n"], "[", "s", "]"}], "*", 
    RowBox[{
     RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}]}], " ", "+", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["k", "g"], "[", "s", "]"}], " ", "*", 
    RowBox[{"a", "[", "2", "]"}]}]}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{"k", "[", "s", "]"}], "*", 
   RowBox[{
    RowBox[{
     RowBox[{"frenet", "[", "cx", "]"}], "[", "s", "]"}], "[", "2", 
    "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5911839809576735`*^9, 3.5911840523367567`*^9}, {
   3.59118409034593*^9, 3.5911842270017467`*^9}, {3.591184262162758*^9, 
   3.591184277106612*^9}, {3.59118467761052*^9, 3.5911846817297554`*^9}, {
   3.591247611926702*^9, 3.5912476277139297`*^9}, {3.6114713820901165`*^9, 
   3.6114713829871674`*^9}, 3.6148618590199385`*^9, 3.6149177908753595`*^9, 
   3.615262281932314*^9}],

Cell[TextData[{
 "Here ",
 Cell[BoxData[
  SubscriptBox["k", "n"]],
  Evaluatable->False,
  CellChangeTimes->{{3.5911839809576735`*^9, 3.5911840523367567`*^9}, {
   3.59118409034593*^9, 3.5911842270017467`*^9}, {3.591184262162758*^9, 
   3.591184277106612*^9}}],
 " denotes the normal curvature defined above, ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["k", "g"], " "}]],
  Evaluatable->False,
  CellChangeTimes->{{3.5911839809576735`*^9, 3.5911840523367567`*^9}, {
   3.59118409034593*^9, 3.5911842270017467`*^9}, {3.591184262162758*^9, 
   3.591184277106612*^9}}],
 " the so called ",
 StyleBox["geodesic  curvature",
  FontColor->RGBColor[0, 0, 1]],
 " considered later, and k = k[s] the curvature of the curve. A trivial but \
remarkable consequence of this formula is"
}], "Text",
 CellChangeTimes->{{3.5911844346546235`*^9, 3.5911845590627394`*^9}, {
   3.5911846124467926`*^9, 3.5911846528151016`*^9}, {3.5911846911002913`*^9, 
   3.591184738406997*^9}, 3.591184783935601*^9, {3.591184882295227*^9, 
   3.591184892598817*^9}, {3.591184945407837*^9, 3.5911850142957773`*^9}, 
   3.5912474146331553`*^9, {3.591247670036804*^9, 3.5912477102692747`*^9}},
 CellTags->"geodc"],

Cell[TextData[{
 StyleBox["Lemma.",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" The geodesic curvature satisfies the formula",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.591247751796548*^9, 3.5912479321172647`*^9}, {
   3.5912479914753685`*^9, 3.5912480101954017`*^9}, 3.611471384289242*^9, {
   3.6116387366198363`*^9, 3.61163878415312*^9}, {3.6116388403912187`*^9, 
   3.611638846319229*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{
     SubscriptBox["k", "g"], "(", "s", ")"}], "2"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"k", "(", "s", ")"}], "2"], "-", 
    SuperscriptBox[
     RowBox[{
      SubscriptBox["k", "n"], "(", "s", ")"}], "2"]}]}], 
  TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6116388736348767`*^9, 3.611638942649398*^9}}],

Cell[TextData[{
 StyleBox["A point ",
  FontSlant->"Italic"],
 "cx",
 StyleBox["[s] is a",
  FontSlant->"Italic"],
 StyleBox[" flat point of the curve",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" (what means",
  FontSlant->"Italic"],
 " k[s] = 0) ",
 StyleBox["iff ",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.591247751796548*^9, 3.5912479321172647`*^9}, {
   3.5912479914753685`*^9, 3.5912480101954017`*^9}, 3.611471384289242*^9, {
   3.6116387366198363`*^9, 3.61163878415312*^9}, 3.611638959684628*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["k", "n"], "[", "s", "]"}], "=", " ", 
  RowBox[{
   RowBox[{
    SubscriptBox["k", "g"], "[", "s", "]"}], "=", " ", "0.", 
   "  "}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5912479532553015`*^9, 3.5912479532553015`*^9}, 
   3.5912480620186925`*^9, {3.5984431524080944`*^9, 3.598443158216427*^9}, 
   3.61839774271371*^9}],

Cell["\<\
In particular, any line lying in the surface has vanishing normal and \
geodesic curvatures. \[FilledSquare]\
\>", "Text",
 CellChangeTimes->{{3.5912480764175177`*^9, 3.5912480831255293`*^9}, {
   3.591248205517848*^9, 3.5912482771579456`*^9}, 3.598429103155684*^9, {
   3.618397761840804*^9, 3.618397761842804*^9}}],

Cell[TextData[{
 " A curve on the surface is said to be an ",
 StyleBox["asymptotic curve",
  FontColor->RGBColor[0, 0, 1]],
 " if its normal curvature at all points is identically zero. An implicit \
differential equation for the asymptotic curves is"
}], "Text",
 CellChangeTimes->{{3.5912513948692684`*^9, 3.5912515055345984`*^9}, {
   3.5912515441348057`*^9, 3.5912516055903206`*^9}, 3.591341039365374*^9, {
   3.6183978275525627`*^9, 3.61839783503199*^9}, 3.6184068933910985`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
     RowBox[{
      RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], "\[Equal]", " ", 
   "0"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], " ", "\[NotEqual]", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], ";"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5912516204781723`*^9, 3.591251639128239*^9}, {
   3.591251688890085*^9, 3.5912517049450035`*^9}, 3.591251797316287*^9, {
   3.5912544370822725`*^9, 3.5912544610826454`*^9}}],

Cell["\<\
Any line contained in a surface is an asymptotic curve. Asymptotic curves \
exist only at points with non positive Gaussian curvature; therefore a ruled \
surface has non-negative curvature at all its points. On  spheres there don\
\[CloseCurlyQuote]t exist  asymptotic curves since the second fundamental \
form is definite:\
\>", "Text",
 CellChangeTimes->{{3.591254508871379*^9, 3.5912545339588137`*^9}, {
   3.5912545724790173`*^9, 3.5912546562148066`*^9}, {3.5915138824234624`*^9, 
   3.5915139679813557`*^9}, 3.598429175227811*^9, {3.615359907563843*^9, 
   3.6153599694273815`*^9}, {3.6153600463797827`*^9, 3.615360088875213*^9}, {
   3.615360418947092*^9, 3.615360511867407*^9}, {3.615360549322549*^9, 
   3.615360598043336*^9}, 3.618406903278664*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fund2", "[", 
          RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"s1", ",", "s2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], "]"}], "\[Equal]", " ", 
      "0"}], ")"}], "&&", "  ", 
    RowBox[{"(", 
     RowBox[{"v", "<", 
      RowBox[{"Pi", "/", "2"}]}], ")"}], "&&", "  ", 
    RowBox[{"(", 
     RowBox[{"v", ">", 
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "2"}]}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{"r", ">", "0"}], ")"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"s1", ",", "s2", ",", "v"}], "}"}], ",", "Reals"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591251918655227*^9, 3.591251930794922*^9}, {
   3.5912519649228735`*^9, 3.591252048466652*^9}, {3.591252241953719*^9, 
   3.5912522623128834`*^9}, {3.5912522937856836`*^9, 3.591252347257742*^9}, 
   3.591252871539729*^9, {3.5912537907793064`*^9, 3.591253941118905*^9}, 
   3.591253983300318*^9, {3.591254121708235*^9, 3.591254134867987*^9}, {
   3.611639104484082*^9, 3.6116391257157197`*^9}, 3.6148618590355387`*^9, 
   3.6149177908909597`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"r", ">", "0"}], "&&", 
  RowBox[{"s1", "\[Equal]", "0"}], "&&", 
  RowBox[{"s2", "\[Equal]", "0"}], "&&", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["\[Pi]", "2"]}], "<", "v", "<", 
   FractionBox["\[Pi]", "2"]}]}]], "Output",
 CellChangeTimes->{3.591253993872923*^9, 3.59125413666109*^9, 
  3.6116391321117306`*^9, 3.615360610912072*^9, 3.61839790129778*^9}]
}, Closed]],

Cell["\<\
 The angle \[Theta] between cx''[s] and a[2] equals the angle between the \
tangential plane of the surface and the osculating plane of the curve. By \
Pythagoras it follows\
\>", "Text",
 CellChangeTimes->{{3.5911844346546235`*^9, 3.5911845590627394`*^9}, {
   3.5911846124467926`*^9, 3.5911846528151016`*^9}, {3.5911846911002913`*^9, 
   3.591184738406997*^9}, 3.591184783935601*^9, {3.591184882295227*^9, 
   3.591184892598817*^9}, {3.591184945407837*^9, 3.5911850142957773`*^9}, 
   3.5912474146331553`*^9, {3.591247670036804*^9, 3.5912477102692747`*^9}, 
   3.611471385545314*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["k", "n"], "=", 
    RowBox[{"k", " ", 
     RowBox[{"sin", "(", "\[Theta]", ")"}]}]}], ",", "      ", 
   RowBox[{
    RowBox[{"or", "   ", 
     FractionBox["1", 
      SubscriptBox["r", "n"]]}], "=", 
    FractionBox[
     RowBox[{" ", 
      RowBox[{"sin", "(", "\[Theta]", ")"}]}], "r"]}], ","}], 
  TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.591185108512166*^9, 3.591185329658815*^9}, {
   3.591185370764166*^9, 3.591185390363287*^9}, {3.5911854204750094`*^9, 
   3.5911854560440435`*^9}, 3.591185489753972*^9}],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "n"], TraditionalForm]],
  Evaluatable->False,
  CellChangeTimes->{{3.591185108512166*^9, 3.591185329658815*^9}, {
    3.591185370764166*^9, 3.591185390363287*^9}, {3.5911854204750094`*^9, 
    3.5911854560440435`*^9}, 3.591185489753972*^9}],
 " = 1/",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "n"], TraditionalForm]]],
 " and r = 1/k are the corresponding curvature radii. This formula is the \
content of \n\n",
 StyleBox["Meusnier\[CloseCurlyQuote]s Proposition",
  FontColor->RGBColor[0, 0, 1]],
 ". ",
 StyleBox["All curves ",
  FontSlant->"Italic"],
 "cx",
 StyleBox[" on the surface sf whose osculating plane at the point ",
  FontSlant->"Italic"],
 "cx",
 StyleBox["[s] has an angle \[Theta] \[NotEqual] 0, \[Pi]   with the \
tangential plane have at this point the same curvature, namely\n ",
  FontSlant->"Italic"],
 "k = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "n"], TraditionalForm]],
  Evaluatable->False,
  CellChangeTimes->{{3.591185108512166*^9, 3.591185329658815*^9}, {
    3.591185370764166*^9, 3.591185390363287*^9}, {3.5911854204750094`*^9, 
    3.5911854560440435`*^9}, 3.591185489753972*^9},
  FontSlant->"Plain"],
 "/sin(\[Theta]). \[FilledRectangle]"
}], "Text",
 CellChangeTimes->{{3.5911854976874256`*^9, 3.5911855165425043`*^9}, {
  3.5911855569068127`*^9, 3.591185646350929*^9}, {3.59118578763901*^9, 
  3.59118583029445*^9}, {3.591186005119449*^9, 3.591186281990285*^9}, {
  3.598429373769359*^9, 3.5984293827549753`*^9}, {3.5984432845576525`*^9, 
  3.598443288191861*^9}, {3.611471386802386*^9, 3.6114713884584804`*^9}}],

Cell[TextData[{
 "In particular one obtains such a curve intersecting the surface with a \
plane containing the point x = sf[u,v]: a ",
 StyleBox["plane section",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface. The curvature of the plane section through x containing \
the tangent vector"
}], "Text",
 CellChangeTimes->{{3.5911866587728357`*^9, 3.591186787255185*^9}, {
   3.591186817454912*^9, 3.5911868375110593`*^9}, {3.5911868704389424`*^9, 
   3.5911871717431765`*^9}, 3.6116396765994873`*^9}],

Cell[" tt[\[Tau]]  = amf[1][sf]*Cos[\[Tau]] + amf[2][sf]*Sin[\[Tau]] ", "Text",
 CellChangeTimes->{{3.5911866587728357`*^9, 3.591186787255185*^9}, {
  3.591186817454912*^9, 3.5911868375110593`*^9}, {3.5911868704389424`*^9, 
  3.5911871717431765`*^9}, {3.6116396765994873`*^9, 3.611639688003107*^9}, {
  3.6153607884512267`*^9, 3.6153608190829787`*^9}}],

Cell["is defined by the normal curvature ", "Text",
 CellChangeTimes->{{3.5911866587728357`*^9, 3.591186787255185*^9}, {
  3.591186817454912*^9, 3.5911868375110593`*^9}, {3.5911868704389424`*^9, 
  3.5911871717431765`*^9}, {3.6116396765994873`*^9, 3.611639688003107*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["k", "n"], "[", "\[Tau]", "]"}], "=", " ", 
   RowBox[{"-", 
    RowBox[{"fund2", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"sf", "[", 
        RowBox[{"u", ",", "v"}], "]"}], 
       RowBox[{"tt", "[", "\[Tau]", "]"}]}], ",", 
      RowBox[{"tt", "[", "\[Tau]", "]"}]}], "]"}], " "}]}], 
  TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5911872243951874`*^9, 3.591187294696209*^9}, 
   3.5911873290491734`*^9, {3.6183982560420704`*^9, 3.618398263809515*^9}}],

Cell[TextData[{
 "and the angle \[Theta] by Meusnier\[CloseCurlyQuote]s formula. The case  \
\[Theta] = 0, \[Pi]  is excluded since the intersection of the tangent plane \
with the surface yields a curve  (or a point) being singular at this point. \
The special sections containing the normal of the surface (corresponding to  \
\[Theta] = \[Pi]/2) at a considered point are called ",
 StyleBox["normal sections ",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["at this point.",
  FontColor->GrayLevel[0]],
 " For the normal sections the curvature at this point coincides with the \
normal curvature. This property is an appropriate geometric interpretation of \
the second fundamental form."
}], "Text",
 CellChangeTimes->{{3.591187367878394*^9, 3.5911875588153152`*^9}, {
   3.5911875983665776`*^9, 3.591187677583109*^9}, {3.591187709710946*^9, 
   3.591187782231094*^9}, {3.5911878983987384`*^9, 3.591187971934944*^9}, 
   3.5913413340342913`*^9, {3.611639842490179*^9, 3.611639889290261*^9}, {
   3.611639940676751*^9, 3.611639947384763*^9}}],

Cell["\<\
By the last formula the normal curvature of curves through a point sf[u,v] on \
the surface is a quadratic form of the tangent vectors at this point. Its \
extrema values under the condition\
\>", "Text",
 CellChangeTimes->{{3.591255092426669*^9, 3.5912552697677803`*^9}, 
   3.591255317035863*^9, {3.591255404676817*^9, 3.5912554445504875`*^9}, 
   3.5914189635761013`*^9, {3.5914191306166553`*^9, 3.591419151610856*^9}, 
   3.618406972686634*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{"tt", ",", "tt"}], "]"}], " ", "\[Equal]", " ", "1"}], 
  ","}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5914192915048575`*^9, 3.591419294121007*^9}, {
  3.5914193733635397`*^9, 3.591419415121928*^9}}],

Cell[TextData[{
 " i.e. varying \[Tau], are called the ",
 StyleBox["principal curvatures",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface at this point. They are the eigenvalues of the second \
fundamental form"
}], "Text",
 CellChangeTimes->{{3.591255092426669*^9, 3.5912552697677803`*^9}, 
   3.591255317035863*^9, {3.591255404676817*^9, 3.5912554445504875`*^9}, 
   3.5914189635761013`*^9, {3.5914191306166553`*^9, 3.591419151610856*^9}, {
   3.5914194705841007`*^9, 3.591419508504269*^9}, 3.59150772294116*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", "prcurvatures", "]"}], ";", 
   RowBox[{
    RowBox[{
     RowBox[{"prcurvatures", "[", "ff_", "]"}], "[", 
     RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", 
    RowBox[{"Eigenvalues", "[", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"cf", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", "ff", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}]}]}], 
  "\[IndentingNewLine]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5912555454202642`*^9, 3.591255666928878*^9}, 
   3.5912557322461925`*^9, {3.5923133603434553`*^9, 3.5923135255321455`*^9}, {
   3.592313755554549*^9, 3.5923137596573563`*^9}, {3.592313883084773*^9, 
   3.5923138845043755`*^9}, {3.5923139232080436`*^9, 
   3.5923139658897185`*^9}, {3.5923140976943502`*^9, 3.59231414305923*^9}, {
   3.5923141935877185`*^9, 3.592314214320155*^9}, {3.592314548823943*^9, 
   3.592314676946968*^9}, 3.614861859051139*^9, 3.614863501734024*^9, 
   3.6179720955858417`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"prcurvatures", "::", "usage"}], " ", "=", " ", 
   "\"\<prcurvatures[f][u,v] yields the principal curvatures of the surface \
f[u,v].\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6153610380975056`*^9, 3.6153611275666227`*^9}}],

Cell["For a sphere of radius r we obtain ", "Text",
 CellChangeTimes->{{3.591419571946898*^9, 3.591419599568478*^9}, {
   3.591419672176631*^9, 3.591419681112142*^9}, 3.5914215436806746`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"prcurvatures", "[", 
     RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", ">", "0"}], ",", " ", 
     RowBox[{
      RowBox[{"Cos", "[", "v", "]"}], ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5912556786912985`*^9, 3.59125568522771*^9}, {
  3.591255752541828*^9, 3.5912558042715187`*^9}, {3.591419629908213*^9, 
  3.5914196592438912`*^9}, {3.592314726508255*^9, 3.5923147697359304`*^9}, {
  3.611640033496914*^9, 3.611640064338168*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", "r"], ",", 
   FractionBox["1", "r"]}], "}"}]], "Output",
 CellChangeTimes->{3.5923147731211367`*^9, 3.592314908076974*^9, 
  3.592315587317767*^9, 3.5923157003711653`*^9, 3.6116400041844625`*^9, 
  3.6116400664285717`*^9, 3.6153611765904264`*^9}]
}, Closed]],

Cell["\<\
As expected by symmetry reasons, the normal curvature on a sphere is \
constant. In general the principal curvatures  differ and vary; e. g. for the \
hyperbolic paraboloid one has\
\>", "Text",
 CellChangeTimes->{{3.591419786766185*^9, 3.591419851071863*^9}, {
  3.5914200225206695`*^9, 3.591420025927864*^9}, {3.591420094999815*^9, 
  3.591420137944271*^9}, {3.591420194544509*^9, 3.5914202251602592`*^9}, {
  3.5914202937611837`*^9, 3.591420296000312*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"prcurvatures", "[", "hypsf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{"v", "\[Element]", " ", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5912556786912985`*^9, 3.59125568522771*^9}, {
  3.591255752541828*^9, 3.5912558042715187`*^9}, {3.5913414958377757`*^9, 
  3.5913415065081944`*^9}, {3.5914198948743687`*^9, 3.591419913586439*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{"Cosh", "[", 
       RowBox[{"2", " ", "v"}], "]"}], 
      RowBox[{"3", "/", "2"}]]]}], ",", 
   FractionBox["1", 
    SqrtBox[
     RowBox[{"Cosh", "[", 
      RowBox[{"2", " ", "v"}], "]"}]]]}], "}"}]], "Output",
 CellChangeTimes->{3.5913415097218*^9, 3.591419917163643*^9, 
  3.6116401002962313`*^9, 3.6153612360594015`*^9}]
}, Closed]],

Cell[TextData[{
 "A point sf[u, v]  is said to be an ",
 StyleBox["umbilic",
  FontColor->RGBColor[0, 0, 1]],
 " (or an umbilic point) if the principal curvatures at this point coincide. \
Special umbilic points are the",
 StyleBox[" flat points",
  FontColor->RGBColor[0, 0, 1]],
 " defined by the property that both principal curvatures at this point are \
zero, or that the second fundamental form is zero at this point. On a sphere \
all points are umbilic, and all points of a plane are flat points.as shown at \
the end of Section 3.2. "
}], "Text",
 CellChangeTimes->{{3.5914206128734355`*^9, 3.591420717416415*^9}, 
   3.5914207584237604`*^9, {3.591421160424754*^9, 3.591421316560684*^9}, {
   3.591421360529199*^9, 3.5914214038246756`*^9}, {3.591421572585328*^9, 
   3.5914215837359657`*^9}, {3.5914216161288185`*^9, 3.5914216186169605`*^9}, 
   3.5914216810255303`*^9, {3.5914417174874754`*^9, 3.5914417322295017`*^9}, {
   3.6153612636999826`*^9, 3.6153612654830847`*^9}, {3.618398779056985*^9, 
   3.6183988121208763`*^9}, 3.6183988661469665`*^9}],

Cell[TextData[{
 "The directions in the tangent plane defined by the eigenvectors of the \
second fundamental form are called ",
 StyleBox["principal directions",
  FontColor->RGBColor[0, 0, 1]],
 ". At an umbilic the principal directions are not defined, or any direction \
can be considered as a principal direction. For a non umbilic point there \
exist exactly two principal directions orthogonal to each other. Curves on \
the surface  whose tangents at each point have principal directions are \
called ",
 StyleBox["principal curves",
  FontColor->RGBColor[0, 0, 1]],
 ". Outside the set of the umbilic points there exist two families of \
principal curves orthogonal to each other, namely the integral curves of the \
principal  directions. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has two functions admitting the calculation of the principal directions:"
}], "Text",
 CellChangeTimes->{{3.591421836304412*^9, 3.5914220785842695`*^9}, {
   3.5914222012562857`*^9, 3.591422254088308*^9}, {3.591422290704402*^9, 
   3.5914223437044334`*^9}, {3.5914223746402025`*^9, 
   3.5914223980085397`*^9}, {3.5914224586890106`*^9, 3.5914225164723153`*^9}, 
   3.5914418208220572`*^9, {3.5984546613739953`*^9, 3.5984546967180166`*^9}, {
   3.6116402144728317`*^9, 3.611640215564834*^9}, 3.618406981744152*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Eigenvectors", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"cf", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", "hypsf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], ",", " ", 
   RowBox[{"v", "\[Element]", " ", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591186146479534*^9, 3.591186166391673*^9}, {
   3.5914225738175955`*^9, 3.591422608636587*^9}, 3.614861859051139*^9, 
   3.6148635017496243`*^9, 3.617972096893916*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5914226147959394`*^9, 3.611640289774164*^9, 
  3.615361535402523*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Eigensystem", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"cf", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", "hypsf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], ",", " ", 
   RowBox[{"v", "\[Element]", " ", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5913416993869333`*^9, 3.5913417963723035`*^9}, 
   3.614861859066739*^9, 3.614863501765224*^9, 3.6179720982649946`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"Cosh", "[", 
         RowBox[{"2", " ", "v"}], "]"}], 
        RowBox[{"3", "/", "2"}]]]}], ",", 
     FractionBox["1", 
      SqrtBox[
       RowBox[{"Cosh", "[", 
        RowBox[{"2", " ", "v"}], "]"}]]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.59134180573232*^9, 3.6116403047813907`*^9, 
  3.6153615477002263`*^9}]
}, Closed]],

Cell["\<\
From this result it follows that on the parabolic hyperboloid hypsf[u,v]  \
there don\[CloseCurlyQuote]t exist umbilics, and that the parameter lines {u \
,t} and {t,v} are the principal curves.\
\>", "Text",
 CellChangeTimes->{{3.5914229744565105`*^9, 3.591423241632792*^9}, {
  3.6183990352646394`*^9, 3.6183990356326604`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", "hypsf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], ",", " ", 
   RowBox[{"v", "\[Element]", " ", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5913416993869333`*^9, 3.5913417963723035`*^9}, {
  3.5914420245290146`*^9, 3.5914421216703854`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["s1", "2"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["s1", "2"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["s2", "2"]}]}], ")"}], " ", 
     RowBox[{"Cosh", "[", 
      RowBox[{"2", " ", "v"}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.5914421257731924`*^9, 3.611640331941038*^9, 
  3.615361934654359*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", "hypsf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], ",", " ", 
   RowBox[{"v", "\[Element]", " ", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5913416993869333`*^9, 3.5913417963723035`*^9}, {
  3.5914420245290146`*^9, 3.5914421216703854`*^9}, {3.591442168205267*^9, 
  3.5914421830252934`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["s1", "2"], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["s2", "2"]}], "+", 
   RowBox[{
    SuperscriptBox["s1", "2"], " ", 
    RowBox[{"Cosh", "[", 
     RowBox[{"2", " ", "v"}], "]"}]}]}], 
  RowBox[{"2", " ", 
   SqrtBox[
    RowBox[{"Cosh", "[", 
     RowBox[{"2", " ", "v"}], "]"}]]}]]], "Output",
 CellChangeTimes->{3.5914421989061213`*^9, 3.6116403368862467`*^9, 
  3.615361939870657*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "hypsf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}]}], ",", " ", 
   RowBox[{"v", "\[Element]", " ", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5913416993869333`*^9, 3.5913417963723035`*^9}, {
   3.5914420245290146`*^9, 3.5914421216703854`*^9}, {3.591442168205267*^9, 
   3.5914421830252934`*^9}, 3.5914423088239145`*^9, {3.5914427746251326`*^9, 
   3.591442808165191*^9}, {3.59144284725886*^9, 3.591442868974098*^9}}],

Cell[BoxData[
 RowBox[{"s1", " ", 
  RowBox[{"Cosh", "[", "v", "]"}]}]], "Output",
 CellChangeTimes->{3.5914428715169024`*^9, 3.611640361830691*^9, 
  3.615361946830055*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "hypsf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}]}], ",", " ", 
   RowBox[{"v", "\[Element]", " ", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5913416993869333`*^9, 3.5913417963723035`*^9}, {
   3.5914420245290146`*^9, 3.5914421216703854`*^9}, {3.591442168205267*^9, 
   3.5914421830252934`*^9}, 3.5914423088239145`*^9, {3.5914427746251326`*^9, 
   3.591442808165191*^9}, {3.59144284725886*^9, 3.5914429074437656`*^9}}],

Cell[BoxData[
 FractionBox["s2", 
  SqrtBox[
   RowBox[{"Sech", "[", 
    RowBox[{"2", " ", "v"}], "]"}]]]], "Output",
 CellChangeTimes->{3.5914429122017736`*^9, 3.6116403673531003`*^9, 
  3.6153619512103057`*^9}]
}, Closed]],

Cell[TextData[{
 "The product of the eigenvalues is the determinant of the matrix Table[",
 "cf[",
 "i,j][sf][u,v] ], and this is the Gaussian curvature, see Section 3.2. Using \
a long working time ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " verified"
}], "Text",
 CellChangeTimes->{{3.591345466125239*^9, 3.591345517773193*^9}, {
   3.5914233072975483`*^9, 3.5914233377202883`*^9}, {3.5914233679840193`*^9, 
   3.5914234270003943`*^9}, {3.5914235564968014`*^9, 3.591423599200244*^9}, {
   3.5915079289499435`*^9, 3.5915079404446006`*^9}, 3.5984298919242697`*^9, 
   3.614861859082339*^9, 3.614863501812024*^9, 3.617972099835085*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"gauss", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "-", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"prcurvatures", "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], "*", 
     RowBox[{
      RowBox[{
       RowBox[{"prcurvatures", "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}]}]}], ",", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{"v", "\[Element]", " ", "Reals"}], ",", " ", 
     RowBox[{"v", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5913423152136145`*^9, 3.5913424135873876`*^9}, {
   3.59134244879665*^9, 3.591342507515153*^9}, 3.5913425460004206`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5913425372956047`*^9, 3.5913439568474503`*^9}]
}, Closed]],

Cell[TextData[{
 "If amf[1][sf][u,v], ",
 "amf[",
 "2][sf][u,v] have principal directions and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "1"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "2"], TraditionalForm]]],
 " denote the principal curvature radii,  the normal form of the second \
fundamental form gives ",
 StyleBox["Euler\[CloseCurlyQuote]s formula",
  FontColor->RGBColor[0, 0, 1]],
 " for the normal curvature"
}], "Text",
 CellChangeTimes->{{3.591508114652565*^9, 3.5915083854050508`*^9}, 
   3.5984299357759466`*^9, {3.6148618591135387`*^9, 3.614861859144739*^9}, {
   3.6149177909221597`*^9, 3.6149177909533596`*^9}, {3.615262300306364*^9, 
   3.6152623012024155`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", 
    SubscriptBox["r", "n"]], "\[LongEqual]", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["cos", "2"], "(", "\[Tau]", ")"}], 
     SubscriptBox["r", "1"]], " ", "+", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["sin", "2"], "(", "\[Tau]", ")"}], 
      SubscriptBox["r", "2"]], "."}]}]}], TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.591508404647152*^9, 3.5915084060942345`*^9}, {
   3.5915084395291467`*^9, 3.5915084509828014`*^9}, {3.5915084879509163`*^9, 
   3.5915086366044188`*^9}, 3.591508698468957*^9, {3.5915087375851946`*^9, 
   3.5915087569603024`*^9}},
 TextAlignment->Center],

Cell[TextData[{
 "where ",
 "\[Tau] denotes the angle of the tangent vector of the curve with the first \
principal direction.",
 "\nAnother important invariant of the surface is the ",
 StyleBox["mean curvature",
  FontColor->RGBColor[0, 0, 1]],
 " defined as the trace of the second fundamental form"
}], "Text",
 CellChangeTimes->{{3.5914236744605484`*^9, 3.591423751543957*^9}, {
  3.5914243571205945`*^9, 3.591424357792633*^9}, {3.598451012192274*^9, 
  3.5984510125012918`*^9}, {3.615362094107479*^9, 3.615362161155314*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Tr"}]], "Input",
 CellChangeTimes->{{3.5914239305261946`*^9, 3.591423939273695*^9}, {
  3.5914243681542253`*^9, 3.5914243684412417`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\!\(\*RowBox[{\\\"Tr\\\", \\\"[\\\", StyleBox[\\\"list\\\", \
\\\"TI\\\"], \\\"]\\\"}]\) finds the trace of the matrix or tensor \
\!\(\*StyleBox[\\\"list\\\", \\\"TI\\\"]\). \\n\!\(\*RowBox[{\\\"Tr\\\", \
\\\"[\\\", RowBox[{StyleBox[\\\"list\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\
\"f\\\", \\\"TI\\\"]}], \\\"]\\\"}]\) finds a generalized trace, combining \
terms with \!\(\*StyleBox[\\\"f\\\", \\\"TI\\\"]\) instead of Plus. \
\\n\!\(\*RowBox[{\\\"Tr\\\", \\\"[\\\", RowBox[{StyleBox[\\\"list\\\", \\\"TI\
\\\"], \\\",\\\", StyleBox[\\\"f\\\", \\\"TI\\\"], \\\",\\\", \
StyleBox[\\\"n\\\", \\\"TI\\\"]}], \\\"]\\\"}]\) goes down to level \
\!\(\*StyleBox[\\\"n\\\", \\\"TI\\\"]\) in \!\(\*StyleBox[\\\"list\\\", \
\\\"TI\\\"]\). \"\>", "MSG"], "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Tr"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.5984510267131042`*^9},
 CellTags->"Info3598454626-3632977"]
}, Closed]],

Cell[BoxData[
 RowBox[{"Clear", "[", "ff", "]"}]], "Input",
 CellChangeTimes->{{3.5914530718375034`*^9, 3.5914530774847136`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"meancurvature", "[", "ff_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"cf", "[", 
        RowBox[{"1", ",", "1"}], "]"}], "[", "ff", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", "+", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"cf", "[", 
        RowBox[{"2", ",", "2"}], "]"}], "[", "ff", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], ")"}], "/", "2"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.591453039732647*^9, 3.591453186263705*^9}, 
   3.591453315572332*^9, 3.614861859144739*^9, 3.614863136537382*^9, {
   3.617972101448177*^9, 3.6179721027672524`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"meancurvature", "::", "usage"}], " ", "=", " ", 
   "\"\<meancurvature[f][u,v] is the mean curvature of the surface f[u,v] in \
the Euclidean 3-space.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6153650924458*^9, 3.6153652075853853`*^9}, 
   3.615365241170306*^9}],

Cell[TextData[{
 StyleBox["Remark,",
  FontColor->RGBColor[0, 0, 1]],
 " The signs of the mean curvature, of , ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "1"], TraditionalForm]],
  Evaluatable->False,
  CellChangeTimes->{{3.591508404647152*^9, 3.5915084060942345`*^9}, {
    3.5915084395291467`*^9, 3.5915084509828014`*^9}, {3.5915084879509163`*^9, 
    3.5915086366044188`*^9}, 3.591508698468957*^9, {3.5915087375851946`*^9, 
    3.5915087569603024`*^9}},
  TextAlignment->Center],
 ", and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "2"], TraditionalForm]],
  Evaluatable->False,
  CellChangeTimes->{{3.591508404647152*^9, 3.5915084060942345`*^9}, {
    3.5915084395291467`*^9, 3.5915084509828014`*^9}, {3.5915084879509163`*^9, 
    3.5915086366044188`*^9}, 3.591508698468957*^9, {3.5915087375851946`*^9, 
    3.5915087569603024`*^9}},
  TextAlignment->Center],
 ", are opposite to the definitions in [B-R], see (61.26), p. 89."
}], "Text",
 CellChangeTimes->{{3.5915132001654396`*^9, 3.5915133912293673`*^9}, {
   3.615365277023357*^9, 3.6153652880139856`*^9}, {3.6154345328328114`*^9, 
   3.6154345703196774`*^9}, 3.6184070924544845`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"meancurvature", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "-", 
    RowBox[{
     RowBox[{"Tr", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"cf", "[", 
           RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "/", "2"}]}], ",", 
   " ", 
   RowBox[{"v", " ", "\[Element]", " ", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591424392201601*^9, 3.591424478700548*^9}, {
   3.5914245920050287`*^9, 3.5914246060768337`*^9}, 3.5914432841844273`*^9, {
   3.591443426487877*^9, 3.5914434841143785`*^9}, {3.591443521382844*^9, 
   3.5914435245496497`*^9}, 3.591444524511406*^9, 3.591452112560619*^9, 
   3.591453529043107*^9, {3.5914535906632147`*^9, 3.5914535921140175`*^9}, {
   3.591509215258516*^9, 3.591509217562648*^9}, {3.614861859160339*^9, 
   3.614861859160339*^9}, 3.6148631365529823`*^9, 3.614863501843224*^9, 
   3.617972104512352*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.591453614110056*^9, 3.5915091934402676`*^9, 
  3.591509240578964*^9, 3.6116405825398784`*^9, 3.6153654578637004`*^9, 
  3.618406353445215*^9}]
}, Closed]],

Cell[TextData[{
 "Also the following general equation has been confirmed by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", using about 20 min of evaluating time:"
}], "Text",
 CellChangeTimes->{{3.5914271254729347`*^9, 3.5914271808651032`*^9}, {
   3.591453651908922*^9, 3.5914536546389275`*^9}, 3.5914579284684405`*^9, {
   3.615365395470132*^9, 3.615365402398528*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"meancurvature", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", "\[Equal]", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"prcurvatures", "[", "sf", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], " ", "+", 
       RowBox[{
        RowBox[{
         RowBox[{"prcurvatures", "[", "sf", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "/", "2"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", "Reals"}], ",", " ", 
     RowBox[{"v", "\[Element]", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.591425022610658*^9, {3.5914250548025*^9, 3.5914251408384204`*^9}, {
   3.591425286552755*^9, 3.5914253533975782`*^9}, 3.591453535875919*^9, 
   3.614861859160339*^9, 3.6148631365685825`*^9, 3.615365573002286*^9, {
   3.6153732193236303`*^9, 3.6153732221637926`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.591426135260298*^9, 3.591454372427388*^9}]
}, Closed]],

Cell["\<\
The traditional denotations of the Gaussian and the mean curvature are\
\>", "Text",
 CellChangeTimes->{{3.591510504133235*^9, 3.5915105337009263`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"K", "=", 
   RowBox[{
    RowBox[{"gauss", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], ";", 
  RowBox[{"H", "=", " ", 
   RowBox[{
    RowBox[{"meancurvature", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.591509404812358*^9, 3.5915094861910124`*^9}, {
   3.5915098286475997`*^9, 3.591509840613284*^9}, 3.591510578280476*^9, 
   3.6148618591759386`*^9, 3.6148631365841827`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tt", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"s1", ",", "s2"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.591509404812358*^9, 3.5915094861910124`*^9}, {
  3.5915098286475997`*^9, 3.591509840613284*^9}, {3.591510578280476*^9, 
  3.5915105854378853`*^9}, {3.615365503896333*^9, 3.6153655065834866`*^9}}],

Cell["\<\
We verify the well known relation, proved e.g. in [B-R], (62.19), p.93:\
\>", "Text",
 CellChangeTimes->{{3.591512624125492*^9, 3.5915126308448763`*^9}, {
  3.591512932918154*^9, 3.5915129927415752`*^9}, {3.591514476205425*^9, 
  3.591514484732912*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"K", "*", 
     RowBox[{
      RowBox[{
       RowBox[{"fund1", "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{"tt", ",", "tt"}], "]"}]}], " ", "+", " ", 
    RowBox[{"2", "*", "H", "*", 
     RowBox[{
      RowBox[{
       RowBox[{"fund2a", "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{"tt", ",", "tt"}], "]"}]}], " ", "+", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"d", "[", 
         RowBox[{
          RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ".", "tt"}], ")"}], ".", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"d", "[", 
         RowBox[{
          RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ".", "tt"}], ")"}]}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5915095082782755`*^9, 3.591509568263706*^9}, {
  3.591509610320112*^9, 3.591509645545127*^9}, {3.591509733351149*^9, 
  3.591509753367294*^9}, {3.5915098645436525`*^9, 3.591509870040967*^9}, {
  3.591510188080158*^9, 3.591510252920867*^9}, {3.591510335568594*^9, 
  3.5915103952670083`*^9}, {3.5915125071888037`*^9, 3.59151253055614*^9}, {
  3.6148618591759386`*^9, 3.6148618591759386`*^9}, {3.6149177909533596`*^9, 
  3.61491779096896*^9}, {3.61526232208561*^9, 3.6152623239587173`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "5688.73246600000038597499951720237731933594`9.775615423199271", ",", "0"}],
   "}"}]], "Output",
 CellChangeTimes->{3.591512327010498*^9, 3.591512568725323*^9, 
  3.615378991836799*^9}]
}, Closed]],

Cell[TextData[{
 "The last Dot product is named the",
 StyleBox[" third fundamental form",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface:"
}], "Text",
 CellChangeTimes->{{3.591510744132962*^9, 3.591510787156423*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"fund3", "[", "ff_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], "[", 
   RowBox[{"x_List", ",", "y_List"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{
        RowBox[{"amf", "[", "3", "]"}], "[", "ff", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ".", "x"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{
        RowBox[{"amf", "[", "3", "]"}], "[", "ff", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ".", "y"}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.5915107902566004`*^9, 3.591510920463048*^9}, {
  3.5915111307120733`*^9, 3.591511134304279*^9}, {3.614861859191539*^9, 
  3.614861859191539*^9}, {3.61491779096896*^9, 3.6149177909845595`*^9}, {
  3.6152623260058346`*^9, 3.615262327597925*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fund3", "[", 
     RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "[", 
   RowBox[{"tt", ",", "tt"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5915135006626267`*^9, 3.591513610408904*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["s1", "2"], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["s2", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["s1", "2"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "v"}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.5915136115579696`*^9, 3.59151370178013*^9, 
  3.61164071429771*^9, 3.611640772985013*^9, 3.6154346439830065`*^9, 
  3.6154346779130664`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", 
      RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{"tt", ",", "tt"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5915136280619135`*^9, 3.591513662912907*^9}, 
   3.5915136981689234`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.591513665973082*^9, 3.5915137062083836`*^9, 
  3.6116407872122383`*^9, 3.615434689581887*^9}]
}, Closed]],

Cell["\<\
It degenerates if K = 0, and it is the first fundamental form of the unit \
sphere under the parameter representation of the Gauss map otherwise.\
\>", "Text",
 CellChangeTimes->{{3.5915109744131336`*^9, 3.5915110763489637`*^9}, {
  3.6154347044799128`*^9, 3.6154347134031286`*^9}}],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"K", ",", "H", ",", "cx", ",", "tt", ",", " ", "\[Gamma]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591511821736598*^9, 3.5915118333552628`*^9}, 
   3.5915119055813932`*^9, {3.5915119646777735`*^9, 3.591511972552224*^9}, {
   3.591513428718512*^9, 3.591513460286318*^9}, {3.591513764215701*^9, 
   3.5915137673668814`*^9}, 3.6114713927527266`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["3.5. Graphs of Functions", "Subsection",
 CellChangeTimes->{{3.591592516559106*^9, 3.591592541566536*^9}, 
   3.611640876709595*^9, 3.6116416079920797`*^9, 3.615434814350906*^9, 
   3.6154364406381626`*^9, {3.6184074755410967`*^9, 3.618407498629137*^9}}],

Cell["\<\
In this section we consider surfaces as graphs of functions of two variables: \
We shall calculate the invariants of the graphs and apply the results to \
visualize the relation of the curvature with the local shape of a surface.\
\>", "Text",
 CellChangeTimes->{{3.5915973790152225`*^9, 3.591597457390705*^9}, {
  3.5916065041192923`*^9, 3.5916066114464307`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "graph"}]], "Input",
 CellChangeTimes->{{3.5915926925891743`*^9, 3.5915926960793734`*^9}}],

Cell[BoxData[
 StyleBox["\<\"graph[f][x,y,...] is the canonical parameter representation of \
the \\ngraph {x,y,...f[x,y,...]} of the function f, in arbitrary dimension.\"\
\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6184683573419595`*^9},
 CellTags->"Info3618475557-7588711"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"graph", "[", "f", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5915927300373163`*^9, 3.591592744128122*^9}, 
   3.5984303193338203`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"u", ",", "v", ",", 
   RowBox[{"f", "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5915927452251844`*^9, 3.6116409935226*^9, 
  3.6154349025222607`*^9, 3.6184683698999815`*^9}]
}, Closed]],

Cell["The moving frame of the surface graph[f] is", "Text",
 CellChangeTimes->{{3.5915977489033785`*^9, 3.5915978063746657`*^9}, {
  3.5915982482159376`*^9, 3.591598249815029*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"amf", "[", "1", "]"}], "[", 
   RowBox[{"graph", "[", "f", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.591592810221902*^9, 3.5915928362723923`*^9}, {
   3.5915975202423*^9, 3.5915975270816913`*^9}, {3.591597567498003*^9, 
   3.5915975708171926`*^9}, 3.614861859207139*^9, 3.6149177909845595`*^9, 
   3.615275815323556*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", 
    SqrtBox[
     RowBox[{"1", "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"]}]]], ",", "0", ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}], 
    SqrtBox[
     RowBox[{"1", "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"]}]]]}], "}"}]], "Output",
 CellChangeTimes->{3.5915928381655006`*^9, 3.5915975325110016`*^9, 
  3.5915975719352565`*^9, 3.611641041118284*^9, 3.6154349172330866`*^9, 
  3.618468383456405*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"amf", "[", "2", "]"}], "[", 
   RowBox[{"graph", "[", "f", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.591592810221902*^9, 3.5915928362723923`*^9}, {
   3.5915975202423*^9, 3.5915975270816913`*^9}, {3.591597567498003*^9, 
   3.591597605425172*^9}, 3.614861859207139*^9, 3.6149177910001593`*^9, 
   3.615275816315613*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], 
     RowBox[{
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"]}]]}]]}], ",", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"]}]]}]], "+", 
    FractionBox[
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], 
     RowBox[{
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"u", ",", "v"}], "]"}], "2"]}]]}]]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "v"}], "]"}], 
    RowBox[{
     SqrtBox[
      RowBox[{"1", "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}]], " ", 
     SqrtBox[
      RowBox[{"1", "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}]]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.5915976071662717`*^9, 3.611641041180684*^9, 
  3.615434917357887*^9, 3.618468387278412*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"amf", "[", "3", "]"}], "[", 
   RowBox[{"graph", "[", "f", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.591592810221902*^9, 3.5915928362723923`*^9}, {
   3.5915975202423*^9, 3.5915975270816913`*^9}, {3.591597567498003*^9, 
   3.591597605425172*^9}, {3.5915976544389753`*^9, 3.5915976736180725`*^9}, 
   3.614861859207139*^9, 3.6149177910157595`*^9, 3.6152758172926683`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], 
     SqrtBox[
      RowBox[{"1", "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}]]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], 
     SqrtBox[
      RowBox[{"1", "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}]]]}], ",", 
   FractionBox["1", 
    SqrtBox[
     RowBox[{"1", "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "2"]}]]]}], "}"}]], "Output",
 CellChangeTimes->{3.5915976744681215`*^9, 3.611641041211884*^9, 
  3.6154349173890867`*^9, 3.6184683927228217`*^9}]
}, Closed]],

Cell["\<\
We consider the special position that the tangent plane of the surface at the \
point {u, v}={0, 0}  is the u, v-plane z = 0 and the point graph[f][0,0] is \
the origin. These conditions are\
\>", "Text",
 CellChangeTimes->{{3.5915982913974075`*^9, 3.5915985371594644`*^9}, 
   3.5915987400710697`*^9, 3.59168583181394*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "tcond", "]"}], ";", 
  RowBox[{
   RowBox[{"tcond", "[", "ff_", "]"}], ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"ff", "[", 
         RowBox[{"u", ",", "v"}], "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"u", "\[Rule]", "0"}], ",", 
          RowBox[{"v", "\[Rule]", "0"}]}], "}"}]}], ")"}], "\[Equal]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["ff", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"u", "\[Rule]", "0"}], ",", 
          RowBox[{"v", "\[Rule]", "0"}]}], "}"}]}], ")"}], "\[Equal]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["ff", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"u", "\[Rule]", "0"}], ",", 
          RowBox[{"v", "\[Rule]", "0"}]}], "}"}]}], ")"}], "\[Equal]", 
      "0"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.5915929268945756`*^9, 3.5915930649064693`*^9}, {
  3.591593102353611*^9, 3.5915931751407747`*^9}, {3.591593263948854*^9, 
  3.5915933381660986`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tcond", "[", "f", "]"}]], "Input",
 CellChangeTimes->{{3.5915931846653194`*^9, 3.591593224104575*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"0", ",", "0"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"0", ",", "0"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"0", ",", "0"}], "]"}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.5915932022913275`*^9, 3.59159322542665*^9}, 
   3.5915933469226*^9, 3.5984538132214837`*^9, 3.6116411601308928`*^9, 
   3.6154350481329165`*^9, 3.6184685276162586`*^9}]
}, Closed]],

Cell["\<\
Each surface sf locally, in the neighborhood of an arbitrary regular point,  \
can be represented in this way. The function f is the distance of the point \
sf[u,v] from the tangent plane at the point sf[0,0]. The frame at the point \
{0,0} then is the standard basis:\
\>", "Text",
 CellChangeTimes->{{3.591598628758703*^9, 3.591598711359428*^9}, {
  3.591598745871402*^9, 3.59159889951919*^9}, {3.5915991083351336`*^9, 
  3.591599135631695*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"amf", "[", "1", "]"}], "[", 
        RowBox[{"graph", "[", "f", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"amf", "[", "2", "]"}], "[", 
        RowBox[{"graph", "[", "f", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"amf", "[", "3", "]"}], "[", 
        RowBox[{"graph", "[", "f", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "}"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "\[Rule]", "0"}], ",", 
      RowBox[{"v", "\[Rule]", "0"}]}], "}"}]}], ",", 
   RowBox[{"tcond", "[", "f", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5915989328190947`*^9, 3.5915990016440315`*^9}, {
  3.591599046445594*^9, 3.591599054701066*^9}, {3.614861859222739*^9, 
  3.614861859222739*^9}, {3.6149177910313597`*^9, 3.6149177910313597`*^9}, {
  3.6152758184227333`*^9, 3.6152758205978575`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.591599055801129*^9, 3.5984538520447044`*^9, 
  3.6116412053085723`*^9, 3.615435070534556*^9, 3.6184685620299187`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ss", "=", 
   RowBox[{"{", 
    RowBox[{"s1", ",", "s2"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5915944041560698`*^9, 3.5915944155127196`*^9}, 
   3.591599225201818*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fund1", "[", 
    RowBox[{"graph", "[", "f", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "[", 
  RowBox[{"ss", ",", "ss"}], "]"}]], "Input",
 CellChangeTimes->{{3.5915942364314766`*^9, 3.591594247940135*^9}, {
   3.591594278312872*^9, 3.591594297073945*^9}, {3.5915944248652544`*^9, 
   3.5915944299525456`*^9}, 3.5915993268266306`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["s2", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
  RowBox[{"2", " ", "s1", " ", "s2", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["s1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.591599334023042*^9, 3.5984538658804955`*^9, 
  3.6116412211738005`*^9, 3.6154350817509756`*^9, 3.618468575009142*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "\[Rule]", "0"}], ",", 
      RowBox[{"v", "\[Rule]", "0"}]}], "}"}]}], ",", 
   RowBox[{"tcond", "[", "f", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5915944688857727`*^9, 3.591594505640875*^9}, {
  3.591599368362006*^9, 3.5915993755534177`*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["s1", "2"], "+", 
  SuperscriptBox["s2", "2"]}]], "Output",
 CellChangeTimes->{
  3.591594506685934*^9, {3.591599353755171*^9, 3.5915993777005405`*^9}, 
   3.5984538791842566`*^9, 3.611641227351411*^9, 3.6154350891921887`*^9, 
   3.618468590031968*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fund2a", "[", 
    RowBox[{"graph", "[", "f", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "[", 
  RowBox[{"ss", ",", "ss"}], "]"}]], "Input",
 CellChangeTimes->{{3.5915945394578085`*^9, 3.59159454052787*^9}, {
   3.591594591249771*^9, 3.5915946618878117`*^9}, {3.591594739650259*^9, 
   3.591594762532568*^9}, 3.5916053890825157`*^9, 3.5916054716252365`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"s2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"s2", " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{"s1", " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
   RowBox[{"s1", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"s2", " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{"s1", " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], 
  SqrtBox[
   RowBox[{"1", "+", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "2"]}]]]], "Output",
 CellChangeTimes->{3.5915993874790998`*^9, 3.5916053951328616`*^9, 
  3.591605472600292*^9, 3.598453884569565*^9, 3.611641234121823*^9, 
  3.615435110111826*^9, 3.618468711322181*^9, 3.6184688665112534`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "\[Rule]", "0"}], ",", 
      RowBox[{"v", "\[Rule]", "0"}]}], "}"}]}], ",", 
   RowBox[{"tcond", "[", "f", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5915944688857727`*^9, 3.591594505640875*^9}, {
  3.591599368362006*^9, 3.5915993755534177`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["s2", "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"0", ",", "0"}], "]"}]}], "+", 
  RowBox[{"2", " ", "s1", " ", "s2", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"0", ",", "0"}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["s1", "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"0", ",", "0"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.591599405295119*^9, 3.5916054116028037`*^9, 
  3.5916054780736055`*^9, 3.598453890134883*^9, 3.6116412387706313`*^9, 
  3.6154351164142365`*^9, 3.6184688287435875`*^9, 3.6184688698808594`*^9}]
}, Closed]],

Cell["\<\
We will compare this expression with the first non vanishing term of the \
Taylor series of f at {0,0}:\
\>", "Text",
 CellChangeTimes->{{3.5916010136001086`*^9, 3.5916010984949646`*^9}, {
  3.591605432806016*^9, 3.5916054543502483`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Series"}]], "Input",
 CellChangeTimes->{{3.5915936651197996`*^9, 3.5915936737732944`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\!\(\*RowBox[{\\\"Series\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"f\\\", \\\"TI\\\"], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{StyleBox[\\\"x\\\", \\\"TI\\\"], \\\",\\\", \
SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"0\\\", \
\\\"TR\\\"]], \\\",\\\", StyleBox[\\\"n\\\", \\\"TI\\\"]}], \\\"}\\\"}]}], \\\
\"]\\\"}]\) generates a power series expansion for \!\(\*StyleBox[\\\"f\\\", \
\\\"TI\\\"]\) about the point \!\(\*RowBox[{StyleBox[\\\"x\\\", \\\"TI\\\"], \
\\\"=\\\", SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"0\\\", \
\\\"TR\\\"]]}]\) to order \!\(\*SuperscriptBox[RowBox[{\\\"(\\\", \
RowBox[{StyleBox[\\\"x\\\", \\\"TI\\\"], \\\"-\\\", \
SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"0\\\", \
\\\"TR\\\"]]}], \\\")\\\"}], StyleBox[\\\"n\\\", \\\"TI\\\"]]\). \
\\n\!\(\*RowBox[{\\\"Series\\\", \\\"[\\\", RowBox[{StyleBox[\\\"f\\\", \
\\\"TI\\\"], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{StyleBox[\\\"x\\\", \\\"TI\
\\\"], \\\",\\\", SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \
StyleBox[\\\"0\\\", \\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"n\\\", \
\\\"TI\\\"], StyleBox[\\\"x\\\", \\\"TI\\\"]]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{StyleBox[\\\"y\\\", \\\"TI\\\"], \\\",\\\", \
SubscriptBox[StyleBox[\\\"y\\\", \\\"TI\\\"], StyleBox[\\\"0\\\", \
\\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"n\\\", \\\"TI\\\"], \
StyleBox[\\\"y\\\", \\\"TI\\\"]]}], \\\"}\\\"}], \\\",\\\", StyleBox[\\\"\
\[Ellipsis]\\\", \\\"TR\\\"]}], \\\"]\\\"}]\) successively finds series \
expansions with respect to \!\(\*StyleBox[\\\"x\\\", \\\"TI\\\"]\), then \!\(\
\*StyleBox[\\\"y\\\", \\\"TI\\\"]\), etc. \"\>", "MSG"], 
  "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Series"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.611641257085063*^9},
 CellTags->"Info3611648456-7479549"]
}, Closed]],

Cell["The first term of this series along an arbitrary line is", "Text",
 CellChangeTimes->{{3.591601114977907*^9, 3.5916011479037905`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"s1", "*", "t"}]}], ";", 
  RowBox[{
   RowBox[{"v", "[", "t_", "]"}], " ", ":=", 
   RowBox[{"s2", "*", "t"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5916003676521626`*^9, 3.5916004260495024`*^9}, {
  3.591600594235122*^9, 3.591600630105174*^9}, {3.6184687864831133`*^9, 
  3.618468807839551*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], ",", 
       RowBox[{"v", "[", "t", "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "2"}], "}"}]}], "]"}], ",", 
   RowBox[{"tcond", "[", "f", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5915937069431915`*^9, 3.591593725240238*^9}, {
  3.59159376058526*^9, 3.5915937987624435`*^9}, {3.591593849634353*^9, 
  3.591593853378567*^9}, {3.591594000297971*^9, 3.591594019612075*^9}, {
  3.5915998108033123`*^9, 3.591599837041813*^9}, {3.5916003026874466`*^9, 
  3.5916003256267586`*^9}, {3.5916004415553894`*^9, 3.5916004544021244`*^9}, {
  3.5916006394597087`*^9, 3.591600644394991*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["s2", "2"], " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"0", ",", "0"}], "]"}]}], "+", 
      RowBox[{"2", " ", "s1", " ", "s2", " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"0", ",", "0"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["s1", "2"], " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"0", ",", "0"}], "]"}]}]}], ")"}], " ", 
    SuperscriptBox["t", "2"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "t", "]"}], "3"],
    SeriesData[$CellContext`t, 0, {}, 2, 3, 1],
    Editable->False]}],
  SeriesData[$CellContext`t, 0, {
   Rational[1, 2] ($CellContext`s2^2 
      Derivative[0, 2][$CellContext`f][
       0, 0] + ((2 $CellContext`s1) $CellContext`s2) 
      Derivative[1, 1][$CellContext`f][0, 0] + $CellContext`s1^2 
      Derivative[2, 0][$CellContext`f][0, 0])}, 2, 3, 1],
  Editable->False]], "Output",
 CellChangeTimes->{3.591600460519474*^9, 3.591600647187151*^9, 
  3.5984539294741335`*^9, 3.611641316645968*^9, 3.6154352461440644`*^9, 
  3.6184686158188133`*^9, 3.6184688185567694`*^9}]
}, Closed]],

Cell["\<\
This is the half of the second fundamental form of graph[f] at the point \
{0,0}. We consider simple test functions with given principal curvatures of \
their graphs:\
\>", "Text",
 CellChangeTimes->{{3.591601196950596*^9, 3.5916012447353287`*^9}, {
  3.591601283679556*^9, 3.5916013527195053`*^9}, {3.6154352752225156`*^9, 
  3.615435283849331*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"testf", "[", 
    RowBox[{"k1_", ",", "k2_"}], "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k1", "*", 
       RowBox[{"u", "^", "2"}]}], "+", 
      RowBox[{"k2", "*", 
       RowBox[{"v", "^", "2"}]}]}], ")"}]}], "/", "2"}]}]], "Input",
 CellChangeTimes->{{3.5915953083397865`*^9, 3.591595409400567*^9}, {
   3.591596024913772*^9, 3.5915960290890107`*^9}, 3.591686360140068*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tcond", "[", 
  RowBox[{"testf", "[", 
   RowBox[{"k1", ",", "k2"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.591595419727157*^9, 3.5915954602054725`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{3.5915954627376175`*^9, 3.59159603659144*^9, 
  3.591686367674882*^9, 3.5984539741056857`*^9, 3.611641395176506*^9, 
  3.61543534624944*^9, 3.6184689382713795`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"prcurvatures", "[", 
      RowBox[{"graph", "[", 
       RowBox[{"testf", "[", 
        RowBox[{"k1", ",", "k2"}], "]"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "\[Rule]", "0"}], ",", 
      RowBox[{"v", "\[Rule]", "0"}]}], "}"}]}], ",", " ", 
   RowBox[{"k1", "\[GreaterEqual]", " ", "k2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591601370840542*^9, 3.591601405881546*^9}, 
   3.591604992271819*^9, {3.591605166785801*^9, 3.5916051749442673`*^9}, 
   3.591605221897953*^9, {3.5916055418982563`*^9, 3.5916055638985147`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"k2", ",", "k1"}], "}"}]], "Output",
 CellChangeTimes->{3.591605568378771*^9, 3.59168637266689*^9, 
  3.598454003501367*^9, 3.6116414082493286`*^9, 3.6154353703358827`*^9, 
  3.6184689749938445`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"gauss", "[", 
      RowBox[{"graph", "[", 
       RowBox[{"testf", "[", 
        RowBox[{"k1", ",", "k2"}], "]"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "\[Rule]", "0"}], ",", 
      RowBox[{"v", "\[Rule]", "0"}]}], "}"}]}], ",", " ", 
   RowBox[{"k1", "\[GreaterEqual]", " ", "k2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591601370840542*^9, 3.591601405881546*^9}, 
   3.591604992271819*^9, {3.591605166785801*^9, 3.5916051749442673`*^9}, 
   3.591605221897953*^9, {3.5916055418982563`*^9, 3.5916055638985147`*^9}, {
   3.5916056076470165`*^9, 3.5916056199587207`*^9}}],

Cell[BoxData[
 RowBox[{"k1", " ", "k2"}]], "Output",
 CellChangeTimes->{3.591605621361801*^9, 3.591686383150109*^9, 
  3.59845400983873*^9, 3.6116414162989426`*^9, 3.615435394625125*^9, 
  3.618469020031123*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"meancurvature", "[", 
      RowBox[{"graph", "[", 
       RowBox[{"testf", "[", 
        RowBox[{"k1", ",", "k2"}], "]"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "\[Rule]", "0"}], ",", 
      RowBox[{"v", "\[Rule]", "0"}]}], "}"}]}], ",", " ", 
   RowBox[{"k1", "\[GreaterEqual]", " ", "k2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591601370840542*^9, 3.591601405881546*^9}, 
   3.591604992271819*^9, {3.591605166785801*^9, 3.5916051749442673`*^9}, 
   3.591605221897953*^9, {3.5916055418982563`*^9, 3.5916055638985147`*^9}, {
   3.5916056076470165`*^9, 3.591605642184992*^9}, 3.614861859238339*^9, 
   3.6148631365841827`*^9, 3.615275821972936*^9, 3.615275880248269*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"k1", "+", "k2"}], "2"]], "Output",
 CellChangeTimes->{3.5916056439690943`*^9, 3.591686387377716*^9, 
  3.598454014634004*^9, 3.611641422507754*^9, 3.615435402331539*^9, 
  3.618469048984774*^9, 3.618469947534753*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"fund2", "[", 
     RowBox[{"graph", "[", 
      RowBox[{"testf", "[", 
       RowBox[{"k1", ",", "k2"}], "]"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "[", 
   RowBox[{"ss", ",", "ss"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"u", "\[Rule]", "0"}], ",", 
    RowBox[{"v", "\[Rule]", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.591596189028159*^9, 3.5915962745710516`*^9}, 
   3.5916064079967937`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k1", " ", 
   SuperscriptBox["s1", "2"]}], "+", 
  RowBox[{"k2", " ", 
   SuperscriptBox["s2", "2"]}]}]], "Output",
 CellChangeTimes->{3.5915962463054347`*^9, 3.591596277008191*^9, 
  3.591606410580942*^9, 3.591686472241865*^9, 3.5916865379335804`*^9, 
  3.5984540226754637`*^9, 3.61164143174297*^9, 3.6154354120035553`*^9, 
  3.6184690571747885`*^9}]
}, Closed]],

Cell[TextData[{
 "In the near of  an ",
 StyleBox["elliptic point",
  FontColor->RGBColor[0, 0, 1]],
 ", i.e. K[u,v] >0, the shape of the surface is similar to"
}], "Text",
 CellChangeTimes->{{3.5916056834863544`*^9, 3.591605780221887*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"graph", "[", 
     RowBox[{"testf", "[", 
      RowBox[{"1", ",", "3"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", ".3"}], ",", ".3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", ".3"}], ",", ".3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591595505721076*^9, 3.591595605058758*^9}, 
   3.5915957711872597`*^9}],

Cell["\<\
In particular, for an umbilic point with K > 0 we have the shape nearly to a \
spherical surface\
\>", "Text",
 CellChangeTimes->{{3.591605792010562*^9, 3.5916059000707426`*^9}, {
  3.5916860947056017`*^9, 3.591686125422056*^9}, {3.618469149698551*^9, 
  3.6184691517889547`*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"graph", "[", 
     RowBox[{"testf", "[", 
      RowBox[{"3", ",", "3"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", ".3"}], ",", ".3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", ".3"}], ",", ".3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591595505721076*^9, 3.591595605058758*^9}, {
  3.591595742887641*^9, 3.591595750138056*^9}, {3.591605870594056*^9, 
  3.5916058715061083`*^9}}],

Cell[TextData[{
 "Near an",
 StyleBox[" hyperbolic point",
  FontColor->RGBColor[0, 0, 1]],
 ", K<0, the shape of the surface is near to"
}], "Text",
 CellChangeTimes->{{3.5916060217467017`*^9, 3.5916060856463566`*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"graph", "[", 
     RowBox[{"testf", "[", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "3"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", ".3"}], ",", ".3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", ".3"}], ",", ".3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591595505721076*^9, 3.591595645378064*^9}, {
  3.591596110219651*^9, 3.5915961157469673`*^9}, {3.591686418702571*^9, 
  3.591686425004982*^9}}],

Cell[TextData[{
 "This is a ",
 StyleBox["saddle point",
  FontColor->RGBColor[0, 0, 1]],
 " of the function ftest.  For a ",
 StyleBox["parabolic point",
  FontColor->RGBColor[0, 0, 1]],
 ", i.e. k1>k2 = 0, (or k1<k2 = 0) , the shape of the surface is of type"
}], "Text",
 CellChangeTimes->{{3.591606125706648*^9, 3.591606367550481*^9}, 
   3.591686581754058*^9}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"graph", "[", 
     RowBox[{"testf", "[", 
      RowBox[{"0", ",", "3"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", ".3"}], ",", ".3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", ".3"}], ",", ".3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591595505721076*^9, 3.591595645378064*^9}, {
   3.5915956756417947`*^9, 3.591595686778432*^9}, 3.5916064444268775`*^9, 
   3.591686453256632*^9}],

Cell["\<\
As an exercise plot the intersection of the surface with its tangent plane at \
the point {0,0}  in each of the cases:\
\>", "Text",
 CellChangeTimes->{{3.5916867209219017`*^9, 3.5916868015584435`*^9}, {
   3.5916868490917273`*^9, 3.591686866766558*^9}, 3.5916875684089904`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"graph", "[", 
        RowBox[{"testf", "[", 
         RowBox[{"k1", ",", "k2"}], "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ")"}], ".", 
     RowBox[{"stb", "[", "3", "]"}]}], " ", "\[Equal]", "0"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", "v"}], "}"}], ",", " ", "Reals"}], "]"}]], "Input",
 CellChangeTimes->{{3.591687035543255*^9, 3.591687042812867*^9}, {
   3.591687140562639*^9, 3.5916871955839357`*^9}, 3.6148618592539387`*^9, 
   3.6149177910625596`*^9, {3.618469330019268*^9, 3.618469340970487*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"k2", "<", "0"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"k1", "<", "0"}], "&&", 
        RowBox[{"u", "\[Equal]", "0"}], "&&", 
        RowBox[{"v", "\[Equal]", "0"}]}], ")"}], "||", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"k1", "\[GreaterEqual]", "0"}], "&&", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"v", "\[Equal]", 
           RowBox[{"-", 
            SqrtBox[
             RowBox[{"-", 
              FractionBox[
               RowBox[{"k1", " ", 
                SuperscriptBox["u", "2"]}], "k2"]}]]}]}], "||", 
          RowBox[{"v", "\[Equal]", 
           SqrtBox[
            RowBox[{"-", 
             FractionBox[
              RowBox[{"k1", " ", 
               SuperscriptBox["u", "2"]}], "k2"]}]]}]}], ")"}]}], ")"}]}], 
     ")"}]}], ")"}], "||", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"k2", "\[Equal]", "0"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"k1", "<", "0"}], "&&", 
        RowBox[{"u", "\[Equal]", "0"}]}], ")"}], "||", 
      RowBox[{"k1", "\[Equal]", "0"}], "||", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"k1", ">", "0"}], "&&", 
        RowBox[{"u", "\[Equal]", "0"}]}], ")"}]}], ")"}]}], ")"}], "||", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"k2", ">", "0"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"k1", "\[LessEqual]", "0"}], "&&", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"v", "\[Equal]", 
           RowBox[{"-", 
            SqrtBox[
             RowBox[{"-", 
              FractionBox[
               RowBox[{"k1", " ", 
                SuperscriptBox["u", "2"]}], "k2"]}]]}]}], "||", 
          RowBox[{"v", "\[Equal]", 
           SqrtBox[
            RowBox[{"-", 
             FractionBox[
              RowBox[{"k1", " ", 
               SuperscriptBox["u", "2"]}], "k2"]}]]}]}], ")"}]}], ")"}], "||", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"k1", ">", "0"}], "&&", 
        RowBox[{"u", "\[Equal]", "0"}], "&&", 
        RowBox[{"v", "\[Equal]", "0"}]}], ")"}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.6116415117867107`*^9, 3.615435593728275*^9, 
  3.618469252565132*^9, 3.6184693453540945`*^9, 3.6184699785944076`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"u", ",", "v", ",", "ss", ",", "testf"}], "]"}]], "Input",
 CellChangeTimes->{{3.5916885145818524`*^9, 3.5916885328650846`*^9}, {
  3.618470302669377*^9, 3.6184703062573833`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["3.6. Ruled Surfaces: Criterion of Developability", "Subsection",
 CellChangeTimes->{{3.591771408757987*^9, 3.5917714528555093`*^9}, {
   3.594270351054023*^9, 3.5942703667164507`*^9}, 3.611641617461296*^9, 
   3.611667344308116*^9, 3.6154364525565834`*^9, 3.6154517959096875`*^9, {
   3.6184703670506897`*^9, 3.6184703699678946`*^9}, 3.618561968272961*^9}],

Cell["Ruled surface have been introduced in Subsection 2.1.2;", "Text",
 CellChangeTimes->{{3.59202391500099*^9, 3.592023996339533*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ruled", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "[", 
  RowBox[{"s", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.5920228263062778`*^9, 3.5920228604391375`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "t", "]"}], "[", "1", "]"}], "+", 
    RowBox[{"s", " ", 
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "t", "]"}], "[", "2", "]"}], "+", 
    RowBox[{"s", " ", 
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "t", "]"}], "[", "3", "]"}], "+", 
    RowBox[{"s", " ", 
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.592022847023114*^9, 3.592022862326741*^9}, 
   3.592023111802379*^9, 3.592023833818447*^9, 3.5920240034375453`*^9, 
   3.5920467760852103`*^9, 3.5921112247244034`*^9, 3.611641739640711*^9, 
   3.6154364771266265`*^9, 3.618491188199978*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsf", "[", 
   RowBox[{"s_", ",", "t_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"ruled", "[", 
    RowBox[{"x", ",", " ", "y"}], "]"}], "[", 
   RowBox[{"s", ",", "t"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5917723210491667`*^9, 3.591772332008794*^9}, {
   3.591772366105744*^9, 3.591772383985767*^9}, {3.591971789454519*^9, 
   3.5919717908585215`*^9}, 3.5919720609641957`*^9, {3.5920231716284847`*^9, 
   3.592023191643319*^9}, {3.5920234488097715`*^9, 3.592023471414211*^9}, 
   3.5920240269935865`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rsf", "[", 
  RowBox[{"s", ",", " ", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.591772390090116*^9, 3.591772396432479*^9}, 
   3.5919717922625237`*^9, 3.591972063741001*^9, 3.592023652046928*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "t", "]"}], "[", "1", "]"}], "+", 
    RowBox[{"s", " ", 
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "t", "]"}], "[", "2", "]"}], "+", 
    RowBox[{"s", " ", 
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "t", "]"}], "[", "3", "]"}], "+", 
    RowBox[{"s", " ", 
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.591972118278696*^9, 3.5920231989441323`*^9, 
  3.5920234909610453`*^9, 3.592024036338003*^9, 3.5920467761320105`*^9, 
  3.5921112247400036`*^9, 3.6116417729935694`*^9, 3.615436495097858*^9, 
  3.6184912225668383`*^9}]
}, Closed]],

Cell["We set", "Text",
 CellChangeTimes->{{3.592024050081627*^9, 3.59202405156363*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"xx", "[", "t_", "]"}], " ", "=", 
   RowBox[{"vec", "[", 
    RowBox[{"x", "[", "t", "]"}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"yy", "[", "t_", "]"}], " ", "=", 
   RowBox[{"vec", "[", 
    RowBox[{"y", "[", "t", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.591771503590411*^9, 3.5917715096997604`*^9}, {
   3.591771552281196*^9, 3.5917715868411727`*^9}, {3.591771626377434*^9, 
   3.591771658025244*^9}, {3.5917719866660414`*^9, 3.5917720404511175`*^9}, {
   3.591772073435004*^9, 3.5917722000862484`*^9}, {3.591772279558794*^9, 
   3.591772307915416*^9}, {3.5919717709996862`*^9, 3.5919717880817165`*^9}, 
   3.591971995686881*^9, {3.592023012071404*^9, 3.5920230840655303`*^9}}],

Cell["\<\
and assume that the following three conditions are satisfied:\
\>", "Text",
 CellChangeTimes->{{3.592024086991292*^9, 3.5920240913905*^9}, {
  3.5920241521058064`*^9, 3.592024182026659*^9}}],

Cell["Conditions. 1. t is the arc length of the curve xx[t]: ", "Text",
 CellChangeTimes->{{3.5917724731278653`*^9, 3.5917725324312572`*^9}, 
   3.591971800358938*^9, 3.591972152161956*^9, {3.6154366314108973`*^9, 
   3.615436634546503*^9}, 3.6184912621753073`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"xx", "'"}], "[", "t", "]"}], ".", 
   RowBox[{
    RowBox[{"xx", "'"}], "[", "t", "]"}]}], "\[Equal]", " ", "1"}]], "Input",
 CellChangeTimes->{{3.5917725466500707`*^9, 3.5917725635370364`*^9}, 
   3.5917727670656776`*^9, {3.5919718012949395`*^9, 3.5919718020593405`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "2"], "+", 
   SuperscriptBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "2"], "+", 
   SuperscriptBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], "2"]}], 
  "\[Equal]", "1"}]], "Output",
 CellChangeTimes->{3.5917725663882*^9, 3.5917727826395683`*^9, 
  3.5919455199253545`*^9, 3.59196621085752*^9, 3.591972137763131*^9, 
  3.59202321473136*^9, 3.592024206705902*^9, 3.5920467761476107`*^9, 
  3.592111224755604*^9, 3.6116418211664543`*^9, 3.6154365481691513`*^9, 
  3.6184912708489227`*^9}]
}, Closed]],

Cell["2.s is the arc length of the rulings (the generating lines)", "Text",
 CellChangeTimes->{{3.5917726476638484`*^9, 3.5917727400471325`*^9}, 
   3.5919721589635677`*^9, {3.592024220246726*^9, 3.5920242610719976`*^9}, 
   3.6184912986169715`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"yy", "[", "t", "]"}], ".", 
   RowBox[{"yy", "[", "t", "]"}]}], "\[Equal]", " ", "1"}]], "Input",
 CellChangeTimes->{{3.5917727481735973`*^9, 3.591772758993216*^9}, {
  3.5919718461606183`*^9, 3.5919718469562197`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{
     RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], "2"], "+", 
   SuperscriptBox[
    RowBox[{
     RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "2"], "+", 
   SuperscriptBox[
    RowBox[{
     RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "2"]}], "\[Equal]", 
  "1"}]], "Output",
 CellChangeTimes->{3.591772788115882*^9, 3.5919455199409547`*^9, 
  3.5919662108731203`*^9, 3.5919721626139746`*^9, 3.592023219302168*^9, 
  3.5920242646600037`*^9, 3.5920467761632104`*^9, 3.592111224771204*^9, 
  3.6116418268760643`*^9, 3.61543656458038*^9, 3.618491302189378*^9}]
}, Closed]],

Cell["3. The directrix intersects the rulings orthogonal :", "Text",
 CellChangeTimes->{{3.5917728253350105`*^9, 3.5917728708076115`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"xx", "'"}], "[", "t", "]"}], ".", 
   RowBox[{"yy", "[", "t", "]"}]}], "\[Equal]", " ", "0"}]], "Input",
 CellChangeTimes->{{3.5917728840893707`*^9, 3.5917728999052753`*^9}, {
  3.5919718565346365`*^9, 3.5919718575018387`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], "+", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], "+", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
  "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.5917729045735426`*^9, 3.5919455199565544`*^9, 
  3.5919662108887205`*^9, 3.5919721682611847`*^9, 3.592023224372177*^9, 
  3.59202427377042*^9, 3.59204677617881*^9, 3.5921112247868037`*^9, 
  3.611641851836108*^9, 3.6154365886824226`*^9, 3.6184913099737916`*^9}]
}, Closed]],

Cell["We collect these conditions and their derivatives into", "Text",
 CellChangeTimes->{{3.591772976055631*^9, 3.5917730201351523`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ruledcond", "[", 
   RowBox[{"f_", ",", "g_", ",", "t_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], "[", "t", "]"}], ".", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "t", "]"}]}], "\[Equal]", " ", "1"}], ",", 
    " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], "[", "t", "]"}], ".", 
      RowBox[{
       RowBox[{"f", "''"}], "[", "t", "]"}]}], "\[Equal]", " ", "0"}], ",", 
    " ", 
    RowBox[{
     RowBox[{
      RowBox[{"g", "[", "t", "]"}], ".", 
      RowBox[{"g", "[", "t", "]"}]}], "\[Equal]", " ", "1"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"g", "'"}], "[", "t", "]"}], ".", 
      RowBox[{"g", "[", "t", "]"}]}], "\[Equal]", "  ", "0"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], "[", "t", "]"}], ".", 
      RowBox[{"g", "[", "t", "]"}]}], " ", "\[Equal]", " ", "0"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"f", "''"}], "[", "t", "]"}], ".", 
       RowBox[{"g", "[", "t", "]"}]}], " ", "+", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "'"}], "[", "t", "]"}], ".", 
       RowBox[{
        RowBox[{"g", "'"}], "[", "t", "]"}]}]}], " ", "\[Equal]", " ", 
     "0"}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5917730578503094`*^9, 3.591773257268716*^9}, {
  3.591773294164826*^9, 3.5917733554303303`*^9}, {3.5917734069742785`*^9, 
  3.5917734221761475`*^9}, {3.5917735277751875`*^9, 3.5917735384467983`*^9}, {
  3.5919718795134773`*^9, 3.5919719042083206`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ruledcond", "[", 
  RowBox[{"xx", ",", "yy", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.5917734434103622`*^9, 3.5917734747451544`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "2"], 
     "+", 
     SuperscriptBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "2"], 
     "+", 
     SuperscriptBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], "2"]}], 
    "\[Equal]", "1"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
    "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "2"]}], "\[Equal]", 
    "1"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
    "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
    "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
    "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5917734761412344`*^9, 3.5917735456182084`*^9, 
  3.5919455199721546`*^9, 3.5919662109043207`*^9, 3.5919721804448056`*^9, 
  3.5920233560364084`*^9, 3.5920242937072554`*^9, 3.5920467762100105`*^9, 
  3.592111224802404*^9, 3.6116418674829354`*^9, 3.615436669818165*^9, 
  3.6184913259794197`*^9, 3.618546093035349*^9}]
}, Closed]],

Cell["\<\
Now we calculate the \[OpenCurlyDoubleQuote]fundamental\
\[CloseCurlyDoubleQuote] invariants of the ruled surface and express them by \
the defining vectors. For the first fundamental form we obtain\
\>", "Text",
 CellChangeTimes->{{3.592024910672739*^9, 3.5920249298295727`*^9}, {
   3.5920258232431417`*^9, 3.592025891040861*^9}, 3.618491368785895*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"ruledcond", "[", 
     RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fund1", "[", "rsf", "]"}], "[", 
       RowBox[{"s", ",", " ", "t"}], "]"}], "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"u1", ",", "u2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"u1", ",", "u2"}], "}"}]}], "]"}], ",", 
     RowBox[{"TimeConstraint", "\[Rule]", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591773629631014*^9, 3.591773714170849*^9}, {
   3.5917737484678106`*^9, 3.5917737560822463`*^9}, {3.591773808723257*^9, 
   3.591773814242573*^9}, {3.591775768244335*^9, 3.5917757816751037`*^9}, {
   3.5917786327132173`*^9, 3.591778658722705*^9}, {3.591788739317565*^9, 
   3.591788759352711*^9}, 3.5917889229130664`*^9, 3.5917890378886423`*^9, {
   3.59178994401447*^9, 3.5917900186787405`*^9}, 3.5917933838012147`*^9, {
   3.591793669191538*^9, 3.5917937009843564`*^9}, {3.5917951837611666`*^9, 
   3.5917952037283087`*^9}, {3.591795236712195*^9, 3.591795257680394*^9}, {
   3.5917967300736103`*^9, 3.59179673880011*^9}, 3.5919455581142216`*^9, 
   3.591945593588684*^9, {3.5919476014838104`*^9, 3.5919476613255157`*^9}, {
   3.5919499489159336`*^9, 3.59195003789849*^9}, 3.5920236628265467`*^9, 
   3.592024567659336*^9, {3.6184922379570217`*^9, 3.6184923055051403`*^9}, {
   3.61849235670443*^9, 3.61849236233604*^9}, 3.618493122774976*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["u1", "2"], "+", 
  RowBox[{
   SuperscriptBox["u2", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{
      SuperscriptBox["s", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
         "2"]}], ")"}]}], "-", 
     RowBox[{"2", " ", "s", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
       ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.5920245570513177`*^9, 3.5920245964725866`*^9, 
  3.5920468212004895`*^9, 3.611642042156442*^9, 3.615436873741723*^9, 
  3.6184915387325935`*^9, 3.618492255491452*^9, 3.618492308765546*^9, 
  3.618492364286043*^9, 3.6184931335389943`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
     ")"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
     ")"}]}], ",", 
   RowBox[{"Evaluate", "[", 
    RowBox[{"ruledcond", "[", 
     RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6184932156419387`*^9, 3.618493233987571*^9}, {
   3.618493313578911*^9, 3.6184933488349724`*^9}, 3.6184959796391935`*^9, 
   3.6184960168452587`*^9, 3.6184960623505383`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.618493357742588*^9, {3.6184960373124948`*^9, 3.618496064222542*^9}}]
}, Closed]],

Cell["The coefficients are", "Text",
 CellChangeTimes->{{3.5920256205363855`*^9, 3.592025648600835*^9}, {
  3.5920259057828865`*^9, 3.592025917529707*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"ruledcond", "[", 
     RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"1", ",", "1"}], "]"}], "[", "rsf", "]"}], "[", 
       RowBox[{"s", ",", " ", "t"}], "]"}], "\[Equal]", " ", "1"}], ",", 
     RowBox[{"TimeConstraint", "\[Rule]", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591773629631014*^9, 3.591773714170849*^9}, {
   3.5917737484678106`*^9, 3.5917737560822463`*^9}, {3.591773808723257*^9, 
   3.591773814242573*^9}, {3.591775768244335*^9, 3.5917757816751037`*^9}, {
   3.5917786327132173`*^9, 3.591778658722705*^9}, {3.591788739317565*^9, 
   3.591788759352711*^9}, 3.5917889229130664`*^9, 3.5917890378886423`*^9, {
   3.59178994401447*^9, 3.5917900186787405`*^9}, 3.5917933838012147`*^9, {
   3.591793669191538*^9, 3.5917937009843564`*^9}, {3.5917951837611666`*^9, 
   3.5917952037283087`*^9}, {3.591795236712195*^9, 3.591795257680394*^9}, {
   3.5917967300736103`*^9, 3.59179673880011*^9}, 3.5919455581142216`*^9, 
   3.591945593588684*^9, {3.5919476014838104`*^9, 3.5919476613255157`*^9}, {
   3.5919499489159336`*^9, 3.59195003789849*^9}, 3.5920236628265467`*^9, 
   3.592024567659336*^9, {3.592024950874009*^9, 3.5920250921166573`*^9}, 
   3.5920251260467167`*^9, 3.5920257017501283`*^9, 3.6176282336851797`*^9, 
   3.6184923352699924`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.592025706742137*^9, 3.611644918644727*^9, 
  3.615436953972664*^9, 3.61849244219258*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"1", ",", "2"}], "]"}], "[", "rsf", "]"}], "[", 
       RowBox[{"s", ",", " ", "t"}], "]"}], "\[Equal]", " ", "0"}], ",", 
     RowBox[{"TimeConstraint", "\[Rule]", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591773629631014*^9, 3.591773714170849*^9}, {
   3.5917737484678106`*^9, 3.5917737560822463`*^9}, {3.591773808723257*^9, 
   3.591773814242573*^9}, {3.591775768244335*^9, 3.5917757816751037`*^9}, {
   3.5917786327132173`*^9, 3.591778658722705*^9}, {3.591788739317565*^9, 
   3.591788759352711*^9}, 3.5917889229130664`*^9, 3.5917890378886423`*^9, {
   3.59178994401447*^9, 3.5917900186787405`*^9}, 3.5917933838012147`*^9, {
   3.591793669191538*^9, 3.5917937009843564`*^9}, {3.5917951837611666`*^9, 
   3.5917952037283087`*^9}, {3.591795236712195*^9, 3.591795257680394*^9}, {
   3.5917967300736103`*^9, 3.59179673880011*^9}, 3.5919455581142216`*^9, 
   3.591945593588684*^9, {3.5919476014838104`*^9, 3.5919476613255157`*^9}, {
   3.5919499489159336`*^9, 3.59195003789849*^9}, 3.5920236628265467`*^9, 
   3.592024567659336*^9, {3.592024950874009*^9, 3.5920250784978333`*^9}, 
   3.5920251338467307`*^9, 3.5920251948428383`*^9, 3.6176282415886316`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.592025084394644*^9, 3.592025136748336*^9, 
  3.59202519610644*^9, 3.5920257227633653`*^9, 3.611644929907947*^9, 
  3.615436954643465*^9, 3.6184928568413086`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"2", ",", "2"}], "]"}], "[", "rsf", "]"}], "[", 
       RowBox[{"s", ",", " ", "t"}], "]"}], "\[Equal]", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"xx", "'"}], "[", "t", "]"}], "+", " ", 
         RowBox[{"s", "*", 
          RowBox[{
           RowBox[{"yy", "'"}], "[", "t", "]"}]}]}], ")"}], ".", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"xx", "'"}], "[", "t", "]"}], "+", " ", 
         RowBox[{"s", "*", 
          RowBox[{
           RowBox[{"yy", "'"}], "[", "t", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{"TimeConstraint", "\[Rule]", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591773629631014*^9, 3.591773714170849*^9}, {
   3.5917737484678106`*^9, 3.5917737560822463`*^9}, {3.591773808723257*^9, 
   3.591773814242573*^9}, {3.591775768244335*^9, 3.5917757816751037`*^9}, {
   3.5917786327132173`*^9, 3.591778658722705*^9}, {3.591788739317565*^9, 
   3.591788759352711*^9}, 3.5917889229130664`*^9, 3.5917890378886423`*^9, {
   3.59178994401447*^9, 3.5917900186787405`*^9}, 3.5917933838012147`*^9, {
   3.591793669191538*^9, 3.5917937009843564`*^9}, {3.5917951837611666`*^9, 
   3.5917952037283087`*^9}, {3.591795236712195*^9, 3.591795257680394*^9}, {
   3.5917967300736103`*^9, 3.59179673880011*^9}, 3.5919455581142216`*^9, 
   3.591945593588684*^9, {3.5919476014838104`*^9, 3.5919476613255157`*^9}, {
   3.5919499489159336`*^9, 3.59195003789849*^9}, 3.5920236628265467`*^9, 
   3.592024567659336*^9, {3.592024950874009*^9, 3.5920250784978333`*^9}, 
   3.5920251338467307`*^9, {3.5920251948428383`*^9, 3.5920252157780743`*^9}, {
   3.5920254784357357`*^9, 3.5920255461554546`*^9}, 3.6176282474619675`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5920255567010736`*^9, 3.592025745243005*^9, 
  3.6116449377547607`*^9, 3.6154369547682657`*^9, 3.61849286897813*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"2", ",", "2"}], "]"}], "[", "rsf", "]"}], "[", 
      RowBox[{"s", ",", " ", "t"}], "]"}], ",", 
     RowBox[{"TimeConstraint", "\[Rule]", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591773629631014*^9, 3.591773714170849*^9}, {
   3.5917737484678106`*^9, 3.5917737560822463`*^9}, {3.591773808723257*^9, 
   3.591773814242573*^9}, {3.591775768244335*^9, 3.5917757816751037`*^9}, {
   3.5917786327132173`*^9, 3.591778658722705*^9}, {3.591788739317565*^9, 
   3.591788759352711*^9}, 3.5917889229130664`*^9, 3.5917890378886423`*^9, {
   3.59178994401447*^9, 3.5917900186787405`*^9}, 3.5917933838012147`*^9, {
   3.591793669191538*^9, 3.5917937009843564`*^9}, {3.5917951837611666`*^9, 
   3.5917952037283087`*^9}, {3.591795236712195*^9, 3.591795257680394*^9}, {
   3.5917967300736103`*^9, 3.59179673880011*^9}, 3.5919455581142216`*^9, 
   3.591945593588684*^9, {3.5919476014838104`*^9, 3.5919476613255157`*^9}, {
   3.5919499489159336`*^9, 3.59195003789849*^9}, 3.5920236628265467`*^9, 
   3.592024567659336*^9, {3.592024950874009*^9, 3.5920250784978333`*^9}, 
   3.5920251338467307`*^9, {3.5920251948428383`*^9, 3.5920252157780743`*^9}, {
   3.5920254784357357`*^9, 3.5920255461554546`*^9}, 3.6176282474619675`*^9, {
   3.618495351020489*^9, 3.61849537412413*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["x", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "+", 
     RowBox[{"s", " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}]}], 
    ")"}], "2"], "+", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["x", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "+", 
     RowBox[{"s", " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}]}], 
    ")"}], "2"], "+", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["x", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], "+", 
     RowBox[{"s", " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
    ")"}], "2"]}]], "Output",
 CellChangeTimes->{3.6184954406738467`*^9}]
}, Closed]],

Cell["The Gaussian curvature:", "Text",
 CellChangeTimes->{{3.5920274989668846`*^9, 3.5920275363757505`*^9}, {
  3.6154383312678833`*^9, 3.615438345729109*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"gauss", "[", "rsf", "]"}], "[", 
      RowBox[{"s", ",", " ", "t"}], "]"}], ",", 
     RowBox[{"TimeConstraint", " ", "->", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591773629631014*^9, 3.591773714170849*^9}, {
   3.5917737484678106`*^9, 3.5917737560822463`*^9}, {3.591773808723257*^9, 
   3.591773814242573*^9}, {3.591775768244335*^9, 3.5917757816751037`*^9}, {
   3.5917786327132173`*^9, 3.591778658722705*^9}, 3.591945531859376*^9, 
   3.5919662569712014`*^9, {3.591966314535302*^9, 3.5919663241605196`*^9}, 
   3.5920236574601374`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
          "-", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}]}], 
         ")"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], 
           " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
         ")"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
          "-", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
         ")"}]}]}], ")"}], "2"], "/", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{
        SuperscriptBox["s", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
           "2"], "+", 
          SuperscriptBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
           "2"], "+", 
          SuperscriptBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
           "2"]}], ")"}]}], "-", 
       RowBox[{"2", " ", "s", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
         ")"}]}]}], ")"}], "2"]}], ")"}]}]], "Output",
 CellChangeTimes->{3.591971598576584*^9, 3.6154375749629545`*^9, 
  3.61850951263246*^9, 3.6185467916513762`*^9}]
}, Closed]],

Cell["\<\
Thus we obtained the always non-positive Gaussian curvature of a ruled \
surface:\
\>", "Text",
 CellChangeTimes->{{3.615440149154676*^9, 3.6154401960015583`*^9}, 
   3.6184976289988904`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"gaussrsf", "[", 
   RowBox[{"s_", ",", " ", "t_"}], "]"}], " ", ":=", " ", "\n", "  ", 
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", 
              "t", "]"}], "[", "\n", "          ", "2", "]"}], "*", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "\n", "          ", "1", "]"}]}], " ", "-", 
           " ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", 
              "t", "]"}], "[", "\n", "          ", "1", "]"}], "*", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "\n", "          ", "2", "]"}]}]}], ")"}]}], 
        " ", "+", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "*", "\n", "       ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"-", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", 
                "t", "]"}], "[", "3", "]"}]}], ")"}], "*", "\n", "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "1", "]"}]}], " ", "+", " ", "\n", "        ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", 
              "t", "]"}], "[", "1", "]"}], "*", "\n", "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "3", "]"}]}]}], ")"}]}], " ", "+", " ", "\n", 
        "      ", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", 
              "t", "]"}], "[", "\n", "          ", "3", "]"}], "*", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "\n", "          ", "2", "]"}]}], " ", "-", 
           " ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", 
              "t", "]"}], "[", "\n", "          ", "2", "]"}], "*", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "\n", "          ", "3", "]"}]}]}], ")"}]}]}], 
       ")"}], "^", "2"}], "/", "\n", "    ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", " ", "+", " ", 
        RowBox[{
         RowBox[{"s", "^", "2"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "\n", "          ", "1", "]"}], "^", "2"}], 
           " ", "+", " ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "\n", "           ", "t", "]"}], "[", "2", "]"}], "^", "2"}], 
           " ", "+", " ", "\n", "        ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "3", "]"}], "^", "2"}]}], ")"}]}], " ", "-", 
        " ", "\n", "      ", 
        RowBox[{"2", "*", "s", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], "*", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
              "\n", "           ", "t", "]"}], "[", "1", "]"}]}], " ", "+", 
           " ", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "*", "\n", 
            "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
              "t", "]"}], "[", "2", "]"}]}], " ", "+", " ", "\n", "        ", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "*", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
              "t", "]"}], "[", "\n", "          ", "3", "]"}]}]}], ")"}]}]}], 
       ")"}], "^", "2"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.615439990985998*^9, 3.615440036756479*^9}, {
   3.615440098298587*^9, 3.61544011742422*^9}, {3.6185634258433294`*^9, 
   3.618563441960251*^9}, 3.6185634929331665`*^9}],

Cell["\<\
 We  calculate the coefficients of the second fundamental form with respect \
to the cobasis \[Sigma][1], \[Sigma][2]:\
\>", "Text",
 CellChangeTimes->{{3.591971612569808*^9, 3.591971643707463*^9}, {
   3.5920275682310066`*^9, 3.592027618712695*^9}, {3.5920276500999503`*^9, 
   3.592027688772418*^9}, 3.592046285230348*^9, {3.6154383708919525`*^9, 
   3.6154383797527685`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"cf", "[", 
        RowBox[{"1", ",", "1"}], "]"}], "[", "rsf", "]"}], "[", 
      RowBox[{"s", ",", " ", "t"}], "]"}], ",", 
     RowBox[{"TimeConstraint", " ", "->", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591773629631014*^9, 3.591773714170849*^9}, {
   3.5917737484678106`*^9, 3.5917737560822463`*^9}, {3.591773808723257*^9, 
   3.591773814242573*^9}, {3.591775768244335*^9, 3.5917757816751037`*^9}, {
   3.5917786327132173`*^9, 3.591778658722705*^9}, {3.591788739317565*^9, 
   3.591788759352711*^9}, 3.5919455433721952`*^9, 3.59202365875494*^9, 
   3.5920277181784697`*^9, 3.5920277515937285`*^9, 3.617972115784997*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5917888047923107`*^9, 3.592027776787773*^9, 
  3.6116451192142797`*^9, 3.615438408113618*^9, 3.6185468668435087`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rsfc", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "[", 
   RowBox[{"s_", ",", "t_"}], "]"}], ":=", "0"}]], "Input",
 CellChangeTimes->{{3.5917888627836275`*^9, 3.591788891982297*^9}, 
   3.592027795305005*^9, {3.5920463146675997`*^9, 3.592046340828846*^9}, 
   3.592046432603807*^9, 3.592046856191351*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"cf", "[", 
        RowBox[{"1", ",", "2"}], "]"}], "[", "rsf", "]"}], "[", 
      RowBox[{"s", ",", " ", "t"}], "]"}], ",", 
     RowBox[{"TimeConstraint", " ", "->", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591773629631014*^9, 3.591773714170849*^9}, {
   3.5917737484678106`*^9, 3.5917737560822463`*^9}, {3.591773808723257*^9, 
   3.591773814242573*^9}, {3.591775768244335*^9, 3.5917757816751037`*^9}, {
   3.5917786327132173`*^9, 3.591778658722705*^9}, {3.591788739317565*^9, 
   3.591788759352711*^9}, 3.5919455433721952`*^9, 3.59202365875494*^9, 
   3.5920277181784697`*^9, 3.5920277515937285`*^9, {3.5920278491563*^9, 
   3.5920278705283375`*^9}, 3.592046850528541*^9, 3.617972162048643*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], "-", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}]}], 
      ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
      ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], "-", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
      ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    RowBox[{
     SuperscriptBox["s", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "2"], 
       "+", 
       SuperscriptBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "2"], 
       "+", 
       SuperscriptBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], "2"]}],
       ")"}]}], "-", 
    RowBox[{"2", " ", "s", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
      ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.5920278906679726`*^9, 3.615438767335449*^9, 
  3.618547388820425*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rsfc", "[", 
    RowBox[{"1", ",", " ", "2"}], "]"}], "[", 
   RowBox[{"s_", ",", " ", "t_"}], "]"}], " ", ":=", " ", "\n", "  ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "2", "]"}], "*", "\n", "       ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
           "]"}], "[", "1", "]"}]}], " ", "-", " ", "\n", "      ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "1", "]"}], "*", "\n", "       ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
           "]"}], "[", "2", "]"}]}]}], ")"}]}], " ", "+", " ", "\n", "    ", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", 
             "t", "]"}], "[", "\n", "         ", "3", "]"}]}], ")"}], "*", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
           "]"}], "[", "\n", "        ", "1", "]"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "1", "]"}], "*", "\n", "       ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
           "]"}], "[", "3", "]"}]}]}], ")"}]}], " ", "+", " ", "\n", "    ", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "3", "]"}], "*", "\n", "       ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
           "]"}], "[", "2", "]"}]}], " ", "-", " ", "\n", "      ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "2", "]"}], "*", "\n", "       ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
           "]"}], "[", "3", "]"}]}]}], ")"}]}]}], ")"}], "/", "\n", "   ", 
   RowBox[{"(", 
    RowBox[{"1", " ", "+", " ", 
     RowBox[{
      RowBox[{"s", "^", "2"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
           "]"}], "[", "1", "]"}], "^", "\n", "       ", "2"}], " ", "+", " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
           "]"}], "[", "2", "]"}], "^", "\n", "       ", "2"}], " ", "+", " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
           "]"}], "[", "3", "]"}], "^", "\n", "       ", "2"}]}], ")"}]}], 
     " ", "-", " ", 
     RowBox[{"2", "*", "s", "*", "\n", "     ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], "*", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "\n", "        ", "1", "]"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "*", "\n", "       ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "2", "]"}]}], " ", "+", " ", "\n", "      ", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "*", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "\n", "        ", "3", "]"}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Input",
 CellChangeTimes->{{3.592046383806921*^9, 3.592046453539044*^9}, {
  3.614861859285139*^9, 3.614861859347539*^9}, {3.6149177910937595`*^9, 
  3.6149177911561604`*^9}, {3.615439089538415*^9, 3.615439122516873*^9}, {
  3.615439153966528*^9, 3.6154392339010687`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rsfc", "[", 
    RowBox[{"2", ",", "1"}], "]"}], "[", 
   RowBox[{"s_", ",", " ", "t_"}], "]"}], " ", ":=", 
  RowBox[{
   RowBox[{"rsfc", "[", 
    RowBox[{"1", ",", "2"}], "]"}], "[", 
   RowBox[{"s", ",", " ", "t"}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.5920285948376093`*^9, 3.5920286219348574`*^9}, {
  3.5920464791854887`*^9, 3.5920465062983365`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"cf", "[", 
        RowBox[{"2", ",", "2"}], "]"}], "[", "rsf", "]"}], "[", 
      RowBox[{"s", ",", " ", "t"}], "]"}], ",", 
     RowBox[{"TimeConstraint", " ", "->", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591773629631014*^9, 3.591773714170849*^9}, {
   3.5917737484678106`*^9, 3.5917737560822463`*^9}, {3.591773808723257*^9, 
   3.591773814242573*^9}, {3.591775768244335*^9, 3.5917757816751037`*^9}, {
   3.5917786327132173`*^9, 3.591778658722705*^9}, {3.591788739317565*^9, 
   3.591788759352711*^9}, 3.5919455433721952`*^9, 3.59202365875494*^9, 
   3.5920277181784697`*^9, 3.5920277515937285`*^9, {3.5920278491563*^9, 
   3.5920278705283375`*^9}, {3.5920279197152243`*^9, 3.592027932912847*^9}, 
   3.592046889169809*^9, 3.617972174952381*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "+", 
          RowBox[{"s", " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"s", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
          "-", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
          "-", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}]}], 
         ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["s", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
          "-", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}]}], 
         ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], "-", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "+", 
          RowBox[{"s", " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"s", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], 
           " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
         ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["s", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], 
           " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
         ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "+", 
          RowBox[{"s", " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"s", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
          "-", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], 
          "-", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
         ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["s", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
          "-", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
         ")"}]}]}], ")"}]}]}], ")"}], "/", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{
      SuperscriptBox["s", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
         "2"]}], ")"}]}], "-", 
     RowBox[{"2", " ", "s", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
       ")"}]}]}], ")"}], 
   RowBox[{"3", "/", "2"}]]}]], "Output",
 CellChangeTimes->{3.592028032597022*^9, 3.6154394709746847`*^9, 
  3.6185480623048077`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rsfc", "[", 
    RowBox[{"2", ",", " ", "2"}], "]"}], "[", 
   RowBox[{"s_", ",", " ", "t_"}], "]"}], " ", ":=", " ", "\n", "  ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", 
             "t", "]"}], "[", "1", "]"}]}], ")"}], "*", "\n", "       ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "2", "]"}]}], " ", "+", " ", "\n", "      ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "2", "]"}], "*", "\n", "       ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
             "t", "]"}], "[", "1", "]"}], " ", "+", " ", "\n", "        ", 
           RowBox[{"s", "*", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "1", "]"}]}]}], ")"}]}], " ", "+", " ", "\n", 
        "      ", 
        RowBox[{"s", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "2", "]"}], "*", "\n", "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
              "t", "]"}], "[", "1", "]"}]}], " ", "-", " ", "\n", "        ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "1", "]"}], "*", "\n", "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
              "t", "]"}], "[", "2", "]"}]}], " ", "-", " ", "\n", "        ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", 
              "t", "]"}], "[", "1", "]"}], "*", "\n", "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "2", "]"}]}]}], ")"}]}], " ", "+", " ", "\n", 
        "      ", 
        RowBox[{
         RowBox[{"s", "^", "2"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "2", "]"}], "*", "\n", "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "1", "]"}]}], " ", "-", " ", "\n", "        ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "1", "]"}], "*", "\n", "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "2", "]"}]}]}], ")"}]}]}], ")"}]}], " ", "+", 
     " ", "\n", "    ", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "1", "]"}], "*", "\n", "       ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "3", "]"}]}], " ", "-", " ", "\n", "      ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "3", "]"}], "*", "\n", "       ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
             "t", "]"}], "[", "1", "]"}], " ", "+", " ", "\n", "        ", 
           RowBox[{"s", "*", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "1", "]"}]}]}], ")"}]}], " ", "+", " ", "\n", 
        "      ", 
        RowBox[{"s", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"-", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
                "t", "]"}], "[", "3", "]"}]}], ")"}], "*", "\n", "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
              "t", "]"}], "[", "1", "]"}]}], " ", "+", " ", "\n", "        ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "1", "]"}], "*", "\n", "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
              "t", "]"}], "[", "3", "]"}]}], " ", "+", " ", "\n", "        ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", 
              "t", "]"}], "[", "1", "]"}], "*", "\n", "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "3", "]"}]}]}], ")"}]}], " ", "+", " ", "\n", 
        "      ", 
        RowBox[{
         RowBox[{"s", "^", "2"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"-", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
                "t", "]"}], "[", "3", "]"}]}], ")"}], "*", "\n", "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "1", "]"}]}], " ", "+", " ", "\n", "        ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "1", "]"}], "*", "\n", "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "3", "]"}]}]}], ")"}]}]}], ")"}]}], " ", "+", 
     " ", "\n", "    ", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", 
             "t", "]"}], "[", "\n", "         ", "2", "]"}]}], ")"}], "*", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "3", "]"}]}], " ", "+", " ", "\n", "      ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "3", "]"}], "*", "\n", "       ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
             "t", "]"}], "[", "2", "]"}], " ", "+", " ", "\n", "        ", 
           RowBox[{"s", "*", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "2", "]"}]}]}], ")"}]}], " ", "+", " ", "\n", 
        "      ", 
        RowBox[{"s", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "3", "]"}], "*", "\n", "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
              "t", "]"}], "[", "2", "]"}]}], " ", "-", " ", "\n", "        ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "2", "]"}], "*", "\n", "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
              "t", "]"}], "[", "3", "]"}]}], " ", "-", " ", "\n", "        ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", 
              "t", "]"}], "[", "2", "]"}], "*", "\n", "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "3", "]"}]}]}], ")"}]}], " ", "+", " ", "\n", 
        "      ", 
        RowBox[{
         RowBox[{"s", "^", "2"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "3", "]"}], "*", "\n", "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "2", "]"}]}], " ", "-", " ", "\n", "        ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "2", "]"}], "*", "\n", "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "3", "]"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], 
   "/", "\n", "   ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", " ", "+", " ", 
      RowBox[{
       RowBox[{"s", "^", "2"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t",
             "]"}], "[", "1", "]"}], "^", "\n", "        ", "2"}], " ", "+", 
         " ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t",
             "]"}], "[", "2", "]"}], "^", "\n", "        ", "2"}], " ", "+", 
         " ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t",
             "]"}], "[", "3", "]"}], "^", "\n", "        ", "2"}]}], ")"}]}], 
      " ", "-", " ", 
      RowBox[{"2", "*", "s", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], "*", "\n", 
          "        ", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t",
             "]"}], "[", "1", "]"}]}], " ", "+", " ", "\n", "       ", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "*", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t",
             "]"}], "[", "\n", "         ", "2", "]"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "*", "\n", 
          "        ", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t",
             "]"}], "[", "3", "]"}]}]}], ")"}]}]}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"3", "/", "2"}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.618548391200186*^9, 3.61854839374299*^9}, 
   3.6185484318850574`*^9}],

Cell["\<\
 The Gaussian curvature is the determinant of these coefficients, see Section \
3.2\
\>", "Text",
 CellChangeTimes->{{3.5920281482400255`*^9, 3.592028194182106*^9}, {
  3.5920282896542735`*^9, 3.5920282970642867`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Assuming", "[", 
   RowBox[{
    RowBox[{"ruledcond", "[", 
     RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"Det", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"rsfc", "[", 
           RowBox[{"i", ",", "j"}], "]"}], "[", 
          RowBox[{"s", ",", "t"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
      RowBox[{"TimeConstraint", " ", "->", " ", "Infinity"}]}], "]"}]}], 
   "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.591773629631014*^9, 3.591773714170849*^9}, {
   3.5917737484678106`*^9, 3.5917737560822463`*^9}, {3.591773808723257*^9, 
   3.591773814242573*^9}, {3.591775768244335*^9, 3.5917757816751037`*^9}, {
   3.5917786327132173`*^9, 3.591778658722705*^9}, {3.591788739317565*^9, 
   3.591788759352711*^9}, 3.5919455433721952`*^9, 3.59202365875494*^9, 
   3.5920277181784697`*^9, 3.5920277515937285`*^9, {3.5920278491563*^9, 
   3.5920278705283375`*^9}, {3.5920279197152243`*^9, 3.592027932912847*^9}, {
   3.5920283473743753`*^9, 3.592028382022036*^9}, {3.5920284192281013`*^9, 
   3.5920285315326986`*^9}, 3.592046635310563*^9, {3.5920469265942745`*^9, 
   3.592046955766326*^9}, 3.6148618596127396`*^9, 3.614863501843224*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"301.69033389999998462371877394616603851318`8.500161308966243", ",", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], "2"], 
        "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "2"]}], ")"}], 
         " ", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
          "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}],
           ")"}]}], "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}],
           ")"}], "2"]}], ")"}], "/", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          SuperscriptBox["s", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
             "2"], "+", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
             "2"], "+", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
             "2"]}], ")"}]}], "-", 
         RowBox[{"2", " ", "s", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
            "+", 
            RowBox[{
             RowBox[{
              RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
            "+", 
            RowBox[{
             RowBox[{
              RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "3", 
              "]"}]}]}], ")"}]}]}], ")"}], "2"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5920285598467484`*^9, 3.5920286641017313`*^9, 
  3.592046984953977*^9, 3.6116453637135086`*^9, 3.615439788825243*^9, 
  3.6185487966448975`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Krsf", "[", 
   RowBox[{"s_", ",", " ", "t_"}], "]"}], " ", ":=", " ", "\n", "  ", 
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
          "]"}], "[", "1", "]"}], "^", "2"}], " ", "+", " ", "\n", "     ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
          "]"}], "[", "2", "]"}], "^", "2"}], " ", "+", " ", "\n", "     ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
          "]"}], "[", "3", "]"}], "^", "2"}], " ", "+", " ", "\n", "     ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], " ", "+", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "^", "2"}], " ", 
          "+", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "^", "2"}]}], 
         ")"}], "*", "\n", "      ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "1", "]"}], "^", "2"}]}], " ", "-", " ", "\n", "     ", 
       RowBox[{"2", "*", 
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], "*", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t", 
          "]"}], "[", "1", "]"}], "*", "\n", "      ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "*", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
             "t", "]"}], "[", "\n", "         ", "2", "]"}]}], " ", "+", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "*", "\n", 
           "        ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
             "t", "]"}], "[", "3", "]"}]}]}], ")"}]}], " ", "-", " ", "\n", 
       "     ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "*", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
             "t", "]"}], "[", "\n", "         ", "2", "]"}]}], " ", "+", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "*", "\n", 
           "        ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
             "t", "]"}], "[", "3", "]"}]}]}], ")"}], "^", "2"}]}], ")"}], "/",
      "\n", "    ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", " ", "+", " ", 
        RowBox[{
         RowBox[{"s", "^", "2"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "1", "]"}], "^", "\n", "         ", "2"}], " ",
            "+", " ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "2", "]"}], "^", "\n", "         ", "2"}], " ",
            "+", " ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "3", "]"}], "^", "\n", "         ", "2"}]}], 
          ")"}]}], " ", "-", " ", 
        RowBox[{"2", "*", "s", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], "*", "\n", 
            "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
              "t", "]"}], "[", "1", "]"}]}], " ", "+", " ", "\n", "        ", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "*", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
              "t", "]"}], "[", "\n", "          ", "2", "]"}]}], " ", "+", 
           " ", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "*", "\n", 
            "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
              "t", "]"}], "[", "3", "]"}]}]}], ")"}]}]}], ")"}], "^", "2"}]}],
     ")"}]}]}]], "Input",
 CellChangeTimes->{{3.5920466545921965`*^9, 3.592046673967431*^9}, {
  3.6148618596127396`*^9, 3.61486185967514*^9}, {3.6149177914057603`*^9, 
  3.6149177914681606`*^9}, {3.618549408914773*^9, 3.618549437447223*^9}}],

Cell["We control", "Text",
 CellChangeTimes->{{3.615440232958023*^9, 3.61544023660843*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"Krsf", "[", 
      RowBox[{"s", ",", "t"}], "]"}], "-", " ", 
     RowBox[{"gaussrsf", "[", 
      RowBox[{"s", ",", "t"}], "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592031391735322*^9, 3.5920314016257396`*^9}, {
   3.615440245282045*^9, 3.6154403257781863`*^9}, 3.618549469052879*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5920314028425417`*^9, 3.5920470643737164`*^9, 
  3.5921115103765054`*^9, 3.611645441214445*^9, 3.611650246662485*^9, 
  3.6154403527662334`*^9, 3.6185494842005053`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Krsf", "[", 
  RowBox[{"s", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.6185500438046885`*^9, 3.6185500537107058`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "2"], 
      "+", 
      SuperscriptBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "2"], 
      "+", 
      SuperscriptBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], "2"], 
      "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "2"]}],
       "-", 
      RowBox[{"2", " ", 
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
        ")"}], "2"]}], ")"}], "/", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{
        SuperscriptBox["s", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
           "2"], "+", 
          SuperscriptBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
           "2"], "+", 
          SuperscriptBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
           "2"]}], ")"}]}], "-", 
       RowBox[{"2", " ", "s", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
         ")"}]}]}], ")"}], "2"]}], ")"}]}]], "Output",
 CellChangeTimes->{3.61855005620671*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["It follows the",
  FontColor->GrayLevel[0]],
 StyleBox["\nCriterion.",
  FontColor->RGBColor[0, 0, 1]],
 " The ruled surface rsf[s, t] := xx]t] + s*yy][t], where xx, yy satisfy the \
conditions "
}], "Text",
 CellChangeTimes->{{3.5919695796873407`*^9, 3.5919695872065535`*^9}, {
   3.591969771286877*^9, 3.5919698988795013`*^9}, {3.5919699317799587`*^9, 
   3.5919699517635937`*^9}, 3.592023584436409*^9, {3.592029928671152*^9, 
   3.5920299343651624`*^9}, {3.5920470783513412`*^9, 3.592047080753745*^9}, {
   3.5922183538404703`*^9, 3.592218371311469*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ruledcond", "[", 
   RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"xx", "'"}], ".", 
      RowBox[{"xx", "'"}]}], "\[Equal]", "1"}], ",", " ", 
    RowBox[{
     RowBox[{"yy", ".", "yy"}], " ", "\[Equal]", " ", "1"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"xx", "'"}], ".", "yy"}], "\[Equal]", " ", "0"}]}], 
   "}"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.591969981590846*^9, 3.5919701060166655`*^9}, {
   3.592047093514568*^9, 3.5920470950589705`*^9}, 3.6185546260787363`*^9}],

Cell["has the Gaussian curvature", "Text",
 CellChangeTimes->{{3.5920299951116695`*^9, 3.5920300221777163`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Krsf", "(", 
    RowBox[{"s", ",", "t"}], ")"}], "\[LongEqual]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["yy", "\[Prime]",
         MultilineFunction->None], "(", "t", ")"}], ".", 
       RowBox[{
        SuperscriptBox["yy", "\[Prime]",
         MultilineFunction->None], "(", "t", ")"}]}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["xx", "\[Prime]",
           MultilineFunction->None], "(", "t", ")"}], ".", 
         RowBox[{
          SuperscriptBox["yy", "\[Prime]",
           MultilineFunction->None], "(", "t", ")"}]}], ")"}], "2"]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"s", " ", 
           RowBox[{
            SuperscriptBox["yy", "\[Prime]",
             MultilineFunction->None], "(", "t", ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["xx", "\[Prime]",
            MultilineFunction->None], "(", "t", ")"}]}], ")"}], ".", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"s", " ", 
           RowBox[{
            SuperscriptBox["yy", "\[Prime]",
             MultilineFunction->None], "(", "t", ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["xx", "\[Prime]",
            MultilineFunction->None], "(", "t", ")"}]}], ")"}]}], ")"}], 
      "2"]]}]}], TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.592030032660935*^9, 3.5920301076346664`*^9}, {
   3.592030144840732*^9, 3.5920302698905516`*^9}, 3.592032530350122*^9, 
   3.5920471394254484`*^9}],

Cell["The surface is developable iff ", "Text",
 CellChangeTimes->{{3.591970202222034*^9, 3.591970227213278*^9}, {
  3.5919702655562363`*^9, 3.591970270403514*^9}, {3.5920303196546392`*^9, 
  3.592030324241047*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"(*", 
   RowBox[{
    RowBox[{")", "                          ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["yy", "\[Prime]",
        MultilineFunction->None], "(", "t", ")"}], ".", 
      RowBox[{
       SuperscriptBox["yy", "\[Prime]",
        MultilineFunction->None], "(", "t", ")"}]}]}], "\[LongEqual]", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["yy", "\[Prime]",
          MultilineFunction->None], "(", "t", ")"}], ".", 
        RowBox[{
         SuperscriptBox["xx", "\[Prime]",
          MultilineFunction->None], "(", "t", ")"}]}], ")"}], "2"], "."}]}]}],
   TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5919703342231636`*^9, 3.591970334456177*^9}, 
   3.5919703812638545`*^9, 3.592047182216324*^9, {3.592047410741125*^9, 
   3.5920474186035385`*^9}, {3.6116464842946773`*^9, 3.611646496306698*^9}}],

Cell[TextData[{
 StyleBox["Proof",
  FontColor->RGBColor[0, 0, 1]],
 ". First we check the formula for the curvature  Krsf[s,t]:"
}], "Text",
 CellChangeTimes->{{3.591970572095769*^9, 3.591970666820187*^9}, {
   3.5919707419874864`*^9, 3.591970840188103*^9}, {3.5919710737404613`*^9, 
   3.5919710961077414`*^9}, {3.591971168891904*^9, 3.591971219956825*^9}, {
   3.5919712500365453`*^9, 3.591971385892316*^9}, {3.5919714409454646`*^9, 
   3.591971459415521*^9}, {3.5919714898212605`*^9, 3.591971502003957*^9}, {
   3.592030403785587*^9, 3.5920304817545238`*^9}, {3.5920305450906353`*^9, 
   3.5920305474462395`*^9}, {3.5920326139818687`*^9, 
   3.5920326269922915`*^9}, {3.592047221075992*^9, 3.5920472221835938`*^9}, {
   3.615442227593127*^9, 3.6154423098988714`*^9}, 3.618553138569324*^9, {
   3.618553195618624*^9, 3.618553225009076*^9}, {3.61855355192325*^9, 
   3.6185535876161127`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Krsf", "[", 
       RowBox[{"s", ",", "t"}], "]"}], " ", "\[Equal]", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"yy", "'"}], "[", "t", "]"}], ".", 
           RowBox[{
            RowBox[{"yy", "'"}], "[", "t", "]"}]}], " ", "-", 
          RowBox[{
           RowBox[{"(", " ", 
            RowBox[{
             RowBox[{
              RowBox[{"xx", "'"}], "[", "t", "]"}], ".", 
             RowBox[{
              RowBox[{"yy", "'"}], "[", "t", "]"}]}], ")"}], "^", "2"}]}], 
         ")"}]}], "/", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"xx", "'"}], "[", "t", "]"}], " ", "+", 
            RowBox[{"s", "*", 
             RowBox[{
              RowBox[{"yy", "'"}], "[", "t", "]"}]}]}], ")"}], ".", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"xx", "'"}], "[", "t", "]"}], " ", "+", 
            RowBox[{"s", "*", 
             RowBox[{
              RowBox[{"yy", "'"}], "[", "t", "]"}]}]}], ")"}]}], ")"}], "^", 
        "2"}]}]}], ",", 
     RowBox[{"TimeConstraint", " ", "->", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.592030563233467*^9, 3.592030592951519*^9}, {
   3.5920314597202415`*^9, 3.5920314666778536`*^9}, {3.5920315132439356`*^9, 
   3.592031539623582*^9}, 3.592031682098632*^9, {3.592032371151842*^9, 
   3.5920323779846544`*^9}, {3.592032515015295*^9, 3.5920325452325478`*^9}, {
   3.592032592266631*^9, 3.5920325936082335`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5920313806593027`*^9, 3.592031506036723*^9, 
  3.5920316726294155`*^9, 3.5920320291524415`*^9, 3.5920325175424995`*^9, 
  3.5920325482277536`*^9, 3.5920325962446375`*^9, 3.592111532918545*^9, 
  3.611651100030784*^9, 3.615440764123356*^9, 3.618553305817218*^9}]
}, Closed]],

Cell["\<\
 A surface, in particular a ruled surface, is developable iff its Gaussian \
curvature equals zero, see  Subsection 2.2 .3. Thus the ruled surface is \
developable iff condition (*) is valid   \[FilledSquare]\
\>", "Text",
 CellChangeTimes->{{3.5920326603919506`*^9, 3.5920326808747864`*^9}, {
   3.5920327676577387`*^9, 3.5920328681687155`*^9}, {3.5920473610394373`*^9, 
   3.5920473823490753`*^9}, {3.592047433064764*^9, 3.592047457588007*^9}, {
   3.5920477355725155`*^9, 3.5920477384756813`*^9}, 3.6154423422533283`*^9, {
   3.615443194014824*^9, 3.615443196276828*^9}, {3.618553735753973*^9, 
   3.6185537650040245`*^9}}],

Cell[TextData[{
 StyleBox["Corollary.",
  FontColor->RGBColor[0, 0, 1]],
 " The condition (*) can be written in the form"
}], "Text",
 CellChangeTimes->{{3.615443353993105*^9, 3.615443453926881*^9}, 
   3.615443697817709*^9, 3.6154437382841797`*^9, 3.6185539467131433`*^9}],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(*", "*)"}], "                       ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["xx", "\[Prime]",
         MultilineFunction->None], "(", "t", ")"}], " ", ".", 
       RowBox[{
        SuperscriptBox["xx", "\[Prime]",
         MultilineFunction->None], "(", "t", ")"}]}], ")"}], "*", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["yy", "\[Prime]",
         MultilineFunction->None], "(", "t", ")"}], ".", 
       RowBox[{
        SuperscriptBox["yy", "\[Prime]",
         MultilineFunction->None], "(", "t", ")"}]}], ")"}]}], "\[LongEqual]", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["yy", "\[Prime]",
          MultilineFunction->None], "(", "t", ")"}], ".", 
        RowBox[{
         SuperscriptBox["xx", "\[Prime]",
          MultilineFunction->None], "(", "t", ")"}]}], ")"}], "2"], "."}]}]}],
   TraditionalForm]],
 Evaluatable->False,
 CellChangeTimes->{{3.5919703342231636`*^9, 3.591970334456177*^9}, 
   3.5919703812638545`*^9, 3.592047182216324*^9, {3.592047410741125*^9, 
   3.5920474186035385`*^9}, {3.6116464842946773`*^9, 
   3.611646496306698*^9}}]], "Text",
 CellChangeTimes->{{3.6154435063429728`*^9, 3.615443534313822*^9}, {
  3.615443574858293*^9, 3.6154436171811676`*^9}, {3.6154436514544277`*^9, 
  3.6154436537008314`*^9}, {3.6154437181133447`*^9, 3.6154437181133447`*^9}, {
  3.615443791183873*^9, 3.615443791183873*^9}}],

Cell["A ruled surface", "Text",
 CellChangeTimes->{{3.615444030473133*^9, 3.615444048054364*^9}, {
  3.618554659743596*^9, 3.6185546844384394`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ruled", "[", 
   RowBox[{"xx", ",", "yy"}], "]"}], "[", 
  RowBox[{"s", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.615444057507981*^9, 3.6154440603159857`*^9}, {
  3.6154441029508605`*^9, 3.615444114292081*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], "[", "1", "]"}], ",", 
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], "[", "2", "]"}], ",", 
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], "[", "3", "]"}]}], "}"}], "[", "1", 
     "]"}], "+", 
    RowBox[{"s", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], ",", 
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], ",", 
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}]}], "}"}], "[", "1", 
      "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], "[", "1", "]"}], ",", 
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], "[", "2", "]"}], ",", 
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], "[", "3", "]"}]}], "}"}], "[", "2", 
     "]"}], "+", 
    RowBox[{"s", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], ",", 
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], ",", 
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}]}], "}"}], "[", "2", 
      "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], "[", "1", "]"}], ",", 
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], "[", "2", "]"}], ",", 
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], "[", "3", "]"}]}], "}"}], "[", "3", 
     "]"}], "+", 
    RowBox[{"s", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], ",", 
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], ",", 
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}]}], "}"}], "[", "3", 
      "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6154441195336895`*^9}]
}, Closed]],

Cell[TextData[{
 " satisfying  the conditions yy(t).yy(t)==1 and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"yy", "(", "t", ")"}], ".", 
    RowBox[{
     SuperscriptBox["xx", "\[Prime]",
      MultilineFunction->None], "(", "t", ")"}]}], TraditionalForm]],
  Evaluatable->False,
  CellChangeTimes->{{3.5919703342231636`*^9, 3.591970334456177*^9}, 
    3.5919703812638545`*^9, 3.592047182216324*^9, {3.592047410741125*^9, 
    3.5920474186035385`*^9}, {3.6116464842946773`*^9, 3.611646496306698*^9}}],
 " == 0 is developable iff condition (**) is  satisfied, t an arbitrary \
parameter.\n",
 StyleBox["Proof.",
  FontColor->RGBColor[0, 0, 1]],
 " Remember: the conditions yy(t).yy(t)==1 and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"yy", "(", "t", ")"}], ".", 
    RowBox[{
     SuperscriptBox["xx", "\[Prime]",
      MultilineFunction->None], "(", "t", ")"}]}], TraditionalForm]],
  Evaluatable->False,
  CellChangeTimes->{{3.5919703342231636`*^9, 3.591970334456177*^9}, 
    3.5919703812638545`*^9, 3.592047182216324*^9, {3.592047410741125*^9, 
    3.5920474186035385`*^9}, {3.6116464842946773`*^9, 3.611646496306698*^9}}],
 " == 0 being assumed in addition to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["xx", "\[Prime]",
      MultilineFunction->None], "(", "t", ")"}], " ", ".", 
    RowBox[{
     SuperscriptBox["xx", "\[Prime]",
      MultilineFunction->None], "(", "t", ")"}]}], TraditionalForm]],
  Evaluatable->False,
  CellChangeTimes->{{3.5919703342231636`*^9, 3.591970334456177*^9}, 
    3.5919703812638545`*^9, 3.592047182216324*^9, {3.592047410741125*^9, 
    3.5920474186035385`*^9}, {3.6116464842946773`*^9, 3.611646496306698*^9}}],
 " == 1 as we calculated the Gaussian curvature; the other three conditions \
in ruledcond follow by deriving those.  If t is the arc length of the curve \
xx[t] condition [**) reduces to (*) and is proved. Now condition (**) is \
invariant under a parameter transformation. Thus the criterion is valid for \
any parametrizations  of xx[t], yy[t].\[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.615444168190175*^9, 3.6154444057473927`*^9}, {
   3.615444442173456*^9, 3.6154444708775067`*^9}, 3.615444591231718*^9, {
   3.6154446991215076`*^9, 3.615444904449068*^9}, {3.6154449408595324`*^9, 
   3.6154449687991815`*^9}, {3.615445015068863*^9, 3.6154450421193104`*^9}, {
   3.618554242692463*^9, 3.6185542543768835`*^9}, {3.618554289866946*^9, 
   3.6185543196317987`*^9}, {3.618554692082453*^9, 3.6185547207709026`*^9}, 
   3.618554780019807*^9, {3.6185548133258657`*^9, 3.618554836772707*^9}, {
   3.6185548901092005`*^9, 3.618554909624835*^9}, {3.6185549522753096`*^9, 
   3.6185550958111615`*^9}}],

Cell["\<\
Now we control our result using the expression of the Gaussian curvature as \
the quotient of two determinants, namely the determinants of the coefficients \
of the second  over the first fundamental form, see Section 3.2. For the \
second fundamental form we obtain\
\>", "Text",
 CellChangeTimes->{{3.592112863023681*^9, 3.5921130169023514`*^9}, {
   3.592113231402728*^9, 3.59211328907603*^9}, 3.6116512417882333`*^9, {
   3.61856207403701*^9, 3.618562085612673*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fund2", "[", "rsf", "]"}], "[", 
       RowBox[{"s", ",", " ", "t"}], "]"}], "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"u1", ",", "u2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"u1", ",", "u2"}], "}"}]}], "]"}], ",", 
     RowBox[{"TimeConstraint", "\[Rule]", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591773629631014*^9, 3.591773714170849*^9}, {
   3.5917737484678106`*^9, 3.5917737560822463`*^9}, {3.591773808723257*^9, 
   3.591773814242573*^9}, {3.591775768244335*^9, 3.5917757816751037`*^9}, {
   3.5917786327132173`*^9, 3.591778658722705*^9}, {3.591788739317565*^9, 
   3.591788759352711*^9}, 3.5917889229130664`*^9, 3.5917890378886423`*^9, {
   3.59178994401447*^9, 3.5917900186787405`*^9}, 3.5917933838012147`*^9, {
   3.591793669191538*^9, 3.5917937009843564`*^9}, {3.5917951837611666`*^9, 
   3.5917952037283087`*^9}, {3.591795236712195*^9, 3.591795257680394*^9}, {
   3.5917967300736103`*^9, 3.59179673880011*^9}, 3.5919455581142216`*^9, 
   3.591945593588684*^9, {3.5919476014838104`*^9, 3.5919476613255157`*^9}, {
   3.5919499489159336`*^9, 3.59195003789849*^9}, 3.5920236628265467`*^9, 
   3.592047774872763*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"u2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "u1", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}]}], " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
            "+", 
            RowBox[{
             RowBox[{
              RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "2", 
              "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
             " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
            "-", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
             " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "2", 
              "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
            "-", 
            RowBox[{
             RowBox[{
              RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "2", 
              "]"}]}]}], ")"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}], "+", 
      RowBox[{"u2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}],
              " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
            "+", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
             " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
               "+", 
               RowBox[{"s", " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "[", "1", 
                 "]"}]}]}], ")"}]}], "+", 
            RowBox[{"s", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "[", "1", 
                  "]"}]}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "[", "2", 
                 "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}],
                 " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "[", "1", 
                   "]"}], "+", 
                  RowBox[{"s", " ", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["y", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "[", "1", 
                    "]"}]}]}], ")"}]}], "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "[", "1", 
                   "]"}], "+", 
                  RowBox[{"s", " ", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "[", "1", 
                    "]"}]}]}], ")"}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "[", "2", 
                 "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
             " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], 
            "-", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
             " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
               "+", 
               RowBox[{"s", " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "[", "1", 
                 "]"}]}]}], ")"}]}], "+", 
            RowBox[{"s", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}],
                 " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "[", "3", 
                 "]"}]}], "-", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}],
                 " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "[", "1", 
                   "]"}], "+", 
                  RowBox[{"s", " ", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["y", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "[", "1", 
                    "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "[", "1", 
                   "]"}], "+", 
                  RowBox[{"s", " ", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "[", "1", 
                    "]"}]}]}], ")"}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "[", "3", 
                 "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}],
              " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], 
            "+", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
             " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["x", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
               "+", 
               RowBox[{"s", " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "[", "2", 
                 "]"}]}]}], ")"}]}], "+", 
            RowBox[{"s", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "[", "2", 
                  "]"}]}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "[", "3", 
                 "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}],
                 " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "[", "2", 
                   "]"}], "+", 
                  RowBox[{"s", " ", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["y", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "[", "2", 
                    "]"}]}]}], ")"}]}], "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "[", "2", 
                   "]"}], "+", 
                  RowBox[{"s", " ", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "[", "2", 
                    "]"}]}]}], ")"}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "[", "3", 
                 "]"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], 
  "/", 
  RowBox[{"(", 
   RowBox[{"\[Sqrt]", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{
       SuperscriptBox["s", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
          "2"]}], ")"}]}], "-", 
      RowBox[{"2", " ", "s", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.5920478906873875`*^9, 3.611651834308474*^9, 
  3.615445986576169*^9, 3.618555784848772*^9}]
}, Closed]],

Cell["\<\
We calculate the coefficients of the second fundamental form:\
\>", "Text",
 CellChangeTimes->{{3.5920481697323475`*^9, 3.592048223499423*^9}, {
  3.611651325841181*^9, 3.611651328352785*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fd2", "[", 
        RowBox[{"1", ",", "1"}], "]"}], "[", "rsf", "]"}], "[", 
      RowBox[{"s", ",", " ", "t"}], "]"}], ",", 
     RowBox[{"TimeConstraint", "\[Rule]", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591773629631014*^9, 3.591773714170849*^9}, {
   3.5917737484678106`*^9, 3.5917737560822463`*^9}, {3.591773808723257*^9, 
   3.591773814242573*^9}, {3.591775768244335*^9, 3.5917757816751037`*^9}, {
   3.5917786327132173`*^9, 3.591778658722705*^9}, {3.591788739317565*^9, 
   3.591788759352711*^9}, 3.5917889229130664`*^9, 3.5917890378886423`*^9, {
   3.59178994401447*^9, 3.5917900186787405`*^9}, 3.5917933838012147`*^9, {
   3.591793669191538*^9, 3.5917937009843564`*^9}, {3.5917951837611666`*^9, 
   3.5917952037283087`*^9}, {3.591795236712195*^9, 3.591795257680394*^9}, {
   3.5917967300736103`*^9, 3.59179673880011*^9}, 3.5919455581142216`*^9, 
   3.591945593588684*^9, {3.5919476014838104`*^9, 3.5919476613255157`*^9}, {
   3.5919499489159336`*^9, 3.59195003789849*^9}, {3.59195236660818*^9, 
   3.5919524075738525`*^9}, {3.5919527647832794`*^9, 
   3.5919527686988864`*^9}, {3.591972928029319*^9, 3.59197293456573*^9}, {
   3.5919729663585863`*^9, 3.5919729992434435`*^9}, {3.591973035076707*^9, 
   3.591973039694315*^9}, 3.5920236728261642`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.591952854655038*^9, 3.5919730234858866`*^9, 
  3.5919731305488744`*^9, 3.592048380530405*^9, 3.5921115946790533`*^9, 
  3.6116519104366074`*^9, 3.615450736777027*^9, 3.6185561399677954`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fa", "[", 
    RowBox[{"1", ",", " ", "1"}], "]"}], "[", 
   RowBox[{"s_", ",", " ", "t_"}], "]"}], " ", ":=", " ", "0"}]], "Input",
 CellChangeTimes->{
  3.592048429597211*^9, {3.5921117118976593`*^9, 3.5921117176696696`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fd2", "[", 
        RowBox[{"1", ",", "2"}], "]"}], "[", "rsf", "]"}], "[", 
      RowBox[{"s", ",", " ", "t"}], "]"}], ",", 
     RowBox[{"TimeConstraint", "\[Rule]", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591773629631014*^9, 3.591773714170849*^9}, {
   3.5917737484678106`*^9, 3.5917737560822463`*^9}, {3.591773808723257*^9, 
   3.591773814242573*^9}, {3.591775768244335*^9, 3.5917757816751037`*^9}, {
   3.5917786327132173`*^9, 3.591778658722705*^9}, {3.591788739317565*^9, 
   3.591788759352711*^9}, 3.5917889229130664`*^9, 3.5917890378886423`*^9, {
   3.59178994401447*^9, 3.5917900186787405`*^9}, 3.5917933838012147`*^9, {
   3.591793669191538*^9, 3.5917937009843564`*^9}, {3.5917951837611666`*^9, 
   3.5917952037283087`*^9}, {3.591795236712195*^9, 3.591795257680394*^9}, {
   3.5917967300736103`*^9, 3.59179673880011*^9}, 3.5919455581142216`*^9, 
   3.591945593588684*^9, {3.5919476014838104`*^9, 3.5919476613255157`*^9}, {
   3.5919499489159336`*^9, 3.59195003789849*^9}, {3.59195236660818*^9, 
   3.5919524075738525`*^9}, {3.591972358191518*^9, 3.591972401185193*^9}, {
   3.5919725408522387`*^9, 3.5919725457818475`*^9}, 3.592023669799759*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["x", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}]}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}]}], 
      ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], "-", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}]}], 
      ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], "-", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}]}], 
      ")"}], " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["y", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], ")"}],
   "/", 
  RowBox[{"(", 
   RowBox[{"\[Sqrt]", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{
       SuperscriptBox["s", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
          "2"]}], ")"}]}], "-", 
      RowBox[{"2", " ", "s", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.5919724148352175`*^9, 3.591972593517931*^9, 
  3.5919728163643227`*^9, 3.592048455787709*^9, 3.592111656517562*^9, 
  3.611651944741068*^9, 3.6154507563394613`*^9, 3.6185561649278393`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fa", "[", 
    RowBox[{"1", ",", " ", "2"}], "]"}], "[", 
   RowBox[{"s_", ",", " ", "t_"}], "]"}], " ", ":=", " ", "\n", "  ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", "t", 
        "]"}], "[", "3", "]"}], "*", "\n", "     ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}]}], ")"}], "*", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
           "]"}], "[", "\n", "        ", "1", "]"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], "*", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "\n",
            "         ", "t", "]"}], "[", "2", "]"}]}]}], ")"}]}], " ", "+", 
     " ", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "*", "\n", "     ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "2", "]"}], "*", "\n", "       ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
           "]"}], "[", "1", "]"}]}], " ", "-", " ", "\n", "      ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "1", "]"}], "*", "\n", "       ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
           "]"}], "[", "2", "]"}]}]}], ")"}]}], " ", "+", " ", "\n", "    ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "*", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "1", "]"}]}], " ", "-", " ", "\n", "      ", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], "*", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "2", "]"}]}]}], ")"}], "*", "\n", "     ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
        "]"}], "[", "3", "]"}]}]}], ")"}], "/", "\n", "   ", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"1", " ", "+", " ", 
     RowBox[{
      RowBox[{"s", "^", "2"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
           "]"}], "[", "\n", "         ", "1", "]"}], "^", "2"}], " ", "+", 
        " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
           "]"}], "[", "\n", "         ", "2", "]"}], "^", "2"}], " ", "+", 
        " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
           "]"}], "[", "\n", "         ", "3", "]"}], "^", "2"}]}], ")"}]}], 
     " ", "-", " ", "\n", "     ", 
     RowBox[{"2", "*", "s", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], "*", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "\n", "         ", "1", "]"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "*", "\n", 
         "        ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "2", "]"}]}], " ", "+", " ", "\n", "       ", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "*", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "\n", "         ", "3", "]"}]}]}], ")"}]}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6185565731181564`*^9, 3.618556640307474*^9}, {
  3.618556692723566*^9, 3.61855670039878*^9}, {3.618556736512843*^9, 
  3.618556750131667*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fa", "[", 
    RowBox[{"2", ",", "1"}], "]"}], "[", 
   RowBox[{"s_", ",", "t_"}], "]"}], " ", ":=", 
  RowBox[{
   RowBox[{"fa", "[", 
    RowBox[{"1", ",", "2"}], "]"}], "[", 
   RowBox[{"s", ",", " ", "t"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5919524988028126`*^9, 3.5919525572249155`*^9}, {
   3.5919526620726995`*^9, 3.591952664225503*^9}, {3.591973412129369*^9, 
   3.5919734181665792`*^9}, 3.592023671406562*^9, {3.592111790209797*^9, 
   3.5921117943438044`*^9}, 3.6185562000123014`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fd2", "[", 
        RowBox[{"2", ",", "2"}], "]"}], "[", "rsf", "]"}], "[", 
      RowBox[{"s", ",", " ", "t"}], "]"}], ",", 
     RowBox[{"TimeConstraint", "\[Rule]", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591773629631014*^9, 3.591773714170849*^9}, {
   3.5917737484678106`*^9, 3.5917737560822463`*^9}, {3.591773808723257*^9, 
   3.591773814242573*^9}, {3.591775768244335*^9, 3.5917757816751037`*^9}, {
   3.5917786327132173`*^9, 3.591778658722705*^9}, {3.591788739317565*^9, 
   3.591788759352711*^9}, 3.5917889229130664`*^9, 3.5917890378886423`*^9, {
   3.59178994401447*^9, 3.5917900186787405`*^9}, 3.5917933838012147`*^9, {
   3.591793669191538*^9, 3.5917937009843564`*^9}, {3.5917951837611666`*^9, 
   3.5917952037283087`*^9}, {3.591795236712195*^9, 3.591795257680394*^9}, {
   3.5917967300736103`*^9, 3.59179673880011*^9}, 3.5919455581142216`*^9, 
   3.591945593588684*^9, {3.5919476014838104`*^9, 3.5919476613255157`*^9}, {
   3.5919499489159336`*^9, 3.59195003789849*^9}, {3.59195236660818*^9, 
   3.5919524075738525`*^9}, {3.5919527647832794`*^9, 
   3.5919527686988864`*^9}, {3.5919532628765545`*^9, 3.591953272751372*^9}, {
   3.591973168425741*^9, 3.591973191108181*^9}, {3.591973224133439*^9, 
   3.5919732446630745`*^9}, 3.592023674042967*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "+", 
          RowBox[{"s", " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"s", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
           " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
             "+", 
             RowBox[{"s", " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "[", "1", 
               "]"}]}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
             "+", 
             RowBox[{"s", " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "[", "1", 
               "]"}]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}]}], 
         ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], "-", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "+", 
          RowBox[{"s", " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"s", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], 
          "-", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
             "+", 
             RowBox[{"s", " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "[", "1", 
               "]"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
             "+", 
             RowBox[{"s", " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "[", "1", 
               "]"}]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
         ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "+", 
          RowBox[{"s", " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"s", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
           " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
             "+", 
             RowBox[{"s", " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "[", "2", 
               "]"}]}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
             "+", 
             RowBox[{"s", " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "[", "2", 
               "]"}]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
         ")"}]}]}], ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"\[Sqrt]", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{
       SuperscriptBox["s", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
          "2"]}], ")"}]}], "-", 
      RowBox[{"2", " ", "s", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.5919532794593835`*^9, {3.5919732273314447`*^9, 3.5919732458486767`*^9}, 
   3.592048578449725*^9, 3.592111929642842*^9, 3.6116520052847743`*^9, 
   3.6154508213135757`*^9, 3.618556258684004*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fa", "[", 
    RowBox[{"2", ",", " ", "2"}], "]"}], "[", 
   RowBox[{"s_", ",", " ", "t_"}], "]"}], " ", ":=", " ", "\n", "  ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", 
             "t", "]"}], "[", "1", "]"}]}], ")"}], "*", "\n", "       ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "2", "]"}]}], " ", "+", " ", "\n", "      ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "2", "]"}], "*", "\n", "       ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
             "t", "]"}], "[", "1", "]"}], " ", "+", " ", "\n", "        ", 
           RowBox[{"s", "*", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "1", "]"}]}]}], ")"}]}], " ", "+", " ", "\n", 
        "      ", 
        RowBox[{"s", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"-", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
                "t", "]"}], "[", "1", "]"}]}], ")"}], "*", "\n", "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
              "t", "]"}], "[", "2", "]"}]}], " ", "+", " ", "\n", "        ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "2", "]"}], "*", "\n", "         ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
                "t", "]"}], "[", "1", "]"}], " ", "+", " ", "\n", 
              "          ", 
              RowBox[{"s", "*", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"Derivative", "[", "2", "]"}], "[", "y", "]"}], "[",
                  "t", "]"}], "[", "1", "]"}]}]}], ")"}]}], " ", "-", " ", 
           "\n", "        ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", 
                "t", "]"}], "[", "1", "]"}], " ", "+", " ", "\n", 
              "          ", 
              RowBox[{"s", "*", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[",
                  "t", "]"}], "[", "1", "]"}]}]}], ")"}], "*", "\n", 
            "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "2", "]"}]}]}], ")"}]}]}], ")"}]}], " ", "+", 
     " ", "\n", "    ", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "1", "]"}], "*", "\n", "       ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "3", "]"}]}], " ", "-", " ", "\n", "      ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "3", "]"}], "*", "\n", "       ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
             "t", "]"}], "[", "1", "]"}], " ", "+", " ", "\n", "        ", 
           RowBox[{"s", "*", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "1", "]"}]}]}], ")"}]}], " ", "+", " ", "\n", 
        "      ", 
        RowBox[{"s", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "1", "]"}], "*", "\n", "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
              "t", "]"}], "[", "3", "]"}]}], " ", "-", " ", "\n", "        ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "3", "]"}], "*", "\n", "         ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
                "t", "]"}], "[", "1", "]"}], " ", "+", " ", "\n", 
              "          ", 
              RowBox[{"s", "*", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"Derivative", "[", "2", "]"}], "[", "y", "]"}], "[",
                  "t", "]"}], "[", "1", "]"}]}]}], ")"}]}], " ", "+", " ", 
           "\n", "        ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", 
                "t", "]"}], "[", "1", "]"}], " ", "+", " ", "\n", 
              "          ", 
              RowBox[{"s", "*", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[",
                  "t", "]"}], "[", "1", "]"}]}]}], ")"}], "*", "\n", 
            "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "3", "]"}]}]}], ")"}]}]}], ")"}]}], " ", "+", 
     " ", "\n", "    ", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", 
             "t", "]"}], "[", "\n", "         ", "2", "]"}]}], ")"}], "*", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "3", "]"}]}], " ", "+", " ", "\n", "      ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "3", "]"}], "*", "\n", "       ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
             "t", "]"}], "[", "2", "]"}], " ", "+", " ", "\n", "        ", 
           RowBox[{"s", "*", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "2", "]"}]}]}], ")"}]}], " ", "+", " ", "\n", 
        "      ", 
        RowBox[{"s", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"-", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
                "t", "]"}], "[", "2", "]"}]}], ")"}], "*", "\n", "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
              "t", "]"}], "[", "3", "]"}]}], " ", "+", " ", "\n", "        ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "3", "]"}], "*", "\n", "         ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", 
                "t", "]"}], "[", "2", "]"}], " ", "+", " ", "\n", 
              "          ", 
              RowBox[{"s", "*", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"Derivative", "[", "2", "]"}], "[", "y", "]"}], "[",
                  "t", "]"}], "[", "2", "]"}]}]}], ")"}]}], " ", "-", " ", 
           "\n", "        ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", 
                "t", "]"}], "[", "2", "]"}], " ", "+", " ", "\n", 
              "          ", 
              RowBox[{"s", "*", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[",
                  "t", "]"}], "[", "2", "]"}]}]}], ")"}], "*", "\n", 
            "         ", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "2", "]"}], "[", "y", "]"}], "[", 
              "t", "]"}], "[", "3", "]"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], 
   "/", "\n", "   ", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"1", " ", "+", " ", 
     RowBox[{
      RowBox[{"s", "^", "2"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
           "]"}], "[", "\n", "         ", "1", "]"}], "^", "2"}], " ", "+", 
        " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
           "]"}], "[", "\n", "         ", "2", "]"}], "^", "2"}], " ", "+", 
        " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
           "]"}], "[", "\n", "         ", "3", "]"}], "^", "2"}]}], ")"}]}], 
     " ", "-", " ", "\n", "     ", 
     RowBox[{"2", "*", "s", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], "*", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "\n", "         ", "1", "]"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "*", "\n", 
         "        ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "2", "]"}]}], " ", "+", " ", "\n", "       ", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "*", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "\n", "         ", "3", "]"}]}]}], ")"}]}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5919732754107285`*^9, 3.5919733017747755`*^9}, {
   3.5920485906614237`*^9, 3.5920486099175253`*^9}, 3.592048655164113*^9, {
   3.5921118349662757`*^9, 3.5921118422982883`*^9}, {3.61486185979994*^9, 
   3.6148618599871407`*^9}, {3.6149177915773606`*^9, 3.6149177917645607`*^9}}],

Cell["\<\
The determinant Det[fa[i,j][s,t]] of the second fundamental form is\
\>", "Text",
 CellChangeTimes->{{3.5921133369837136`*^9, 3.5921133636441603`*^9}, {
  3.611652241578389*^9, 3.6116522849620657`*^9}, {3.6116523173789225`*^9, 
  3.6116523304049454`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"Det", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fa", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", 
         RowBox[{"s", ",", " ", "t"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"TimeConstraint", "\[Rule]", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591953703343328*^9, 3.591953781561866*^9}, 
   3.592023675415769*^9, 3.6148618600027404`*^9, 3.614863501858824*^9}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "2"], 
      "+", 
      SuperscriptBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "2"], 
      "+", 
      SuperscriptBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], "2"], 
      "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "2"]}],
       "-", 
      RowBox[{"2", " ", 
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
        ")"}], "2"]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{
       SuperscriptBox["s", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
          "2"]}], ")"}]}], "-", 
      RowBox[{"2", " ", "s", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.5919538234791393`*^9, 3.5919737119462957`*^9, 
  3.592048738455877*^9, 3.5921120534914594`*^9, 3.5921121227399807`*^9, 
  3.6116524597447724`*^9, 3.618556359725382*^9, 3.6185568713282804`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"detfa", "[", 
   RowBox[{"s_", ",", " ", "t_"}], "]"}], " ", ":=", " ", "\n", "  ", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
         "]"}], "[", "1", "]"}], "^", "2"}], " ", "+", " ", "\n", "     ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
         "]"}], "[", "2", "]"}], "^", "2"}], " ", "+", " ", "\n", "     ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
         "]"}], "[", "3", "]"}], "^", "2"}], " ", "+", " ", "\n", "     ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], " ", "+", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "^", "2"}], " ", 
         "+", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "^", "2"}]}], ")"}],
        "*", "\n", "      ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t", 
          "]"}], "[", "1", "]"}], "^", "2"}]}], " ", "-", " ", "\n", "     ", 
      RowBox[{"2", "*", 
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], "*", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t", 
         "]"}], "[", "1", "]"}], "*", "\n", "      ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "*", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t",
             "]"}], "[", "\n", "         ", "2", "]"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "*", "\n", 
          "        ", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t",
             "]"}], "[", "3", "]"}]}]}], ")"}]}], " ", "-", " ", "\n", 
      "     ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "*", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t",
             "]"}], "[", "\n", "         ", "2", "]"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "*", "\n", 
          "        ", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t",
             "]"}], "[", "3", "]"}]}]}], ")"}], "^", "2"}]}], ")"}]}], "/", 
   "\n", "   ", 
   RowBox[{"(", 
    RowBox[{"1", " ", "+", " ", 
     RowBox[{
      RowBox[{"s", "^", "2"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
           "]"}], "[", "1", "]"}], "^", "\n", "       ", "2"}], " ", "+", " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
           "]"}], "[", "2", "]"}], "^", "2"}], " ", "+", " ", "\n", "      ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "t", 
           "]"}], "[", "3", "]"}], "^", "2"}]}], ")"}]}], " ", "-", " ", "\n",
      "    ", 
     RowBox[{"2", "*", "s", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], "*", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "\n", "        ", "1", "]"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "*", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "\n",
            "         ", "t", "]"}], "[", "2", "]"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "*", "\n", "       ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "2", "]"}], "[", "x", "]"}], "[", "t", 
           "]"}], "[", "3", "]"}]}]}], ")"}]}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.591954021537087*^9, 3.591954073875179*^9}, {
  3.5920489980117226`*^9, 3.592049027986437*^9}, {3.59211216177125*^9, 
  3.592112191146101*^9}, {3.6148618600027404`*^9, 3.6148618600651407`*^9}, {
  3.614917791780161*^9, 3.6149177918425612`*^9}}],

Cell["The quotient of the determinants is", "Text",
 CellChangeTimes->{{3.592113393424613*^9, 3.5921134297102766`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"detfa", "[", 
       RowBox[{"s", ",", "t"}], "]"}], "/", 
      RowBox[{"Det", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"rgT", "[", 
            RowBox[{"i", ",", "j"}], "]"}], "[", "rsf", "]"}], "[", 
          RowBox[{"s", ",", "t"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}]}], ",", 
     RowBox[{"TimeConstraint", "\[Rule]", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5919676261801605`*^9, 3.591967669766637*^9}, {
   3.591967706021101*^9, 3.5919677109039097`*^9}, {3.591967770386814*^9, 
   3.5919678540029607`*^9}, {3.5920491350405607`*^9, 
   3.5920492534233313`*^9}, {3.592049573543641*^9, 3.5920496692571154`*^9}, {
   3.592049704033105*^9, 3.5920497102974634`*^9}, 3.592050945314102*^9, {
   3.5920511461695905`*^9, 3.592051226626192*^9}, 3.592055181657555*^9, 
   3.6148618600807405`*^9, 3.614863501874424*^9, 3.6176282733734493`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "2"], 
      "+", 
      SuperscriptBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "2"], 
      "+", 
      SuperscriptBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], "2"], 
      "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "2"]}],
       "-", 
      RowBox[{"2", " ", 
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
        ")"}], "2"]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{
       SuperscriptBox["s", "4"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
           "2"], "+", 
          SuperscriptBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
           "2"], "+", 
          SuperscriptBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
           "2"]}], ")"}], "2"]}], "-", 
      RowBox[{"4", " ", "s", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["s", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
             " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
            "+", 
            RowBox[{
             RowBox[{
              RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
             " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], 
            "-", 
            RowBox[{
             RowBox[{
              RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}],
                 "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}],
                 "2"]}], ")"}]}]}], ")"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
         "-", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
             "2"], "+", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
             "2"], "+", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
             "2"]}], ")"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
         "-", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
             "2"], "+", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
             "2"], "+", 
            SuperscriptBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
             "2"]}], ")"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["s", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], "2"],
          "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "2"], "+", 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "2"]}], 
               ")"}]}], " ", 
             SuperscriptBox[
              RowBox[{
               RowBox[{
                SuperscriptBox["x", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
              "2"]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{
              RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
             " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "[", "2", 
                 "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "[", "3", 
                 "]"}]}]}], ")"}]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "[", "2", 
                 "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["x", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "[", "3", 
                 "]"}]}]}], ")"}], "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.592055244071125*^9, 3.59211242960812*^9, 
  3.611653195192464*^9, 3.6185578195915456`*^9}]
}, Closed]],

Cell["Comparing with the expression Krsf[s,t] defined above gives", "Text",
 CellChangeTimes->{{3.5921134527515173`*^9, 3.5921135289264507`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"%", "-", 
      RowBox[{"Krsf", "[", 
       RowBox[{"s", ",", "t"}], "]"}]}], ",", 
     RowBox[{"TimeConstraint", "\[Rule]", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5919676261801605`*^9, 3.591967669766637*^9}, {
   3.591967706021101*^9, 3.5919677109039097`*^9}, {3.591967770386814*^9, 
   3.5919678540029607`*^9}, {3.5920491350405607`*^9, 
   3.5920492534233313`*^9}, {3.592049573543641*^9, 3.5920496692571154`*^9}, {
   3.592049704033105*^9, 3.5920497102974634`*^9}, 3.592050945314102*^9, {
   3.5920511461695905`*^9, 3.592051226626192*^9}, 3.592055181657555*^9, 
   3.592055268737536*^9, {3.5920553221935935`*^9, 3.592055377169738*^9}, 
   3.592058731034568*^9, {3.592112568931965*^9, 3.592112574875575*^9}, 
   3.5921126374472847`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.59205697537615*^9, 3.5920589934185753`*^9, 
  3.592112549697131*^9, 3.59211261755725*^9, 3.6116536590748787`*^9, 
  3.6185603356097713`*^9}]
}, Closed]],

Cell["OK. We yet calculate the mean curvature", "Text",
 CellChangeTimes->{{3.5921135377560663`*^9, 3.592113576865335*^9}, {
  3.6185605679688683`*^9, 3.6185605756163054`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"meancurvature", "[", "rsf", "]"}], "[", 
      RowBox[{"s", ",", "t"}], "]"}], ",", 
     RowBox[{"TimeConstraint", "\[Rule]", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5919676261801605`*^9, 3.591967669766637*^9}, {
   3.591967706021101*^9, 3.5919677109039097`*^9}, {3.591967770386814*^9, 
   3.5919678540029607`*^9}, {3.5920491350405607`*^9, 
   3.5920492534233313`*^9}, {3.592049573543641*^9, 3.5920496692571154`*^9}, {
   3.592049704033105*^9, 3.5920497102974634`*^9}, 3.592050945314102*^9, {
   3.5920511461695905`*^9, 3.592051226626192*^9}, 3.592055181657555*^9, 
   3.592055268737536*^9, {3.5920553221935935`*^9, 3.592055377169738*^9}, 
   3.592058731034568*^9, {3.592112568931965*^9, 3.592112574875575*^9}, 
   3.5921126374472847`*^9, {3.592113589844558*^9, 3.592113639499445*^9}, 
   3.61486186009634*^9, 3.614863136599783*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "+", 
          RowBox[{"s", " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"s", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
           " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
             "+", 
             RowBox[{"s", " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "[", "1", 
               "]"}]}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
             "+", 
             RowBox[{"s", " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "[", "1", 
               "]"}]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}]}], 
         ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], "-", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "+", 
          RowBox[{"s", " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"s", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], 
          "-", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
             "+", 
             RowBox[{"s", " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "[", "1", 
               "]"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
             "+", 
             RowBox[{"s", " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "[", "1", 
               "]"}]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
         ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "+", 
          RowBox[{"s", " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"s", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
           " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
             "+", 
             RowBox[{"s", " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "[", "2", 
               "]"}]}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
             "+", 
             RowBox[{"s", " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "[", "2", 
               "]"}]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
         ")"}]}]}], ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{
        SuperscriptBox["s", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
           "2"], "+", 
          SuperscriptBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
           "2"], "+", 
          SuperscriptBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
           "2"]}], ")"}]}], "-", 
       RowBox[{"2", " ", "s", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
         ")"}]}]}], ")"}], 
     RowBox[{"3", "/", "2"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.5921138303657804`*^9, 3.5921145158465843`*^9, 
  3.6116650690285196`*^9, 3.618560781626089*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"rsfc", "[", 
          RowBox[{"1", ",", "1"}], "]"}], "[", 
         RowBox[{"s", ",", "t"}], "]"}], "+", 
        RowBox[{
         RowBox[{"rsfc", "[", 
          RowBox[{"2", ",", "2"}], "]"}], "[", 
         RowBox[{"s", ",", "t"}], "]"}]}], ")"}], "/", "2"}], ",", 
     RowBox[{"TimeConstraint", "\[Rule]", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5919676261801605`*^9, 3.591967669766637*^9}, {
   3.591967706021101*^9, 3.5919677109039097`*^9}, {3.591967770386814*^9, 
   3.5919678540029607`*^9}, {3.5920491350405607`*^9, 
   3.5920492534233313`*^9}, {3.592049573543641*^9, 3.5920496692571154`*^9}, {
   3.592049704033105*^9, 3.5920497102974634`*^9}, 3.592050945314102*^9, {
   3.5920511461695905`*^9, 3.592051226626192*^9}, 3.592055181657555*^9, 
   3.592055268737536*^9, {3.5920553221935935`*^9, 3.592055377169738*^9}, 
   3.592058731034568*^9, {3.592112568931965*^9, 3.592112574875575*^9}, 
   3.5921126374472847`*^9, {3.592113589844558*^9, 3.592113639499445*^9}, {
   3.5921139773804383`*^9, 3.592114013931303*^9}, {3.5921140833046246`*^9, 
   3.592114101431856*^9}, 3.5921143285994554`*^9, {3.5921143809843473`*^9, 
   3.592114405835191*^9}, 3.6116650552848954`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "+", 
          RowBox[{"s", " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"s", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
           " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
             "+", 
             RowBox[{"s", " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "[", "1", 
               "]"}]}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
             "+", 
             RowBox[{"s", " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "[", "1", 
               "]"}]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}]}], 
         ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], "-", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "+", 
          RowBox[{"s", " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"s", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], 
          "-", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
             "+", 
             RowBox[{"s", " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "[", "1", 
               "]"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
             "+", 
             RowBox[{"s", " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "[", "1", 
               "]"}]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
         ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "+", 
          RowBox[{"s", " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"s", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
           " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
             "+", 
             RowBox[{"s", " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "[", "2", 
               "]"}]}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
             "+", 
             RowBox[{"s", " ", 
              RowBox[{
               RowBox[{
                SuperscriptBox["y", "\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "[", "2", 
               "]"}]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
         ")"}]}]}], ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{
        SuperscriptBox["s", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
           "2"], "+", 
          SuperscriptBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
           "2"], "+", 
          SuperscriptBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
           "2"]}], ")"}]}], "-", 
       RowBox[{"2", " ", "s", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
         ")"}]}]}], ")"}], 
     RowBox[{"3", "/", "2"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.5921141811947966`*^9, 3.5921143450730844`*^9, 
  3.5921145313062115`*^9, 3.611665577183812*^9, 3.6185612366131124`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"%", "-", "%%"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6185612597444353`*^9, 3.6185613193158426`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6185613235560856`*^9}]
}, Closed]],

Cell["OK.", "Text",
 CellChangeTimes->{{3.592114541290229*^9, 3.592114545346236*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["3.7. The Normal Congruences", "Subsection",
 CellChangeTimes->{{3.591688363105586*^9, 3.5916883848832245`*^9}, 
   3.5917714021446085`*^9, 3.5985964668405457`*^9, 3.615451802305699*^9, 
   3.615559274768277*^9}],

Cell[CellGroupData[{

Cell["3.7.1. Normal Surfaces of a Surface", "Subsubsection",
 CellChangeTimes->{{3.5922181089604635`*^9, 3.5922181546640778`*^9}, {
   3.5988619755006013`*^9, 3.598861982021413*^9}, 3.6185622090977354`*^9, 
   3.6185639613379583`*^9}],

Cell[TextData[{
 "The normals of a surface form a 2-parameter family of lines, named the ",
 StyleBox["normal congruence of the surface",
  FontColor->RGBColor[0, 0, 1]],
 ":"
}], "Text",
 CellChangeTimes->{{3.5922049711314583`*^9, 3.592205009202636*^9}, {
   3.592205189986976*^9, 3.592205219635672*^9}, {3.592205300843317*^9, 
   3.5922053260107565`*^9}, 3.5922053597396855`*^9, 3.592217768303979*^9, {
   3.598596409822446*^9, 3.598596446888111*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"normals", "[", 
    RowBox[{"ff_", ",", " ", "u_", ",", "v_"}], "]"}], "[", "s_", "]"}], " ", 
  ":=", " ", 
  RowBox[{
   RowBox[{"ff", "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "+", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "3", "]"}], "[", "ff", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "*", "s"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.592205394333664*^9, 3.5922054044162407`*^9}, {
   3.592205454349097*^9, 3.59220549234127*^9}, 3.5922055233200417`*^9, 
   3.5922056857913346`*^9, 3.61486186009634*^9, 3.614917791858161*^9, 
   3.615531673064457*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"normals", "::", "usage"}], " ", "=", " ", 
   "\"\<normals[f,u,v][s] is the normal congruence of the surface f[u,v]; s \
the line parameter.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.615531879804282*^9, 3.6155319923537197`*^9}, {
  3.615532027924754*^9, 3.615532036194227*^9}}],

Cell["\<\
Consider a curve on the surface sf[u, v], given in the parameter  \
neighborhood by \
\>", "Text",
 CellChangeTimes->{{3.5922057532761946`*^9, 3.592205856435095*^9}, {
  3.598595786398551*^9, 3.5985957881769543`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Gamma]", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"hu", "[", "t", "]"}], ",", 
    RowBox[{"hv", "[", "t", "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5922059133623505`*^9, 3.592205943501075*^9}, 
   3.6185624445392017`*^9}],

Cell["\<\
Then the normals along the curve form a ruled surface with directrix\
\>", "Text",
 CellChangeTimes->{{3.592206047180005*^9, 3.592206078795813*^9}, {
  3.5922061699950294`*^9, 3.592206174531289*^9}, {3.5985957986133723`*^9, 
  3.5985957997521744`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xx", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"sf", "[", 
   RowBox[{
    RowBox[{"hu", "[", "t", "]"}], ",", 
    RowBox[{"hv", "[", "t", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5922060867402678`*^9, 3.5922061155499153`*^9}}],

Cell["The normal vectors of the surface along the curve are", "Text",
 CellChangeTimes->{{3.5922062089312563`*^9, 3.5922062280593505`*^9}, {
   3.611665413773525*^9, 3.6116654420563745`*^9}, 3.6146693565981827`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"yy", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{
    RowBox[{"hu", "[", "t", "]"}], ",", 
    RowBox[{"hv", "[", "t", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5922062360348067`*^9, 3.5922063003584857`*^9}, 
   3.6148618601119404`*^9, 3.614917791873761*^9, 3.615531676222638*^9}],

Cell["\<\
The parameter representation of the ruled surface generated by the normals of \
the surface along the curve is\
\>", "Text",
 CellChangeTimes->{{3.611665474582432*^9, 3.611665527762925*^9}, 
   3.618562101492581*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsf", "[", 
   RowBox[{"s_", ",", "t_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"xx", "[", "t", "]"}], " ", "+", "  ", 
   RowBox[{"s", "*", 
    RowBox[{"yy", "[", "t", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.5922063337603965`*^9, 3.592206366014241*^9}}],

Cell[TextData[{
 "Such a surface is named a ",
 StyleBox["normal surface.",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.5922180596636443`*^9, 3.592218076359599*^9}, {
   3.6116655888370323`*^9, 3.6116656122682734`*^9}, 3.6146694043429136`*^9, 
   3.618562954160351*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rsf", "[", 
  RowBox[{"s", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.5922064062155404`*^9, 3.5922064138929796`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "1", "]"}], "[", 
     RowBox[{
      RowBox[{"hu", "[", "t", "]"}], ",", 
      RowBox[{"hv", "[", "t", "]"}]}], "]"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"s", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "t", "]"}], ",", 
            RowBox[{"hv", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "t", "]"}], ",", 
            RowBox[{"hv", "[", "t", "]"}]}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "t", "]"}], ",", 
            RowBox[{"hv", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "t", "]"}], ",", 
            RowBox[{"hv", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}]}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{
                RowBox[{"hu", "[", "t", "]"}], ",", 
                RowBox[{"hv", "[", "t", "]"}]}], "]"}]}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}]}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}]}]}], ")"}], "2"]}], 
        ")"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "2", "]"}], "[", 
     RowBox[{
      RowBox[{"hu", "[", "t", "]"}], ",", 
      RowBox[{"hv", "[", "t", "]"}]}], "]"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"s", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "t", "]"}], ",", 
             RowBox[{"hv", "[", "t", "]"}]}], "]"}]}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "t", "]"}], ",", 
            RowBox[{"hv", "[", "t", "]"}]}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "t", "]"}], ",", 
            RowBox[{"hv", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "t", "]"}], ",", 
            RowBox[{"hv", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}]}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{
                RowBox[{"hu", "[", "t", "]"}], ",", 
                RowBox[{"hv", "[", "t", "]"}]}], "]"}]}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}]}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}]}]}], ")"}], "2"]}], 
        ")"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "3", "]"}], "[", 
     RowBox[{
      RowBox[{"hu", "[", "t", "]"}], ",", 
      RowBox[{"hv", "[", "t", "]"}]}], "]"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"s", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "t", "]"}], ",", 
            RowBox[{"hv", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "t", "]"}], ",", 
            RowBox[{"hv", "[", "t", "]"}]}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "t", "]"}], ",", 
            RowBox[{"hv", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "t", "]"}], ",", 
            RowBox[{"hv", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}]}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{
                RowBox[{"hu", "[", "t", "]"}], ",", 
                RowBox[{"hv", "[", "t", "]"}]}], "]"}]}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}]}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "t", "]"}], ",", 
               RowBox[{"hv", "[", "t", "]"}]}], "]"}]}]}], ")"}], "2"]}], 
        ")"}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5922064164231243`*^9, 3.6116656236250935`*^9, 
  3.611665747551711*^9, 3.615532181860244*^9, 3.6185629606417217`*^9}]
}, Closed]],

Cell[TextData[{
 "We will answer the question: \n",
 StyleBox["Which curves on the surface generate developable normal surfaces?",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 "\nTo this aim we have to consider the Gaussian curvature gauss[rsf][s,t] \
and find those curves for which this Gaussian curvature equals zero. The \
direct calculation of gauss[rsf][s,t]  symbolically in this generality is \
hopeless: "
}], "Text",
 CellChangeTimes->{{3.5922067006993837`*^9, 3.5922067612428465`*^9}, {
   3.59220679293966*^9, 3.592206827362629*^9}, {3.5922068605635276`*^9, 
   3.5922071163711596`*^9}, 3.5922074624679546`*^9, {3.5922178556159735`*^9, 
   3.592217870047799*^9}, {3.5922179504163957`*^9, 3.592217957559804*^9}, 
   3.6116657781901655`*^9, 3.615532199768268*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Krsf", ",", 
   RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.592206528380528*^9, 3.592206541620285*^9}, {
  3.61553224945711*^9, 3.615532286417224*^9}, {3.618563047210673*^9, 
  3.6185630693639402`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Simplify", "::", "time"}], "MessageName"], ":", 
  " ", "\<\"Time spent on a transformation exceeded \[NoBreak]\\!\\(300.`\\)\
\[NoBreak] seconds, and the transformation was aborted. Increasing the value \
of TimeConstraint option may improve the result of simplification. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Simplify/time\\\", \
ButtonNote -> \\\"Simplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6155325932987766`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Simplify", "::", "time"}], "MessageName"], ":", 
  " ", "\<\"Time spent on a transformation exceeded \[NoBreak]\\!\\(300.`\\)\
\[NoBreak] seconds, and the transformation was aborted. Increasing the value \
of TimeConstraint option may improve the result of simplification. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Simplify/time\\\", \
ButtonNote -> \\\"Simplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.615533195882242*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Simplify", "::", "time"}], "MessageName"], ":", 
  " ", "\<\"Time spent on a transformation exceeded \[NoBreak]\\!\\(300.`\\)\
\[NoBreak] seconds, and the transformation was aborted. Increasing the value \
of TimeConstraint option may improve the result of simplification. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Simplify/time\\\", \
ButtonNote -> \\\"Simplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6155334983434873`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], ":", 
  " ", "\<\"Further output of \[NoBreak]\\!\\(\\*StyleBox[\\(Simplify :: time\
\\), \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.615533498374687*^9}],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.5922071524312215`*^9, 3.615537559541273*^9}]
}, Closed]],

Cell["\<\
Therefore we will apply Criterion 3.6.1 proved in the last section. The \
condition of developability we will consider is\
\>", "Text",
 CellChangeTimes->{{3.5922072468236203`*^9, 3.5922073230269794`*^9}, {
  3.5922074788518915`*^9, 3.5922075577394037`*^9}, {3.592218413391876*^9, 
  3.592218423719467*^9}}],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{"(*", 
   RowBox[{
    RowBox[{")", "                      ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["yy", "\[Prime]",
        MultilineFunction->None], "(", "t", ")"}], ".", 
      RowBox[{
       SuperscriptBox["yy", "\[Prime]",
        MultilineFunction->None], "(", "t", ")"}]}]}], "\[LongEqual]", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["yy", "\[Prime]",
          MultilineFunction->None], "(", "t", ")"}], ".", 
        RowBox[{
         SuperscriptBox["xx", "\[Prime]",
          MultilineFunction->None], "(", "t", ")"}]}], ")"}], "2"], "."}]}]}],
   TraditionalForm]],
 Evaluatable->False,
 CellChangeTimes->{{3.5919703342231636`*^9, 3.591970334456177*^9}, 
   3.5919703812638545`*^9, 3.592047182216324*^9, {3.592047410741125*^9, 
   3.5920474186035385`*^9}, {3.6116464842946773`*^9, 
   3.611646496306698*^9}}]], "Text",
 CellChangeTimes->{{3.6154435063429728`*^9, 3.615443534313822*^9}, {
  3.615443574858293*^9, 3.6154436171811676`*^9}, {3.6154436514544277`*^9, 
  3.6154436537008314`*^9}, {3.6154437181133447`*^9, 3.6154437181133447`*^9}, {
  3.615443791183873*^9, 3.615443791183873*^9}, {3.6155330280896454`*^9, 
  3.6155330478407745`*^9}}],

Cell["\<\
We consider a fixed value t and assume that the frame of sf[\[Gamma][t]] at \
this point has principal directions, such that\
\>", "Text",
 CellChangeTimes->{{3.5922081614029317`*^9, 3.592208197498996*^9}, {
   3.592208436427662*^9, 3.592208587483302*^9}, {3.615532908975832*^9, 
   3.6155329097028737`*^9}, 3.618562485131524*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cf", "[", 
    RowBox[{"1", ",", "1"}], "]"}], " ", "=", " ", "k1"}], ";", " ", 
  RowBox[{
   RowBox[{"cf", "[", 
    RowBox[{"1", ",", "2"}], "]"}], " ", "=", " ", "0"}], ";", " ", 
  RowBox[{
   RowBox[{"cf", "[", 
    RowBox[{"2", ",", "2"}], "]"}], " ", "=", " ", "k2"}], ";"}]], "Input",
 CellChangeTimes->{{3.592208596248803*^9, 3.5922086683489275`*^9}, {
  3.6179721880391293`*^9, 3.6179721906402783`*^9}}],

Cell["\<\
are given by the principal curvatures of sf at this point. For the tangent \
vector of the curve xx[t] at this point we have\
\>", "Text",
 CellChangeTimes->{{3.5922086876910334`*^9, 3.5922087121154304`*^9}, {
  3.5922087602831855`*^9, 3.592208787339733*^9}, {3.6155329249997487`*^9, 
  3.6155329518872867`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["xx", "\[Prime]",
     MultilineFunction->None], "(", "t", ")"}], "\[LongEqual]", " ", 
   RowBox[{
    RowBox[{"x", " ", 
     RowBox[{
      RowBox[{"amf", "(", "1", ")"}], "\[InvisibleApplication]", 
      RowBox[{"(", "sf", ")"}]}]}], "+", 
    RowBox[{"y", " ", 
     RowBox[{
      RowBox[{"amf", "(", "2", ")"}], "\[InvisibleApplication]", 
      RowBox[{"(", "sf", ")"}]}], "  ", "with", "  ", 
     SuperscriptBox["x", "2"]}], " ", "+", " ", 
    SuperscriptBox["y", "2"]}], "\[LongEqual]", "1"}], 
  TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5922087972623005`*^9, 3.5922088957339325`*^9}, {
   3.5922089455897846`*^9, 3.5922090179659243`*^9}, {3.6155329861842484`*^9, 
   3.615532999689021*^9}, 3.6185626038273125`*^9}],

Cell["\<\
assuming that t is the arc length of the curve.  Using the third derivation \
equation we obtain for the derivative of yy[t]\
\>", "Text",
 CellChangeTimes->{{3.592209073251086*^9, 3.5922091739078436`*^9}, {
   3.615533014047842*^9, 3.6155330161909647`*^9}, 3.618563604760563*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["yy", "\[Prime]",
     MultilineFunction->None], "(", "t", ")"}], " ", "\[LongEqual]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "(", 
      RowBox[{
       RowBox[{"amf", "(", "3", ")"}], "\[InvisibleApplication]", 
       RowBox[{"(", "sf", ")"}]}], ")"}], "\[InvisibleApplication]", 
     RowBox[{"(", 
      RowBox[{"\[Gamma]", "(", "t", ")"}], ")"}]}], ".", 
    SuperscriptBox["\[Gamma]", "\[Prime]",
     MultilineFunction->None]}], "\[LongEqual]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"amf", "(", "1", ")"}], "\[InvisibleApplication]", 
        RowBox[{"(", "sf", ")"}]}], 
       RowBox[{"\[Omega]", "(", "2", ")"}]}], " ", "-", 
      RowBox[{
       RowBox[{
        RowBox[{"amf", "(", "2", ")"}], "\[InvisibleApplication]", 
        RowBox[{"(", "sf", ")"}]}], 
       RowBox[{"\[Omega]", "(", "1", ")"}]}]}], " ", ")"}], ".", 
    SuperscriptBox["\[Gamma]", "\[Prime]",
     MultilineFunction->None]}]}], TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5922091796091695`*^9, 3.592209399005718*^9}, 
   3.5922094301304984`*^9, {3.5922094720768976`*^9, 3.5922095483502607`*^9}, {
   3.6155331102723455`*^9, 3.615533147672485*^9}, {3.618562644897662*^9, 
   3.6185626640177555`*^9}, 3.6185636420766973`*^9}],

Cell[TextData[{
 "In the chosen frame with principal directions we have, using the formulas \
for the ",
 ButtonBox["\[Omega][i]",
  BaseStyle->"Hyperlink",
  ButtonData->"cij"],
 " in Subsection 2.2.3, Inserting \[Sigma][1] = x, \[Sigma][2] = y"
}], "Text",
 CellChangeTimes->{{3.5922096102918034`*^9, 3.5922096605156755`*^9}, {
  3.592213357239681*^9, 3.5922134378152895`*^9}, {3.5922134816957994`*^9, 
  3.5922134817037997`*^9}, {3.592215535215254*^9, 3.5922155360162997`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"\[Omega]", "[", "1", "]"}]}], " ", "==", " ", 
   RowBox[{"k2", "*", "y"}]}], ";", "  ", 
  RowBox[{
   RowBox[{"\[Omega]", "[", "2", "]"}], " ", "==", " ", 
   RowBox[{"k1", "*", "x"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5922135413852134`*^9, 3.5922136907857585`*^9}, {
  3.59221373679439*^9, 3.5922137769206853`*^9}, {3.592215489306628*^9, 
  3.5922155094177785`*^9}}],

Cell["It follows:", "Text",
 CellChangeTimes->{{3.592213810783622*^9, 3.592213814695846*^9}, {
  3.5922138524090033`*^9, 3.5922138799195766`*^9}, {3.592215530463982*^9, 
  3.59221555909562*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"yy", "'"}], ".", 
    RowBox[{"yy", "'"}]}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"k1", "^", "2"}], "*", 
     RowBox[{"x", "^", "2"}]}], " ", "+", " ", 
    RowBox[{
     RowBox[{"k2", "^", "2"}], "*", 
     RowBox[{"y", "^", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"xx", "'"}], ".", 
   RowBox[{"yy", "'"}]}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"k1", "*", 
    RowBox[{"x", "^", "2"}]}], "+", " ", 
   RowBox[{"k2", "*", 
    RowBox[{"y", "^", "2"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.5922155975878215`*^9, 3.592215639401213*^9}, {
   3.592215732299526*^9, 3.592215762529256*^9}, 3.592215806385764*^9}],

Cell["\<\
In the case k1 == k2 any curve on the surface is a principal  curves, and the \
corresponding normal surface is always developable:\
\>", "Text",
 CellChangeTimes->{{3.592216110336149*^9, 3.592216217967305*^9}, {
  3.592216888759672*^9, 3.592216900167325*^9}, {3.592217137663909*^9, 
  3.5922171386879673`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"x", "^", "2"}], " ", "+", " ", 
       RowBox[{"y", "^", "2"}]}], " ", "==", " ", "1"}], ",", " ", 
     RowBox[{"k1", " ", "==", " ", "k2"}]}], "}"}], ",", " ", "\n", "  ", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"k1", "^", "2"}], "*", 
       RowBox[{"x", "^", "2"}]}], " ", "+", " ", 
      RowBox[{
       RowBox[{"k2", "^", "2"}], "*", 
       RowBox[{"y", "^", "2"}]}]}], " ", "==", " ", "\n", "    ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"k1", "*", 
         RowBox[{"x", "^", "2"}]}], " ", "+", " ", 
        RowBox[{"k2", "*", 
         RowBox[{"y", "^", "2"}]}]}], ")"}], "^", "2"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.592215866233187*^9, 3.5922159659308896`*^9}, {
  3.59221601646778*^9, 3.5922160588312035`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5922159676109858`*^9, 3.59221604374734*^9, 
  3.611666981123878*^9, 3.6155376308957987`*^9, 3.618563734630991*^9}]
}, Closed]],

Cell[TextData[{
 "We used ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "2"], " ", "+", " ", 
    SuperscriptBox["y", "2"]}], "\[LongEqual]", "1"}]],
  Evaluatable->False,
  CellChangeTimes->{{3.5922087972623005`*^9, 3.5922088957339325`*^9}, {
   3.5922089455897846`*^9, 3.5922090179659243`*^9}}],
 " since t must be assumed to be  the arc length of the curve xx[t]. Now we \
assume \nk1 <k2 and solve the condition"
}], "Text",
 CellChangeTimes->{{3.5922162494631066`*^9, 3.5922163814636564`*^9}, 
   3.592216485983635*^9, {3.615537646480226*^9, 3.6155376744510756`*^9}, {
   3.6155377729340477`*^9, 3.6155377904996786`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"k1", "^", "2"}], "*", 
        RowBox[{"x", "^", "2"}]}], " ", "+", " ", 
       RowBox[{
        RowBox[{"k2", "^", "2"}], "*", 
        RowBox[{"y", "^", "2"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"k1", "*", 
          RowBox[{"x", "^", "2"}]}], "+", " ", 
         RowBox[{"k2", "*", 
          RowBox[{"y", "^", "2"}]}]}], ")"}], "^", "2"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "^", "2"}], "+", 
       RowBox[{"y", "^", "2"}]}], "\[Equal]", "1"}], ",", 
     RowBox[{"k1", "<", "k2"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}], ",", "Reals"}], "]"}]], "Input",
 CellChangeTimes->{{3.592200842980342*^9, 3.592200961997149*^9}, {
   3.592201251093684*^9, 3.5922013459261084`*^9}, {3.5922015293455997`*^9, 
   3.592201554663048*^9}, {3.5922020007245607`*^9, 3.5922020071349277`*^9}, {
   3.592202175170539*^9, 3.592202182919982*^9}, 3.5922023318775015`*^9, 
   3.5922033977764673`*^9, {3.5922035067917027`*^9, 3.5922035132950745`*^9}, {
   3.5922035968798556`*^9, 3.592203648999837*^9}, 3.6148618601275406`*^9, 
   3.614917791904961*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k1", "<", "k2"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "\[Equal]", 
       RowBox[{"-", "1"}]}], "&&", 
      RowBox[{"y", "\[Equal]", "0"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "\[Equal]", "0"}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"y", "\[Equal]", 
         RowBox[{"-", "1"}]}], "||", 
        RowBox[{"y", "\[Equal]", "1"}]}], ")"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "\[Equal]", "1"}], "&&", 
      RowBox[{"y", "\[Equal]", "0"}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.592216445368312*^9, 3.6116671118053074`*^9, 
  3.615537829702548*^9, 3.618563764913723*^9}]
}, Closed]],

Cell[TextData[{
 "Thus we proved\n",
 StyleBox["Proposition.",
  FontColor->RGBColor[0, 0, 1]],
 " ",
 StyleBox["A curve on a regular surface is a principal curve of the surface \
iff its corresponding normal surface is developable",
  FontSlant->"Italic"],
 ". \[FilledRectangle]\n\nWe remember, that on a surface without umbilic \
points there exist two families of principal lines intersecting orthogonally, \
namely the integral curves of the two fields of principal directions."
}], "Text",
 CellChangeTimes->{{3.59221665199113*^9, 3.5922166772315736`*^9}, {
   3.5922167386160846`*^9, 3.5922167741271152`*^9}, {3.592217151807718*^9, 
   3.592217208774976*^9}, {3.592217254623598*^9, 3.5922173034473915`*^9}, {
   3.592217335319214*^9, 3.592217420312075*^9}, {3.5922175010716944`*^9, 
   3.5922175148644834`*^9}, {3.592218543152298*^9, 3.5922185677917075`*^9}, {
   3.5984545080142236`*^9, 3.5984545145705986`*^9}, {3.598454584037572*^9, 
   3.5984545866857233`*^9}, 3.6155384990217237`*^9}],

Cell[TextData[{
 StyleBox["Corollary",
  FontColor->RGBColor[0, 0, 1]],
 ". ",
 StyleBox["On a developable surface a family of generating lines and their \
orthogonal trajectories are ",
  FontSlant->"Italic"],
 "principal curve",
 StyleBox["s",
  FontSlant->"Italic"],
 ".\n",
 StyleBox["Proof",
  FontColor->RGBColor[0, 0, 1]],
 ". The normal vector of the surface along a generating line is constant. \
Thus the normal surface over a generating line is a plane. \[FilledRectangle]"
}], "Text",
 CellChangeTimes->{{3.598595326447343*^9, 3.598595355291794*^9}, {
   3.5985954204219084`*^9, 3.598595640085894*^9}, {3.5985957006764*^9, 
   3.5985957064952106`*^9}, 3.6174428163857994`*^9, 3.618564000414193*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["3.7.2. Normal Surfaces of the Helix", "Subsubsection",
 CellChangeTimes->{{3.592115389572919*^9, 3.592115426638584*^9}, 
   3.5921354646825233`*^9, 3.5922182112163124`*^9, 3.5942701628864923`*^9, 
   3.598596137570768*^9, 3.6116673526853304`*^9, 3.6119986168238125`*^9, {
   3.6155592477178297`*^9, 3.615559249355833*^9}, 3.6161383195804777`*^9, 
   3.618564015369048*^9, 3.6186374644950294`*^9},
 CellTags->"helix"],

Cell[TextData[{
 "Also the family of all normals to a given curve forms a 2-dimensional \
family of lines: ",
 StyleBox["The normal congruence of the curve",
  FontColor->RGBColor[0, 0, 1]],
 ". As example we consider the normal congruence of a helix."
}], "Text",
 CellChangeTimes->{{3.598596193044465*^9, 3.5985962126692996`*^9}, {
   3.598596242824153*^9, 3.5985963424459276`*^9}, 3.5986252137382*^9, 
   3.5986252462330575`*^9, {3.6156418819882107`*^9, 3.615641952219534*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"hel", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"helix", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "[", "t", "]"}], "/", 
   RowBox[{"Sqrt", "[", "2", "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.592115431786593*^9, 3.5921154360142*^9}, {
  3.59211546966346*^9, 3.5921154800374775`*^9}, {3.592115539411182*^9, 
  3.592115660030594*^9}, {3.5921157321963205`*^9, 3.5921157646287775`*^9}, {
  3.614750259680585*^9, 3.6147502813958235`*^9}, {3.614750440531703*^9, 
  3.614750474570963*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hel", "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.614750403200837*^9, 3.614750411578052*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"Cos", "[", "t", "]"}], 
    SqrtBox["2"]], ",", 
   FractionBox[
    RowBox[{"Sin", "[", "t", "]"}], 
    SqrtBox["2"]], ",", 
   FractionBox["t", 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{3.6147504129508543`*^9, 3.6147504477077155`*^9, 
  3.614750484071379*^9, 3.6155386447883797`*^9, 3.6185670601572003`*^9}]
}, Closed]],

Cell["\<\
With the norming by 1/Sqrt[2] t becomes the arc length parameter of the curve \
hel:\
\>", "Text",
 CellChangeTimes->{{3.6147505405122786`*^9, 3.6147506061883936`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"hel", "'"}], "[", "t", "]"}], ".", 
   RowBox[{
    RowBox[{"hel", "'"}], "[", "t", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592115673696218*^9, 3.5921156966750584`*^9}, {
  3.5921157757515974`*^9, 3.5921157855640144`*^9}, {3.614750345465136*^9, 
  3.614750352344748*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{
  3.5921156985158615`*^9, 3.592115738171131*^9, 3.5921157953452315`*^9, 
   3.592985965462344*^9, 3.598596566602721*^9, {3.5986766050820775`*^9, 
   3.5986766143328934`*^9}, 3.611925103994628*^9, 3.6147501092495213`*^9, 
   3.61475029088064*^9, 3.614750356416355*^9, 3.614750454946128*^9, 
   3.6147504892193885`*^9, 3.6155386608564076`*^9, 3.6185670699027576`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "frenet"}]], "Input",
 CellChangeTimes->{{3.592115995524783*^9, 3.592115997724387*^9}}],

Cell[BoxData[
 StyleBox["\<\"frenet[curve][t] yields the Frenet frame for a generally \
curved \\ncurve[t] in the n-dimensional Euclidean space. Generally curved \
means that the \\nrank of the first n-1 derivatives of curve[t] must be n-1 \
at each point t.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.592985965658355*^9},
 CellTags->"Info3592989565-2940166"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"helixnormalsf", "[", "a_", "]"}], "[", 
   RowBox[{"s_", ",", "t_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"hel", "[", "t", "]"}], " ", "+", " ", 
   RowBox[{"s", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"frenet", "[", "hel", "]"}], "[", "t", "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], "*", 
       RowBox[{"Cos", "[", 
        RowBox[{"a", "[", "t", "]"}], "]"}]}], " ", "+", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"frenet", "[", "hel", "]"}], "[", "t", "]"}], "[", 
        RowBox[{"[", "3", "]"}], "]"}], "*", 
       RowBox[{"Sin", "[", 
        RowBox[{"a", "[", "t", "]"}], "]"}]}]}], ")"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.592115877026975*^9, 3.592115984230363*^9}, {
  3.592116019377225*^9, 3.5921161327894244`*^9}, {3.59859658850516*^9, 
  3.5985966192840137`*^9}, {3.614750762812669*^9, 3.61475076927108*^9}}],

Cell["\<\
Here a[t] denotes the angle of the normal chosen at the point hel[t] with the \
principal normal at this point. The surface generated by the principal \
normals is\
\>", "Text",
 CellChangeTimes->{{3.598596667690899*^9, 3.598596740636627*^9}, {
   3.598596885264481*^9, 3.5985969100217247`*^9}, 3.614750778131896*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f0", "[", "t_", "]"}], " ", ":=", " ", "0"}], ";", 
  RowBox[{
   RowBox[{"helixnormalsf", "[", "f0", "]"}], "[", 
   RowBox[{"s", ",", "t"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5985967629914665`*^9, 3.598596787421109*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"Cos", "[", "t", "]"}], 
     SqrtBox["2"]], "-", 
    RowBox[{"s", " ", 
     RowBox[{"Cos", "[", "t", "]"}]}]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"Sin", "[", "t", "]"}], 
     SqrtBox["2"]], "-", 
    RowBox[{"s", " ", 
     RowBox[{"Sin", "[", "t", "]"}]}]}], ",", 
   FractionBox["t", 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{3.592116329100169*^9, 3.592985965751361*^9, 
  3.5985968137227554`*^9, 3.5985968455936117`*^9, 3.598625280100717*^9, 
  3.61192521888883*^9, 3.6155387103708944`*^9, 3.6156420485809035`*^9, 
  3.6159533808044834`*^9, 3.616064859788976*^9, 3.6162210929906735`*^9, 
  3.618567123074799*^9, 3.6185804169433503`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"helixnormalsf", "[", "f0", "]"}], "[", 
     RowBox[{"s", ",", "t"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"4", "*", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"s", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5921161521646585`*^9, 3.5921162529720354`*^9}, 
   3.5921162866056943`*^9, {3.5921163851354675`*^9, 3.59211639789629*^9}, 
   3.598596854392027*^9, 3.614861860143141*^9, 3.6149177919205613`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"gauss", "[", 
    RowBox[{"helixnormalsf", "[", "f0", "]"}], "]"}], "[", 
   RowBox[{"s", ",", "t"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.592116441529567*^9, 3.592116487518447*^9}, 
   3.5985969281489563`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["1", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        SqrtBox["2"], " ", "s"}], "+", 
       SuperscriptBox["s", "2"]}], ")"}], "2"]}]]}]], "Output",
 CellChangeTimes->{3.592116490170452*^9, 3.5929859669214277`*^9, 
  3.59859693033296*^9, 3.5986253062931633`*^9, 3.6119252373748627`*^9, 
  3.615538728217326*^9, 3.6156420719341445`*^9, 3.6185671379446497`*^9}]
}, Closed]],

Cell["Waiting  for the result a long time we obtained ", "Text",
 CellChangeTimes->{{3.6155454978738985`*^9, 3.6155455235827436`*^9}, 
   3.615642092604181*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", 
     RowBox[{"helixnormalsf", "[", "a", "]"}], "]"}], "[", 
    RowBox[{"s", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"a", "[", "t", "]"}], "\[Element]", "Reals"}], ",", 
     RowBox[{"s", "\[Element]", "Reals"}], ",", 
     RowBox[{"t", "\[Element]", "Reals"}]}], "}"}], ",", 
   RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.592116441529567*^9, 3.5921165134768925`*^9}, {
  3.5921165735837984`*^9, 3.5921166331759033`*^9}, {3.5985969638886194`*^9, 
  3.5985969657918224`*^9}, {3.6119269126930046`*^9, 3.611926926561429*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"8", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["a", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SqrtBox["2"], "+", 
         RowBox[{
          SuperscriptBox["a", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}], ")"}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"4", "-", 
      RowBox[{"4", " ", 
       SqrtBox["2"], " ", "s", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"a", "[", "t", "]"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["s", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", 
           RowBox[{"a", "[", "t", "]"}]}], "]"}], "+", 
         RowBox[{"4", " ", 
          RowBox[{
           SuperscriptBox["a", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["2"], "+", 
            RowBox[{
             SuperscriptBox["a", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}], 
        ")"}]}]}], ")"}], "2"]]}]], "Output",
 CellChangeTimes->{3.592116564691783*^9, 3.592116796055789*^9, 
  3.5929860061006684`*^9, 3.5929862143855815`*^9, 3.5985979428371387`*^9, 
  3.611926868981728*^9, 3.6119293099180155`*^9}]
}, Closed]],

Cell["\<\
We enter this result into the definition of the curvature function:\
\>", "Text",
 CellChangeTimes->{{3.615642127345442*^9, 3.615642168201914*^9}, 
   3.615894763370123*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ghns", "[", 
   RowBox[{"a_", ",", "s_", ",", " ", "t_"}], "]"}], " ", ":=", " ", "\n", 
  "  ", 
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"8", "*", 
       RowBox[{"(", 
        RowBox[{"1", " ", "+", " ", 
         RowBox[{"2", "*", 
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "1", "]"}], "[", "a", "]"}], "[", "t", 
           "]"}], "*", "\n", "       ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Sqrt", "[", "2", "]"}], " ", "+", " ", 
            RowBox[{
             RowBox[{
              RowBox[{"Derivative", "[", "1", "]"}], "[", "a", "]"}], "[", 
             "\n", "         ", "t", "]"}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
     "\n", "    ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4", " ", "-", " ", 
        RowBox[{"4", "*", 
         RowBox[{"Sqrt", "[", "2", "]"}], "*", "s", "*", 
         RowBox[{"Cos", "[", 
          RowBox[{"a", "[", "t", "]"}], "]"}]}], " ", "+", " ", "\n", 
        "      ", 
        RowBox[{
         RowBox[{"s", "^", "2"}], "*", 
         RowBox[{"(", 
          RowBox[{"3", " ", "+", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", "*", 
             RowBox[{"a", "[", "t", "]"}]}], "]"}], " ", "+", " ", "\n", 
           "        ", 
           RowBox[{"4", "*", 
            RowBox[{
             RowBox[{
              RowBox[{"Derivative", "[", "1", "]"}], "[", "a", "]"}], "[", 
             "t", "]"}], "*", "\n", "         ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sqrt", "[", "2", "]"}], " ", "+", " ", 
              RowBox[{
               RowBox[{
                RowBox[{"Derivative", "[", "1", "]"}], "[", "\n", 
                "            ", "a", "]"}], "[", "t", "]"}]}], ")"}]}]}], 
          ")"}]}]}], ")"}], "^", "2"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.6156118107257924`*^9, 3.6156118848727226`*^9}, {
  3.6159550844054756`*^9, 3.615955095372295*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"meancurvature", "[", 
     RowBox[{"helixnormalsf", "[", "a", "]"}], "]"}], "[", 
    RowBox[{"s", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"a", "[", "t", "]"}], "\[Element]", "Reals"}], ",", 
     RowBox[{"s", "\[Element]", "Reals"}], ",", 
     RowBox[{"t", "\[Element]", "Reals"}]}], "}"}], ",", 
   RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.592116441529567*^9, 3.5921165134768925`*^9}, {
  3.5921165735837984`*^9, 3.5921166331759033`*^9}, {3.5985969638886194`*^9, 
  3.5985969657918224`*^9}, {3.6119269126930046`*^9, 3.611926926561429*^9}, {
  3.616161573161564*^9, 3.6161615792923746`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Simplify", "::", "time"}], "MessageName"], ":", 
  " ", "\<\"Time spent on a transformation exceeded \[NoBreak]\\!\\(300.`\\)\
\[NoBreak] seconds, and the transformation was aborted. Increasing the value \
of TimeConstraint option may improve the result of simplification. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Simplify/time\\\", \
ButtonNote -> \\\"Simplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.616218645377575*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Simplify", "::", "time"}], "MessageName"], ":", 
  " ", "\<\"Time spent on a transformation exceeded \[NoBreak]\\!\\(300.`\\)\
\[NoBreak] seconds, and the transformation was aborted. Increasing the value \
of TimeConstraint option may improve the result of simplification. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Simplify/time\\\", \
ButtonNote -> \\\"Simplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6162189456157017`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Simplify", "::", "time"}], "MessageName"], ":", 
  " ", "\<\"Time spent on a transformation exceeded \[NoBreak]\\!\\(300.`\\)\
\[NoBreak] seconds, and the transformation was aborted. Increasing the value \
of TimeConstraint option may improve the result of simplification. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Simplify/time\\\", \
ButtonNote -> \\\"Simplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.616219294806715*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], ":", 
  " ", "\<\"Further output of \[NoBreak]\\!\\(\\*StyleBox[\\(Simplify :: time\
\\), \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6162192948691154`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "32"}], " ", 
     SqrtBox["2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"a", "[", "t", "]"}], "]"}]}], "-", 
    RowBox[{"224", " ", 
     SuperscriptBox["s", "4"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"a", "[", "t", "]"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["a", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
    RowBox[{"64", " ", 
     SqrtBox["2"], " ", 
     SuperscriptBox["s", "4"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"a", "[", "t", "]"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["a", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
    RowBox[{"64", " ", "s", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sin", "[", 
        RowBox[{"2", " ", 
         RowBox[{"a", "[", "t", "]"}]}], "]"}], "+", 
       RowBox[{
        SuperscriptBox["a", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     SuperscriptBox["s", "4"], " ", 
     RowBox[{"(", 
      RowBox[{"3", "+", 
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", 
         RowBox[{"a", "[", "t", "]"}]}], "]"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"5", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"a", "[", "t", "]"}], "]"}]}], "+", 
       RowBox[{"Sin", "[", 
        RowBox[{"3", " ", 
         RowBox[{"a", "[", "t", "]"}]}], "]"}], "+", 
       RowBox[{"8", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"a", "[", "t", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["a", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "-", 
    RowBox[{"8", " ", 
     SqrtBox["2"], " ", 
     SuperscriptBox["s", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"7", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"a", "[", "t", "]"}], "]"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"3", " ", 
          RowBox[{"a", "[", "t", "]"}]}], "]"}]}], "+", 
       RowBox[{"12", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"a", "[", "t", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["a", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["s", "2"], " ", 
     RowBox[{
      SuperscriptBox["a", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"10", " ", 
        RowBox[{"(", 
         RowBox[{"4", "-", 
          RowBox[{"4", " ", 
           SqrtBox["2"], " ", "s", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"a", "[", "t", "]"}], "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["s", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", 
               RowBox[{"a", "[", "t", "]"}]}], "]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"a", "[", "t", "]"}], "]"}]}], "+", 
       RowBox[{"16", " ", "s", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SqrtBox["2"]}], "+", 
          RowBox[{"s", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"a", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["a", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "+", 
    RowBox[{"8", " ", 
     SuperscriptBox["s", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", 
          RowBox[{"a", "[", "t", "]"}]}], "]"}]}], "+", 
       RowBox[{"Sin", "[", 
        RowBox[{"4", " ", 
         RowBox[{"a", "[", "t", "]"}]}], "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"5", "+", 
          RowBox[{"3", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", 
             RowBox[{"a", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["a", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["s", "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["a", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"24", " ", 
        SqrtBox["2"], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"a", "[", "t", "]"}], "]"}]}], "-", 
       RowBox[{"8", " ", "s", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", " ", 
             RowBox[{"a", "[", "t", "]"}]}], "]"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{
            SuperscriptBox["a", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        SqrtBox["2"], " ", 
        SuperscriptBox["s", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"39", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"a", "[", "t", "]"}], "]"}]}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"3", " ", 
             RowBox[{"a", "[", "t", "]"}]}], "]"}]}], "+", 
          RowBox[{"8", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"a", "[", "t", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["a", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
      ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"4", " ", 
    SqrtBox[
     RowBox[{"4", "-", 
      RowBox[{"4", " ", 
       SqrtBox["2"], " ", "s", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"a", "[", "t", "]"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["s", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", 
           RowBox[{"a", "[", "t", "]"}]}], "]"}], "+", 
         RowBox[{"4", " ", 
          RowBox[{
           SuperscriptBox["a", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["2"], "+", 
            RowBox[{
             SuperscriptBox["a", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}], 
        ")"}]}]}]], " ", 
    RowBox[{"(", 
     RowBox[{"16", "-", 
      RowBox[{"32", " ", 
       SqrtBox["2"], " ", "s", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"a", "[", "t", "]"}], "]"}]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["s", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"5", "+", 
         RowBox[{"3", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", 
            RowBox[{"a", "[", "t", "]"}]}], "]"}]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{
           SuperscriptBox["a", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["2"], "+", 
            RowBox[{
             SuperscriptBox["a", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}], ")"}]}],
       "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["s", "3"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"a", "[", "t", "]"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SqrtBox["2"], " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", 
              RowBox[{"a", "[", "t", "]"}]}], "]"}]}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{
           SuperscriptBox["a", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{"2", "+", 
            RowBox[{
             SqrtBox["2"], " ", 
             RowBox[{
              SuperscriptBox["a", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
        ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["s", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", 
              RowBox[{"a", "[", "t", "]"}]}], "]"}]}], ")"}], "2"], "+", 
         RowBox[{"8", " ", 
          RowBox[{
           SuperscriptBox["a", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox["2"], " ", 
             RowBox[{"(", 
              RowBox[{"3", "+", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", 
                 RowBox[{"a", "[", "t", "]"}]}], "]"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox["a", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{"7", "+", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", 
                 RowBox[{"a", "[", "t", "]"}]}], "]"}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["a", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SqrtBox["2"]}], "+", 
                  RowBox[{
                   SuperscriptBox["a", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.6161638295807266`*^9, 3.6162207804285245`*^9}]
}, Closed]],

Cell["\<\
We use this result to define the mean curvature of normal surfaces of a helix:\
\>", "Text",
 CellChangeTimes->{{3.6162212166988907`*^9, 3.6162212376653275`*^9}, {
   3.61622127301499*^9, 3.616221288334217*^9}, 3.6186374962098846`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"mhns", "[", 
   RowBox[{"a_", ",", " ", "s_", ",", " ", "t_"}], "]"}], " ", ":=", " ", 
  "\n", "  ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "32"}], "*", 
      RowBox[{"Sqrt", "[", "2", "]"}], "*", 
      RowBox[{"Sin", "[", 
       RowBox[{"a", "[", "t", "]"}], "]"}]}], " ", "-", " ", "\n", "    ", 
     RowBox[{"224", "*", 
      RowBox[{"s", "^", "4"}], "*", 
      RowBox[{"Sin", "[", 
       RowBox[{"a", "[", "t", "]"}], "]"}], "*", "\n", "     ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", "1", "]"}], "[", "a", "]"}], "[", "t", 
        "]"}], "^", "3"}]}], " ", "-", " ", "\n", "    ", 
     RowBox[{"64", "*", 
      RowBox[{"Sqrt", "[", "2", "]"}], "*", 
      RowBox[{"s", "^", "4"}], "*", 
      RowBox[{"Sin", "[", 
       RowBox[{"a", "[", "t", "]"}], "]"}], "*", "\n", "     ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", "1", "]"}], "[", "a", "]"}], "[", "t", 
        "]"}], "^", "4"}]}], " ", "+", " ", "\n", "    ", 
     RowBox[{"64", "*", "s", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"2", "*", 
          RowBox[{"a", "[", "t", "]"}]}], "]"}], " ", "+", " ", "\n", 
        "      ", 
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", "2", "]"}], "[", "a", "]"}], "[", "t", 
         "]"}]}], ")"}]}], " ", "-", " ", "\n", "    ", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], "*", 
      RowBox[{"s", "^", "4"}], "*", 
      RowBox[{"(", 
       RowBox[{"3", " ", "+", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", "*", 
          RowBox[{"a", "[", "t", "]"}]}], "]"}]}], ")"}], "*", "\n", "     ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"5", "*", 
         RowBox[{"Sin", "[", 
          RowBox[{"a", "[", "t", "]"}], "]"}]}], " ", "+", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"3", "*", 
          RowBox[{"a", "[", "t", "]"}]}], "]"}], " ", "+", " ", "\n", 
        "      ", 
        RowBox[{"8", "*", 
         RowBox[{"Cos", "[", 
          RowBox[{"a", "[", "t", "]"}], "]"}], "*", 
         RowBox[{
          RowBox[{
           RowBox[{"Derivative", "[", "2", "]"}], "[", "a", "]"}], "[", "\n", 
          "        ", "t", "]"}]}]}], ")"}]}], " ", "-", " ", 
     RowBox[{"8", "*", 
      RowBox[{"Sqrt", "[", "2", "]"}], "*", 
      RowBox[{"s", "^", "2"}], "*", "\n", "     ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"7", "*", 
         RowBox[{"Sin", "[", 
          RowBox[{"a", "[", "t", "]"}], "]"}]}], " ", "+", " ", 
        RowBox[{"3", "*", 
         RowBox[{"Sin", "[", 
          RowBox[{"3", "*", 
           RowBox[{"a", "[", "t", "]"}]}], "]"}]}], " ", "+", " ", "\n", 
        "      ", 
        RowBox[{"12", "*", 
         RowBox[{"Cos", "[", 
          RowBox[{"a", "[", "t", "]"}], "]"}], "*", 
         RowBox[{
          RowBox[{
           RowBox[{"Derivative", "[", "2", "]"}], "[", "a", "]"}], "[", "\n", 
          "        ", "t", "]"}]}]}], ")"}]}], " ", "-", " ", 
     RowBox[{"4", "*", 
      RowBox[{"s", "^", "2"}], "*", "\n", "     ", 
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "a", "]"}], "[", "t", 
       "]"}], "*", "\n", "     ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"10", "*", 
         RowBox[{"(", 
          RowBox[{"4", " ", "-", " ", 
           RowBox[{"4", "*", 
            RowBox[{"Sqrt", "[", "2", "]"}], "*", "s", "*", "\n", "         ", 
            RowBox[{"Cos", "[", 
             RowBox[{"a", "[", "t", "]"}], "]"}]}], " ", "+", " ", "\n", 
           "        ", 
           RowBox[{
            RowBox[{"s", "^", "2"}], "*", 
            RowBox[{"(", 
             RowBox[{"3", " ", "+", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"2", "*", 
                RowBox[{"a", "[", "t", "]"}]}], "]"}]}], ")"}]}]}], ")"}], 
         "*", "\n", "       ", 
         RowBox[{"Sin", "[", 
          RowBox[{"a", "[", "t", "]"}], "]"}]}], " ", "+", " ", 
        RowBox[{"16", "*", "s", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Sqrt", "[", "2", "]"}]}], " ", "+", " ", "\n", 
           "        ", 
           RowBox[{"s", "*", 
            RowBox[{"Cos", "[", 
             RowBox[{"a", "[", "t", "]"}], "]"}]}]}], ")"}], "*", "\n", 
         "       ", 
         RowBox[{
          RowBox[{
           RowBox[{"Derivative", "[", "2", "]"}], "[", "a", "]"}], "[", "t", 
          "]"}]}]}], ")"}]}], " ", "+", " ", "\n", "    ", 
     RowBox[{"8", "*", 
      RowBox[{"s", "^", "3"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"6", "*", 
         RowBox[{"Sin", "[", 
          RowBox[{"2", "*", 
           RowBox[{"a", "[", "t", "]"}]}], "]"}]}], " ", "+", " ", "\n", 
        "      ", 
        RowBox[{"Sin", "[", 
         RowBox[{"4", "*", 
          RowBox[{"a", "[", "t", "]"}]}], "]"}], " ", "+", " ", "\n", 
        "      ", 
        RowBox[{"2", "*", 
         RowBox[{"(", 
          RowBox[{"5", " ", "+", " ", 
           RowBox[{"3", "*", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", "*", 
              RowBox[{"a", "[", "t", "]"}]}], "]"}]}]}], ")"}], "*", "\n", 
         "       ", 
         RowBox[{
          RowBox[{
           RowBox[{"Derivative", "[", "2", "]"}], "[", "a", "]"}], "[", "t", 
          "]"}]}]}], ")"}]}], " ", "-", " ", "\n", "    ", 
     RowBox[{"4", "*", 
      RowBox[{"s", "^", "2"}], "*", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", "1", "]"}], "[", "a", "]"}], "[", "t", 
        "]"}], "^", "2"}], "*", "\n", "     ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"24", "*", 
         RowBox[{"Sqrt", "[", "2", "]"}], "*", 
         RowBox[{"Sin", "[", 
          RowBox[{"a", "[", "t", "]"}], "]"}]}], " ", "-", " ", "\n", 
        "      ", 
        RowBox[{"8", "*", "s", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", "*", 
            RowBox[{"Sin", "[", 
             RowBox[{"2", "*", 
              RowBox[{"a", "[", "t", "]"}]}], "]"}]}], " ", "+", " ", "\n", 
           "        ", 
           RowBox[{"2", "*", 
            RowBox[{
             RowBox[{
              RowBox[{"Derivative", "[", "2", "]"}], "[", "a", "]"}], "[", 
             "t", "]"}]}]}], ")"}]}], " ", "+", " ", "\n", "      ", 
        RowBox[{
         RowBox[{"Sqrt", "[", "2", "]"}], "*", 
         RowBox[{"s", "^", "2"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"39", "*", 
            RowBox[{"Sin", "[", 
             RowBox[{"a", "[", "t", "]"}], "]"}]}], " ", "+", " ", "\n", 
           "        ", 
           RowBox[{"3", "*", 
            RowBox[{"Sin", "[", 
             RowBox[{"3", "*", 
              RowBox[{"a", "[", "t", "]"}]}], "]"}]}], " ", "+", " ", 
           RowBox[{"8", "*", 
            RowBox[{"Cos", "[", 
             RowBox[{"a", "[", "t", "]"}], "]"}], "*", "\n", "         ", 
            RowBox[{
             RowBox[{
              RowBox[{"Derivative", "[", "2", "]"}], "[", "a", "]"}], "[", 
             "t", "]"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", "\n", "   ", 
   RowBox[{"(", 
    RowBox[{"4", "*", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"4", " ", "-", " ", 
       RowBox[{"4", "*", 
        RowBox[{"Sqrt", "[", "2", "]"}], "*", "s", "*", "\n", "       ", 
        RowBox[{"Cos", "[", 
         RowBox[{"a", "[", "t", "]"}], "]"}]}], " ", "+", " ", "\n", "      ", 
       RowBox[{
        RowBox[{"s", "^", "2"}], "*", 
        RowBox[{"(", 
         RowBox[{"3", " ", "+", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", "*", 
            RowBox[{"a", "[", "t", "]"}]}], "]"}], " ", "+", " ", "\n", 
          "        ", 
          RowBox[{"4", "*", 
           RowBox[{
            RowBox[{
             RowBox[{"Derivative", "[", "1", "]"}], "[", "a", "]"}], "[", "t",
             "]"}], "*", "\n", "         ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Sqrt", "[", "2", "]"}], " ", "+", " ", 
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "\n", 
               "            ", "a", "]"}], "[", "t", "]"}]}], ")"}]}]}], 
         ")"}]}]}], "]"}], "*", "\n", "    ", 
     RowBox[{"(", 
      RowBox[{"16", " ", "-", " ", 
       RowBox[{"32", "*", 
        RowBox[{"Sqrt", "[", "2", "]"}], "*", "s", "*", 
        RowBox[{"Cos", "[", 
         RowBox[{"a", "[", "t", "]"}], "]"}]}], " ", "+", " ", "\n", "     ", 
       RowBox[{"8", "*", 
        RowBox[{"s", "^", "2"}], "*", 
        RowBox[{"(", 
         RowBox[{"5", " ", "+", " ", 
          RowBox[{"3", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", "*", 
             RowBox[{"a", "[", "t", "]"}]}], "]"}]}], " ", "+", " ", "\n", 
          "       ", 
          RowBox[{"4", "*", 
           RowBox[{
            RowBox[{
             RowBox[{"Derivative", "[", "1", "]"}], "[", "a", "]"}], "[", "t",
             "]"}], "*", "\n", "        ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Sqrt", "[", "2", "]"}], " ", "+", " ", 
             RowBox[{
              RowBox[{
               RowBox[{"Derivative", "[", "1", "]"}], "[", "a", "]"}], "[", 
              "\n", "          ", "t", "]"}]}], ")"}]}]}], ")"}]}], " ", "-", 
       " ", 
       RowBox[{"8", "*", 
        RowBox[{"s", "^", "3"}], "*", 
        RowBox[{"Cos", "[", 
         RowBox[{"a", "[", "t", "]"}], "]"}], "*", "\n", "      ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Sqrt", "[", "2", "]"}], "*", 
           RowBox[{"(", 
            RowBox[{"3", " ", "+", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"2", "*", 
               RowBox[{"a", "[", "t", "]"}]}], "]"}]}], ")"}]}], " ", "+", 
          " ", "\n", "       ", 
          RowBox[{"4", "*", 
           RowBox[{
            RowBox[{
             RowBox[{"Derivative", "[", "1", "]"}], "[", "a", "]"}], "[", "t",
             "]"}], "*", "\n", "        ", 
           RowBox[{"(", 
            RowBox[{"2", " ", "+", " ", 
             RowBox[{
              RowBox[{"Sqrt", "[", "2", "]"}], "*", 
              RowBox[{
               RowBox[{
                RowBox[{"Derivative", "[", "1", "]"}], "[", "\n", 
                "            ", "a", "]"}], "[", "t", "]"}]}]}], ")"}]}]}], 
         ")"}]}], " ", "+", " ", "\n", "     ", 
       RowBox[{
        RowBox[{"s", "^", "4"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", " ", "+", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"2", "*", 
               RowBox[{"a", "[", "t", "]"}]}], "]"}]}], ")"}], "^", "2"}], 
          " ", "+", " ", "\n", "       ", 
          RowBox[{"8", "*", 
           RowBox[{
            RowBox[{
             RowBox[{"Derivative", "[", "1", "]"}], "[", "a", "]"}], "[", "t",
             "]"}], "*", "\n", "        ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"Sqrt", "[", "2", "]"}], "*", 
              RowBox[{"(", 
               RowBox[{"3", " ", "+", " ", 
                RowBox[{"Cos", "[", "\n", "            ", 
                 RowBox[{"2", "*", 
                  RowBox[{"a", "[", "t", "]"}]}], "]"}]}], ")"}]}], " ", "+", 
             " ", "\n", "         ", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Derivative", "[", "1", "]"}], "[", "a", "]"}], "[", 
               "t", "]"}], "*", "\n", "          ", 
              RowBox[{"(", 
               RowBox[{"7", " ", "+", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"2", "*", 
                  RowBox[{"a", "[", "t", "]"}]}], "]"}], " ", "+", " ", "\n", 
                "           ", 
                RowBox[{"2", "*", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Derivative", "[", "1", "]"}], "[", "a", "]"}], 
                  "[", "t", "]"}], "*", "\n", "            ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", "*", 
                    RowBox[{"Sqrt", "[", "2", "]"}]}], " ", "+", " ", "\n", 
                   "            ", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Derivative", "[", "1", "]"}], "[", "a", "]"}], 
                    "[", "\n", "            ", "t", "]"}]}], ")"}]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.616220953588829*^9, 3.6162210258013554`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ghns", "[", 
  RowBox[{"f0", ",", "s", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.6160648287761216`*^9, 3.616064847152954*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["8", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"4", "-", 
      RowBox[{"4", " ", 
       SqrtBox["2"], " ", "s"}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["s", "2"]}]}], ")"}], "2"]]}]], "Output",
 CellChangeTimes->{3.616064867354989*^9, 3.6162211637367983`*^9, 
  3.6185678156394114`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "-", 
   RowBox[{"(", 
    RowBox[{"-", 
     FractionBox["1", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           SqrtBox["2"], " ", "s"}], "+", 
          SuperscriptBox["s", "2"]}], ")"}], "2"]}]]}], ")"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.616064901285049*^9, 3.6160649548867435`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6160649568679466`*^9, 3.6162211682296057`*^9, 
  3.618567838381712*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mhns", "[", 
  RowBox[{"f0", ",", "s", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.6162211138791103`*^9, 3.616221126343532*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6162211300875387`*^9, 3.618567842697959*^9}]
}, Closed]],

Cell["This surface is a minimal surface.", "Text",
 CellChangeTimes->{{3.615642285373719*^9, 3.6156423036257515`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"prcurvatures", "[", 
     RowBox[{"helixnormalsf", "[", "f0", "]"}], "]"}], "[", 
    RowBox[{"s", ",", "t"}], "]"}], ",", 
   RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "3000"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.615894921679201*^9, 3.615894935500825*^9}, {
   3.615894967122081*^9, 3.6158950225801783`*^9}, {3.6158987413929405`*^9, 
   3.615898787225821*^9}, {3.6158988989532175`*^9, 3.6158989146936445`*^9}, 
   3.6159533218831797`*^9, {3.6159533536604357`*^9, 3.6159533547992373`*^9}, 
   3.6159542222075615`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SqrtBox["2"], " ", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"9", " ", 
                SqrtBox["2"], " ", "s"}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["s", "2"]}], "-", 
               RowBox[{"240", " ", 
                SqrtBox["2"], " ", 
                SuperscriptBox["s", "3"]}], "+", 
               RowBox[{"1044", " ", 
                SuperscriptBox["s", "4"]}], "-", 
               RowBox[{"1764", " ", 
                SqrtBox["2"], " ", 
                SuperscriptBox["s", "5"]}], "+", 
               RowBox[{"4788", " ", 
                SuperscriptBox["s", "6"]}], "-", 
               RowBox[{"5328", " ", 
                SqrtBox["2"], " ", 
                SuperscriptBox["s", "7"]}], "+", 
               RowBox[{"9846", " ", 
                SuperscriptBox["s", "8"]}], "-", 
               RowBox[{"7606", " ", 
                SqrtBox["2"], " ", 
                SuperscriptBox["s", "9"]}], "+", 
               RowBox[{"9846", " ", 
                SuperscriptBox["s", "10"]}], "-", 
               RowBox[{"5328", " ", 
                SqrtBox["2"], " ", 
                SuperscriptBox["s", "11"]}], "+", 
               RowBox[{"4788", " ", 
                SuperscriptBox["s", "12"]}], "-", 
               RowBox[{"1764", " ", 
                SqrtBox["2"], " ", 
                SuperscriptBox["s", "13"]}], "+", 
               RowBox[{"1044", " ", 
                SuperscriptBox["s", "14"]}], "-", 
               RowBox[{"240", " ", 
                SqrtBox["2"], " ", 
                SuperscriptBox["s", "15"]}], "+", 
               RowBox[{"81", " ", 
                SuperscriptBox["s", "16"]}], "-", 
               RowBox[{"9", " ", 
                SqrtBox["2"], " ", 
                SuperscriptBox["s", "17"]}], "+", 
               SuperscriptBox["s", "18"]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SqrtBox["2"], " ", "s"}], "-", 
                 SuperscriptBox["s", "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SqrtBox["2"], "-", 
                  RowBox[{"2", " ", "s"}], "+", 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   SuperscriptBox["s", "2"]}]}], ")"}], "2"]}], ")"}]}], 
            ")"}]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           SqrtBox["2"], " ", "s"}], "+", 
          SuperscriptBox["s", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SqrtBox["2"], "-", 
          RowBox[{"2", " ", "s"}], "+", 
          RowBox[{
           SqrtBox["2"], " ", 
           SuperscriptBox["s", "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"], " ", "s"}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["s", "2"]}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"], " ", 
           SuperscriptBox["s", "3"]}], "-", 
          SuperscriptBox["s", "4"]}], ")"}]}], ")"}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SqrtBox["2"], " ", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"9", " ", 
              SqrtBox["2"], " ", "s"}], "+", 
             RowBox[{"81", " ", 
              SuperscriptBox["s", "2"]}], "-", 
             RowBox[{"240", " ", 
              SqrtBox["2"], " ", 
              SuperscriptBox["s", "3"]}], "+", 
             RowBox[{"1044", " ", 
              SuperscriptBox["s", "4"]}], "-", 
             RowBox[{"1764", " ", 
              SqrtBox["2"], " ", 
              SuperscriptBox["s", "5"]}], "+", 
             RowBox[{"4788", " ", 
              SuperscriptBox["s", "6"]}], "-", 
             RowBox[{"5328", " ", 
              SqrtBox["2"], " ", 
              SuperscriptBox["s", "7"]}], "+", 
             RowBox[{"9846", " ", 
              SuperscriptBox["s", "8"]}], "-", 
             RowBox[{"7606", " ", 
              SqrtBox["2"], " ", 
              SuperscriptBox["s", "9"]}], "+", 
             RowBox[{"9846", " ", 
              SuperscriptBox["s", "10"]}], "-", 
             RowBox[{"5328", " ", 
              SqrtBox["2"], " ", 
              SuperscriptBox["s", "11"]}], "+", 
             RowBox[{"4788", " ", 
              SuperscriptBox["s", "12"]}], "-", 
             RowBox[{"1764", " ", 
              SqrtBox["2"], " ", 
              SuperscriptBox["s", "13"]}], "+", 
             RowBox[{"1044", " ", 
              SuperscriptBox["s", "14"]}], "-", 
             RowBox[{"240", " ", 
              SqrtBox["2"], " ", 
              SuperscriptBox["s", "15"]}], "+", 
             RowBox[{"81", " ", 
              SuperscriptBox["s", "16"]}], "-", 
             RowBox[{"9", " ", 
              SqrtBox["2"], " ", 
              SuperscriptBox["s", "17"]}], "+", 
             SuperscriptBox["s", "18"]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{
                SqrtBox["2"], " ", "s"}], "-", 
               SuperscriptBox["s", "2"]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SqrtBox["2"], "-", 
                RowBox[{"2", " ", "s"}], "+", 
                RowBox[{
                 SqrtBox["2"], " ", 
                 SuperscriptBox["s", "2"]}]}], ")"}], "2"]}], ")"}]}], 
          ")"}]}], ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         SqrtBox["2"], " ", "s"}], "+", 
        SuperscriptBox["s", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox["2"], "-", 
        RowBox[{"2", " ", "s"}], "+", 
        RowBox[{
         SqrtBox["2"], " ", 
         SuperscriptBox["s", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"], " ", "s"}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["s", "2"]}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"], " ", 
         SuperscriptBox["s", "3"]}], "-", 
        SuperscriptBox["s", "4"]}], ")"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.615904692350993*^9, 3.6159534777118535`*^9, 
  3.6159547491452866`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"%", "[", 
    RowBox[{"[", "1", "]"}], "]"}], " ", "+", 
   RowBox[{"%", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.615954856208275*^9, 3.6159548880323305`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6159548947247424`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"%%", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "*", 
   RowBox[{"%%", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.615954903070757*^9, 3.615954985548102*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"9", " ", 
         SqrtBox["2"], " ", "s"}], "-", 
        RowBox[{"81", " ", 
         SuperscriptBox["s", "2"]}], "+", 
        RowBox[{"240", " ", 
         SqrtBox["2"], " ", 
         SuperscriptBox["s", "3"]}], "-", 
        RowBox[{"1044", " ", 
         SuperscriptBox["s", "4"]}], "+", 
        RowBox[{"1764", " ", 
         SqrtBox["2"], " ", 
         SuperscriptBox["s", "5"]}], "-", 
        RowBox[{"4788", " ", 
         SuperscriptBox["s", "6"]}], "+", 
        RowBox[{"5328", " ", 
         SqrtBox["2"], " ", 
         SuperscriptBox["s", "7"]}], "-", 
        RowBox[{"9846", " ", 
         SuperscriptBox["s", "8"]}], "+", 
        RowBox[{"7606", " ", 
         SqrtBox["2"], " ", 
         SuperscriptBox["s", "9"]}], "-", 
        RowBox[{"9846", " ", 
         SuperscriptBox["s", "10"]}], "+", 
        RowBox[{"5328", " ", 
         SqrtBox["2"], " ", 
         SuperscriptBox["s", "11"]}], "-", 
        RowBox[{"4788", " ", 
         SuperscriptBox["s", "12"]}], "+", 
        RowBox[{"1764", " ", 
         SqrtBox["2"], " ", 
         SuperscriptBox["s", "13"]}], "-", 
        RowBox[{"1044", " ", 
         SuperscriptBox["s", "14"]}], "+", 
        RowBox[{"240", " ", 
         SqrtBox["2"], " ", 
         SuperscriptBox["s", "15"]}], "-", 
        RowBox[{"81", " ", 
         SuperscriptBox["s", "16"]}], "+", 
        RowBox[{"9", " ", 
         SqrtBox["2"], " ", 
         SuperscriptBox["s", "17"]}], "-", 
        SuperscriptBox["s", "18"]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{
          SqrtBox["2"], " ", "s"}], "-", 
         SuperscriptBox["s", "2"]}], ")"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SqrtBox["2"], "-", 
         RowBox[{"2", " ", "s"}], "+", 
         RowBox[{
          SqrtBox["2"], " ", 
          SuperscriptBox["s", "2"]}]}], ")"}], "4"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "s"}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["s", "2"]}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["s", "3"]}], "+", 
         SuperscriptBox["s", "4"]}], ")"}], "2"]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.6159549883873067`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "-", 
   RowBox[{"ghns", "[", 
    RowBox[{"f0", ",", "s", ",", "t"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6159551298951554`*^9, 3.615955261684187*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6159551999548783`*^9, 3.6159552450389576`*^9}]
}, Closed]],

Cell["\<\
Now we consider the surface generated by the binormals of hel[t]\
\>", "Text",
 CellChangeTimes->{{3.6159599427064085`*^9, 3.6159599750764656`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fc", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"Pi", "/", "2"}]}]], "Input",
 CellChangeTimes->{{3.6159555144670305`*^9, 3.61595553112786*^9}, {
  3.6159579271516685`*^9, 3.615957930833275*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"helixnormalsf", "[", "fc", "]"}], "[", 
  RowBox[{"s", ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"Cos", "[", "t", "]"}], 
     SqrtBox["2"]], "+", 
    FractionBox[
     RowBox[{"s", " ", 
      RowBox[{"Sin", "[", "t", "]"}]}], 
     SqrtBox["2"]]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"s", " ", 
       RowBox[{"Cos", "[", "t", "]"}]}], 
      SqrtBox["2"]]}], "+", 
    FractionBox[
     RowBox[{"Sin", "[", "t", "]"}], 
     SqrtBox["2"]]}], ",", 
   RowBox[{
    FractionBox["t", 
     SqrtBox["2"]], "+", 
    FractionBox[
     RowBox[{"s", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", "t", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "t", "]"}], "2"]}], ")"}]}], 
     SqrtBox["2"]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6159602426793356`*^9, 3.6185804973302917`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"helixnormalsf", "[", "fc", "]"}], "[", 
     RowBox[{"s", ",", "t"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"4", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6159599842024813`*^9, 3.615960107395898*^9}, 
   3.615960139095154*^9, {3.6159602904934196`*^9, 3.615960307419449*^9}, {
   3.6159604721869383`*^9, 3.6159604830289574`*^9}, 3.616046306241881*^9}],

Cell[BoxData[
 RowBox[{"heli", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"hel", "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", 
      RowBox[{"4", "*", "Pi"}]}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Red", ",", "Thick"}], "}"}]}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.598677449620761*^9, 3.5986775251872935`*^9}, 
   3.6147509195461445`*^9, {3.6159605660367036`*^9, 3.615960574819519*^9}, 
   3.6160463345871305`*^9}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"heli", ",", "%%"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6159605853183374`*^9, 3.6159606207303996`*^9}, {
  3.6159606748780947`*^9, 3.61596068908972*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"mhns", "[", 
   RowBox[{"fc", ",", "s", ",", "t"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6162213456955175`*^9, 3.6162213704371605`*^9}, {
  3.616221406816425*^9, 3.6162214456448927`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["1", 
   RowBox[{"2", " ", 
    SqrtBox[
     RowBox[{"2", "+", 
      SuperscriptBox["s", "2"]}]]}]]}]], "Output",
 CellChangeTimes->{3.6162213897655945`*^9, 3.616221446721295*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ghns", "[", 
  RowBox[{"fc", ",", "s", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.615958270633072*^9, 3.6159582879491024`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["8", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"4", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["s", "2"]}]}], ")"}], "2"]]}]], "Output",
 CellChangeTimes->{3.61595829222351*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"cf", "[", 
      RowBox[{"1", ",", "1"}], "]"}], "[", 
     RowBox[{"helixnormalsf", "[", "fc", "]"}], "]"}], "[", 
    RowBox[{"s", ",", "t"}], "]"}], ",", 
   RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5985979735847926`*^9, 3.5985979804176044`*^9}, 
   3.6155461112045755`*^9, {3.615958319929158*^9, 3.6159583313015785`*^9}, 
   3.6179723575538254`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5985979895904207`*^9, 3.5986253583816547`*^9, 
  3.6119304315287857`*^9, 3.6155461196129904`*^9, 3.6155500405036583`*^9, 
  3.6156148133566666`*^9, 3.61595834930401*^9, 3.615958559280379*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"cf", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "[", 
     RowBox[{"helixnormalsf", "[", "fc", "]"}], "]"}], "[", 
    RowBox[{"s", ",", "t"}], "]"}], ",", 
   RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5985979735847926`*^9, 3.5985980169864693`*^9}, 
   3.615550069613309*^9, {3.6159587191650596`*^9, 3.615958720054261*^9}, 
   3.615959291686065*^9, 3.61797235903191*^9}],

Cell[BoxData[
 FractionBox[
  SqrtBox["2"], 
  RowBox[{"2", "+", 
   SuperscriptBox["s", "2"]}]]], "Output",
 CellChangeTimes->{3.5985980195292735`*^9, 3.598625364684066*^9, 
  3.6119304434004064`*^9, 3.6155528160605335`*^9, 3.6159588061664124`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"cf", "[", 
      RowBox[{"2", ",", "2"}], "]"}], "[", 
     RowBox[{"helixnormalsf", "[", "fc", "]"}], "]"}], "[", 
    RowBox[{"s", ",", "t"}], "]"}], ",", 
   RowBox[{"TimeConstraint", "  ", "\[Rule]", " ", "Infinity"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5985979735847926`*^9, 3.5985980169864693`*^9}, {
   3.5985980716177645`*^9, 3.598598088060194*^9}, {3.61193075312335*^9, 
   3.61193079271622*^9}, {3.6159592758520374`*^9, 3.615959299080478*^9}, 
   3.6179723604549913`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["1", 
   SqrtBox[
    RowBox[{"2", "+", 
     SuperscriptBox["s", "2"]}]]]}]], "Output",
 CellChangeTimes->{3.616066359659018*^9}]
}, Closed]],

Cell["Thus the mean curvature of this surface is", "Text",
 CellChangeTimes->{3.616065523621974*^9, 3.6185806840470195`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"mc", "[", "s_", "]"}], " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"meancurvature", "[", 
      RowBox[{"helixnormalsf", "[", "fc", "]"}], "]"}], "[", 
     RowBox[{"s", ",", "t"}], "]"}], ",", 
    RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6160655398460026`*^9, 3.6160656265041547`*^9}, {
  3.616065657033408*^9, 3.6160656698098307`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["1", 
   RowBox[{"2", " ", 
    SqrtBox[
     RowBox[{"2", "+", 
      SuperscriptBox["s", "2"]}]]}]]}]], "Output",
 CellChangeTimes->{3.6160659610003176`*^9, 3.6185809167682285`*^9}]
}, Closed]],

Cell["\<\
The Gaussian curvature of this surface is (remember K == Det[{cf[i,j]}] == \
-cf[1,2]^2 in our case)\
\>", "Text",
 CellChangeTimes->{{3.5985984819296856`*^9, 3.5985985005873184`*^9}, {
  3.5986759777113757`*^9, 3.598676051780306*^9}, {3.6179723743077836`*^9, 
  3.6179723752968397`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"gc", "[", 
   RowBox[{"s_", ",", " ", "t_"}], "]"}], " ", ":=", " ", "\n", "  ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", " ", "+", " ", 
        RowBox[{"s", "^", "2"}]}], ")"}]}], ")"}], "^", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.5985985332225757`*^9, 3.5985986252783375`*^9}, 
   3.5986764434345937`*^9, {3.6148618601587405`*^9, 3.6148618601743402`*^9}, {
   3.614917791936161*^9, 3.6149177919517612`*^9}, 3.615959695243174*^9, {
   3.6159597270204296`*^9, 3.615959761855291*^9}, 3.6159598773890944`*^9}],

Cell["Test:", "Text",
 CellChangeTimes->{{3.615960445885292*^9, 3.615960447414095*^9}, 
   3.6159607784154763`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ghns", "[", 
     RowBox[{"fc", ",", "s", ",", "t"}], "]"}], "-", 
    RowBox[{"gc", "[", 
     RowBox[{"s", ",", "t"}], "]"}]}], ",", 
   RowBox[{"TimeConstraint", "  ", "\[Rule]", " ", "Infinity"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.615614878658381*^9, 3.6156149511985083`*^9}, {
   3.6156163463245587`*^9, 3.615616348867363*^9}, {3.6159598080469723`*^9, 
   3.61595981821819*^9}, 3.6159598587314615`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["2", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"2", "+", 
       SuperscriptBox["s", "2"]}], ")"}], "2"]]}], "-", 
  RowBox[{"gc", "[", 
   RowBox[{"s", ",", "t"}], "]"}]}]], "Output",
 CellChangeTimes->{
  3.6156162851880517`*^9, 3.615616350286966*^9, {3.615959863146269*^9, 
   3.6159598894791155`*^9}, 3.6185809447390776`*^9}]
}, Closed]],

Cell["For constant functions", "Text",
 CellChangeTimes->{{3.5985991958025393`*^9, 3.598599219654981*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"b", "[", "t_", "]"}], " ", ":=", " ", "b0"}]], "Input",
 CellChangeTimes->{{3.598598670518417*^9, 3.598598714650894*^9}}],

Cell["we obtain", "Text",
 CellChangeTimes->{{3.598599228453397*^9, 3.5985992318542027`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ghns", "[", 
  RowBox[{"b", ",", "s", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.59859876895459*^9, 3.5985987769886036`*^9}, {
  3.6159608690048356`*^9, 3.615960881438058*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["8", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"4", "-", 
      RowBox[{"4", " ", 
       SqrtBox["2"], " ", "s", " ", 
       RowBox[{"Cos", "[", "b0", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["s", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "b0"}], "]"}]}], ")"}]}]}], ")"}], 
    "2"]]}]], "Output",
 CellChangeTimes->{3.5985987824330134`*^9, 3.598625548639589*^9, 
  3.6119976167856135`*^9, 3.6155591224496098`*^9, 3.6156163746542087`*^9, 
  3.615960884402063*^9, 3.6160464243496885`*^9, 3.6160650705141463`*^9, 
  3.618580965409114*^9, 3.6186339306832223`*^9}]
}, Closed]],

Cell["We define this result as", "Text",
 CellChangeTimes->{{3.5985992454106264`*^9, 3.598599341522395*^9}, {
  3.598626051615672*^9, 3.5986260638772936`*^9}, {3.615616410768272*^9, 
  3.615616415947481*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fk", "[", 
   RowBox[{"b0_", ",", " ", "s_"}], "]"}], " ", ":=", " ", "\n", "  ", 
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{"8", "/", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4", " ", "-", " ", 
        RowBox[{"4", "*", 
         RowBox[{"Sqrt", "[", "2", "]"}], "*", "s", "*", 
         RowBox[{"Cos", "[", "b0", "]"}]}], " ", "+", " ", "\n", "      ", 
        RowBox[{
         RowBox[{"s", "^", "2"}], "*", 
         RowBox[{"(", 
          RowBox[{"3", " ", "+", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", "*", "b0"}], "]"}]}], ")"}]}]}], ")"}], "^", "2"}]}],
     ")"}]}]}]], "Input",
 CellChangeTimes->{{3.59211724625698*^9, 3.5921172766458335`*^9}, {
  3.592986255894956*^9, 3.5929862946561728`*^9}, {3.598626094203747*^9, 
  3.598626148367042*^9}, {3.598626178724695*^9, 3.598626203481939*^9}, {
  3.6160652504320517`*^9, 3.6160652672800817`*^9}}],

Cell["\<\

The Gauss curvature is\
\>", "Text",
 CellChangeTimes->{{3.592119332557844*^9, 3.592119362213496*^9}, {
   3.592119393772352*^9, 3.592119503097344*^9}, 3.592119739437759*^9, 
   3.592218721320489*^9, {3.5986021506037292`*^9, 3.5986021927238035`*^9}, {
   3.5986027878960485`*^9, 3.598602866005386*^9}, {3.5986029141938705`*^9, 
   3.5986029316815014`*^9}, {3.6147508491900206`*^9, 
   3.6147508587060375`*^9}, {3.6159626497931795`*^9, 3.615962659792797*^9}, 
   3.6185809964063683`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fk", "[", 
  RowBox[{"b0", ",", "s"}], "]"}]], "Input",
 CellChangeTimes->{{3.598602341797665*^9, 3.5986023937769566`*^9}, {
  3.6159626946588583`*^9, 3.6159627225829077`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["8", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"4", "-", 
      RowBox[{"4", " ", 
       SqrtBox["2"], " ", "s", " ", 
       RowBox[{"Cos", "[", "b0", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["s", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "b0"}], "]"}]}], ")"}]}]}], ")"}], 
    "2"]]}]], "Output",
 CellChangeTimes->{
  3.5986024006877685`*^9, 3.598625858378133*^9, 3.6159627272941155`*^9, 
   3.616046466173362*^9, 3.616065284954912*^9, {3.618581016655204*^9, 
   3.618581023987217*^9}, 3.6186339733648977`*^9}]
}, Closed]],

Cell["It doesn\[CloseCurlyQuote]t depend on t, and it can\[CloseCurlyQuote]t \
be constant.", "Text",
 CellChangeTimes->{{3.5986029694803677`*^9, 3.598603022614061*^9}, 
   3.5986258329656878`*^9, {3.6160465113042407`*^9, 3.616046519353855*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"mhns", "[", 
    RowBox[{"b", ",", "s", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s", "\[Element]", "Reals"}], ",", 
     RowBox[{"b0", "\[Element]", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6162215392762575`*^9, 3.616221575873922*^9}, {
  3.616221623766006*^9, 3.616221657056464*^9}, {3.616221701032942*^9, 
  3.6162217109077587`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "32"}], " ", 
     SqrtBox["2"], " ", 
     RowBox[{"Sin", "[", "b0", "]"}]}], "-", 
    RowBox[{"2", " ", 
     SqrtBox["2"], " ", 
     SuperscriptBox["s", "4"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "b0"}], "]"}]}], ")"}], "2"], " ", 
     RowBox[{"Sin", "[", "b0", "]"}]}], "+", 
    RowBox[{"64", " ", "s", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "b0"}], "]"}]}], "-", 
    RowBox[{"8", " ", 
     SqrtBox["2"], " ", 
     SuperscriptBox["s", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"7", " ", 
        RowBox[{"Sin", "[", "b0", "]"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"3", " ", "b0"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"8", " ", 
     SuperscriptBox["s", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "b0"}], "]"}]}], "+", 
       RowBox[{"Sin", "[", 
        RowBox[{"4", " ", "b0"}], "]"}]}], ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"4", " ", 
    SqrtBox[
     RowBox[{"4", "-", 
      RowBox[{"4", " ", 
       SqrtBox["2"], " ", "s", " ", 
       RowBox[{"Cos", "[", "b0", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["s", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "b0"}], "]"}]}], ")"}]}]}]], " ", 
    RowBox[{"(", 
     RowBox[{"16", "-", 
      RowBox[{"32", " ", 
       SqrtBox["2"], " ", "s", " ", 
       RowBox[{"Cos", "[", "b0", "]"}]}], "-", 
      RowBox[{"8", " ", 
       SqrtBox["2"], " ", 
       SuperscriptBox["s", "3"], " ", 
       RowBox[{"Cos", "[", "b0", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "b0"}], "]"}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["s", "4"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "b0"}], "]"}]}], ")"}], "2"]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["s", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"5", "+", 
         RowBox[{"3", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "b0"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.616221578307526*^9, 3.6162217228885803`*^9, 
  3.6186339858137197`*^9}]
}, Closed]],

Cell["\<\
We use this result defining the mean curvature function which doesn\
\[CloseCurlyQuote]t depend on t also:\
\>", "Text",
 CellChangeTimes->{{3.6161590823363886`*^9, 3.616159138293687*^9}, {
  3.6185810940313396`*^9, 3.618581100661351*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fm", "[", 
   RowBox[{"b0_", ",", " ", "s_"}], "]"}], " ", ":=", " ", "\n", "  ", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"4", " ", "+", " ", 
         RowBox[{"3", "*", 
          RowBox[{"s", "^", "2"}]}], " ", "-", " ", "\n", "       ", 
         RowBox[{"4", "*", 
          RowBox[{"Sqrt", "[", "2", "]"}], "*", "s", "*", 
          RowBox[{"Cos", "[", "b0", "]"}]}], " ", "+", " ", "\n", "       ", 
         RowBox[{
          RowBox[{"s", "^", "2"}], "*", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", "*", "b0"}], "]"}]}]}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"3", "/", "2"}], ")"}]}], "*", "\n", "     ", 
      RowBox[{"Sin", "[", "b0", "]"}]}], ")"}]}], "/", 
   RowBox[{"(", 
    RowBox[{"32", " ", "+", " ", 
     RowBox[{"80", "*", 
      RowBox[{"s", "^", "2"}]}], " ", "+", " ", "\n", "    ", 
     RowBox[{"19", "*", 
      RowBox[{"s", "^", "4"}]}], " ", "-", " ", 
     RowBox[{"8", "*", 
      RowBox[{"Sqrt", "[", "2", "]"}], "*", "s", "*", "\n", "     ", 
      RowBox[{"(", 
       RowBox[{"8", " ", "+", " ", 
        RowBox[{"7", "*", 
         RowBox[{"s", "^", "2"}]}]}], ")"}], "*", 
      RowBox[{"Cos", "[", "b0", "]"}]}], " ", "+", " ", "\n", "    ", 
     RowBox[{"12", "*", 
      RowBox[{"s", "^", "2"}], "*", 
      RowBox[{"(", 
       RowBox[{"4", " ", "+", " ", 
        RowBox[{"s", "^", "2"}]}], ")"}], "*", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", "*", "b0"}], "]"}]}], " ", "-", " ", "\n", "    ", 
     RowBox[{"8", "*", 
      RowBox[{"Sqrt", "[", "2", "]"}], "*", 
      RowBox[{"s", "^", "3"}], "*", 
      RowBox[{"Cos", "[", 
       RowBox[{"3", "*", "b0"}], "]"}]}], " ", "+", " ", "\n", "    ", 
     RowBox[{
      RowBox[{"s", "^", "4"}], "*", 
      RowBox[{"Cos", "[", 
       RowBox[{"4", "*", "b0"}], "]"}]}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.6161589553053656`*^9, 3.616159015381071*^9}, 
   3.6161590480943284`*^9}],

Cell["\<\
The surface with b0=0 is the first Plot in this subsection. For its Gaussian \
curvature we have\
\>", "Text",
 CellChangeTimes->{{3.5921197057105*^9, 3.5921198127890882`*^9}, {
  3.598625877503766*^9, 3.5986258782369676`*^9}, {3.6160697888216105`*^9, 
  3.616069835157339*^9}, {3.616158909035684*^9, 3.6161589226701083`*^9}}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fk", "[", 
    RowBox[{"0", ",", "s"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", 
     RowBox[{"-", "1"}], ",", "4"}], "}"}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5921196132023373`*^9, 3.592119672810042*^9}}],

Cell["\<\
A special, maybe interesting case is the family of all developable normal \
surfaces of hel:\
\>", "Text",
 CellChangeTimes->{{3.5986762850007153`*^9, 3.5986763039079485`*^9}, 
   3.598677027328019*^9, 3.5986771789134855`*^9, {3.598677823038617*^9, 
   3.5986778833015223`*^9}, {3.59886097254364*^9, 3.598860974992844*^9}, {
   3.614750898345707*^9, 3.6147509051785192`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ghns", "[", 
  RowBox[{"a", ",", "s", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.61615919116218*^9, 3.616159199726595*^9}, {
  3.616159280550337*^9, 3.6161592986775684`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"8", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["a", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SqrtBox["2"], "+", 
         RowBox[{
          SuperscriptBox["a", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}], ")"}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"4", "-", 
      RowBox[{"4", " ", 
       SqrtBox["2"], " ", "s", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"a", "[", "t", "]"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["s", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", 
           RowBox[{"a", "[", "t", "]"}]}], "]"}], "+", 
         RowBox[{"4", " ", 
          RowBox[{
           SuperscriptBox["a", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["2"], "+", 
            RowBox[{
             SuperscriptBox["a", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}], 
        ")"}]}]}], ")"}], "2"]]}]], "Output",
 CellChangeTimes->{3.6161593005183716`*^9, 3.618634066731062*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "fk0", "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"fk0", "[", "c_", "]"}], "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "t"}], "/", 
     RowBox[{"Sqrt", "[", "2", "]"}]}], "+", "c"}]}]}]], "Input",
 CellChangeTimes->{{3.598676328337591*^9, 3.59867640139252*^9}, {
   3.598676511013912*^9, 3.59867654371157*^9}, {3.598676575691626*^9, 
   3.598676581198436*^9}, {3.5986770878561254`*^9, 3.5986771385718145`*^9}, {
   3.598677224200365*^9, 3.5986772442776003`*^9}, {3.616071675260008*^9, 
   3.6160716763052096`*^9}, {3.616071828385494*^9, 3.616071874281227*^9}, 
   3.616159812620471*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"helixnormalsf", "[", 
    RowBox[{"fk0", "[", "c", "]"}], "]"}], "[", 
   RowBox[{"s", ",", "t"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.598676883932567*^9, 3.5986769177222266`*^9}, {
   3.598677276569657*^9, 3.5986773082689123`*^9}, 3.5988610762526217`*^9, 
   3.616159430981401*^9, 3.616159797769245*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", 
        SqrtBox["2"]], "-", 
       RowBox[{"s", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"c", "-", 
          FractionBox["t", 
           SqrtBox["2"]]}], "]"}]}]}], ")"}]}], "+", 
    FractionBox[
     RowBox[{"s", " ", 
      RowBox[{"Sin", "[", "t", "]"}], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"c", "-", 
        FractionBox["t", 
         SqrtBox["2"]]}], "]"}]}], 
     SqrtBox["2"]]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", 
        SqrtBox["2"]], "-", 
       RowBox[{"s", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"c", "-", 
          FractionBox["t", 
           SqrtBox["2"]]}], "]"}]}]}], ")"}], " ", 
     RowBox[{"Sin", "[", "t", "]"}]}], "-", 
    FractionBox[
     RowBox[{"s", " ", 
      RowBox[{"Cos", "[", "t", "]"}], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"c", "-", 
        FractionBox["t", 
         SqrtBox["2"]]}], "]"}]}], 
     SqrtBox["2"]]}], ",", 
   FractionBox[
    RowBox[{"t", "+", 
     RowBox[{"s", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"c", "-", 
        FractionBox["t", 
         SqrtBox["2"]]}], "]"}]}]}], 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5986769205302315`*^9, {3.598677291935684*^9, 3.5986773115605183`*^9}, 
   3.5988611208687005`*^9, 3.6119983982873135`*^9, 3.6156254251763487`*^9, 
   3.616071770086829*^9, 3.616071908545501*^9, 3.6161598371905146`*^9, 
   3.6186344532997403`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"heli", ",", "%"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.598677532332106*^9, 3.5986775546713457`*^9}, {
   3.5986776447147036`*^9, 3.5986776520467167`*^9}, {3.618634556041521*^9, 
   3.6186345592863264`*^9}, 3.618634594339588*^9}],

Cell["\<\
The Gaussian curvature of all this surfaces  is zero : the surfaces are \
developable:\
\>", "Text",
 CellChangeTimes->{{3.616072449117479*^9, 3.616072467977912*^9}, {
  3.616072504020899*^9, 3.616072551661968*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"ghns", "[", 
   RowBox[{
    RowBox[{"fk0", "[", "c", "]"}], ",", "s", ",", "t"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.6160722148946133`*^9, {3.616072298680667*^9, 3.6160723061998796`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.616072088636921*^9, 3.616072216095815*^9, 
  3.616072315651765*^9, 3.616159864662163*^9, 3.618634636490862*^9}]
}, Closed]],

Cell["For the mean curvature of these surfaces we have", "Text",
 CellChangeTimes->{{3.59886124013091*^9, 3.59886125743134*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"meancurvature", "[", 
     RowBox[{"helixnormalsf", "[", 
      RowBox[{"fk0", "[", "c", "]"}], "]"}], "]"}], "[", 
    RowBox[{"s", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s", "\[Element]", "Reals"}], ",", 
     RowBox[{"t", "\[Element]", "Reals"}]}], "}"}], ",", 
   RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5986779104923706`*^9, 3.5986779394772215`*^9}, {
   3.598677970271675*^9, 3.5986780040613346`*^9}, {3.6160726003374195`*^9, 
   3.616072605889737*^9}, {3.616072647170162*^9, 3.616072666793285*^9}, 
   3.6160727074646707`*^9, {3.6160731100497913`*^9, 3.6160731278820205`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Simplify", "::", "time"}], "MessageName"], ":", 
  " ", "\<\"Time spent on a transformation exceeded \[NoBreak]\\!\\(300.`\\)\
\[NoBreak] seconds, and the transformation was aborted. Increasing the value \
of TimeConstraint option may improve the result of simplification. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Simplify/time\\\", \
ButtonNote -> \\\"Simplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.618634945480605*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Simplify", "::", "time"}], "MessageName"], ":", 
  " ", "\<\"Time spent on a transformation exceeded \[NoBreak]\\!\\(300.`\\)\
\[NoBreak] seconds, and the transformation was aborted. Increasing the value \
of TimeConstraint option may improve the result of simplification. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Simplify/time\\\", \
ButtonNote -> \\\"Simplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.618635245500332*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Simplify", "::", "time"}], "MessageName"], ":", 
  " ", "\<\"Time spent on a transformation exceeded \[NoBreak]\\!\\(300.`\\)\
\[NoBreak] seconds, and the transformation was aborted. Increasing the value \
of TimeConstraint option may improve the result of simplification. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Simplify/time\\\", \
ButtonNote -> \\\"Simplify::time\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.618635545535659*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], ":", 
  " ", "\<\"Further output of \[NoBreak]\\!\\(\\*StyleBox[\\(Simplify :: time\
\\), \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.618635545566859*^9}],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.5986780075089407`*^9, 3.598861639351211*^9, 
  3.611998461061904*^9, 3.615625463256016*^9, 3.6160725643099318`*^9, 
  3.616073100482244*^9, 3.6160773478242197`*^9, 3.6161300596311703`*^9, 
  3.6161599270778723`*^9, 3.6186358041685133`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"mhns", "[", 
    RowBox[{
     RowBox[{"fk0", "[", "c", "]"}], ",", "s", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c", "\[Element]", "Reals"}], ",", 
     RowBox[{"s", "\[Element]", "Reals"}], ",", 
     RowBox[{"t", "\[Element]", "Reals"}]}], "}"}], ",", 
   RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5986779104923706`*^9, 3.5986779394772215`*^9}, {
   3.598677970271675*^9, 3.5986780040613346`*^9}, {3.6160726003374195`*^9, 
   3.616072605889737*^9}, {3.616072647170162*^9, 3.616072666793285*^9}, 
   3.6160727074646707`*^9, {3.6160731100497913`*^9, 3.6160731278820205`*^9}, {
   3.616221919183725*^9, 3.6162219350801525`*^9}, 3.6162219703518143`*^9, {
   3.616222003455073*^9, 3.6162220106934853`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"Sin", "[", 
    RowBox[{"c", "-", 
     FractionBox["t", 
      SqrtBox["2"]]}], "]"}], 
   RowBox[{
    SqrtBox["2"], " ", 
    RowBox[{"Abs", "[", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      RowBox[{
       SqrtBox["2"], " ", "s", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"c", "-", 
         FractionBox["t", 
          SqrtBox["2"]]}], "]"}]}]}], "]"}]}]]}]], "Output",
 CellChangeTimes->{3.6162220238131084`*^9, 3.6186358356649685`*^9}]
}, Closed]],

Cell["\<\
OK. Since the surface is developable, the rulings are principal curves, and \
one of the principal curvatures is zero. We try\
\>", "Text",
 CellChangeTimes->{{3.6161300942944307`*^9, 3.616130123466482*^9}, {
   3.6161304561838665`*^9, 3.6161305562892427`*^9}, {3.616130841988144*^9, 
   3.616130849164157*^9}, {3.616160213541176*^9, 3.6161602280960007`*^9}, {
   3.6162220415191393`*^9, 3.616222045216346*^9}, 3.6174428205530376`*^9, 
   3.6186375284083414`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"cf", "[", 
      RowBox[{"2", ",", "2"}], "]"}], "[", 
     RowBox[{"helixnormalsf", "[", 
      RowBox[{"fk0", "[", "c", "]"}], "]"}], "]"}], "[", 
    RowBox[{"s", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s", "\[Element]", "Reals"}], ",", 
     RowBox[{"t", "\[Element]", "Reals"}], ",", " ", 
     RowBox[{"c", " ", "\[Element]", "Reals"}]}], "}"}], ",", 
   RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5986779104923706`*^9, 3.5986779394772215`*^9}, {
   3.598677970271675*^9, 3.5986780040613346`*^9}, {3.6160726003374195`*^9, 
   3.616072605889737*^9}, {3.616072647170162*^9, 3.616072666793285*^9}, 
   3.6160727074646707`*^9, {3.6160731100497913`*^9, 3.6160731278820205`*^9}, {
   3.6161308814562135`*^9, 3.6161309258850913`*^9}, 3.6179723903767023`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SqrtBox["2"], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"c", "-", 
      FractionBox["t", 
       SqrtBox["2"]]}], "]"}]}], 
   RowBox[{"Abs", "[", 
    RowBox[{
     RowBox[{"-", "2"}], "+", 
     RowBox[{
      SqrtBox["2"], " ", "s", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"c", "-", 
        FractionBox["t", 
         SqrtBox["2"]]}], "]"}]}]}], "]"}]]}]], "Output",
 CellChangeTimes->{3.61613588970461*^9, 3.616160283678899*^9, 
  3.616222114730068*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"%", "/", "2"}], "-", "%%"}], "\[IndentingNewLine]", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s", "\[Element]", "Reals"}], ",", 
     RowBox[{"t", "\[Element]", "Reals"}], ",", " ", 
     RowBox[{"c", " ", "\[Element]", "Reals"}]}], "}"}], ",", 
   RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.61616075102452*^9, 3.6161608727359333`*^9}, {
  3.6162228170433016`*^9, 3.6162228478065557`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6161608770727406`*^9}]
}, Closed]],

Cell["OK.", "Text",
 CellChangeTimes->{{3.616160897446377*^9, 3.6161609008627825`*^9}, 
   3.6186375347887526`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"prcurvatures", "[", 
     RowBox[{"helixnormalsf", "[", 
      RowBox[{"fk0", "[", "c", "]"}], "]"}], "]"}], "[", 
    RowBox[{"s", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s", "\[Element]", "Reals"}], ",", 
     RowBox[{"t", "\[Element]", "Reals"}], ",", " ", 
     RowBox[{"c", " ", "\[Element]", "Reals"}]}], "}"}], ",", 
   RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5986779104923706`*^9, 3.5986779394772215`*^9}, {
   3.598677970271675*^9, 3.5986780040613346`*^9}, {3.6160726003374195`*^9, 
   3.616072605889737*^9}, {3.616072647170162*^9, 3.616072666793285*^9}, 
   3.6160727074646707`*^9, {3.6160731100497913`*^9, 3.6160731278820205`*^9}, {
   3.6161308814562135`*^9, 3.6161309258850913`*^9}, {3.616135898284625*^9, 
   3.6161359165366573`*^9}, 3.616223198666772*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SqrtBox["2"], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"c", "-", 
        FractionBox["t", 
         SqrtBox["2"]]}], "]"}]}], 
     RowBox[{"Abs", "[", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{
        SqrtBox["2"], " ", "s", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"c", "-", 
          FractionBox["t", 
           SqrtBox["2"]]}], "]"}]}]}], "]"}]]}], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.616223244125252*^9}]
}, Closed]],

Cell["OK.", "Text",
 CellChangeTimes->{{3.6161382203643036`*^9, 3.6161382447939463`*^9}, {
   3.616161469499381*^9, 3.616161473227788*^9}, 3.6186375387199593`*^9}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.8. Surfaces of Revolution", "Subsection",
 CellChangeTimes->{{3.5922186227278495`*^9, 3.592218655535726*^9}, 
   3.5924598940730705`*^9, 3.611998625801326*^9, 3.6120759619398127`*^9, 
   3.616138350874133*^9, 3.616236325855336*^9}],

Cell["\<\
Any body produced on a lathe or a potter\[CloseCurlyQuote]s wheel is bordered \
by a surface of revolution. Such surfaces are not only easy to produce;  they \
may serve also as easy to handle examples in surface geometry. The reason is \
that the geometric properties of such a surface are defined by the properties \
of its generating curve, the profile curve or meridian of the surface. Thus \
two-dimensional problems for surfaces can be reduced to one-dimensional \
problems for curves, e.g. partial differential equations for surfaces  to \
ordinary differential equations for the meridians, which are much easier to \
solve. In this section we consider some of these applications.\
\>", "Text",
 CellChangeTimes->{{3.594271376925708*^9, 3.594271399649008*^9}, 
   3.594271494168414*^9, {3.5942716242798557`*^9, 3.594271650616362*^9}, 
   3.5942717013762655`*^9, {3.5942718587122645`*^9, 3.5942719851514964`*^9}, {
   3.5942721101926484`*^9, 3.594272209720341*^9}, {3.5942723600879416`*^9, 
   3.5942724882642727`*^9}, {3.594272641160018*^9, 3.5942727229756975`*^9}, {
   3.5942727668722086`*^9, 3.5942729100653987`*^9}, {3.594272942136233*^9, 
   3.5942729601122613`*^9}, {3.5942729958403044`*^9, 3.594273047392253*^9}, {
   3.5942747450093517`*^9, 3.5942747465524397`*^9}, 3.594274784344601*^9}],

Cell[CellGroupData[{

Cell["3.8.1. Definition and Fundamental Invariants", "Subsubsection",
 CellChangeTimes->{{3.5924599150863075`*^9, 3.5924599499211693`*^9}, 
   3.618637581542035*^9, 3.62048228513097*^9}],

Cell[TextData[{
 "Rotating a curve in the x,z-plane around the z-axis generates a ",
 StyleBox["surface of revolution",
  FontColor->RGBColor[0, 0, 1]],
 ". A parameter representation of a surface of revolution is"
}], "Text",
 CellChangeTimes->{{3.5922246929608603`*^9, 3.5922247958887477`*^9}, 
   3.618637861515727*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sfrev", "[", 
    RowBox[{"f_", ",", "h_"}], "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "u", "]"}], "*", 
     RowBox[{"Cos", "[", "v", "]"}]}], ",", 
    RowBox[{
     RowBox[{"f", "[", "u", "]"}], "*", 
     RowBox[{"Sin", "[", "v", "]"}]}], ",", " ", 
    RowBox[{"h", "[", "u", "]"}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5922251535142026`*^9, 3.5922251573054194`*^9}, {
  3.592225626315245*^9, 3.59222574073979*^9}, {3.5927415105422573`*^9, 
  3.592741513818263*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{"f", ",", "h"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.592226758859023*^9, 3.592226768058549*^9}, {
   3.5922268420587816`*^9, 3.59222685356244*^9}, {3.592227075467132*^9, 
   3.5922270836586003`*^9}, {3.592316504708578*^9, 3.592316515347797*^9}, 
   3.592741514426664*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", "v", "]"}], " ", 
    RowBox[{"f", "[", "u", "]"}]}], ",", 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"h", "[", "u", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.612072262393315*^9, 3.616234545143409*^9}]
}, Closed]],

Cell[TextData[{
 "The rotating curves v = const. are the ",
 StyleBox["meridians",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface of revolution, e.g."
}], "Text",
 CellChangeTimes->{{3.592455608074743*^9, 3.5924556618168373`*^9}, 
   3.5942709406726584`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sfrev", "[", 
    RowBox[{"f", ",", "h"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "/.", " ", 
  RowBox[{"v", "\[Rule]", " ", "0"}]}]], "Input",
 CellChangeTimes->{{3.592226758859023*^9, 3.592226768058549*^9}, {
   3.5922268420587816`*^9, 3.59222685356244*^9}, {3.592227075467132*^9, 
   3.5922270836586003`*^9}, {3.592316504708578*^9, 3.592316515347797*^9}, {
   3.592455691269689*^9, 3.592455708289319*^9}, 3.5927415323198953`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"f", "[", "u", "]"}], ",", "0", ",", 
   RowBox[{"h", "[", "u", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6120722981173773`*^9, 3.616234548762615*^9}]
}, Closed]],

Cell["The sphere and the torus are such surfaces", "Text",
 CellChangeTimes->{{3.5922271717606397`*^9, 3.592227193319873*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{"Cos", ",", "Sin"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.592226758859023*^9, 3.592226768058549*^9}, {
  3.5922268420587816`*^9, 3.59222685356244*^9}, {3.592227075467132*^9, 
  3.5922270836586003`*^9}, {3.612072328365831*^9, 3.6120723342938414`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", "u", "]"}], " ", 
    RowBox[{"Cos", "[", "v", "]"}]}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", "u", "]"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"Sin", "[", "u", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5922263743030276`*^9, 3.59222676929662*^9, 
  3.5922268569546337`*^9, 3.592227086244748*^9, 3.612072335339043*^9, 
  3.6162345841434774`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sphero", "[", "1", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5923061930991216`*^9, 3.592306214393159*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", "u", "]"}], " ", 
    RowBox[{"Cos", "[", "v", "]"}]}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", "v", "]"}], " ", 
    RowBox[{"Sin", "[", "u", "]"}]}], ",", 
   RowBox[{"Sin", "[", "v", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.59230620364474*^9, 3.5923062152043605`*^9}, 
   3.595660771867504*^9, 3.612072340299852*^9, 3.6162345901962876`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ftor", "[", "v_", "]"}], " ", ":=", 
   RowBox[{"3", "+", 
    RowBox[{"Cos", "[", "v", "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"htor", "[", "v_", "]"}], " ", ":=", " ", 
   RowBox[{"Sin", "[", "v", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5922272678111334`*^9, 3.592227311142612*^9}, {
   3.592227345322567*^9, 3.592227440772026*^9}, 3.5927415350966997`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "torus"}]], "Input",
 CellChangeTimes->{{3.5923062653272486`*^9, 3.592306284000481*^9}}],

Cell[BoxData[
 StyleBox["\<\"{u,v}->torus[a,b][u,v] is a parametrization of the torus \
formed by revolving a circle of radius b in the xz-plane about the z-axis \
along a circle of radius a in the xy-plane. {u,v}->torus[a,b,c][u,v] is a \
parametrization of the torus formed by revolving an ellipse with axes of \
lengths b and c in the xz-plane about the z-axis along a circle of radius a \
in the xy-plane. {u,v}->torus[a,b,b,d,d][u,v] is a surface formed by moving a \
circle of radius b in the xz-plane along an ellipse in the xy-plane. \
{u,v}->torus[a,b,c,d,e][u,v] is a surface formed by moving an ellipse in the \
xz-plane along an ellipse in the xy-plane.  To plot try \
torus[8,3][0,3Pi/2,-Pi,Pi].\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6162346327687626`*^9},
 CellTags->"Info3616241832-1704369"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{"ftor", ",", "htor"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{3.5927415501507263`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", "+", 
      RowBox[{"Cos", "[", "u", "]"}]}], ")"}], " ", 
    RowBox[{"Cos", "[", "v", "]"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", "+", 
      RowBox[{"Cos", "[", "u", "]"}]}], ")"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"Sin", "[", "u", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5923063411901817`*^9, 3.6120724089711723`*^9, 
  3.6162346716440306`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"torus", "[", 
   RowBox[{"3", ",", "1"}], "]"}], "[", 
  RowBox[{"v", ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.5923063610022163`*^9, 3.5923063772574453`*^9}, {
  3.612072444539235*^9, 3.6120724721980834`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", "+", 
      RowBox[{"Cos", "[", "u", "]"}]}], ")"}], " ", 
    RowBox[{"Cos", "[", "v", "]"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", "+", 
      RowBox[{"Cos", "[", "u", "]"}]}], ")"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"Sin", "[", "u", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.612072474241687*^9, 3.6162346888352613`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"torus", "[", 
    RowBox[{"8", ",", "3"}], "]"}], "[", 
   RowBox[{"0", ",", 
    RowBox[{"3", 
     RowBox[{"Pi", "/", "2"}]}], ",", 
    RowBox[{"-", "Pi"}], ",", "Pi"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"torus", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "[", 
    RowBox[{"v", ",", "u"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "Pi"}], ",", "Pi"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5922257630910683`*^9, 3.592225775968805*^9}, {
   3.592225989373011*^9, 3.5922259964974184`*^9}, {3.5922260927779255`*^9, 
   3.5922261304900827`*^9}, {3.5922261650030565`*^9, 
   3.5922261971228933`*^9}, {3.592226229242731*^9, 3.5922263441073008`*^9}, {
   3.592226740379966*^9, 3.592226750132524*^9}, {3.592226787731674*^9, 
   3.59222679937234*^9}, {3.59222687175648*^9, 3.592226888444435*^9}, {
   3.5922269726212497`*^9, 3.5922269743323474`*^9}, 3.5922270304075546`*^9, {
   3.5922271192936387`*^9, 3.5922271563647594`*^9}, {3.592227492203968*^9, 
   3.59222750168251*^9}, {3.5922275492762327`*^9, 3.592227574379668*^9}, {
   3.5922279260677834`*^9, 3.5922279324121466`*^9}, {3.5922280294676976`*^9, 
   3.5922280530840483`*^9}, 3.5923064930564485`*^9, {3.6120725609778395`*^9, 
   3.6120725888394885`*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{"ftor", ",", "htor"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "Pi"}], ",", "Pi"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5922257630910683`*^9, 3.592225775968805*^9}, {
   3.592225989373011*^9, 3.5922259964974184`*^9}, {3.5922260927779255`*^9, 
   3.5922261304900827`*^9}, {3.5922261650030565`*^9, 
   3.5922261971228933`*^9}, {3.592226229242731*^9, 3.5922263441073008`*^9}, {
   3.592226740379966*^9, 3.592226750132524*^9}, {3.592226787731674*^9, 
   3.59222679937234*^9}, {3.59222687175648*^9, 3.592226888444435*^9}, {
   3.5922269726212497`*^9, 3.5922269743323474`*^9}, 3.5922270304075546`*^9, {
   3.5922271192936387`*^9, 3.5922271563647594`*^9}, {3.592227492203968*^9, 
   3.59222750168251*^9}, {3.5922275492762327`*^9, 3.592227574379668*^9}, {
   3.5922279260677834`*^9, 3.5922279324121466`*^9}, {3.5922280294676976`*^9, 
   3.5922280530840483`*^9}, 3.5927415515391293`*^9}],

Cell["Example of rotating function graphs", "Text",
 CellChangeTimes->{{3.59427376520831*^9, 3.594273780472183*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"id", "[", "u_", "]"}], " ", ":=", " ", "u"}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5922276737623525`*^9, 3.5922277054741664`*^9}, {
  3.5942736968433995`*^9, 3.594273702465721*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{"Cos", ",", "id"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", "u", "]"}], " ", 
    RowBox[{"Cos", "[", "v", "]"}]}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", "u", "]"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", "u"}], "}"}]], "Output",
 CellChangeTimes->{3.5988825531838455`*^9, 3.6120732044165697`*^9, 
  3.616234759971386*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{"Cos", ",", "id"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"4", "*", 
      RowBox[{"Pi", "/", "2"}]}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5922257630910683`*^9, 3.592225775968805*^9}, {
   3.592225989373011*^9, 3.5922259964974184`*^9}, {3.5922260927779255`*^9, 
   3.5922261304900827`*^9}, {3.5922261650030565`*^9, 
   3.5922261971228933`*^9}, {3.592226229242731*^9, 3.5922263441073008`*^9}, {
   3.592226740379966*^9, 3.592226750132524*^9}, {3.592226787731674*^9, 
   3.59222679937234*^9}, {3.59222687175648*^9, 3.592226888444435*^9}, {
   3.5922269726212497`*^9, 3.5922269743323474`*^9}, 3.5922270304075546`*^9, {
   3.5922271192936387`*^9, 3.5922271563647594`*^9}, {3.592227492203968*^9, 
   3.59222750168251*^9}, {3.5922275492762327`*^9, 3.592227574379668*^9}, {
   3.592227739908136*^9, 3.5922277753561635`*^9}, {3.592228075636338*^9, 
   3.592228080619623*^9}, {3.5942731171882453`*^9, 3.594273179040783*^9}, {
   3.594273287980014*^9, 3.59427333423666*^9}, {3.5942733772041173`*^9, 
   3.5942733783931856`*^9}, {3.5942734515083675`*^9, 
   3.5942734539215055`*^9}, {3.594273661022351*^9, 3.594273673524066*^9}, {
   3.5942737331404757`*^9, 3.594273734280541*^9}, {3.594273822492586*^9, 
   3.594273824035675*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{"id", ",", "Sin"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"u", " ", 
    RowBox[{"Cos", "[", "v", "]"}]}], ",", 
   RowBox[{"u", " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"Sin", "[", "u", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.598882617502758*^9, 3.612073248159046*^9, 
  3.6162347996110554`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{"id", ",", "Sin"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"4", "*", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5922257630910683`*^9, 3.592225775968805*^9}, {
   3.592225989373011*^9, 3.5922259964974184`*^9}, {3.5922260927779255`*^9, 
   3.5922261304900827`*^9}, {3.5922261650030565`*^9, 
   3.5922261971228933`*^9}, {3.592226229242731*^9, 3.5922263441073008`*^9}, {
   3.592226740379966*^9, 3.592226750132524*^9}, {3.592226787731674*^9, 
   3.59222679937234*^9}, {3.59222687175648*^9, 3.592226888444435*^9}, {
   3.5922269726212497`*^9, 3.5922269743323474`*^9}, 3.5922270304075546`*^9, {
   3.5922271192936387`*^9, 3.5922271563647594`*^9}, {3.592227492203968*^9, 
   3.59222750168251*^9}, {3.5922275492762327`*^9, 3.592227574379668*^9}, {
   3.592227739908136*^9, 3.5922277753561635`*^9}, {3.592228075636338*^9, 
   3.592228080619623*^9}, {3.5942731171882453`*^9, 3.594273179040783*^9}, {
   3.594273287980014*^9, 3.59427333423666*^9}, {3.5942733772041173`*^9, 
   3.5942733783931856`*^9}, {3.5942734515083675`*^9, 3.594273490251583*^9}, {
   3.594273530348877*^9, 3.5942735469958286`*^9}}],

Cell["\<\
We return to the general surfaces of revolution. The intersections of the \
surface with the axis are singularities:\
\>", "Text",
 CellChangeTimes->{{3.592307003801346*^9, 3.592307178864853*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Cross", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "1", "]"}], "[", 
      RowBox[{"sfrev", "[", 
       RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "2", "]"}], "[", 
      RowBox[{"sfrev", "[", 
       RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.592307183295261*^9, 3.592307206632902*^9}, 
   3.5923114948741784`*^9, {3.5927415609927454`*^9, 3.592741561928747*^9}, 
   3.61760002546109*^9, 3.617600085817596*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Cos", "[", "v", "]"}]}], " ", 
    RowBox[{"f", "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["h", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"f", "[", "u", "]"}]}], " ", 
    RowBox[{"Sin", "[", "v", "]"}], " ", 
    RowBox[{
     SuperscriptBox["h", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}], ",", 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["f", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5988831545961013`*^9, 3.616234882104*^9}]
}, Closed]],

Cell["\<\
This vector vanishes for f[u] == 0. If f[u] \[NotEqual]0 the singularities of \
the surface are circles generated by rotating a singularity of the meridian. \
\>", "Text",
 CellChangeTimes->{{3.5988833745252876`*^9, 3.5988834041653395`*^9}, {
   3.5988834859718833`*^9, 3.5988836255765285`*^9}, 3.612073729544692*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "3", "]"}], "[", 
     RowBox[{"sfrev", "[", 
      RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", " ", "\[Element]", "Reals"}], ",", " ", 
     RowBox[{"v", "\[Element]", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5988828503643675`*^9, 3.5988829588157578`*^9}, 
   3.614861860314741*^9, 3.6149177921077614`*^9, 3.6155317601264367`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"Cos", "[", "v", "]"}], " ", 
      RowBox[{"f", "[", "u", "]"}], " ", 
      RowBox[{
       SuperscriptBox["h", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], 
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "u", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["f", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["h", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], "2"]}], ")"}]}]]]}], 
   ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], " ", 
      RowBox[{"Sin", "[", "v", "]"}], " ", 
      RowBox[{
       SuperscriptBox["h", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], 
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "u", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["f", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["h", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], "2"]}], ")"}]}]]]}], 
   ",", 
   FractionBox[
    RowBox[{
     RowBox[{"f", "[", "u", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}], 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "u", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["h", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}], ")"}]}]]]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.59888296028216*^9, 3.612073767671159*^9}]
}, Closed]],

Cell["This is the null vector iff", "Text",
 CellChangeTimes->{{3.5923116177555943`*^9, 3.59231164965765*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], "\[Equal]", " ", "0"}], ")"}], "  ", "||", 
  " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], "[", "u", "]"}], "\[Equal]", " ", "0"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"h", "'"}], "[", "u", "]"}], "\[Equal]", " ", "0"}], ")"}]}], 
   ")"}]}]], "Input",
 CellChangeTimes->{{3.592311665117277*^9, 3.592311835422776*^9}, 
   3.592741566343555*^9}],

Cell["\<\
We calculate general formulas for the fundamental invariants of the surfaces \
of revolution. To this aim we often assume that u is the arc length of the \
meridians v == const.\
\>", "Text",
 CellChangeTimes->{{3.592312523212384*^9, 3.5923126353141813`*^9}, {
  3.5924558966908503`*^9, 3.5924558969404507`*^9}, {3.618637873730548*^9, 
  3.6186378991117926`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fund1", "[", 
     RowBox[{"sfrev", "[", 
      RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.592293344680974*^9, 3.592293457656372*^9}, 
   3.5927415729891667`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["s2", "2"], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", "u", "]"}], "2"]}], "+", 
  RowBox[{
   SuperscriptBox["s1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["h", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], "2"]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.5983642465540533`*^9, 3.61207381958805*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "f", "]"}], "[", "u", 
       "]"}], "^", "2"}], " ", "+", " ", "\n", "    ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "h", "]"}], "[", "u", 
       "]"}], "^", "2"}]}], " ", "==", " ", "1"}], ",", " ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fund1", "[", 
       RowBox[{"sfrev", "[", 
        RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"s1", ",", "s2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5923126741270494`*^9, 3.592312682005063*^9}, {
   3.5927415848451877`*^9, 3.59274158606199*^9}, {3.614861860330341*^9, 
   3.614861860330341*^9}, {3.6149177921233616`*^9, 3.6149177921233616`*^9}, 
   3.6155317601744394`*^9, 3.616235037932674*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["s1", "2"], "+", 
  RowBox[{
   SuperscriptBox["s2", "2"], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", "u", "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{3.5923126831594653`*^9, 3.612073830445669*^9, 
  3.6162350954343753`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fund2", "[", 
     RowBox[{"sfrev", "[", 
      RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.592293344680974*^9, 3.592293492662834*^9}, 
   3.592741587465992*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["h", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["s2", "2"], " ", 
          RowBox[{"f", "[", "u", "]"}]}], "-", 
         RowBox[{
          SuperscriptBox["s1", "2"], " ", 
          RowBox[{
           SuperscriptBox["f", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["s1", "2"], " ", 
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["h", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], 
   SqrtBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"f", "[", "u", "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["h", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"]}], 
      ")"}]}]]]}]], "Output",
 CellChangeTimes->{3.5983643110133667`*^9, 3.6120738537365103`*^9, 
  3.6162351099892006`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", "1", "]"}], "[", "f", "]"}], "[", "u", 
         "]"}], "^", "2"}], " ", "+", " ", "\n", "    ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", "1", "]"}], "[", "h", "]"}], "[", "u", 
         "]"}], "^", "2"}]}], " ", "==", " ", "1"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], ">", "0"}], ")"}]}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fund2", "[", 
       RowBox[{"sfrev", "[", 
        RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"s1", ",", "s2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592293344680974*^9, 3.592293492662834*^9}, {
  3.592312753687189*^9, 3.5923127859948463`*^9}, {3.592741600554415*^9, 
  3.592741602722819*^9}, {3.612073960315897*^9, 3.612074035164829*^9}, {
  3.614861860330341*^9, 3.6148618603459406`*^9}, {3.614917792138962*^9, 
  3.614917792138962*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["h", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["s2", "2"]}], " ", 
      RowBox[{"f", "[", "u", "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["s1", "2"], " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], "-", 
  RowBox[{
   SuperscriptBox["s1", "2"], " ", 
   RowBox[{
    SuperscriptBox["f", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}], " ", 
   RowBox[{
    SuperscriptBox["h", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "u", "]"}]}]}]], "Output",
 CellChangeTimes->{3.5988837978008313`*^9, 3.612074039860437*^9, 
  3.616235119380417*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", "1", "]"}], "[", "f", "]"}], "[", "u", 
         "]"}], "^", "2"}], " ", "+", " ", "\n", "    ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", "1", "]"}], "[", "h", "]"}], "[", "u", 
         "]"}], "^", "2"}]}], " ", "==", " ", "1"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], ">", "0"}], ")"}]}], ",", " ", "\n", "  ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"cf", "[", 
       RowBox[{"1", ",", " ", "1"}], "]"}], "[", 
      RowBox[{"sfrev", "[", 
       RowBox[{"f", ",", " ", "h"}], "]"}], "]"}], "[", "\n", "    ", 
     RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592293344680974*^9, 3.592293492662834*^9}, {
   3.592293728987649*^9, 3.592293822790614*^9}, {3.5927416150780406`*^9, 
   3.5927416171528444`*^9}, {3.612074104850151*^9, 3.6120741149901686`*^9}, {
   3.6148618603459406`*^9, 3.6148618603459406`*^9}, {3.6149177921545615`*^9, 
   3.6149177921545615`*^9}, 3.617972391888789*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["h", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "u", "]"}]}], "-", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}], " ", 
   RowBox[{
    SuperscriptBox["h", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "u", "]"}]}]}]], "Output",
 CellChangeTimes->{3.598883902945016*^9, 3.612074127532591*^9, 
  3.61623514354486*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "f", "]"}], "[", "u", 
       "]"}], "^", "2"}], " ", "+", " ", "\n", "    ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "h", "]"}], "[", "u", 
       "]"}], "^", "2"}]}], " ", "==", " ", "1"}], ",", " ", "\n", "  ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"cf", "[", 
       RowBox[{"1", ",", " ", "2"}], "]"}], "[", 
      RowBox[{"sfrev", "[", 
       RowBox[{"f", ",", " ", "h"}], "]"}], "]"}], "[", "\n", "    ", 
     RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592293344680974*^9, 3.592293492662834*^9}, {
   3.592293728987649*^9, 3.592293822790614*^9}, {3.592293870589098*^9, 
   3.59229388912193*^9}, {3.5927416267468615`*^9, 3.5927416281196637`*^9}, {
   3.614861860361541*^9, 3.614861860361541*^9}, {3.6149177921701612`*^9, 
   3.6149177921701612`*^9}, 3.6179723934888806`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5922938977799454`*^9, 3.5988839990567846`*^9, 
  3.612074180900285*^9, 3.616235150705272*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", "1", "]"}], "[", "f", "]"}], "[", "u", 
         "]"}], "^", "2"}], " ", "+", " ", "\n", "    ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", "1", "]"}], "[", "h", "]"}], "[", "u", 
         "]"}], "^", "2"}]}], " ", "==", " ", "1"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], ">", "0"}], ")"}]}], ",", " ", "\n", "  ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"cf", "[", 
       RowBox[{"2", ",", " ", "2"}], "]"}], "[", 
      RowBox[{"sfrev", "[", 
       RowBox[{"f", ",", " ", "h"}], "]"}], "]"}], "[", "\n", "    ", 
     RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592293344680974*^9, 3.592293492662834*^9}, {
   3.592293728987649*^9, 3.592293822790614*^9}, {3.592293870589098*^9, 
   3.592293909916767*^9}, {3.592741633018072*^9, 3.5927416341256742`*^9}, {
   3.612074196281912*^9, 3.6120742080599327`*^9}, {3.614861860361541*^9, 
   3.614861860361541*^9}, {3.6149177921857615`*^9, 3.6149177921857615`*^9}, 
   3.61797239487296*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["h", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}], 
   RowBox[{"f", "[", "u", "]"}]]}]], "Output",
 CellChangeTimes->{3.5988840099300036`*^9, 3.6120742275599666`*^9, 
  3.616235157335284*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "f", "]"}], "[", "u", 
       "]"}], "^", "2"}], " ", "+", " ", "\n", "    ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "h", "]"}], "[", "u", 
       "]"}], "^", "2"}]}], " ", "==", " ", "1"}], ",", " ", "\n", "  ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"prcurvatures", "[", 
       RowBox[{"sfrev", "[", 
        RowBox[{"f", ",", " ", "h"}], "]"}], "]"}], "[", " ", 
      RowBox[{"u", ",", " ", "v"}], "]"}], ",", " ", 
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], ">", "0"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592293344680974*^9, 3.592293492662834*^9}, {
  3.592293728987649*^9, 3.592293822790614*^9}, {3.592293870589098*^9, 
  3.592293909916767*^9}, {3.5923129860183973`*^9, 3.592313012959645*^9}, {
  3.5923130719745483`*^9, 3.5923131018642006`*^9}, {3.592741640880486*^9, 
  3.5927416422688885`*^9}, {3.614861860377141*^9, 3.614861860377141*^9}, {
  3.6149177922013617`*^9, 3.6149177922013617`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["h", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}], 
     RowBox[{"f", "[", "u", "]"}]]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["h", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}], "-", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}], " ", 
     RowBox[{
      SuperscriptBox["h", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.598884291336688*^9, 3.6120742627536287`*^9, 
  3.616235381492078*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"prcurvatures", "[", 
    RowBox[{"sfrev", "[", 
     RowBox[{"f", ",", " ", "h"}], "]"}], "]"}], "[", " ", 
   RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.592315825904586*^9, 3.592315836169404*^9}, 
   3.592315870785865*^9, 3.592741650505703*^9, 3.5988843282017965`*^9, {
   3.612074334747755*^9, 3.612074353998189*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["h", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}], 
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "u", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["f", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["h", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], "2"]}], ")"}]}]]]}], 
   ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"f", "[", "u", "]"}], "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["h", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "-", 
       RowBox[{
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["h", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "u", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["f", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["h", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], "2"]}], ")"}]}], ")"}], 
     RowBox[{"3", "/", "2"}]]]}], "}"}]], "Output",
 CellChangeTimes->{3.5988843309699545`*^9, 3.6120742855608683`*^9, 
  3.6120743557921915`*^9, 3.6162354309597645`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "f", "]"}], "[", "u", 
       "]"}], "^", "2"}], " ", "+", " ", "\n", "    ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "h", "]"}], "[", "u", 
       "]"}], "^", "2"}]}], " ", "==", " ", "1"}], ",", " ", "\n", "  ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"gauss", "[", 
       RowBox[{"sfrev", "[", 
        RowBox[{"f", ",", " ", "h"}], "]"}], "]"}], "[", " ", 
      RowBox[{"u", ",", " ", "v"}], "]"}], ",", " ", 
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], ">", "0"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5923159480528*^9, 3.5923159491604023`*^9}, {
  3.592741687072167*^9, 3.5927416925009766`*^9}, {3.614861860392741*^9, 
  3.614861860392741*^9}, {3.614917792216962*^9, 3.614917792216962*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["h", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        SuperscriptBox["h", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], " ", 
      RowBox[{
       SuperscriptBox["h", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], 
  RowBox[{"f", "[", "u", "]"}]]], "Output",
 CellChangeTimes->{3.5988844117515755`*^9, 3.6162354540946054`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", " ", "\[Element]", "Reals"}], ",", " ", 
     RowBox[{"v", "\[Element]", "Reals"}]}], "}"}], ",", "\n", "  ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"gauss", "[", 
      RowBox[{"sfrev", "[", 
       RowBox[{"Cos", ",", " ", "Sin"}], "]"}], "]"}], "[", " ", 
     RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5923159480528*^9, 3.5923159491604023`*^9}, {
   3.592741687072167*^9, 3.5927416925009766`*^9}, 3.5988845224279056`*^9, 
   3.5988845565158553`*^9, {3.598884601500428*^9, 3.598884656618581*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.5988846589017115`*^9, 3.616235471769436*^9}]
}, Closed]],

Cell[TextData[{
 "This is the curvature of the unit sphere; the singularities u = \
\[PlusMinus] \[Pi]/2 of the parameter representation (not the surface!) are \
neglected by ",
 StyleBox["Mathematica.",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.598884719488177*^9, 3.5988849026396523`*^9}, {
   3.5988849344074697`*^9, 3.5988849347754908`*^9}, 3.5988849765198784`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "f", "]"}], "[", "u", 
       "]"}], "^", "2"}], " ", "+", " ", "\n", "    ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "h", "]"}], "[", "u", 
       "]"}], "^", "2"}]}], " ", "==", " ", "1"}], ",", " ", "\n", "  ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"meancurvature", "[", 
       RowBox[{"sfrev", "[", 
        RowBox[{"f", ",", " ", "h"}], "]"}], "]"}], "[", " ", 
      RowBox[{"u", ",", " ", "v"}], "]"}], ",", " ", 
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], ">", "0"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5923159480528*^9, 3.5923159491604023`*^9}, {
   3.5923161606031733`*^9, 3.5923161764528017`*^9}, {3.592741702859395*^9, 
   3.5927417040449967`*^9}, {3.614861860392741*^9, 3.6148618604083414`*^9}, 
   3.6148631366153827`*^9, {3.614917792232562*^9, 3.614917792232562*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{
       SuperscriptBox["h", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{
         RowBox[{"f", "[", "u", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], 
     RowBox[{"f", "[", "u", "]"}]], "-", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}], " ", 
     RowBox[{
      SuperscriptBox["h", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.612074595751813*^9, 3.6162355056994953`*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["The parameter curves u =const, resp. v= const. are the ",
  FontSlant->"Italic"],
 StyleBox["principal curves",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 ". For u= const the normal surfaces are circular cones, or cylinders if the \
tangent to the meridian at u is parallel to the  z-axis, or planes if the \
tangent at u to the meridian is parallel to the x,y-plane. They are planes \
containing the z-axis for the curves v = const."
}], "Text",
 CellChangeTimes->{{3.5923166334400043`*^9, 3.5923167850410705`*^9}, {
   3.592316831903553*^9, 3.592316919622507*^9}, {3.592316964098185*^9, 
   3.592317059741953*^9}, {3.598885239647928*^9, 3.5988852870966425`*^9}, 
   3.6162356507017508`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "f", "]"}], "[", "u", 
       "]"}], "^", "2"}], " ", "+", " ", "\n", "    ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "h", "]"}], "[", "u", 
       "]"}], "^", "2"}]}], " ", "==", " ", "1"}], ",", " ", "\n", "  ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", 
       RowBox[{"sfrev", "[", 
        RowBox[{"f", ",", " ", "h"}], "]"}], "]"}], "[", " ", 
      RowBox[{"u", ",", " ", "v"}], "]"}], ",", " ", 
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], ">", "0"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5923159480528*^9, 3.5923159491604023`*^9}, {
  3.5923161606031733`*^9, 3.5923161764528017`*^9}, {3.5923175406751976`*^9, 
  3.592317559504431*^9}, {3.5927417169150195`*^9, 3.592741717944621*^9}, {
  3.6148618604083414`*^9, 3.614861860423941*^9}, {3.614917792248162*^9, 
  3.614917792248162*^9}, {3.6162357121814585`*^9, 3.6162357144434624`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Cos", "[", "v", "]"}]}], " ", 
    RowBox[{
     SuperscriptBox["h", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Sin", "[", "v", "]"}]}], " ", 
    RowBox[{
     SuperscriptBox["h", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}], ",", 
   RowBox[{
    SuperscriptBox["f", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.598885322406662*^9, 3.6162356934926257`*^9, 
  3.616235729060688*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{"f", ",", " ", "h"}], "]"}], "[", " ", 
  RowBox[{"u", ",", " ", "v"}], "]"}]], "Input",
 CellChangeTimes->{3.616235837855279*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", "v", "]"}], " ", 
    RowBox[{"f", "[", "u", "]"}]}], ",", 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"h", "[", "u", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.616235839540082*^9}]
}, Closed]],

Cell["\<\
A parameter representation of the meridian in the x,z-plane is\
\>", "Text",
 CellChangeTimes->{{3.592318386851884*^9, 3.592318411250327*^9}, 
   3.5923192904366713`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"xx", "[", "u_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"f", "[", "u", "]"}], ",", 
     RowBox[{"h", "[", "u", "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5923177760796113`*^9, 3.592317802069257*^9}, 
   3.592741726399836*^9}],

Cell["\<\
We see that the normal vector of the surface coincides with the normal vector \
of the meridian. For the curvature k[u] of xx[u] we have\
\>", "Text",
 CellChangeTimes->{{3.592318436849972*^9, 3.5923184469743896`*^9}, {
   3.59231853820335*^9, 3.592318550979772*^9}, {3.592319354537184*^9, 
   3.592319416235292*^9}, 3.598454226766137*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "curvatures"}]], "Input",
 CellChangeTimes->{{3.5923178150952797`*^9, 3.59231782085169*^9}}],

Cell[BoxData[
 StyleBox["\<\"curvatures[curve][t] yields the n-1 curvatures of a generally \
curved \\ncurve[t] in the n-dimensional Euclidean space. Generally curved \
means that the \\nrank of the first n-1 derivatives of curve[t] must be n-1 \
at each point t.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6162358933601766`*^9},
 CellTags->"Info3616243093-1704369"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "f", "]"}], "[", "u", 
       "]"}], "^", "2"}], " ", "+", " ", "\n", "    ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "h", "]"}], "[", "u", 
       "]"}], "^", "2"}]}], " ", "==", " ", "1"}], ",", " ", "\n", "  ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"curvatures", "[", "xx", "]"}], "[", "u", "]"}], 
    "\[IndentingNewLine]", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5923159480528*^9, 3.5923159491604023`*^9}, {
   3.5923161606031733`*^9, 3.5923161764528017`*^9}, {3.5923175406751976`*^9, 
   3.592317559504431*^9}, {3.5923177112926974`*^9, 3.592317725878723*^9}, {
   3.5923178594149575`*^9, 3.592317965136343*^9}, 3.5927417433258657`*^9, {
   3.614861860423941*^9, 3.614861860439541*^9}, {3.614917792263762*^9, 
   3.614917792263762*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      SuperscriptBox["h", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}], " ", 
    RowBox[{
     SuperscriptBox["f", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["f", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["h", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.598365149391754*^9, 3.5983651808475533`*^9, {3.61207477014452*^9, 
   3.612074784668145*^9}, {3.6162359205822244`*^9, 3.6162359405034595`*^9}}]
}, Closed]],

Cell["\<\
It follows for the  principal curvature: k2 [u,v] == -k[u]. To obtain a \
geometric interpretation of the  principal curvature k1[u] = -h\
\[CloseCurlyQuote](u)/f(u) we set\
\>", "Text",
 CellChangeTimes->{{3.592318462059616*^9, 3.5923185135553064`*^9}, {
   3.5923197207946267`*^9, 3.592319804972375*^9}, {3.592457358429017*^9, 
   3.5924573688498354`*^9}, 3.5924574456175704`*^9, 3.592457476022024*^9, {
   3.59245750784608*^9, 3.592457516067294*^9}, 3.592741757755891*^9, 
   3.5988856176475487`*^9, {3.598885840976322*^9, 3.5988858679358644`*^9}, 
   3.6120752354153366`*^9, {3.612075287004627*^9, 3.612075303540656*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"f", "'"}], ",", 
    RowBox[{"h", "'"}]}], "}"}], " ", "\[Equal]", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Cos", "[", "\[Alpha]", "]"}], ",", " ", 
    RowBox[{"Sin", "[", "\[Alpha]", "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5923198184663982`*^9, 3.5923198916461267`*^9}, 
   3.5923199762294755`*^9, 3.5923201472057757`*^9, {3.5923201953474607`*^9, 
   3.592320207624682*^9}, 3.592741759237894*^9, {3.5984543124800396`*^9, 
   3.598454319863462*^9}}],

Cell["\<\
where \[Alpha] is the intersection angle of the tangent at xx[u] with the \
x-axis. For the normal curvature radius r1 = 1/k1 we obtain 
r1 = -f[u]/ Sin[\[Alpha]], and this equals the length of the normal segment \
from the point xx[u] to the z-axis with  appropriate sign.\
\>", "Text",
 CellChangeTimes->{{3.592319980987484*^9, 3.592320109001309*^9}, {
   3.5923201533209867`*^9, 3.5923201626030025`*^9}, {3.5923202265163155`*^9, 
   3.5923202504623575`*^9}, {3.5923203898999653`*^9, 3.5923204463161917`*^9}, 
   3.592320613900777*^9, {3.5924575738653955`*^9, 3.5924575840366135`*^9}, 
   3.5942749734884195`*^9, {3.612075640095648*^9, 3.6120756606876836`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"gauss", "[", 
   RowBox[{"sfrev", "[", 
    RowBox[{"g", ",", "h"}], "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6126851006025085`*^9, 3.612685155985676*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"g", "[", "u", "]"}], " ", 
     RowBox[{
      SuperscriptBox["h", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["h", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["g", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "-", 
       RowBox[{
        RowBox[{
         SuperscriptBox["g", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["h", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["g", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["h", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"]}], ")"}], " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"g", "[", "u", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["g", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["h", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], "2"]}], ")"}]}]], " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"g", "[", "u", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", "v", "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "v", "]"}], "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["g", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Sin", "[", "v", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["g", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["h", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], "2"]}], ")"}]}]]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.6126851574637604`*^9, 3.6162360778305006`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"g", "[", "u", "]"}], ">", "0"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["g", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["h", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"]}], "\[Equal]", 
      "1"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{"v", "\[Element]", " ", "Reals"}], ")"}]}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"gauss", "[", 
      RowBox[{"sfrev", "[", 
       RowBox[{"g", ",", "h"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6126853156718097`*^9, 3.612685489498752*^9}, 
   3.6126855397236247`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["h", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        SuperscriptBox["h", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], " ", 
      RowBox[{
       SuperscriptBox["g", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["g", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], " ", 
      RowBox[{
       SuperscriptBox["h", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], 
  RowBox[{"g", "[", "u", "]"}]]], "Output",
 CellChangeTimes->{3.6126854913008547`*^9, 3.6126855473460608`*^9, 
  3.6162361028217444`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"g", "[", "u", "]"}], ">", "0"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["g", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["h", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"]}], "\[Equal]", 
      "1"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{"v", "\[Element]", " ", "Reals"}], ")"}]}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"meancurvature", "[", 
      RowBox[{"sfrev", "[", 
       RowBox[{"g", ",", "h"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6126853156718097`*^9, 3.612685489498752*^9}, 
   3.6126855397236247`*^9, {3.612685581324004*^9, 3.6126856003970947`*^9}, 
   3.614861860439541*^9, 3.6148631366309824`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{
       SuperscriptBox["h", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{
         RowBox[{"g", "[", "u", "]"}], " ", 
         RowBox[{
          SuperscriptBox["g", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], 
     RowBox[{"g", "[", "u", "]"}]], "-", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}], " ", 
     RowBox[{
      SuperscriptBox["h", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.6126856051323657`*^9, 3.616236107423753*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.8.2. Minimal Surfaces of Revolution", "Subsubsection",
 CellChangeTimes->{{3.592460039870927*^9, 3.592460088511812*^9}, 
   3.612075971237429*^9, 3.6120777693766346`*^9, 3.6162363473209743`*^9, 
   3.616249192488927*^9}],

Cell[TextData[{
 "Now we ask: ",
 StyleBox["Do there exist minimal surfaces of revolution? ",
  FontColor->RGBColor[0, 0, 1]],
 " Locally we always can assume that the surface is obtained  rotating the \
graph f[z] of a function of the z coordinate."
}], "Text",
 CellChangeTimes->{{3.5923922154218073`*^9, 3.592392309933213*^9}, {
   3.5923923561738577`*^9, 3.592392418821441*^9}, {3.5923924792458973`*^9, 
   3.592392484629205*^9}, {3.5924037899994526`*^9, 3.5924038106956367`*^9}, {
   3.5924038678159037`*^9, 3.5924039006877837`*^9}, 3.616236447972351*^9},
 CellTags->"sfrev"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"??", "id"}]], "Input",
 CellChangeTimes->{{3.614336919250351*^9, 3.6143369213794727`*^9}}],

Cell[CellGroupData[{

Cell["Global`id", "Print", "PrintUsage",
 CellChangeTimes->{3.6143369243236413`*^9},
 CellTags->"Info3614344124-9136096"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {GridBox[{
       {
        RowBox[{
         RowBox[{"id", "[", "u_", "]"}], ":=", "u"}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[$CellContext`id],
  Editable->False]], "Print",
 CellChangeTimes->{3.614336924334642*^9},
 CellTags->"Info3614344124-9136096"]
}, Closed]]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sfr", "[", "f_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"sfrev", "[", 
    RowBox[{"f", ",", "id"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.592373484017357*^9, 3.5923736033263664`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sfr", "[", "f", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{3.6143369034754486`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", "v", "]"}], " ", 
    RowBox[{"f", "[", "u", "]"}]}], ",", 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", "u"}], "}"}]], "Output",
 CellChangeTimes->{3.6143369050985417`*^9, 3.6162366055482273`*^9}]
}, Closed]],

Cell["For the mean curvature we calculate", "Text",
 CellChangeTimes->{{3.5924039232400737`*^9, 3.592403949191558*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"meancurvature", "[", 
   RowBox[{"sfr", "[", "f", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5923736246204042`*^9, 3.5923736590028644`*^9}, 
   3.614861860455141*^9, 3.6148631366465826`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", 
         SqrtBox[
          RowBox[{"1", "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Sin", "[", "v", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "2"]}]}]]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["f", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"]}], 
         SqrtBox[
          RowBox[{"1", "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Sin", "[", "v", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "2"]}]}]]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"Sin", "[", "v", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["f", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"]}], 
         SqrtBox[
          RowBox[{"1", "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Sin", "[", "v", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "2"]}]}]]]}], ")"}],
       "/", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox[
         RowBox[{"1", "+", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["f", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"]}]], " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "u", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Cos", "[", "v", "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"Sin", "[", "v", "]"}], "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["f", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"Sin", "[", "v", "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["f", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}], "2"]}]}], 
           ")"}]}]]}], ")"}]}]}], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], 
     RowBox[{
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}]], " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "u", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["f", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"]}], ")"}]}]], " ", 
      SqrtBox[
       RowBox[{"1", "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["f", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Sin", "[", "v", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["f", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], "2"]}]}]]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.5923736815449038`*^9, {3.6120763861513577`*^9, 3.612076401673385*^9}, 
   3.6120944017300787`*^9, 3.6162366194166517`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Together", "[", "%", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5923737127917585`*^9, 3.5923737360513997`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"f", "[", "u", "]"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], 
  RowBox[{"2", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "u", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}], ")"}]}], ")"}], 
    RowBox[{"3", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{3.592373743024612*^9, 3.6120764103626003`*^9, 
  3.6120944018704786`*^9, 3.616236644127095*^9}]
}, Closed]],

Cell["\<\
To find the functions f for which the surface is minimal we have to solve the \
differential equation\
\>", "Text",
 CellChangeTimes->{{3.5924039805513515`*^9, 3.5924040254469194`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "-", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
      RowBox[{
       RowBox[{"f", "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["f", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], "\[Equal]", " ", 
     "0"}], "}"}], ",", " ", 
   RowBox[{"f", "[", "u", "]"}], ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.59237394119176*^9, 3.5923739467141695`*^9}, 
   3.592374104087246*^9, {3.592374137658505*^9, 3.5923741653017535`*^9}, {
   3.5923744127337885`*^9, 3.5923746021493206`*^9}, 3.5923746475922008`*^9, {
   3.5923746813506603`*^9, 3.5923747107879114`*^9}, 3.5923748965530376`*^9, 
   3.614861860455141*^9, 3.614864659895658*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"f", "[", "u", "]"}], "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"C", "[", "1", "]"}]]}], " ", "u"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"C", "[", "1", "]"}]}], "-", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"C", "[", "1", "]"}]], " ", 
         RowBox[{"C", "[", "2", "]"}]}]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", " ", 
          RowBox[{"C", "[", "1", "]"}]}]], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"C", "[", "1", "]"}]], " ", 
          RowBox[{"(", 
           RowBox[{"u", "+", 
            RowBox[{"C", "[", "2", "]"}]}], ")"}]}]]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"f", "[", "u", "]"}], "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"C", "[", "1", "]"}]]}], " ", "u"}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"C", "[", "1", "]"}]}], "-", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"C", "[", "1", "]"}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}]}]], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"C", "[", "1", "]"}]], " ", "u"}], "+", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"C", "[", "1", "]"}]], " ", 
           RowBox[{"C", "[", "2", "]"}]}]}]]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.5923741687961597`*^9, 3.592374612726139*^9, 3.5923746525062094`*^9, {
   3.5923746839870644`*^9, 3.592374713829917*^9}, 3.592374906708656*^9, 
   3.5923750934097834`*^9, 3.5924577010992193`*^9, 3.6120764560394807`*^9, 
   3.6120944022448797`*^9, 3.616236687822772*^9}]
}, Closed]],

Cell["The two solutions are", "Text",
 CellChangeTimes->{{3.5924040563586874`*^9, 3.5924040733436594`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f1", "[", "u_", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], "/.", 
    RowBox[{"%", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"f2", "[", "u_", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], "/.", 
    RowBox[{"%", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.5923749685003643`*^9, 3.592375012102441*^9}, {
  3.592375074783351*^9, 3.592375088948176*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"C", "[", "1", "]"}]]}], " ", "u"}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"C", "[", "1", "]"}]}], "-", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"C", "[", "1", "]"}]], " ", 
       RowBox[{"C", "[", "2", "]"}]}]}]], "+", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"C", "[", "1", "]"}]], " ", "u"}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"C", "[", "1", "]"}]], " ", 
       RowBox[{"C", "[", "2", "]"}]}]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.592375016298848*^9, 3.5923750981677923`*^9, 
  3.592457706481229*^9, 3.612076491451543*^9, 3.6120944022916794`*^9, 
  3.6162367780533304`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fcc", "[", "u_", "]"}], "=", " ", 
  RowBox[{
   RowBox[{"f1", "[", "u", "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"C", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"C", "[", "2", "]"}], "\[Rule]", "0"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.5923757214668865`*^9, 3.59237579740782*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"-", "u"}]], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"2", " ", "u"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.5923758009334264`*^9, 3.5924577227832575`*^9, 
  3.61207658650251*^9, 3.6120944023072796`*^9, 3.616236787007746*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", "\[Equal]", 
   RowBox[{"Cosh", "[", "u", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592375859355529*^9, 3.592375867186743*^9}, {
  3.5924577623917265`*^9, 3.5924577724225445`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.592375872865153*^9, 3.5924577743413477`*^9, 
  3.612076590511717*^9, 3.6120944023384795`*^9, 3.616236796430163*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fcd", "[", "u_", "]"}], "=", " ", 
  RowBox[{
   RowBox[{"f2", "[", "u", "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"C", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"C", "[", "2", "]"}], "\[Rule]", "0"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.5923759386972685`*^9, 3.592375946450482*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", "u"}]], "+", 
    SuperscriptBox["\[ExponentialE]", "u"]}], ")"}]}]], "Output",
 CellChangeTimes->{3.5923759478856845`*^9, 3.59245781557222*^9, 
  3.6120766001681337`*^9, 3.6120944023540792`*^9, 3.6162368009853706`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"fcc", "[", "u", "]"}], "\[Equal]", 
   RowBox[{"fcd", "[", "u", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5923759852009497`*^9, 3.592376005075385*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5923760066041875`*^9, 3.6120766084205484`*^9, 
  3.6120944023852797`*^9, 3.6162368071161814`*^9}]
}, Closed]],

Cell[TextData[{
 "The curve y = a*Cosh[u/a+c] is named a ",
 ButtonBox["catenary",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/Catenary.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/Catenary.html"],
 ", and the corresponding surface of revolution is a ",
 StyleBox["catenoid",
  FontColor->RGBColor[0, 0, 1]],
 "."
}], "Text",
 CellChangeTimes->{{3.592403369800419*^9, 3.592403375974772*^9}, {
   3.592403409599695*^9, 3.5924034140069475`*^9}, 3.59240355794518*^9, {
   3.592403598175481*^9, 3.5924036565918226`*^9}, 3.592403704551565*^9, {
   3.592404230990676*^9, 3.5924042309966764`*^9}, 3.592404299751609*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "catenoid"}]], "Input",
 CellChangeTimes->{{3.61623708531147*^9, 3.6162371066523075`*^9}}],

Cell[BoxData[
 StyleBox["\<\"{u,v}->catenoid[a][u,v] is the minimal surface of revolution \
generated by t->catenary[a][t].  To plot try catenoid[1][0,3Pi/2,-1.5,1.5].\"\
\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6162371083371105`*^9},
 CellTags->"Info3616244308-7460579"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"catenoid", "[", "1", "]"}], "[", 
  RowBox[{"0", ",", " ", 
   RowBox[{"3", "*", 
    RowBox[{"Pi", "/", "2"}]}], ",", 
   RowBox[{"-", "1.5"}], ",", "1.5"}], "]"}]], "Input",
 CellChangeTimes->{{3.6162371338275557`*^9, 3.61623721036129*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfr", "[", "Cosh", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592376018163808*^9, 3.592376106974764*^9}}],

Cell["All the catenary functions solve the differential equation :", "Text",
 CellChangeTimes->{{3.592406210985925*^9, 3.5924062689602413`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fch", "[", 
    RowBox[{"a_", ",", "c_"}], "]"}], "[", "u_", "]"}], " ", "=", " ", 
  RowBox[{"a", "*", 
   RowBox[{"Cosh", "[", 
    RowBox[{
     RowBox[{"u", "/", "a"}], "+", "c"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5924063384082136`*^9, 3.592406369394986*^9}}],

Cell[BoxData[
 RowBox[{"a", " ", 
  RowBox[{"Cosh", "[", 
   RowBox[{"c", "+", 
    FractionBox["u", "a"]}], "]"}]}]], "Output",
 CellChangeTimes->{3.5924063711780877`*^9, 3.5924579263324146`*^9, 
  3.6120766825206785`*^9, 3.61209440252568*^9, 3.616237266287388*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "1"}], "-", " ", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fch", "[", 
         RowBox[{"a", ",", "c"}], "]"}], "[", "u", "]"}], ",", "u"}], "]"}], 
     "^", "2"}], " ", "+", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"fch", "[", 
       RowBox[{"a", ",", "c"}], "]"}], "[", "u", "]"}], "*", " ", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fch", "[", 
         RowBox[{"a", ",", "c"}], "]"}], "[", "u", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"u", ",", "2"}], "}"}]}], "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"a", ">", "0"}], ",", 
     RowBox[{"c", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5924058117980933`*^9, 3.5924058226167116`*^9}, {
  3.5924059291928077`*^9, 3.5924061164775195`*^9}, {3.592406313278776*^9, 
  3.5924063256014805`*^9}, {3.592406455974938*^9, 3.5924065108300753`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.592406524963884*^9, 3.6120766883862886`*^9, 
  3.61209440254128*^9, 3.6162372821370163`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"meancurvature", "[", 
     RowBox[{"sfr", "[", 
      RowBox[{"fch", "[", 
       RowBox[{"a", ",", "c"}], "]"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", 
     RowBox[{"c", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{"u", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5923761453976316`*^9, 3.5923762008245287`*^9}, {
   3.592406400466763*^9, 3.592406406930133*^9}, {3.6120767595224133`*^9, 
   3.6120767901920676`*^9}, {3.612076855306582*^9, 3.612076902091064*^9}, 
   3.614861860501941*^9, 3.6148631366465826`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.592376211401347*^9, 3.5924064124374475`*^9, 
  3.5924065297791595`*^9, 3.6120766945483*^9, 3.612076927331908*^9, 
  3.6120944044288836`*^9, 3.6162372943050375`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", 
     RowBox[{"sfr", "[", 
      RowBox[{"fch", "[", 
       RowBox[{"a", ",", "c"}], "]"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", 
     RowBox[{"c", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{"u", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5923761453976316`*^9, 3.5923762008245287`*^9}, {
   3.5923763196031375`*^9, 3.5923763375119686`*^9}, 3.5924065540515475`*^9, {
   3.6120769821348047`*^9, 3.6120769963620296`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   SuperscriptBox[
    RowBox[{"Sech", "[", 
     RowBox[{"c", "+", 
      FractionBox["u", "a"]}], "]"}], "4"], 
   SuperscriptBox["a", "2"]]}]], "Output",
 CellChangeTimes->{3.592376451532569*^9, 3.592376542418329*^9, 
  3.59240657331765*^9, 3.5924066881172156`*^9, 3.612076959171564*^9, 
  3.612076999560035*^9, 3.612094404756484*^9, 3.6162373029318523`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"c", "\[Rule]", "0"}], ",", 
      RowBox[{"a", "\[Rule]", "1"}]}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592376419677313*^9, 3.592376439489348*^9}, {
  3.592376495290646*^9, 3.592376538362322*^9}, {3.5924066466428432`*^9, 
  3.592406682546897*^9}}],

Cell["\<\
Now we consider the first solution family depending on the integration \
constants C[1], C[2]\
\>", "Text",
 CellChangeTimes->{{3.5924067279284925`*^9, 3.5924067953433485`*^9}, 
   3.6162455668285513`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fc", "[", 
    RowBox[{"c1_", ",", "c2_"}], "]"}], "[", "u_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"f1", "[", "u", "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"C", "[", "1", "]"}], "\[Rule]", "c1"}], ",", 
     RowBox[{
      RowBox[{"C", "[", "2", "]"}], "\[Rule]", "c2"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.5923766072208424`*^9, 3.5923766754709625`*^9}, {
  3.592376706561817*^9, 3.592376714455431*^9}, {3.5923767748899374`*^9, 
  3.5923767911919656`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fc", "[", 
   RowBox[{"0", ",", "0"}], "]"}], "[", "u", "]"}]], "Input",
 CellChangeTimes->{{3.5923767197594404`*^9, 3.592376729462657*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"-", "u"}]], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"2", " ", "u"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.592376732551463*^9, 3.592376797853177*^9, 
  3.612077048778122*^9, 3.6120944048500843`*^9, 3.616245585147599*^9}]
}, Closed]],

Cell["\<\
We want to show that all solutions are catenoids; for c1=c2=0 we have fc[0,0] \
= Cosh[u]. Insert arbitrary values for c1,c2 in the next cell and plot the \
corresponding surfaces:\
\>", "Text",
 CellChangeTimes->{{3.5924044154162245`*^9, 3.592404454479459*^9}, {
   3.592404494679758*^9, 3.5924046417831717`*^9}, 3.592406810392209*^9, {
   3.6186381829491167`*^9, 3.6186382067574778`*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfr", "[", 
     RowBox[{"fc", "[", 
      RowBox[{"1", ",", ".1"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592376018163808*^9, 3.592376106974764*^9}, {
   3.5923768369936457`*^9, 3.592376917848588*^9}, 3.592376962090266*^9, {
   3.592381577598248*^9, 3.592381672414671*^9}, {3.5923817308470135`*^9, 
   3.5923817497980976`*^9}, {3.592381785999168*^9, 3.59238179215052*^9}, {
   3.592381892599265*^9, 3.592381938686901*^9}}],

Cell["All these surfaces are minimal:", "Text",
 CellChangeTimes->{{3.59240467654416*^9, 3.592404687135766*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Together", "[", 
   RowBox[{
    RowBox[{"meancurvature", "[", 
     RowBox[{"sfr", "[", 
      RowBox[{"fc", "[", 
       RowBox[{"c1", ",", "c2"}], "]"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{
  3.5923770400280027`*^9, {3.592402645102968*^9, 3.592402685762294*^9}, {
   3.6120771413018847`*^9, 3.6120771477446957`*^9}, 3.614861860517541*^9, 
   3.614863136662183*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.592377144922587*^9, 3.592402678647887*^9, 
  3.5924027271456614`*^9, 3.6120771157958393`*^9, 3.612077158742715*^9, 
  3.6120944153801026`*^9, 3.6162456489922504`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfr", "[", "Cosh", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592376018163808*^9, 3.592376106974764*^9}, {
  3.5923778949095044`*^9, 3.592377901227515*^9}}],

Cell["", "Text"],

Cell["\<\
To show that any function fc[c1,c2][u] is a catenary we consider the function \
\>", "Text",
 CellChangeTimes->{{3.592406927479906*^9, 3.5924069740795717`*^9}, {
  3.5924070154639387`*^9, 3.592407048239814*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ff", "[", "u", "]"}], " ", "=", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"a", "*", 
     RowBox[{"Cosh", "[", 
      RowBox[{
       RowBox[{"u", "/", "a"}], "+", "c"}], "]"}]}], " ", "-", " ", 
    RowBox[{
     RowBox[{"fc", "[", 
      RowBox[{"c1", ",", "c2"}], "]"}], "[", "u", "]"}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.5924070587674155`*^9, 3.5924070657398143`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "c1"}], "-", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", "c1"]}], "-", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "c1"], " ", "u"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "c1"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", "c1"], " ", 
       RowBox[{"(", 
        RowBox[{"c2", "+", "u"}], ")"}]}]]}], ")"}]}], "+", 
  RowBox[{"a", " ", 
   RowBox[{"Cosh", "[", 
    RowBox[{"c", "+", 
     FractionBox["u", "a"]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.6120772307992415`*^9, 3.6120944154893026`*^9, 
  3.616245678958965*^9}]
}, Closed]],

Cell["\<\
and solve the necessary condition expressed in the equations  {ff[0] == 0,ff\
\[CloseCurlyQuote][0] == 0} for the unknowns a>0, c. If such a solution exist \
then the function fc[c1,c2] [u] equals fch[a,c][u], since both function solve \
the differental equation with the same integration constants c1,c2. \
\>", "Text",
 CellChangeTimes->{{3.59240708559795*^9, 3.592407252647505*^9}, {
   3.5924072923117733`*^9, 3.592407416431873*^9}, 3.6162457001251755`*^9, 
   3.618638246605757*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"a", "*", 
     RowBox[{"Cosh", "[", 
      RowBox[{
       RowBox[{"u", "/", "a"}], "+", "c"}], "]"}]}], " ", "-", " ", 
    RowBox[{
     RowBox[{"fc", "[", 
      RowBox[{"c1", ",", "c2"}], "]"}], "[", "u", "]"}]}], ")"}], "/.", 
  RowBox[{"u", "\[Rule]", " ", "0"}]}]], "Input",
 CellChangeTimes->{3.592391432480026*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "c1"}], "-", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", "c1"]}]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "c1"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "c2", " ", 
       SuperscriptBox["\[ExponentialE]", "c1"]}]]}], ")"}]}], "+", 
  RowBox[{"a", " ", 
   RowBox[{"Cosh", "[", "c", "]"}]}]}]], "Output",
 CellChangeTimes->{3.5923914403414755`*^9, 3.612077277568124*^9, 
  3.612094415520503*^9, 3.616245730755927*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c1", "\[Element]", "Reals"}], ",", 
     RowBox[{"c2", "\[Element]", "Reals"}], ",", 
     RowBox[{"a", "\[Element]", "Reals"}], ",", 
     RowBox[{"c", "\[Element]", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592391170736055*^9, 3.5923913059287877`*^9}, {
  3.5923913602958975`*^9, 3.592391377799898*^9}, {3.5923914969207115`*^9, 
  3.5923915113365364`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", " ", 
   RowBox[{"Cosh", "[", "c", "]"}]}], "+", 
  RowBox[{
   RowBox[{"Cosh", "[", 
    RowBox[{"c1", "-", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Cosh", "[", "c1", "]"}]}], "+", 
     RowBox[{"Sinh", "[", "c1", "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.592391524593294*^9, 3.612077296537757*^9, 
  3.6120944159105034`*^9, 3.6162457499530253`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", "*", 
       RowBox[{"Cosh", "[", 
        RowBox[{
         RowBox[{"u", "/", "a"}], "+", "c"}], "]"}]}], " ", "-", " ", 
      RowBox[{
       RowBox[{"fc", "[", 
        RowBox[{"c1", ",", "c2"}], "]"}], "[", "u", "]"}]}], ")"}], ",", 
    "u"}], "]"}], "/.", 
  RowBox[{"u", "\[Rule]", " ", "0"}]}]], "Input",
 CellChangeTimes->{{3.5923910346082687`*^9, 3.5923910392705355`*^9}, {
  3.5923910704973216`*^9, 3.5923911040812426`*^9}, {3.5923911540981035`*^9, 
  3.592391157953324*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "c1"}], "+", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", "c1"]}]}]]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "c1"}], "-", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", "c1"]}]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "c1"}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "c2", " ", 
       SuperscriptBox["\[ExponentialE]", "c1"]}]]}], ")"}]}], "+", 
  RowBox[{"Sinh", "[", "c", "]"}]}]], "Output",
 CellChangeTimes->{3.5923911605864744`*^9, 3.592402935436575*^9, 
  3.6120773104529815`*^9, 3.612094415941704*^9, 3.616245772365307*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c1", "\[Element]", "Reals"}], ",", 
     RowBox[{"c", "\[Element]", "Reals"}], ",", 
     RowBox[{"c2", "\[Element]", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592391170736055*^9, 3.5923913059287877`*^9}, {
  3.5923913602958975`*^9, 3.592391377799898*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Sinh", "[", "c", "]"}], "+", 
  RowBox[{"Sinh", "[", 
   RowBox[{"c1", "-", 
    RowBox[{"c2", " ", 
     SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}]}]], "Output",
 CellChangeTimes->{3.592391379125974*^9, 3.5924029789880657`*^9, 
  3.61207731542939*^9, 3.612094416160104*^9, 3.6162457859300833`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"a", " ", 
        RowBox[{"Cosh", "[", "c", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Cosh", "[", 
         RowBox[{"c1", "-", 
          RowBox[{"c2", " ", 
           SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Cosh", "[", "c1", "]"}]}], "+", 
          RowBox[{"Sinh", "[", "c1", "]"}]}], ")"}]}]}], "\[Equal]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Sinh", "[", "c", "]"}], "+", 
       RowBox[{"Sinh", "[", 
        RowBox[{"c1", "-", 
         RowBox[{"c2", " ", 
          SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}]}], "\[Equal]", 
      "0"}], ",", 
     RowBox[{"a", ">", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "c"}], "}"}], ",", " ", "Reals"}], "]"}]], "Input",
 CellChangeTimes->{{3.5923790170437927`*^9, 3.5923791509614525`*^9}, {
   3.5923822007118883`*^9, 3.5923822065432215`*^9}, {3.5923905062420483`*^9, 
   3.5923905404490047`*^9}, {3.592391583304652*^9, 3.5923915990655537`*^9}, {
   3.5923916412429667`*^9, 3.5923916766269903`*^9}, {3.592404722684799*^9, 
   3.592404773292694*^9}, 3.614861860533141*^9, 3.614917792341762*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"Cosh", "[", 
      RowBox[{"c1", "-", 
       RowBox[{"c2", " ", 
        SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], "<", "0"}], "&&", 
    RowBox[{
     RowBox[{"Sinh", "[", "c1", "]"}], ">", 
     RowBox[{"Cosh", "[", "c1", "]"}]}], "&&", 
    RowBox[{"a", "\[Equal]", 
     SqrtBox[
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cosh", "[", 
          RowBox[{"c1", "-", 
           RowBox[{"c2", " ", 
            SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Cosh", "[", "c1", "]"}]}], "+", 
           RowBox[{"Sinh", "[", "c1", "]"}]}], ")"}], "2"]}], 
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{"Sinh", "[", 
          RowBox[{"c1", "-", 
           RowBox[{"c2", " ", 
            SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], "2"]}]]]}], "&&", 
    RowBox[{"c", "\[Equal]", 
     RowBox[{"Log", "[", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Sinh", "[", 
         RowBox[{"c1", "-", 
          RowBox[{"c2", " ", 
           SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}]}], "+", 
       SqrtBox[
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"Sinh", "[", 
           RowBox[{"c1", "-", 
            RowBox[{"c2", " ", 
             SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], "2"]}]]}], 
      "]"}]}]}], ")"}], "||", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"Cosh", "[", 
      RowBox[{"c1", "-", 
       RowBox[{"c2", " ", 
        SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], ">", "0"}], "&&", 
    RowBox[{
     RowBox[{"Sinh", "[", "c1", "]"}], "<", 
     RowBox[{"Cosh", "[", "c1", "]"}]}], "&&", 
    RowBox[{"a", "\[Equal]", 
     SqrtBox[
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cosh", "[", 
          RowBox[{"c1", "-", 
           RowBox[{"c2", " ", 
            SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Cosh", "[", "c1", "]"}]}], "+", 
           RowBox[{"Sinh", "[", "c1", "]"}]}], ")"}], "2"]}], 
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{"Sinh", "[", 
          RowBox[{"c1", "-", 
           RowBox[{"c2", " ", 
            SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], "2"]}]]]}], "&&", 
    RowBox[{"c", "\[Equal]", 
     RowBox[{"Log", "[", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Sinh", "[", 
         RowBox[{"c1", "-", 
          RowBox[{"c2", " ", 
           SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}]}], "+", 
       SqrtBox[
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"Sinh", "[", 
           RowBox[{"c1", "-", 
            RowBox[{"c2", " ", 
             SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], "2"]}]]}], 
      "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.5924047827772365`*^9, 3.612077340763835*^9, 
  3.612094416300504*^9, 3.616245844059408*^9}]
}, Closed]],

Cell["\<\
For any real values c1,  c2  only the second case is possible and we see that \
for any such pair we find  numbers a, c  with fc[c1,c2][u] == a*Cosh[u/a + c].\
\>", "Text",
 CellChangeTimes->{{3.5924050900318103`*^9, 3.592405155695566*^9}, {
   3.592405412983282*^9, 3.592405454815675*^9}, {3.592405556992519*^9, 
   3.592405591679503*^9}, {3.5924056395522413`*^9, 3.5924058092159452`*^9}, 
   3.5924074485357094`*^9, 3.592459559078082*^9, {3.612077504922923*^9, 
   3.612077507044527*^9}}],

Cell["\<\
Now we show with the same argumentation that also the second solution f2[u]  \
is a catenary for all values of c1,c2:\
\>", "Text",
 CellChangeTimes->{{3.5924595963153477`*^9, 3.5924596781998916`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fd", "[", 
    RowBox[{"c1_", ",", "c2_"}], "]"}], "[", "u_", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"f2", "[", "u", "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"C", "[", "1", "]"}], "\[Rule]", "c1"}], ",", 
     RowBox[{
      RowBox[{"C", "[", "2", "]"}], "\[Rule]", "c2"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.5923766072208424`*^9, 3.5923766754709625`*^9}, {
  3.592376706561817*^9, 3.592376714455431*^9}, {3.5923767748899374`*^9, 
  3.5923767911919656`*^9}, {3.5924580355170064`*^9, 3.592458056904644*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "c1"}], "-", 
      RowBox[{"c2", " ", 
       SuperscriptBox["\[ExponentialE]", "c1"]}], "-", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "c1"], " ", "u"}]}]], "+", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"c2", " ", 
       SuperscriptBox["\[ExponentialE]", "c1"]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "c1"], " ", "u"}]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.592458058558247*^9, 3.6120775259049597`*^9, 
  3.6120944163161044`*^9, 3.616246171699148*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fd", "[", 
   RowBox[{"0", ",", "0"}], "]"}], "[", "u", "]"}]], "Input",
 CellChangeTimes->{{3.5923767197594404`*^9, 3.592376729462657*^9}, 
   3.5924580763734784`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", "u"}]], "+", 
    SuperscriptBox["\[ExponentialE]", "u"]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.592376732551463*^9, 3.592376797853177*^9, {3.5924580668886614`*^9, 
   3.5924580773562803`*^9}, 3.612077530179367*^9, 3.6120944163473043`*^9, 
   3.616246183414818*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Together", "[", 
   RowBox[{
    RowBox[{"meancurvature", "[", 
     RowBox[{"sfr", "[", 
      RowBox[{"fd", "[", 
       RowBox[{"c1", ",", "c2"}], "]"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{
  3.5923770400280027`*^9, {3.592402645102968*^9, 3.592402685762294*^9}, 
   3.592458198490493*^9, {3.6120775588834176`*^9, 3.612077567744233*^9}, 
   3.6148618605487413`*^9, 3.614863136677783*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5924582084277105`*^9, 3.5924583139930954`*^9, 
  3.6120775782118516`*^9, 3.61209442525492*^9, 3.6162462052780685`*^9}]
}, Closed]],

Cell["\<\
To show that any function fd[c1,c2][u] is a catenary we consider the function \
\>", "Text",
 CellChangeTimes->{{3.592406927479906*^9, 3.5924069740795717`*^9}, {
   3.5924070154639387`*^9, 3.592407048239814*^9}, 3.592458346971554*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ff", "[", "u_", "]"}], " ", ":=", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"a", "*", 
     RowBox[{"Cosh", "[", 
      RowBox[{
       RowBox[{"u", "/", "a"}], "+", "c"}], "]"}]}], " ", "-", " ", 
    RowBox[{
     RowBox[{"fd", "[", 
      RowBox[{"c1", ",", "c2"}], "]"}], "[", "u", "]"}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.5924070587674155`*^9, 3.5924070657398143`*^9}, 
   3.592458381556814*^9, {3.616246614320464*^9, 3.616246623488989*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ff", "[", "u", "]"}]], "Input",
 CellChangeTimes->{{3.6162466290293055`*^9, 3.616246632518505*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "c1"}], "-", 
        RowBox[{"c2", " ", 
         SuperscriptBox["\[ExponentialE]", "c1"]}], "-", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", "c1"], " ", "u"}]}]]}], "-", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"c2", " ", 
        SuperscriptBox["\[ExponentialE]", "c1"]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "c1"], " ", "u"}]}]]}], ")"}]}], 
  "+", 
  RowBox[{"a", " ", 
   RowBox[{"Cosh", "[", 
    RowBox[{"c", "+", 
     FractionBox["u", "a"]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.6162466338525815`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"a", "*", 
     RowBox[{"Cosh", "[", 
      RowBox[{
       RowBox[{"u", "/", "a"}], "+", "c"}], "]"}]}], " ", "-", " ", 
    RowBox[{
     RowBox[{"fd", "[", 
      RowBox[{"c1", ",", "c2"}], "]"}], "[", "u", "]"}]}], ")"}], "/.", 
  RowBox[{"u", "\[Rule]", " ", "0"}]}]], "Input",
 CellChangeTimes->{3.592391432480026*^9, 3.59245841888768*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"c2", " ", 
        SuperscriptBox["\[ExponentialE]", "c1"]}]]}], "-", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "c1"}], "-", 
       RowBox[{"c2", " ", 
        SuperscriptBox["\[ExponentialE]", "c1"]}]}]]}], ")"}]}], "+", 
  RowBox[{"a", " ", 
   RowBox[{"Cosh", "[", "c", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.5924583930228343`*^9, 3.5924584198080816`*^9}, 
   3.6120776054339*^9, 3.61209442533292*^9, 3.616246215502653*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c1", "\[Element]", "Reals"}], ",", 
     RowBox[{"c2", "\[Element]", "Reals"}], ",", 
     RowBox[{"a", "\[Element]", "Reals"}], ",", 
     RowBox[{"c", "\[Element]", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592391170736055*^9, 3.5923913059287877`*^9}, {
  3.5923913602958975`*^9, 3.592391377799898*^9}, {3.5923914969207115`*^9, 
  3.5923915113365364`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", " ", 
   RowBox[{"Cosh", "[", "c", "]"}]}], "+", 
  RowBox[{
   RowBox[{"Cosh", "[", 
    RowBox[{"c1", "+", 
     RowBox[{"c2", " ", 
      SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Cosh", "[", "c1", "]"}]}], "+", 
     RowBox[{"Sinh", "[", "c1", "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.592458434472107*^9, 3.612077614934316*^9, 
  3.6120944256605206`*^9, 3.616246234863761*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", "*", 
       RowBox[{"Cosh", "[", 
        RowBox[{
         RowBox[{"u", "/", "a"}], "+", "c"}], "]"}]}], " ", "-", " ", 
      RowBox[{
       RowBox[{"fd", "[", 
        RowBox[{"c1", ",", "c2"}], "]"}], "[", "u", "]"}]}], ")"}], ",", 
    "u"}], "]"}], "/.", 
  RowBox[{"u", "\[Rule]", " ", "0"}]}]], "Input",
 CellChangeTimes->{{3.5923910346082687`*^9, 3.5923910392705355`*^9}, {
   3.5923910704973216`*^9, 3.5923911040812426`*^9}, {3.5923911540981035`*^9, 
   3.592391157953324*^9}, 3.5924584526617393`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "c1"}], "-", 
       RowBox[{"c2", " ", 
        SuperscriptBox["\[ExponentialE]", "c1"]}]}]], "-", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"c1", "+", 
       RowBox[{"c2", " ", 
        SuperscriptBox["\[ExponentialE]", "c1"]}]}]]}], ")"}]}], "+", 
  RowBox[{"Sinh", "[", "c", "]"}]}]], "Output",
 CellChangeTimes->{3.5924584597129517`*^9, 3.6120776219699287`*^9, 
  3.612094425691721*^9, 3.616246241583145*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c1", "\[Element]", "Reals"}], ",", 
     RowBox[{"c", "\[Element]", "Reals"}], ",", 
     RowBox[{"c2", "\[Element]", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592391170736055*^9, 3.5923913059287877`*^9}, {
  3.5923913602958975`*^9, 3.592391377799898*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Sinh", "[", "c", "]"}], "-", 
  RowBox[{"Sinh", "[", 
   RowBox[{"c1", "+", 
    RowBox[{"c2", " ", 
     SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}]}]], "Output",
 CellChangeTimes->{3.5924584699309697`*^9, 3.6120776290679407`*^9, 
  3.612094425925721*^9, 3.616246248052515*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"a", " ", 
        RowBox[{"Cosh", "[", "c", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Cosh", "[", 
         RowBox[{"c1", "+", 
          RowBox[{"c2", " ", 
           SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Cosh", "[", "c1", "]"}]}], "+", 
          RowBox[{"Sinh", "[", "c1", "]"}]}], ")"}]}]}], "\[Equal]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Sinh", "[", "c", "]"}], "-", 
       RowBox[{"Sinh", "[", 
        RowBox[{"c1", "+", 
         RowBox[{"c2", " ", 
          SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}]}], "\[Equal]", 
      "0"}], ",", 
     RowBox[{"a", ">", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "c"}], "}"}], ",", " ", "Reals"}], "]"}]], "Input",
 CellChangeTimes->{{3.5923790170437927`*^9, 3.5923791509614525`*^9}, {
   3.5923822007118883`*^9, 3.5923822065432215`*^9}, {3.5923905062420483`*^9, 
   3.5923905404490047`*^9}, {3.592391583304652*^9, 3.5923915990655537`*^9}, {
   3.5923916412429667`*^9, 3.5923916766269903`*^9}, {3.592404722684799*^9, 
   3.592404773292694*^9}, 3.5924585256698675`*^9, 3.592459458551506*^9, 
   3.6148618605643415`*^9, 3.614917792357362*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"Cosh", "[", 
      RowBox[{"c1", "+", 
       RowBox[{"c2", " ", 
        SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], "<", "0"}], "&&", 
    RowBox[{
     RowBox[{"Sinh", "[", "c1", "]"}], ">", 
     RowBox[{"Cosh", "[", "c1", "]"}]}], "&&", 
    RowBox[{"a", "\[Equal]", 
     SqrtBox[
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cosh", "[", 
          RowBox[{"c1", "+", 
           RowBox[{"c2", " ", 
            SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Cosh", "[", "c1", "]"}]}], "+", 
           RowBox[{"Sinh", "[", "c1", "]"}]}], ")"}], "2"]}], 
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{"Sinh", "[", 
          RowBox[{"c1", "+", 
           RowBox[{"c2", " ", 
            SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], "2"]}]]]}], "&&", 
    RowBox[{"c", "\[Equal]", 
     RowBox[{"Log", "[", 
      RowBox[{
       RowBox[{"Sinh", "[", 
        RowBox[{"c1", "+", 
         RowBox[{"c2", " ", 
          SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], "+", 
       SqrtBox[
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"Sinh", "[", 
           RowBox[{"c1", "+", 
            RowBox[{"c2", " ", 
             SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], "2"]}]]}], 
      "]"}]}]}], ")"}], "||", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"Cosh", "[", 
      RowBox[{"c1", "+", 
       RowBox[{"c2", " ", 
        SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], ">", "0"}], "&&", 
    RowBox[{
     RowBox[{"Sinh", "[", "c1", "]"}], "<", 
     RowBox[{"Cosh", "[", "c1", "]"}]}], "&&", 
    RowBox[{"a", "\[Equal]", 
     SqrtBox[
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cosh", "[", 
          RowBox[{"c1", "+", 
           RowBox[{"c2", " ", 
            SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Cosh", "[", "c1", "]"}]}], "+", 
           RowBox[{"Sinh", "[", "c1", "]"}]}], ")"}], "2"]}], 
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{"Sinh", "[", 
          RowBox[{"c1", "+", 
           RowBox[{"c2", " ", 
            SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], "2"]}]]]}], "&&", 
    RowBox[{"c", "\[Equal]", 
     RowBox[{"Log", "[", 
      RowBox[{
       RowBox[{"Sinh", "[", 
        RowBox[{"c1", "+", 
         RowBox[{"c2", " ", 
          SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], "+", 
       SqrtBox[
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"Sinh", "[", 
           RowBox[{"c1", "+", 
            RowBox[{"c2", " ", 
             SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], "2"]}]]}], 
      "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.5924594735587325`*^9, 3.6120776419379635`*^9, 
  3.612094425988121*^9, 3.6162462894068804`*^9}]
}, Closed]],

Cell["\<\
Only the second solution is possible. We test the equality of the functions  \
inserting the solution:\
\>", "Text",
 CellChangeTimes->{{3.616249053796994*^9, 3.616249127372203*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ff", "[", "u", "]"}], "/.", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"a", "\[Rule]", 
       SqrtBox[
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cosh", "[", 
            RowBox[{"c1", "+", 
             RowBox[{"c2", " ", 
              SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"Cosh", "[", "c1", "]"}]}], "+", 
             RowBox[{"Sinh", "[", "c1", "]"}]}], ")"}], "2"]}], 
         RowBox[{"1", "+", 
          SuperscriptBox[
           RowBox[{"Sinh", "[", 
            RowBox[{"c1", "+", 
             RowBox[{"c2", " ", 
              SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], "2"]}]]]}], 
      ",", " ", 
      RowBox[{"c", "->", 
       RowBox[{"Log", "[", 
        RowBox[{
         RowBox[{"Sinh", "[", 
          RowBox[{"c1", "+", 
           RowBox[{"c2", " ", 
            SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], "+", 
         SqrtBox[
          RowBox[{"1", "+", 
           SuperscriptBox[
            RowBox[{"Sinh", "[", 
             RowBox[{"c1", "+", 
              RowBox[{"c2", " ", 
               SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], "2"]}]]}], 
        "]"}]}]}], "}"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c1", "\[Element]", "Reals"}], ",", 
     RowBox[{"c2", "\[Element]", "Reals"}], ",", 
     RowBox[{"u", "\[Element]", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6162481074598675`*^9, 3.616248243639656*^9}, {
   3.6162483164488206`*^9, 3.6162483288805313`*^9}, 3.616248579127845*^9, 
   3.6162486162949705`*^9, {3.6162486790345592`*^9, 3.616248707883209*^9}, 
   3.61624882958317*^9, 3.6162489019123073`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.61624833165569*^9, 3.6162487300204754`*^9, 
  3.6162489082436695`*^9}]
}, Closed]],

Cell[TextData[{
 "Thus we proved\n",
 StyleBox["Proposition",
  FontColor->RGBColor[0, 0, 1]],
 ". The only minimal surfaces of revolution are the catenoids, generated \
rotating catenaries.."
}], "Text",
 CellChangeTimes->{{3.5924597361539936`*^9, 3.592459803031311*^9}, {
  3.5924601472459154`*^9, 3.592460166199949*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["3.8.3. Surfaces of Revolution of Constant Gaussian Curvature", \
"Subsubsection",
 CellChangeTimes->{{3.5930088090318155`*^9, 3.593008813228223*^9}, {
   3.5934178586395583`*^9, 3.593417908497246*^9}, 3.6120777755369873`*^9, 
   3.612159908316609*^9, 3.61624922015751*^9, 3.616656611139438*^9}],

Cell["\<\
We assume that the surface of revolution is generated by the graph of a \
function f\
\>", "Text",
 CellChangeTimes->{{3.5934179940789967`*^9, 3.5934181363824463`*^9}, {
   3.593418242759033*^9, 3.593418244974237*^9}, 3.616301755428102*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{"id", ",", "f"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{3.5934182656442733`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"u", " ", 
    RowBox[{"Cos", "[", "v", "]"}]}], ",", 
   RowBox[{"u", " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"f", "[", "u", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5934182674850764`*^9, 3.61209011510775*^9, 
  3.6127570751829166`*^9, 3.61630178254095*^9}]
}, Closed]],

Cell["Its Gaussian curvature is", "Text",
 CellChangeTimes->{{3.59341829782713*^9, 3.5934183065475454`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"gauss", "[", 
    RowBox[{"sfrev", "[", 
     RowBox[{"id", ",", "f"}], "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.593008824007842*^9, 3.59300892540802*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["f", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "u", "]"}]}], 
  RowBox[{"u", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "2"]}], ")"}], 
    "2"]}]]], "Output",
 CellChangeTimes->{3.593008929822828*^9, 3.593322652756812*^9, 
  3.612090125512968*^9, 3.6127570758789563`*^9, 3.616301867748299*^9}]
}, Closed]],

Cell["\<\
Changing the order of the functions the Gaussian curvature is \
\>", "Text",
 CellChangeTimes->{{3.61647409352219*^9, 3.6164741247139745`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"gauss", "[", 
    RowBox[{"sfrev", "[", 
     RowBox[{"f", ",", "id"}], "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6164741576198564`*^9, 3.6164741655013075`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["f", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "u", "]"}], 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"]}], ")"}], 
     "2"]}]]}]], "Output",
 CellChangeTimes->{3.616474167181403*^9}]
}, Closed]],

Cell["\<\
If  f\.b4[u] = 0 then f[u] = u0 = const, and the surface is a plane\
\>", "Text",
 CellChangeTimes->{{3.616473593105568*^9, 3.616473629433646*^9}, {
   3.616473662185519*^9, 3.6164736992976418`*^9}, {3.616474248058029*^9, 
   3.6164742561944942`*^9}, 3.616487116010995*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fc", "[", "u_", "]"}], " ", "=", "1"}], ";", " ", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sfrev", "[", 
      RowBox[{"id", ",", "fc"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "0", ",", "2"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6164737205658584`*^9, 3.616473838821622*^9}}],

Cell["\<\
Changing the order of the arguments in sfrev, we obtain a circular cylinder:\
\>", "Text",
 CellChangeTimes->{{3.6164871579953957`*^9, 3.616487213555574*^9}, 
   3.6186383414936686`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fc", "[", "u_", "]"}], " ", "=", "1"}], ";", " ", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sfrev", "[", 
      RowBox[{"fc", ",", " ", "id"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "0", ",", "2"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6164737205658584`*^9, 3.616473838821622*^9}, {
  3.616474059494244*^9, 3.616474067365694*^9}}],

Cell[BoxData[
 RowBox[{"Clear", "[", "fc", "]"}]], "Input",
 CellChangeTimes->{{3.6164742984839134`*^9, 3.616474307804446*^9}}],

Cell["\<\
 If k =0, the differential equation in both cases reduces to f\.b4\.b4 [u] = \
0, which has the general solution\
\>", "Text",
 CellChangeTimes->{{3.616474377681443*^9, 3.6164744774261484`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fl", "[", "u_", "]"}], " ", ":=", " ", 
  RowBox[{"u0", " ", "+", 
   RowBox[{"u", "*", "c0"}]}]}]], "Input",
 CellChangeTimes->{{3.6164744983583455`*^9, 3.616474559035816*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"gauss", "[", 
   RowBox[{"sfrev", "[", 
    RowBox[{"id", ",", "fl"}], "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.616474586925411*^9, 3.6164746220444202`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6164746234154987`*^9}]
}, Closed]],

Cell["\<\
which yields  besides of the already mentioned developable surfaces  the \
circular cones; e.g. \
\>", "Text",
 CellChangeTimes->{{3.6164746434736457`*^9, 3.616474751481823*^9}, {
  3.6164872703158207`*^9, 3.6164873153713975`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fl", "[", "u_", "]"}], " ", "=", 
   RowBox[{"3", "*", "u"}]}], ";", " ", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sfrev", "[", 
      RowBox[{"id", ",", "fl"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", 
      RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6164737205658584`*^9, 3.616473838821622*^9}, {
  3.616474059494244*^9, 3.616474067365694*^9}, {3.6164747940862603`*^9, 
  3.616474876637982*^9}}],

Cell[BoxData[
 RowBox[{"Clear", "[", "fl", "]"}]], "Input",
 CellChangeTimes->{{3.6164873522455063`*^9, 3.6164873624790916`*^9}}],

Cell["Assuming k \[NotEqual]0 we define the curvature differential \
operator:", "Text",
 CellChangeTimes->{{3.616328440589955*^9, 3.6163284701016426`*^9}, {
   3.61632880241465*^9, 3.6163288045097694`*^9}, {3.616473145681977*^9, 
   3.6164732661538677`*^9}, 3.6164873978281136`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"diff", "[", 
    RowBox[{"f_", ",", "k_"}], "]"}], "[", "u_", "]"}], " ", ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "''"}], "[", "u", "]"}], "-", 
   RowBox[{"k", "*", " ", "u", "*", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{
          RowBox[{"f", "'"}], "[", "u", "]"}], "^", "2"}]}], ")"}], "^", 
      "2"}], "/", 
     RowBox[{
      RowBox[{"f", "'"}], "[", "u", "]"}]}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6163268268226523`*^9, 3.6163268268246527`*^9}, {
  3.616327879928887*^9, 3.616327923097356*^9}}],

Cell["\<\
Its kernel defines the meridians generating surfaces of revolution with \
constant curvature k:\
\>", "Text",
 CellChangeTimes->{{3.61632851358313*^9, 3.616328569550331*^9}, {
  3.616328825054945*^9, 3.6163288317103257`*^9}, {3.6164877106670074`*^9, 
  3.6164877260268855`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"diff", "[", 
        RowBox[{"f", ",", "k"}], "]"}], "[", "u", "]"}], "\[Equal]", " ", 
      "0"}], ",", 
     RowBox[{
      RowBox[{"f", "[", "u0", "]"}], " ", "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], "[", "u0", "]"}], "\[Equal]", " ", "c0"}]}], "}"}],
    ",", " ", 
   RowBox[{"f", "[", "u", "]"}], ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.593009068101471*^9, 3.5930091129671497`*^9}, {
   3.5930091433872027`*^9, 3.593009245723383*^9}, {3.593009299044276*^9, 
   3.593009307530691*^9}, 3.6148618605643415`*^9, 3.6148646599112577`*^9, 
   3.6163941993331203`*^9, {3.6163942501580095`*^9, 3.6163942809992633`*^9}, {
   3.616394314960523*^9, 3.6163943961430655`*^9}, {3.6164733180838375`*^9, 
   3.616473429445207*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Solve", "::", "useq"}], "MessageName"], ":", 
  " ", "\<\"The answer found by Solve contains equational condition(s) \
\[NoBreak]\\!\\({0 \[Equal] \\(\\(\\(\\(\\(\\(-c0\\)\\)\\\\ \\@\\(-\\(\\(1\\/\
\\(Plus[\\(\\(\[LeftSkeleton] 2 \[RightSkeleton]\\)\\)]\\)\\)\\)\\)\\)\\) - \
\\@\\(-\\(\\(c0\\^2\\/\\(Plus[\\(\\(\[LeftSkeleton] 2 \[RightSkeleton]\\)\\)]\
\\)\\)\\)\\)\\)\\)}\\)\[NoBreak]. A likely reason for this is that the \
solution set depends on branch cuts of Mathematica functions. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/Solve\\\", ButtonNote -> \
\\\"Solve::useq\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.6164734088920317`*^9, 3.6164734321493616`*^9}, 
   3.616487546651626*^9, 3.6164896330369606`*^9, 3.616494785245022*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Solve", "::", "useq"}], "MessageName"], ":", 
  " ", "\<\"The answer found by Solve contains equational condition(s) \
\[NoBreak]\\!\\({0 \[Equal] \\(\\(\\(\\(c0\\\\ \
\\@\\(-\\(\\(1\\/\\(Plus[\\(\\(\[LeftSkeleton] 2 \
\[RightSkeleton]\\)\\)]\\)\\)\\)\\)\\)\\) - \\@\\(-\\(\\(c0\\^2\\/\\(Plus[\\(\
\\(\[LeftSkeleton] 2 \[RightSkeleton]\\)\\)]\\)\\)\\)\\)\\)\\)}\\)\[NoBreak]. \
A likely reason for this is that the solution set depends on branch cuts of \
Mathematica functions. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/Solve\\\", ButtonNote -> \\\"Solve::useq\\\"]\\)\"\
\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.6164734088920317`*^9, 3.6164734321493616`*^9}, 
   3.616487546651626*^9, 3.6164896330369606`*^9, 3.616494785619422*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"f", "[", "u", "]"}], "\[Rule]", 
     RowBox[{"ConditionalExpression", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["c0", "2"]}], " ", 
           SqrtBox[
            RowBox[{"-", 
             FractionBox["1", 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}]]}]], " ", 
           SqrtBox[
            FractionBox[
             RowBox[{"1", "-", 
              RowBox[{"k", " ", 
               SuperscriptBox["u", "2"]}], "-", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u", "2"]}], "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}], 
             RowBox[{"1", "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}]]], " ", 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["c0", "2"]}], "-", 
              RowBox[{"k", " ", 
               SuperscriptBox["u", "2"]}], "-", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u", "2"]}], "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}], 
             RowBox[{"1", "+", 
              SuperscriptBox["c0", "2"]}]]], " ", 
           RowBox[{"EllipticE", "[", 
            RowBox[{
             RowBox[{"ArcSin", "[", 
              RowBox[{"u", " ", 
               SqrtBox[
                RowBox[{"-", 
                 FractionBox[
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
                  RowBox[{
                   RowBox[{"-", "1"}], "-", 
                   RowBox[{"k", " ", 
                    SuperscriptBox["u0", "2"]}], "-", 
                   RowBox[{
                    SuperscriptBox["c0", "2"], " ", "k", " ", 
                    SuperscriptBox["u0", "2"]}]}]]}]]}], "]"}], ",", 
             FractionBox[
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}], 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["c0", "2"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 FractionBox[
                  RowBox[{
                   RowBox[{"-", "1"}], "-", 
                   RowBox[{"k", " ", 
                    SuperscriptBox["u0", "2"]}], "-", 
                   RowBox[{
                    SuperscriptBox["c0", "2"], " ", "k", " ", 
                    SuperscriptBox["u0", "2"]}]}], 
                  RowBox[{"1", "+", 
                   SuperscriptBox["c0", "2"]}]]}], ")"}]}]]}], "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             FractionBox[
              SuperscriptBox["c0", "2"], 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}]]}]], " ", 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u", "2"]}], "-", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "-", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}], 
             RowBox[{"1", "+", 
              SuperscriptBox["c0", "2"]}]]], " ", 
           SqrtBox[
            FractionBox["1", 
             RowBox[{"1", "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}]]], " ", 
           SqrtBox[
            RowBox[{"-", 
             FractionBox[
              SuperscriptBox["c0", "2"], 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["c0", "2"]}], "+", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}]]}]], " ", 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["c0", "2"]}], "-", 
              RowBox[{"k", " ", 
               SuperscriptBox["u", "2"]}], "-", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u", "2"]}], "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}], 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["c0", "2"]}], "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}]]], " ", 
           RowBox[{"EllipticE", "[", 
            RowBox[{
             RowBox[{"ArcSin", "[", 
              RowBox[{"u0", " ", 
               SqrtBox[
                RowBox[{"-", 
                 FractionBox[
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
                  RowBox[{
                   RowBox[{"-", "1"}], "-", 
                   RowBox[{"k", " ", 
                    SuperscriptBox["u0", "2"]}], "-", 
                   RowBox[{
                    SuperscriptBox["c0", "2"], " ", "k", " ", 
                    SuperscriptBox["u0", "2"]}]}]]}]]}], "]"}], ",", 
             FractionBox[
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}], 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["c0", "2"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 FractionBox[
                  RowBox[{
                   RowBox[{"-", "1"}], "-", 
                   RowBox[{"k", " ", 
                    SuperscriptBox["u0", "2"]}], "-", 
                   RowBox[{
                    SuperscriptBox["c0", "2"], " ", "k", " ", 
                    SuperscriptBox["u0", "2"]}]}], 
                  RowBox[{"1", "+", 
                   SuperscriptBox["c0", "2"]}]]}], ")"}]}]]}], "]"}]}], "-", 
          RowBox[{
           SqrtBox[
            RowBox[{"-", 
             FractionBox[
              SuperscriptBox["c0", "2"], 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}]]}]], " ", "k", " ", 
           SuperscriptBox["u0", "2"], " ", 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u", "2"]}], "-", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "-", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}], 
             RowBox[{"1", "+", 
              SuperscriptBox["c0", "2"]}]]], " ", 
           SqrtBox[
            FractionBox["1", 
             RowBox[{"1", "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}]]], " ", 
           SqrtBox[
            RowBox[{"-", 
             FractionBox[
              SuperscriptBox["c0", "2"], 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["c0", "2"]}], "+", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}]]}]], " ", 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["c0", "2"]}], "-", 
              RowBox[{"k", " ", 
               SuperscriptBox["u", "2"]}], "-", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u", "2"]}], "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}], 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["c0", "2"]}], "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}]]], " ", 
           RowBox[{"EllipticE", "[", 
            RowBox[{
             RowBox[{"ArcSin", "[", 
              RowBox[{"u0", " ", 
               SqrtBox[
                RowBox[{"-", 
                 FractionBox[
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
                  RowBox[{
                   RowBox[{"-", "1"}], "-", 
                   RowBox[{"k", " ", 
                    SuperscriptBox["u0", "2"]}], "-", 
                   RowBox[{
                    SuperscriptBox["c0", "2"], " ", "k", " ", 
                    SuperscriptBox["u0", "2"]}]}]]}]]}], "]"}], ",", 
             FractionBox[
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}], 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["c0", "2"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 FractionBox[
                  RowBox[{
                   RowBox[{"-", "1"}], "-", 
                   RowBox[{"k", " ", 
                    SuperscriptBox["u0", "2"]}], "-", 
                   RowBox[{
                    SuperscriptBox["c0", "2"], " ", "k", " ", 
                    SuperscriptBox["u0", "2"]}]}], 
                  RowBox[{"1", "+", 
                   SuperscriptBox["c0", "2"]}]]}], ")"}]}]]}], "]"}]}], "-", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             FractionBox[
              SuperscriptBox["c0", "2"], 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}]]}]], " ", "k", " ", 
           SuperscriptBox["u0", "2"], " ", 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u", "2"]}], "-", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "-", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}], 
             RowBox[{"1", "+", 
              SuperscriptBox["c0", "2"]}]]], " ", 
           SqrtBox[
            FractionBox["1", 
             RowBox[{"1", "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}]]], " ", 
           SqrtBox[
            RowBox[{"-", 
             FractionBox[
              SuperscriptBox["c0", "2"], 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["c0", "2"]}], "+", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}]]}]], " ", 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["c0", "2"]}], "-", 
              RowBox[{"k", " ", 
               SuperscriptBox["u", "2"]}], "-", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u", "2"]}], "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}], 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["c0", "2"]}], "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}]]], " ", 
           RowBox[{"EllipticE", "[", 
            RowBox[{
             RowBox[{"ArcSin", "[", 
              RowBox[{"u0", " ", 
               SqrtBox[
                RowBox[{"-", 
                 FractionBox[
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
                  RowBox[{
                   RowBox[{"-", "1"}], "-", 
                   RowBox[{"k", " ", 
                    SuperscriptBox["u0", "2"]}], "-", 
                   RowBox[{
                    SuperscriptBox["c0", "2"], " ", "k", " ", 
                    SuperscriptBox["u0", "2"]}]}]]}]]}], "]"}], ",", 
             FractionBox[
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}], 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["c0", "2"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 FractionBox[
                  RowBox[{
                   RowBox[{"-", "1"}], "-", 
                   RowBox[{"k", " ", 
                    SuperscriptBox["u0", "2"]}], "-", 
                   RowBox[{
                    SuperscriptBox["c0", "2"], " ", "k", " ", 
                    SuperscriptBox["u0", "2"]}]}], 
                  RowBox[{"1", "+", 
                   SuperscriptBox["c0", "2"]}]]}], ")"}]}]]}], "]"}]}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["c0", "2"], " ", 
          SqrtBox[
           RowBox[{"-", 
            FractionBox["1", 
             RowBox[{"1", "+", 
              SuperscriptBox["c0", "2"]}]]}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"k", " ", 
              SuperscriptBox["u", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["c0", "2"], " ", "k", " ", 
              SuperscriptBox["u", "2"]}], "-", 
             RowBox[{"k", " ", 
              SuperscriptBox["u0", "2"]}], "-", 
             RowBox[{
              SuperscriptBox["c0", "2"], " ", "k", " ", 
              SuperscriptBox["u0", "2"]}]}], 
            RowBox[{"1", "+", 
             SuperscriptBox["c0", "2"]}]]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
            RowBox[{"1", "+", 
             RowBox[{"k", " ", 
              SuperscriptBox["u0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["c0", "2"], " ", "k", " ", 
              SuperscriptBox["u0", "2"]}]}]]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["c0", "2"]}], "-", 
             RowBox[{"k", " ", 
              SuperscriptBox["u", "2"]}], "-", 
             RowBox[{
              SuperscriptBox["c0", "2"], " ", "k", " ", 
              SuperscriptBox["u", "2"]}], "+", 
             RowBox[{"k", " ", 
              SuperscriptBox["u0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["c0", "2"], " ", "k", " ", 
              SuperscriptBox["u0", "2"]}]}], 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["c0", "2"]}], "+", 
             RowBox[{"k", " ", 
              SuperscriptBox["u0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["c0", "2"], " ", "k", " ", 
              SuperscriptBox["u0", "2"]}]}]]]}], ")"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"c0", " ", 
          SqrtBox[
           RowBox[{"-", 
            FractionBox["1", 
             RowBox[{"1", "+", 
              SuperscriptBox["c0", "2"]}]]}]]}], "+", 
         SqrtBox[
          RowBox[{"-", 
           FractionBox[
            SuperscriptBox["c0", "2"], 
            RowBox[{"1", "+", 
             SuperscriptBox["c0", "2"]}]]}]]}], "\[Equal]", "0"}]}], "]"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"f", "[", "u", "]"}], "\[Rule]", 
     RowBox[{"ConditionalExpression", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["c0", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             FractionBox["1", 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}]]}]], " ", 
           SqrtBox[
            FractionBox[
             RowBox[{"1", "-", 
              RowBox[{"k", " ", 
               SuperscriptBox["u", "2"]}], "-", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u", "2"]}], "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}], 
             RowBox[{"1", "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}]]], " ", 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["c0", "2"]}], "-", 
              RowBox[{"k", " ", 
               SuperscriptBox["u", "2"]}], "-", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u", "2"]}], "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}], 
             RowBox[{"1", "+", 
              SuperscriptBox["c0", "2"]}]]], " ", 
           RowBox[{"EllipticE", "[", 
            RowBox[{
             RowBox[{"ArcSin", "[", 
              RowBox[{"u", " ", 
               SqrtBox[
                RowBox[{"-", 
                 FractionBox[
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
                  RowBox[{
                   RowBox[{"-", "1"}], "-", 
                   RowBox[{"k", " ", 
                    SuperscriptBox["u0", "2"]}], "-", 
                   RowBox[{
                    SuperscriptBox["c0", "2"], " ", "k", " ", 
                    SuperscriptBox["u0", "2"]}]}]]}]]}], "]"}], ",", 
             FractionBox[
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}], 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["c0", "2"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 FractionBox[
                  RowBox[{
                   RowBox[{"-", "1"}], "-", 
                   RowBox[{"k", " ", 
                    SuperscriptBox["u0", "2"]}], "-", 
                   RowBox[{
                    SuperscriptBox["c0", "2"], " ", "k", " ", 
                    SuperscriptBox["u0", "2"]}]}], 
                  RowBox[{"1", "+", 
                   SuperscriptBox["c0", "2"]}]]}], ")"}]}]]}], "]"}]}], "-", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             FractionBox[
              SuperscriptBox["c0", "2"], 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}]]}]], " ", 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u", "2"]}], "-", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "-", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}], 
             RowBox[{"1", "+", 
              SuperscriptBox["c0", "2"]}]]], " ", 
           SqrtBox[
            FractionBox["1", 
             RowBox[{"1", "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}]]], " ", 
           SqrtBox[
            RowBox[{"-", 
             FractionBox[
              SuperscriptBox["c0", "2"], 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["c0", "2"]}], "+", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}]]}]], " ", 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["c0", "2"]}], "-", 
              RowBox[{"k", " ", 
               SuperscriptBox["u", "2"]}], "-", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u", "2"]}], "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}], 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["c0", "2"]}], "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}]]], " ", 
           RowBox[{"EllipticE", "[", 
            RowBox[{
             RowBox[{"ArcSin", "[", 
              RowBox[{"u0", " ", 
               SqrtBox[
                RowBox[{"-", 
                 FractionBox[
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
                  RowBox[{
                   RowBox[{"-", "1"}], "-", 
                   RowBox[{"k", " ", 
                    SuperscriptBox["u0", "2"]}], "-", 
                   RowBox[{
                    SuperscriptBox["c0", "2"], " ", "k", " ", 
                    SuperscriptBox["u0", "2"]}]}]]}]]}], "]"}], ",", 
             FractionBox[
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}], 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["c0", "2"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 FractionBox[
                  RowBox[{
                   RowBox[{"-", "1"}], "-", 
                   RowBox[{"k", " ", 
                    SuperscriptBox["u0", "2"]}], "-", 
                   RowBox[{
                    SuperscriptBox["c0", "2"], " ", "k", " ", 
                    SuperscriptBox["u0", "2"]}]}], 
                  RowBox[{"1", "+", 
                   SuperscriptBox["c0", "2"]}]]}], ")"}]}]]}], "]"}]}], "+", 
          RowBox[{
           SqrtBox[
            RowBox[{"-", 
             FractionBox[
              SuperscriptBox["c0", "2"], 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}]]}]], " ", "k", " ", 
           SuperscriptBox["u0", "2"], " ", 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u", "2"]}], "-", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "-", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}], 
             RowBox[{"1", "+", 
              SuperscriptBox["c0", "2"]}]]], " ", 
           SqrtBox[
            FractionBox["1", 
             RowBox[{"1", "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}]]], " ", 
           SqrtBox[
            RowBox[{"-", 
             FractionBox[
              SuperscriptBox["c0", "2"], 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["c0", "2"]}], "+", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}]]}]], " ", 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["c0", "2"]}], "-", 
              RowBox[{"k", " ", 
               SuperscriptBox["u", "2"]}], "-", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u", "2"]}], "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}], 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["c0", "2"]}], "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}]]], " ", 
           RowBox[{"EllipticE", "[", 
            RowBox[{
             RowBox[{"ArcSin", "[", 
              RowBox[{"u0", " ", 
               SqrtBox[
                RowBox[{"-", 
                 FractionBox[
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
                  RowBox[{
                   RowBox[{"-", "1"}], "-", 
                   RowBox[{"k", " ", 
                    SuperscriptBox["u0", "2"]}], "-", 
                   RowBox[{
                    SuperscriptBox["c0", "2"], " ", "k", " ", 
                    SuperscriptBox["u0", "2"]}]}]]}]]}], "]"}], ",", 
             FractionBox[
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}], 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["c0", "2"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 FractionBox[
                  RowBox[{
                   RowBox[{"-", "1"}], "-", 
                   RowBox[{"k", " ", 
                    SuperscriptBox["u0", "2"]}], "-", 
                   RowBox[{
                    SuperscriptBox["c0", "2"], " ", "k", " ", 
                    SuperscriptBox["u0", "2"]}]}], 
                  RowBox[{"1", "+", 
                   SuperscriptBox["c0", "2"]}]]}], ")"}]}]]}], "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", 
           SqrtBox[
            RowBox[{"-", 
             FractionBox[
              SuperscriptBox["c0", "2"], 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}]]}]], " ", "k", " ", 
           SuperscriptBox["u0", "2"], " ", 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u", "2"]}], "-", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "-", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}], 
             RowBox[{"1", "+", 
              SuperscriptBox["c0", "2"]}]]], " ", 
           SqrtBox[
            FractionBox["1", 
             RowBox[{"1", "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}]]], " ", 
           SqrtBox[
            RowBox[{"-", 
             FractionBox[
              SuperscriptBox["c0", "2"], 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["c0", "2"]}], "+", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}]]}]], " ", 
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["c0", "2"]}], "-", 
              RowBox[{"k", " ", 
               SuperscriptBox["u", "2"]}], "-", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u", "2"]}], "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}], 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["c0", "2"]}], "+", 
              RowBox[{"k", " ", 
               SuperscriptBox["u0", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["c0", "2"], " ", "k", " ", 
               SuperscriptBox["u0", "2"]}]}]]], " ", 
           RowBox[{"EllipticE", "[", 
            RowBox[{
             RowBox[{"ArcSin", "[", 
              RowBox[{"u0", " ", 
               SqrtBox[
                RowBox[{"-", 
                 FractionBox[
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
                  RowBox[{
                   RowBox[{"-", "1"}], "-", 
                   RowBox[{"k", " ", 
                    SuperscriptBox["u0", "2"]}], "-", 
                   RowBox[{
                    SuperscriptBox["c0", "2"], " ", "k", " ", 
                    SuperscriptBox["u0", "2"]}]}]]}]]}], "]"}], ",", 
             FractionBox[
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}], 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["c0", "2"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 FractionBox[
                  RowBox[{
                   RowBox[{"-", "1"}], "-", 
                   RowBox[{"k", " ", 
                    SuperscriptBox["u0", "2"]}], "-", 
                   RowBox[{
                    SuperscriptBox["c0", "2"], " ", "k", " ", 
                    SuperscriptBox["u0", "2"]}]}], 
                  RowBox[{"1", "+", 
                   SuperscriptBox["c0", "2"]}]]}], ")"}]}]]}], "]"}]}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["c0", "2"], " ", 
          SqrtBox[
           RowBox[{"-", 
            FractionBox["1", 
             RowBox[{"1", "+", 
              SuperscriptBox["c0", "2"]}]]}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"k", " ", 
              SuperscriptBox["u", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["c0", "2"], " ", "k", " ", 
              SuperscriptBox["u", "2"]}], "-", 
             RowBox[{"k", " ", 
              SuperscriptBox["u0", "2"]}], "-", 
             RowBox[{
              SuperscriptBox["c0", "2"], " ", "k", " ", 
              SuperscriptBox["u0", "2"]}]}], 
            RowBox[{"1", "+", 
             SuperscriptBox["c0", "2"]}]]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
            RowBox[{"1", "+", 
             RowBox[{"k", " ", 
              SuperscriptBox["u0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["c0", "2"], " ", "k", " ", 
              SuperscriptBox["u0", "2"]}]}]]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["c0", "2"]}], "-", 
             RowBox[{"k", " ", 
              SuperscriptBox["u", "2"]}], "-", 
             RowBox[{
              SuperscriptBox["c0", "2"], " ", "k", " ", 
              SuperscriptBox["u", "2"]}], "+", 
             RowBox[{"k", " ", 
              SuperscriptBox["u0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["c0", "2"], " ", "k", " ", 
              SuperscriptBox["u0", "2"]}]}], 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["c0", "2"]}], "+", 
             RowBox[{"k", " ", 
              SuperscriptBox["u0", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["c0", "2"], " ", "k", " ", 
              SuperscriptBox["u0", "2"]}]}]]]}], ")"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"c0", " ", 
          SqrtBox[
           RowBox[{"-", 
            FractionBox["1", 
             RowBox[{"1", "+", 
              SuperscriptBox["c0", "2"]}]]}]]}], "-", 
         SqrtBox[
          RowBox[{"-", 
           FractionBox[
            SuperscriptBox["c0", "2"], 
            RowBox[{"1", "+", 
             SuperscriptBox["c0", "2"]}]]}]]}], "\[Equal]", "0"}]}], "]"}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.6164734088940315`*^9, 3.6164734326153884`*^9}, 
   3.61648754707765*^9, 3.6164896334929867`*^9, 3.6164947856818223`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"condsol", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6164896454916725`*^9, 3.6164896529330983`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fpos", "[", 
    RowBox[{"k_", ",", "c0_", ",", "u0_"}], "]"}], "[", "u_", "]"}], " ", "=", 
  RowBox[{
   RowBox[{"f", "[", "u", "]"}], "/.", 
   RowBox[{"condsol", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6163955471910877`*^9, 3.6163957105545745`*^9}, {
  3.6163957632826667`*^9, 3.6163958144663568`*^9}, {3.6164948205166836`*^9, 
  3.6164948762243814`*^9}}],

Cell[BoxData[
 RowBox[{"ConditionalExpression", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["c0", "2"], " ", 
       SqrtBox[
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}]]}]], " ", 
       SqrtBox[
        FractionBox[
         RowBox[{"1", "-", 
          RowBox[{"k", " ", 
           SuperscriptBox["u", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u", "2"]}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}], 
         RowBox[{"1", "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}]]], " ", 
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c0", "2"]}], "-", 
          RowBox[{"k", " ", 
           SuperscriptBox["u", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u", "2"]}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}], 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}]]], " ", 
       RowBox[{"EllipticE", "[", 
        RowBox[{
         RowBox[{"ArcSin", "[", 
          RowBox[{"u", " ", 
           SqrtBox[
            RowBox[{"-", 
             FractionBox[
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}]]}]]}], "]"}], ",", 
         FractionBox[
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"k", " ", 
            SuperscriptBox["u0", "2"]}], "-", 
           RowBox[{
            SuperscriptBox["c0", "2"], " ", "k", " ", 
            SuperscriptBox["u0", "2"]}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["c0", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}], 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}]]}], ")"}]}]]}], "]"}]}], "-", 
      RowBox[{
       SuperscriptBox["c0", "2"], " ", 
       SqrtBox[
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["c0", "2"], 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}]]}]], " ", 
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u", "2"]}], "-", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}], 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}]]], " ", 
       SqrtBox[
        FractionBox["1", 
         RowBox[{"1", "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}]]], " ", 
       SqrtBox[
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["c0", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["c0", "2"]}], "+", 
           RowBox[{"k", " ", 
            SuperscriptBox["u0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["c0", "2"], " ", "k", " ", 
            SuperscriptBox["u0", "2"]}]}]]}]], " ", 
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c0", "2"]}], "-", 
          RowBox[{"k", " ", 
           SuperscriptBox["u", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u", "2"]}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}], 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c0", "2"]}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}]]], " ", 
       RowBox[{"EllipticE", "[", 
        RowBox[{
         RowBox[{"ArcSin", "[", 
          RowBox[{"u0", " ", 
           SqrtBox[
            RowBox[{"-", 
             FractionBox[
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}]]}]]}], "]"}], ",", 
         FractionBox[
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"k", " ", 
            SuperscriptBox["u0", "2"]}], "-", 
           RowBox[{
            SuperscriptBox["c0", "2"], " ", "k", " ", 
            SuperscriptBox["u0", "2"]}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["c0", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}], 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}]]}], ")"}]}]]}], "]"}]}], "+", 
      RowBox[{
       SqrtBox[
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["c0", "2"], 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}]]}]], " ", "k", " ", 
       SuperscriptBox["u0", "2"], " ", 
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u", "2"]}], "-", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}], 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}]]], " ", 
       SqrtBox[
        FractionBox["1", 
         RowBox[{"1", "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}]]], " ", 
       SqrtBox[
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["c0", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["c0", "2"]}], "+", 
           RowBox[{"k", " ", 
            SuperscriptBox["u0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["c0", "2"], " ", "k", " ", 
            SuperscriptBox["u0", "2"]}]}]]}]], " ", 
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c0", "2"]}], "-", 
          RowBox[{"k", " ", 
           SuperscriptBox["u", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u", "2"]}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}], 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c0", "2"]}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}]]], " ", 
       RowBox[{"EllipticE", "[", 
        RowBox[{
         RowBox[{"ArcSin", "[", 
          RowBox[{"u0", " ", 
           SqrtBox[
            RowBox[{"-", 
             FractionBox[
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}]]}]]}], "]"}], ",", 
         FractionBox[
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"k", " ", 
            SuperscriptBox["u0", "2"]}], "-", 
           RowBox[{
            SuperscriptBox["c0", "2"], " ", "k", " ", 
            SuperscriptBox["u0", "2"]}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["c0", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}], 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}]]}], ")"}]}]]}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["c0", "2"], " ", 
       SqrtBox[
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["c0", "2"], 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}]]}]], " ", "k", " ", 
       SuperscriptBox["u0", "2"], " ", 
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u", "2"]}], "-", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}], 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}]]], " ", 
       SqrtBox[
        FractionBox["1", 
         RowBox[{"1", "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}]]], " ", 
       SqrtBox[
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["c0", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["c0", "2"]}], "+", 
           RowBox[{"k", " ", 
            SuperscriptBox["u0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["c0", "2"], " ", "k", " ", 
            SuperscriptBox["u0", "2"]}]}]]}]], " ", 
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c0", "2"]}], "-", 
          RowBox[{"k", " ", 
           SuperscriptBox["u", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u", "2"]}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}], 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c0", "2"]}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}]]], " ", 
       RowBox[{"EllipticE", "[", 
        RowBox[{
         RowBox[{"ArcSin", "[", 
          RowBox[{"u0", " ", 
           SqrtBox[
            RowBox[{"-", 
             FractionBox[
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}]]}]]}], "]"}], ",", 
         FractionBox[
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"k", " ", 
            SuperscriptBox["u0", "2"]}], "-", 
           RowBox[{
            SuperscriptBox["c0", "2"], " ", "k", " ", 
            SuperscriptBox["u0", "2"]}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["c0", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}], 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}]]}], ")"}]}]]}], "]"}]}]}], ")"}], 
    "/", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["c0", "2"], " ", 
      SqrtBox[
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}]]}]], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"k", " ", 
          SuperscriptBox["u", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["c0", "2"], " ", "k", " ", 
          SuperscriptBox["u", "2"]}], "-", 
         RowBox[{"k", " ", 
          SuperscriptBox["u0", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["c0", "2"], " ", "k", " ", 
          SuperscriptBox["u0", "2"]}]}], 
        RowBox[{"1", "+", 
         SuperscriptBox["c0", "2"]}]]], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
        RowBox[{"1", "+", 
         RowBox[{"k", " ", 
          SuperscriptBox["u0", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["c0", "2"], " ", "k", " ", 
          SuperscriptBox["u0", "2"]}]}]]], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["c0", "2"]}], "-", 
         RowBox[{"k", " ", 
          SuperscriptBox["u", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["c0", "2"], " ", "k", " ", 
          SuperscriptBox["u", "2"]}], "+", 
         RowBox[{"k", " ", 
          SuperscriptBox["u0", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["c0", "2"], " ", "k", " ", 
          SuperscriptBox["u0", "2"]}]}], 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["c0", "2"]}], "+", 
         RowBox[{"k", " ", 
          SuperscriptBox["u0", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["c0", "2"], " ", "k", " ", 
          SuperscriptBox["u0", "2"]}]}]]]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"c0", " ", 
      SqrtBox[
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}]]}]]}], "-", 
     SqrtBox[
      RowBox[{"-", 
       FractionBox[
        SuperscriptBox["c0", "2"], 
        RowBox[{"1", "+", 
         SuperscriptBox["c0", "2"]}]]}]]}], "\[Equal]", "0"}]}], 
  "]"}]], "Output",
 CellChangeTimes->{3.6163957133625793`*^9, 3.6163959385177746`*^9, 
  3.6164147051678*^9, 3.6164948790791864`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fneg", "[", 
    RowBox[{"k_", ",", "c0_", ",", "u0_"}], "]"}], "[", "u_", "]"}], " ", "=", 
  RowBox[{
   RowBox[{"f", "[", "u", "]"}], "/.", 
   RowBox[{"condsol", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6163955471910877`*^9, 3.6163957105545745`*^9}, {
   3.6163957632826667`*^9, 3.6163958144663568`*^9}, {3.616414076424296*^9, 
   3.616414086189913*^9}, {3.6164145646271534`*^9, 3.6164145816155834`*^9}, {
   3.6164948995776224`*^9, 3.6164949074868364`*^9}, 3.6164949413232956`*^9}],

Cell[BoxData[
 RowBox[{"ConditionalExpression", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["c0", "2"]}], " ", 
       SqrtBox[
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}]]}]], " ", 
       SqrtBox[
        FractionBox[
         RowBox[{"1", "-", 
          RowBox[{"k", " ", 
           SuperscriptBox["u", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u", "2"]}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}], 
         RowBox[{"1", "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}]]], " ", 
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c0", "2"]}], "-", 
          RowBox[{"k", " ", 
           SuperscriptBox["u", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u", "2"]}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}], 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}]]], " ", 
       RowBox[{"EllipticE", "[", 
        RowBox[{
         RowBox[{"ArcSin", "[", 
          RowBox[{"u", " ", 
           SqrtBox[
            RowBox[{"-", 
             FractionBox[
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}]]}]]}], "]"}], ",", 
         FractionBox[
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"k", " ", 
            SuperscriptBox["u0", "2"]}], "-", 
           RowBox[{
            SuperscriptBox["c0", "2"], " ", "k", " ", 
            SuperscriptBox["u0", "2"]}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["c0", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}], 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}]]}], ")"}]}]]}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["c0", "2"], " ", 
       SqrtBox[
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["c0", "2"], 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}]]}]], " ", 
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u", "2"]}], "-", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}], 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}]]], " ", 
       SqrtBox[
        FractionBox["1", 
         RowBox[{"1", "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}]]], " ", 
       SqrtBox[
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["c0", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["c0", "2"]}], "+", 
           RowBox[{"k", " ", 
            SuperscriptBox["u0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["c0", "2"], " ", "k", " ", 
            SuperscriptBox["u0", "2"]}]}]]}]], " ", 
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c0", "2"]}], "-", 
          RowBox[{"k", " ", 
           SuperscriptBox["u", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u", "2"]}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}], 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c0", "2"]}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}]]], " ", 
       RowBox[{"EllipticE", "[", 
        RowBox[{
         RowBox[{"ArcSin", "[", 
          RowBox[{"u0", " ", 
           SqrtBox[
            RowBox[{"-", 
             FractionBox[
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}]]}]]}], "]"}], ",", 
         FractionBox[
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"k", " ", 
            SuperscriptBox["u0", "2"]}], "-", 
           RowBox[{
            SuperscriptBox["c0", "2"], " ", "k", " ", 
            SuperscriptBox["u0", "2"]}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["c0", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}], 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}]]}], ")"}]}]]}], "]"}]}], "-", 
      RowBox[{
       SqrtBox[
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["c0", "2"], 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}]]}]], " ", "k", " ", 
       SuperscriptBox["u0", "2"], " ", 
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u", "2"]}], "-", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}], 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}]]], " ", 
       SqrtBox[
        FractionBox["1", 
         RowBox[{"1", "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}]]], " ", 
       SqrtBox[
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["c0", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["c0", "2"]}], "+", 
           RowBox[{"k", " ", 
            SuperscriptBox["u0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["c0", "2"], " ", "k", " ", 
            SuperscriptBox["u0", "2"]}]}]]}]], " ", 
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c0", "2"]}], "-", 
          RowBox[{"k", " ", 
           SuperscriptBox["u", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u", "2"]}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}], 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c0", "2"]}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}]]], " ", 
       RowBox[{"EllipticE", "[", 
        RowBox[{
         RowBox[{"ArcSin", "[", 
          RowBox[{"u0", " ", 
           SqrtBox[
            RowBox[{"-", 
             FractionBox[
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}]]}]]}], "]"}], ",", 
         FractionBox[
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"k", " ", 
            SuperscriptBox["u0", "2"]}], "-", 
           RowBox[{
            SuperscriptBox["c0", "2"], " ", "k", " ", 
            SuperscriptBox["u0", "2"]}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["c0", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}], 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}]]}], ")"}]}]]}], "]"}]}], "-", 
      RowBox[{
       SuperscriptBox["c0", "2"], " ", 
       SqrtBox[
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["c0", "2"], 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}]]}]], " ", "k", " ", 
       SuperscriptBox["u0", "2"], " ", 
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u", "2"]}], "-", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}], 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}]]], " ", 
       SqrtBox[
        FractionBox["1", 
         RowBox[{"1", "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}]]], " ", 
       SqrtBox[
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["c0", "2"], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["c0", "2"]}], "+", 
           RowBox[{"k", " ", 
            SuperscriptBox["u0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["c0", "2"], " ", "k", " ", 
            SuperscriptBox["u0", "2"]}]}]]}]], " ", 
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c0", "2"]}], "-", 
          RowBox[{"k", " ", 
           SuperscriptBox["u", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u", "2"]}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}], 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c0", "2"]}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u0", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["c0", "2"], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}]]], " ", 
       RowBox[{"EllipticE", "[", 
        RowBox[{
         RowBox[{"ArcSin", "[", 
          RowBox[{"u0", " ", 
           SqrtBox[
            RowBox[{"-", 
             FractionBox[
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}]]}]]}], "]"}], ",", 
         FractionBox[
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"k", " ", 
            SuperscriptBox["u0", "2"]}], "-", 
           RowBox[{
            SuperscriptBox["c0", "2"], " ", "k", " ", 
            SuperscriptBox["u0", "2"]}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["c0", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{"k", " ", 
                SuperscriptBox["u0", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["c0", "2"], " ", "k", " ", 
                SuperscriptBox["u0", "2"]}]}], 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}]]}], ")"}]}]]}], "]"}]}]}], ")"}], 
    "/", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["c0", "2"], " ", 
      SqrtBox[
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}]]}]], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"k", " ", 
          SuperscriptBox["u", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["c0", "2"], " ", "k", " ", 
          SuperscriptBox["u", "2"]}], "-", 
         RowBox[{"k", " ", 
          SuperscriptBox["u0", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["c0", "2"], " ", "k", " ", 
          SuperscriptBox["u0", "2"]}]}], 
        RowBox[{"1", "+", 
         SuperscriptBox["c0", "2"]}]]], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
        RowBox[{"1", "+", 
         RowBox[{"k", " ", 
          SuperscriptBox["u0", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["c0", "2"], " ", "k", " ", 
          SuperscriptBox["u0", "2"]}]}]]], " ", 
      SqrtBox[
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["c0", "2"]}], "-", 
         RowBox[{"k", " ", 
          SuperscriptBox["u", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["c0", "2"], " ", "k", " ", 
          SuperscriptBox["u", "2"]}], "+", 
         RowBox[{"k", " ", 
          SuperscriptBox["u0", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["c0", "2"], " ", "k", " ", 
          SuperscriptBox["u0", "2"]}]}], 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["c0", "2"]}], "+", 
         RowBox[{"k", " ", 
          SuperscriptBox["u0", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["c0", "2"], " ", "k", " ", 
          SuperscriptBox["u0", "2"]}]}]]]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"c0", " ", 
      SqrtBox[
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}]]}]]}], "+", 
     SqrtBox[
      RowBox[{"-", 
       FractionBox[
        SuperscriptBox["c0", "2"], 
        RowBox[{"1", "+", 
         SuperscriptBox["c0", "2"]}]]}]]}], "\[Equal]", "0"}]}], 
  "]"}]], "Output",
 CellChangeTimes->{3.6164141604772434`*^9, 3.616414586170791*^9, 
  3.616494913524047*^9, 3.6164949482497077`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fpos", "[", 
     RowBox[{"k", ",", "c0", ",", "u0"}], "]"}], "[", "u", "]"}], ",", " ", 
   RowBox[{"c0", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616494960199329*^9, 3.6164950123970203`*^9}, 
   3.616495124764018*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "k"}], " ", 
        SuperscriptBox["u", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["c0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u", "2"]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
        SuperscriptBox["u0", "2"]}]}]], " ", 
     SqrtBox[
      FractionBox[
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
         RowBox[{"(", 
          RowBox[{"u", "-", "u0"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"u", "+", "u0"}], ")"}]}]}], 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
         SuperscriptBox["u0", "2"]}]}]]], " ", 
     RowBox[{"EllipticE", "[", 
      RowBox[{
       RowBox[{"ArcSin", "[", 
        RowBox[{"u", " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
           RowBox[{"1", "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
             SuperscriptBox["u0", "2"]}]}]]]}], "]"}], ",", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c0", "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}]]}]}], "]"}]}], "+", 
    RowBox[{
     SqrtBox[
      FractionBox["1", 
       RowBox[{
        SuperscriptBox["c0", "2"], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
         SuperscriptBox["u0", "2"]}]}]]], " ", 
     SqrtBox[
      FractionBox["1", 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
         SuperscriptBox["u0", "2"]}]}]]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["c0", "2"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
        SuperscriptBox["u0", "2"]}]}], ")"}], " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
        RowBox[{"(", 
         RowBox[{"u", "-", "u0"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"u", "+", "u0"}], ")"}]}]}]], " ", 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
         SuperscriptBox["u", "2"]}], 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["c0", "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
          SuperscriptBox["u0", "2"]}]}]]}]], " ", 
     RowBox[{"EllipticE", "[", 
      RowBox[{
       RowBox[{"ArcSin", "[", 
        RowBox[{"u0", " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
           RowBox[{"1", "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
             SuperscriptBox["u0", "2"]}]}]]]}], "]"}], ",", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c0", "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}]]}]}], "]"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{
    SqrtBox[
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
      RowBox[{"1", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
        SuperscriptBox["u0", "2"]}]}]]], " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
       RowBox[{"(", 
        RowBox[{"u", "-", "u0"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"u", "+", "u0"}], ")"}]}]}]], " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
        SuperscriptBox["u", "2"]}], 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["c0", "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
         SuperscriptBox["u0", "2"]}]}]]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.6164952486594353`*^9}]
}, Closed]],

Cell["We redefine", "Text",
 CellChangeTimes->{{3.616495492066663*^9, 3.616495498244274*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "fpos", "]"}], ";", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"fpos", "[", 
     RowBox[{"k_", ",", " ", "c0_", ",", " ", "u0_"}], "]"}], "[", "\n", 
    "    ", "u_", "]"}], " ", ":=", " ", "\n", "   ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"-", "k"}], ")"}], "*", 
          RowBox[{"u", "^", "2"}]}], " ", "-", " ", 
         RowBox[{
          RowBox[{"c0", "^", "2"}], "*", "\n", "         ", 
          RowBox[{"(", 
           RowBox[{"1", " ", "+", " ", 
            RowBox[{"k", "*", 
             RowBox[{"u", "^", "2"}]}]}], ")"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", " ", "+", " ", 
            RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", "\n", 
          "         ", 
          RowBox[{"u0", "^", "2"}]}]}], "]"}], "*", 
       RowBox[{"Sqrt", "[", "\n", "       ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", " ", "-", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
            RowBox[{"(", 
             RowBox[{"u", " ", "-", " ", "u0"}], ")"}], "*", "\n", 
            "          ", 
            RowBox[{"(", 
             RowBox[{"u", " ", "+", " ", "u0"}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{"c0", "^", "2"}]}], ")"}], "*", "\n", "          ", "k",
             "*", 
            RowBox[{"u0", "^", "2"}]}]}], ")"}]}], "]"}], "*", 
       RowBox[{"EllipticE", "[", "\n", "       ", 
        RowBox[{
         RowBox[{"ArcSin", "[", 
          RowBox[{"u", "*", 
           RowBox[{"Sqrt", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", " ", "+", " ", 
                 RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k"}], ")"}], "/", 
             "\n", "           ", 
             RowBox[{"(", 
              RowBox[{"1", " ", "+", " ", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", " ", "+", " ", 
                  RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", "\n", 
                "            ", 
                RowBox[{"u0", "^", "2"}]}]}], ")"}]}], "]"}]}], "]"}], ",", 
         " ", "\n", "       ", 
         RowBox[{"1", " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "+", " ", 
             RowBox[{"c0", "^", "2"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"c0", "^", "2"}]}], " ", "+", " ", "\n", "          ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", " ", "+", " ", 
                RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
              RowBox[{"u0", "^", "2"}]}]}], ")"}]}]}]}], "]"}]}], " ", "+", 
      " ", "\n", "     ", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c0", "^", "2"}], " ", "-", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", "\n", 
            "          ", 
            RowBox[{"u0", "^", "2"}]}]}], ")"}]}], "]"}], "*", 
       RowBox[{"Sqrt", "[", "\n", "       ", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
            RowBox[{"u0", "^", "2"}]}]}], ")"}]}], "]"}], "*", "\n", "      ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"c0", "^", "2"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", " ", "+", " ", 
            RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
          RowBox[{"u0", "^", "2"}]}]}], ")"}], "*", "\n", "      ", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"-", "1"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", " ", "+", " ", 
            RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", "\n", 
          "         ", 
          RowBox[{"(", 
           RowBox[{"u", " ", "-", " ", "u0"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"u", " ", "+", " ", "u0"}], ")"}]}]}], "]"}], "*", "\n", 
       "      ", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", " ", "-", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
            RowBox[{"u", "^", "2"}]}], ")"}], "/", "\n", "         ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"c0", "^", "2"}]}], " ", "+", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", " ", "+", " ", 
               RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", "\n", 
             "           ", 
             RowBox[{"u0", "^", "2"}]}]}], ")"}]}]}], "]"}], "*", 
       RowBox[{"EllipticE", "[", "\n", "       ", 
        RowBox[{
         RowBox[{"ArcSin", "[", 
          RowBox[{"u0", "*", 
           RowBox[{"Sqrt", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", " ", "+", " ", 
                 RowBox[{"c0", "^", "2"}]}], ")"}], "*", "\n", "            ",
                "k"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"1", " ", "+", " ", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", " ", "+", " ", 
                  RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", "\n", 
                "            ", 
                RowBox[{"u0", "^", "2"}]}]}], ")"}]}], "]"}]}], "]"}], ",", 
         " ", "\n", "       ", 
         RowBox[{"1", " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "+", " ", 
             RowBox[{"c0", "^", "2"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"c0", "^", "2"}]}], " ", "+", " ", "\n", "          ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", " ", "+", " ", 
                RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
              RowBox[{"u0", "^", "2"}]}]}], ")"}]}]}]}], "]"}]}]}], ")"}], 
    "/", "\n", "    ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", " ", "+", " ", 
            RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k"}], ")"}], "/", "\n", 
        "       ", 
        RowBox[{"(", 
         RowBox[{"1", " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "+", " ", 
             RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
           RowBox[{"u0", "^", "2"}]}]}], ")"}]}], "]"}], "*", "\n", "     ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"-", "1"}], " ", "+", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", 
           RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", "\n", "        ", 
         RowBox[{"(", 
          RowBox[{"u", " ", "-", " ", "u0"}], ")"}], "*", 
         RowBox[{"(", 
          RowBox[{"u", " ", "+", " ", "u0"}], ")"}]}]}], "]"}], "*", "\n", 
      "     ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", " ", "-", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "+", " ", 
             RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
           RowBox[{"u", "^", "2"}]}], ")"}], "/", "\n", "        ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"c0", "^", "2"}]}], " ", "+", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", "\n", 
            "          ", 
            RowBox[{"u0", "^", "2"}]}]}], ")"}]}]}], "]"}]}], 
     ")"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.616495509850694*^9, 3.616495528352327*^9}, {
  3.616495560410383*^9, 3.6164956132788763`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fneg", "[", 
     RowBox[{"k", ",", "c0", ",", "u0"}], "]"}], "[", "u", "]"}], ",", " ", 
   RowBox[{"c0", "<", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616494960199329*^9, 3.6164950123970203`*^9}, 
   3.616495124764018*^9, {3.6164956739785824`*^9, 3.6164956824805975`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SqrtBox[
       FractionBox["1", 
        RowBox[{
         SuperscriptBox["c0", "2"], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
          SuperscriptBox["u0", "2"]}]}]]]}], " ", 
     SqrtBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "k"}], " ", 
        SuperscriptBox["u", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["c0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u", "2"]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
        SuperscriptBox["u0", "2"]}]}]], " ", 
     SqrtBox[
      FractionBox[
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
         RowBox[{"(", 
          RowBox[{"u", "-", "u0"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"u", "+", "u0"}], ")"}]}]}], 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
         SuperscriptBox["u0", "2"]}]}]]], " ", 
     RowBox[{"EllipticE", "[", 
      RowBox[{
       RowBox[{"ArcSin", "[", 
        RowBox[{"u", " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
           RowBox[{"1", "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
             SuperscriptBox["u0", "2"]}]}]]]}], "]"}], ",", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c0", "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}]]}]}], "]"}]}], "+", 
    RowBox[{
     SqrtBox[
      FractionBox["1", 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
         SuperscriptBox["u0", "2"]}]}]]], " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
        RowBox[{"(", 
         RowBox[{"u", "-", "u0"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"u", "+", "u0"}], ")"}]}]}]], " ", 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
         SuperscriptBox["u", "2"]}], 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["c0", "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
          SuperscriptBox["u0", "2"]}]}]]}]], " ", 
     RowBox[{"EllipticE", "[", 
      RowBox[{
       RowBox[{"ArcSin", "[", 
        RowBox[{"u0", " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
           RowBox[{"1", "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
             SuperscriptBox["u0", "2"]}]}]]]}], "]"}], ",", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c0", "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}]]}]}], "]"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{
    SqrtBox[
     FractionBox["1", 
      RowBox[{
       SuperscriptBox["c0", "2"], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
        SuperscriptBox["u0", "2"]}]}]]], " ", 
    SqrtBox[
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
      RowBox[{"1", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
        SuperscriptBox["u0", "2"]}]}]]], " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
       RowBox[{"(", 
        RowBox[{"u", "-", "u0"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"u", "+", "u0"}], ")"}]}]}]], " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
        SuperscriptBox["u", "2"]}], 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["c0", "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
         SuperscriptBox["u0", "2"]}]}]]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.6164957457231083`*^9}]
}, Closed]],

Cell["Now we redefine ", "Text",
 CellChangeTimes->{{3.616496134288591*^9, 3.6164961682654505`*^9}, 
   3.6164962078739204`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "fneg", "]"}], ";", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"fneg", "[", 
     RowBox[{"k_", ",", " ", "c0_", ",", " ", "u0_"}], "]"}], "[", "u_", 
    "]"}], " ", ":=", " ", "\n", "   ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"-", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"c0", "^", "2"}], " ", "-", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", " ", "+", " ", 
                RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", "\n", 
              "           ", 
              RowBox[{"u0", "^", "2"}]}]}], ")"}]}], "]"}]}], ")"}], "*", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"-", "k"}], ")"}], "*", 
          RowBox[{"u", "^", "2"}]}], " ", "-", " ", "\n", "        ", 
         RowBox[{
          RowBox[{"c0", "^", "2"}], "*", 
          RowBox[{"(", 
           RowBox[{"1", " ", "+", " ", 
            RowBox[{"k", "*", 
             RowBox[{"u", "^", "2"}]}]}], ")"}]}], " ", "+", " ", "\n", 
         "        ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", " ", "+", " ", 
            RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
          RowBox[{"u0", "^", "2"}]}]}], "]"}], "*", "\n", "      ", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", " ", "-", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", "\n", 
            "          ", 
            RowBox[{"(", 
             RowBox[{"u", " ", "-", " ", "u0"}], ")"}], "*", 
            RowBox[{"(", 
             RowBox[{"u", " ", "+", " ", "u0"}], ")"}]}]}], ")"}], "/", "\n", 
         "        ", 
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
            RowBox[{"u0", "^", "2"}]}]}], ")"}]}], "]"}], "*", "\n", "      ", 
       RowBox[{"EllipticE", "[", 
        RowBox[{
         RowBox[{"ArcSin", "[", "\n", "        ", 
          RowBox[{"u", "*", 
           RowBox[{"Sqrt", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", " ", "+", " ", 
                 RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k"}], ")"}], "/", 
             "\n", "           ", 
             RowBox[{"(", 
              RowBox[{"1", " ", "+", " ", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", " ", "+", " ", 
                  RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", "\n", 
                "            ", 
                RowBox[{"u0", "^", "2"}]}]}], ")"}]}], "]"}]}], "]"}], ",", 
         " ", "\n", "       ", 
         RowBox[{"1", " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "+", " ", 
             RowBox[{"c0", "^", "2"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"c0", "^", "2"}]}], " ", "+", " ", "\n", "          ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", " ", "+", " ", 
                RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
              RowBox[{"u0", "^", "2"}]}]}], ")"}]}]}]}], "]"}]}], " ", "+", 
      " ", "\n", "     ", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", "\n", 
            "          ", 
            RowBox[{"u0", "^", "2"}]}]}], ")"}]}], "]"}], "*", 
       RowBox[{"Sqrt", "[", "\n", "       ", 
        RowBox[{
         RowBox[{"-", "1"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", " ", "+", " ", 
            RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
          RowBox[{"(", 
           RowBox[{"u", " ", "-", " ", "u0"}], ")"}], "*", "\n", "         ", 
          RowBox[{"(", 
           RowBox[{"u", " ", "+", " ", "u0"}], ")"}]}]}], "]"}], "*", 
       RowBox[{"Sqrt", "[", "\n", "       ", 
        RowBox[{"1", " ", "-", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
            RowBox[{"u", "^", "2"}]}], ")"}], "/", "\n", "         ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"c0", "^", "2"}]}], " ", "+", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", " ", "+", " ", 
               RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", "\n", 
             "           ", 
             RowBox[{"u0", "^", "2"}]}]}], ")"}]}]}], "]"}], "*", 
       RowBox[{"EllipticE", "[", "\n", "       ", 
        RowBox[{
         RowBox[{"ArcSin", "[", 
          RowBox[{"u0", "*", 
           RowBox[{"Sqrt", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", " ", "+", " ", 
                 RowBox[{"c0", "^", "2"}]}], ")"}], "*", "\n", "            ",
                "k"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"1", " ", "+", " ", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", " ", "+", " ", 
                  RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", "\n", 
                "            ", 
                RowBox[{"u0", "^", "2"}]}]}], ")"}]}], "]"}]}], "]"}], ",", 
         " ", "\n", "       ", 
         RowBox[{"1", " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "+", " ", 
             RowBox[{"c0", "^", "2"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"c0", "^", "2"}]}], " ", "+", " ", "\n", "          ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", " ", "+", " ", 
                RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
              RowBox[{"u0", "^", "2"}]}]}], ")"}]}]}]}], "]"}]}]}], ")"}], 
    "/", "\n", "    ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c0", "^", "2"}], " ", "-", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "+", " ", 
             RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", "\n", 
           "         ", 
           RowBox[{"u0", "^", "2"}]}]}], ")"}]}], "]"}], "*", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", " ", "+", " ", 
            RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k"}], ")"}], "/", "\n", 
        "       ", 
        RowBox[{"(", 
         RowBox[{"1", " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "+", " ", 
             RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
           RowBox[{"u0", "^", "2"}]}]}], ")"}]}], "]"}], "*", "\n", "     ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"-", "1"}], " ", "+", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", 
           RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", "\n", "        ", 
         RowBox[{"(", 
          RowBox[{"u", " ", "-", " ", "u0"}], ")"}], "*", 
         RowBox[{"(", 
          RowBox[{"u", " ", "+", " ", "u0"}], ")"}]}]}], "]"}], "*", "\n", 
      "     ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", " ", "-", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "+", " ", 
             RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
           RowBox[{"u", "^", "2"}]}], ")"}], "/", "\n", "        ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"c0", "^", "2"}]}], " ", "+", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", "\n", 
            "          ", 
            RowBox[{"u0", "^", "2"}]}]}], ")"}]}]}], "]"}]}], 
     ")"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6164962222103453`*^9, 3.6164963217853203`*^9}}],

Cell[TextData[StyleBox["Properties of the Solutions",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.616553101773759*^9, 3.616553114331781*^9}, 
   3.616647345128044*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fpos", "[", 
     RowBox[{"k", ",", "c0", ",", "u0"}], "]"}], "[", "u", "]"}], "+", 
   RowBox[{
    RowBox[{"fneg", "[", 
     RowBox[{"k", ",", "c0", ",", "u0"}], "]"}], "[", "u", "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6166467744322414`*^9, 3.616646897048457*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.616646899310461*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Lemma",
  FontColor->RGBColor[0, 0, 1]],
 ". The solutions fpos, fneg differ by sign only. ",
 "\[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.616647242682664*^9, 3.616647299076763*^9}, 
   3.6166473329288225`*^9, {3.616648383982584*^9, 3.6166483839885845`*^9}}],

Cell[TextData[{
 "Remember: According to the conditions, fpos must be applied for c0>0, and \
fneg in case c0< 0. \nWe consider the case c0 = 0, in which both conditions \
are satisfied.\n\n",
 StyleBox["Case c0 =0, u0=0:",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.6165531516938467`*^9, 3.6165533617482157`*^9}, {
  3.616554275800621*^9, 3.6165542928358507`*^9}, {3.6166477369539323`*^9, 
  3.6166477503387556`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fpos", "[", 
   RowBox[{"k", ",", "0", ",", "0"}], "]"}], "[", "u", "]"}]], "Input",
 CellChangeTimes->{{3.616553366007023*^9, 3.6165533770206423`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Power", "::", "infy"}], "MessageName"], ":", 
  " ", "\<\"Infinite expression \[NoBreak]\\!\\(1\\/0\\)\[NoBreak] \
encountered. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/infy\\\", ButtonNote -> \
\\\"Power::infy\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6165533780502443`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Power", "::", "infy"}], "MessageName"], ":", 
  " ", "\<\"Infinite expression \[NoBreak]\\!\\(1\\/0\\)\[NoBreak] \
encountered. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/infy\\\", ButtonNote -> \
\\\"Power::infy\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.616553378112644*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Power", "::", "infy"}], "MessageName"], ":", 
  " ", "\<\"Infinite expression \[NoBreak]\\!\\(1\\/0\\)\[NoBreak] \
encountered. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/infy\\\", ButtonNote -> \
\\\"Power::infy\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.616553378175044*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], ":", 
  " ", "\<\"Further output of \[NoBreak]\\!\\(\\*StyleBox[\\(Power :: \
infy\\), \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6165533782062445`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Infinity", "::", "indet"}], "MessageName"], ":", 
  " ", "\<\"Indeterminate expression \[NoBreak]\\!\\(0\\\\ \
\\@\\(\\(\\(-1\\)\\) + \\(\\(k\\\\ u\\^2\\)\\)\\)\\\\ ComplexInfinity\\\\ \
ComplexInfinity\\)\[NoBreak] encountered. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/indet\\\", ButtonNote -> \
\\\"Infinity::indet\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.616553378253044*^9}],

Cell[BoxData["Indeterminate"], "Output",
 CellChangeTimes->{3.616553378253044*^9}]
}, Closed]],

Cell["\<\
The solutions with the initial conditions c0 = u0 = 0 are not contained in \
the family of solutions; thus the spheres are not  found by DSolve:\
\>", "Text",
 CellChangeTimes->{{3.616553530696512*^9, 3.6165536814551773`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"diff", "[", 
        RowBox[{"f", ",", "k"}], "]"}], "[", "u", "]"}], "\[Equal]", "0"}], 
     ",", " ", 
     RowBox[{
      RowBox[{"f", "[", "0", "]"}], " ", "\[Equal]", " ", "0"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "==", "0"}]}], "}"}], ",", 
   RowBox[{"f", "[", "u", "]"}], ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.6165536891147904`*^9, 3.616553704340417*^9}, {
   3.6165537785497475`*^9, 3.6165538590770893`*^9}, {3.616553919901596*^9, 
   3.616553921211998*^9}, {3.616554017635768*^9, 3.616554023532578*^9}, 
   3.616554926477764*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], "\[Rule]", "Indeterminate"}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.616553901649564*^9, 3.616553923271202*^9}, 
   3.6165540261221824`*^9, 3.6165549292857685`*^9}]
}, Closed]],

Cell["Half-spheres are generated by the function", "Text",
 CellChangeTimes->{{3.616558753193776*^9, 3.616558772849811*^9}, {
  3.6186384991017866`*^9, 3.6186385277414246`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fsph", "[", "r_", "]"}], "[", "u_", "]"}], " ", ":=", 
  RowBox[{"r", "-", " ", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"r", "^", "2"}], "-", 
     RowBox[{"u", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6165587812426257`*^9, 3.6165588315059137`*^9}, {
  3.616559024946254*^9, 3.616559026194256*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{"id", ",", 
      RowBox[{"fsph", "[", "1", "]"}]}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616558846871941*^9, 3.616558957226535*^9}}],

Cell["\<\
Of course, fsph satisfies the differential equation with the initial \
conditions\
\>", "Text",
 CellChangeTimes->{{3.6165591945653515`*^9, 3.616559238089428*^9}, {
   3.616559463010623*^9, 3.616559469157034*^9}, 3.6186385519728107`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fsph", "[", "r", "]"}], "[", "0", "]"}], ",", " ", 
   RowBox[{"r", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6165592460922422`*^9, 3.6165593935125012`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.616559394588903*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"fsph", "[", "r", "]"}], "[", "u", "]"}], ",", "u"}], "]"}], "/.",
   " ", 
  RowBox[{"u", "\[Rule]", "0"}]}]], "Input",
 CellChangeTimes->{{3.616559401874116*^9, 3.616559447535396*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6165594507490015`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"diff", "[", 
     RowBox[{
      RowBox[{"fsph", "[", "r", "]"}], ",", 
      RowBox[{"1", "/", 
       RowBox[{"r", "^", "2"}]}]}], "]"}], "[", "u", "]"}], ",", 
   RowBox[{"r", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6165590731815386`*^9, 3.616559144224063*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.6165590936019745`*^9, 3.6165591474220686`*^9}}]
}, Closed]],

Cell["\<\
Also for arbitrary position u0 of the initial values with c0 = 0 Mathematica\
\[CloseCurlyQuote]s  DSolve doesn\[CloseCurlyQuote]t solve the equation:\
\>", "Text",
 CellChangeTimes->{{3.6165556473531213`*^9, 3.6165557078188276`*^9}, {
  3.6165595071275005`*^9, 3.6165595147247143`*^9}, {3.616559595376856*^9, 
  3.6165596105868826`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"diff", "[", 
        RowBox[{"f", ",", "k"}], "]"}], "[", "u", "]"}], "\[Equal]", "0"}], 
     ",", " ", 
     RowBox[{
      RowBox[{"f", "[", "u0", "]"}], " ", "\[Equal]", " ", "0"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "u0", "]"}], "==", "0"}]}], "}"}], ",", 
   RowBox[{"f", "[", "u", "]"}], ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.6165536891147904`*^9, 3.616553704340417*^9}, {
   3.6165537785497475`*^9, 3.6165538590770893`*^9}, {3.616553919901596*^9, 
   3.616553921211998*^9}, {3.616554017635768*^9, 3.616554023532578*^9}, {
   3.616554839398411*^9, 3.616554862876452*^9}, 3.6165549113301373`*^9, {
   3.616554985024667*^9, 3.61655499828469*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"DSolve", "::", "bvnul"}], "MessageName"], ":", 
  " ", "\<\"For some branches of the general solution, the given boundary \
conditions lead to an empty solution. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\
\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/DSolve/bvnul\\\", ButtonNote -> \
\\\"DSolve::bvnul\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6165549153705444`*^9, 3.616555001030295*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], "\[Rule]", "Indeterminate"}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6165548712380667`*^9, 3.6165549154485445`*^9, 
  3.616555001139495*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fpos", "[", 
   RowBox[{"k", ",", "0", ",", "u0"}], "]"}], "[", "u", "]"}]], "Input",
 CellChangeTimes->{{3.6165555090276785`*^9, 3.616555525906908*^9}, {
  3.6165560932331047`*^9, 3.6165560937947054`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "k"}], " ", 
        SuperscriptBox["u", "2"]}], "+", 
       RowBox[{"k", " ", 
        SuperscriptBox["u0", "2"]}]}]], " ", 
     SqrtBox[
      FractionBox[
       RowBox[{"1", "-", 
        RowBox[{"k", " ", 
         RowBox[{"(", 
          RowBox[{"u", "-", "u0"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"u", "+", "u0"}], ")"}]}]}], 
       RowBox[{"1", "+", 
        RowBox[{"k", " ", 
         SuperscriptBox["u0", "2"]}]}]]], " ", 
     RowBox[{"EllipticE", "[", 
      RowBox[{
       RowBox[{"ArcSin", "[", 
        RowBox[{"u", " ", 
         SqrtBox[
          FractionBox["k", 
           RowBox[{"1", "+", 
            RowBox[{"k", " ", 
             SuperscriptBox["u0", "2"]}]}]]]}], "]"}], ",", 
       RowBox[{"1", "+", 
        FractionBox["1", 
         RowBox[{"k", " ", 
          SuperscriptBox["u0", "2"]}]]}]}], "]"}]}], "+", 
    RowBox[{"k", " ", 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox[
        SuperscriptBox["u", "2"], 
        SuperscriptBox["u0", "2"]]}]], " ", 
     SqrtBox[
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"k", " ", 
         SuperscriptBox["u0", "2"]}]]}]], " ", 
     SuperscriptBox["u0", "2"], " ", 
     SqrtBox[
      FractionBox["1", 
       RowBox[{"1", "+", 
        RowBox[{"k", " ", 
         SuperscriptBox["u0", "2"]}]}]]], " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"k", " ", 
        RowBox[{"(", 
         RowBox[{"u", "-", "u0"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"u", "+", "u0"}], ")"}]}]}]], " ", 
     RowBox[{"EllipticE", "[", 
      RowBox[{
       RowBox[{"ArcSin", "[", 
        RowBox[{"u0", " ", 
         SqrtBox[
          FractionBox["k", 
           RowBox[{"1", "+", 
            RowBox[{"k", " ", 
             SuperscriptBox["u0", "2"]}]}]]]}], "]"}], ",", 
       RowBox[{"1", "+", 
        FractionBox["1", 
         RowBox[{"k", " ", 
          SuperscriptBox["u0", "2"]}]]}]}], "]"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{
    SqrtBox[
     RowBox[{"1", "-", 
      FractionBox[
       SuperscriptBox["u", "2"], 
       SuperscriptBox["u0", "2"]]}]], " ", 
    SqrtBox[
     FractionBox["k", 
      RowBox[{"1", "+", 
       RowBox[{"k", " ", 
        SuperscriptBox["u0", "2"]}]}]]], " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"k", " ", 
       RowBox[{"(", 
        RowBox[{"u", "-", "u0"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"u", "+", "u0"}], ")"}]}]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.616555510462881*^9, 3.6165555279037113`*^9}, 
   3.616555852665082*^9, 3.6165560988179145`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fpos", "[", 
   RowBox[{"k", ",", "0", ",", "u0"}], "]"}], "[", "u0", "]"}]], "Input",
 CellChangeTimes->{{3.6165553183660517`*^9, 3.6165553458377004`*^9}, {
  3.6165563652351823`*^9, 3.6165563753128*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Power", "::", "infy"}], "MessageName"], ":", 
  " ", "\<\"Infinite expression \[NoBreak]\\!\\(1\\/0\\)\[NoBreak] \
encountered. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/infy\\\", ButtonNote -> \
\\\"Power::infy\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6165553493789062`*^9, 3.6165563807260094`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Infinity", "::", "indet"}], "MessageName"], ":", 
  " ", "\<\"Indeterminate expression \[NoBreak]\\!\\(0\\\\ ComplexInfinity\\)\
\[NoBreak] encountered. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/indet\\\", ButtonNote -> \
\\\"Infinity::indet\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6165553493789062`*^9, 3.6165563807884097`*^9}],

Cell[BoxData["Indeterminate"], "Output",
 CellChangeTimes->{3.616555349441307*^9, 3.6165563807884097`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"fpos", "[", 
      RowBox[{"k", ",", "0", ",", "u0"}], "]"}], "[", "u", "]"}], ",", " ", 
    "u"}], "]"}], "/.", " ", 
  RowBox[{"u", "\[Rule]", " ", "u0"}]}]], "Input",
 CellChangeTimes->{{3.616556427354491*^9, 3.616556490253802*^9}, 
   3.616556676284128*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Power", "::", "infy"}], "MessageName"], ":", 
  " ", "\<\"Infinite expression \[NoBreak]\\!\\(1\\/\\@0\\)\[NoBreak] \
encountered. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/infy\\\", ButtonNote -> \
\\\"Power::infy\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6165566780625315`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Power", "::", "infy"}], "MessageName"], ":", 
  " ", "\<\"Infinite expression \[NoBreak]\\!\\(1\\/\\@0\\)\[NoBreak] \
encountered. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/infy\\\", ButtonNote -> \
\\\"Power::infy\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.616556678124932*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Power", "::", "infy"}], "MessageName"], ":", 
  " ", "\<\"Infinite expression \[NoBreak]\\!\\(1\\/\\@0\\)\[NoBreak] \
encountered. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/infy\\\", ButtonNote -> \
\\\"Power::infy\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.616556678187332*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], ":", 
  " ", "\<\"Further output of \[NoBreak]\\!\\(\\*StyleBox[\\(Power :: \
infy\\), \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.616556678218532*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Infinity", "::", "indet"}], "MessageName"], ":", 
  " ", "\<\"Indeterminate expression \[NoBreak]\\!\\(ComplexInfinity + \
ComplexInfinity\\)\[NoBreak] encountered. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/indet\\\", ButtonNote -> \
\\\"Infinity::indet\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.616556678265332*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Infinity", "::", "indet"}], "MessageName"], ":", 
  " ", "\<\"Indeterminate expression \[NoBreak]\\!\\(\\(0\\\\ 2\\\\ k\\\\ \
u0\\\\ ComplexInfinity\\)\\/\\@\\(k\\/\\(1 + \\(\\(k\\\\ \
u0\\^2\\)\\)\\)\\)\\)\[NoBreak] encountered. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/indet\\\", ButtonNote -> \
\\\"Infinity::indet\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.616556678327732*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Infinity", "::", "indet"}], "MessageName"], ":", 
  " ", "\<\"Indeterminate expression \[NoBreak]\\!\\(\\(0\\\\ u0\\\\ \
ComplexInfinity\\)\\/\\(u0\\^2\\\\ \\@\\(k\\/\\(1 + \\(\\(k\\\\ \
u0\\^2\\)\\)\\)\\)\\)\\)\[NoBreak] encountered. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/indet\\\", ButtonNote -> \
\\\"Infinity::indet\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.616556678390132*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], ":", 
  " ", "\<\"Further output of \[NoBreak]\\!\\(\\*StyleBox[\\(Infinity :: \
indet\\), \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.616556678405732*^9}],

Cell[BoxData["Indeterminate"], "Output",
 CellChangeTimes->{3.616556495417411*^9, 3.6165566784213324`*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Lemma.",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" ",
  FontColor->RGBColor[1, 0, 0]],
 "The functions fpos,fneg give no solutions in the case c0 = 0, u0= 0; in the \
case  c=0, u0\[NotEqual]0 they give solutions, but the initial conditions are \
not confirmed; they appear as limits.."
}], "Text",
 CellChangeTimes->{{3.616556804843954*^9, 3.616556809586363*^9}, {
   3.6165568403808165`*^9, 3.616557030482751*^9}, {3.616647033782697*^9, 
   3.616647072673566*^9}, {3.616647142312088*^9, 3.616647179627353*^9}, {
   3.616648193332734*^9, 3.616648202115549*^9}, {3.616648234501206*^9, 
   3.616648235686808*^9}, {3.6166482872290497`*^9, 3.616648300709821*^9}, 
   3.61682560562577*^9, 3.6186385827415705`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fpos", "[", 
       RowBox[{"k", ",", "0", ",", "u0"}], "]"}], "[", "u", "]"}], ",", " ", 
     "u"}], "]"}], ",", " ", 
   RowBox[{"u", " ", "\[Rule]", " ", "u0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6166479442626963`*^9, 3.616647983106765*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6166480439936714`*^9}]
}, Closed]],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.6166483460414143`*^9, 3.616648346048414*^9}}],

Cell[TextData[StyleBox["Example. The Pseudosphere",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.6165025853310537`*^9, 3.616502599183878*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "pseudosphere"}]], "Input",
 CellChangeTimes->{{3.616502650383168*^9, 3.6165026597899847`*^9}}],

Cell[BoxData[
 StyleBox["\<\"{u,v}->pseudosphere[a][u,v] is the standard parametrization of \
a pseudosphere of constant negative curvature -1/a^2.  To plot try \
pseudosphere[1][0,3Pi/2,0.001,Pi-0.001].\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.616502661771188*^9},
 CellTags->"Info3616509861-3077392"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"pseudosphere", "[", "1", "]"}], "[", 
  RowBox[{"0", ",", 
   RowBox[{"2", "*", "Pi"}], ",", "0", ",", "Pi"}], "]"}]], "Input",
 CellChangeTimes->{{3.616502709444872*^9, 3.6165027856198053`*^9}}],

Cell["", "Text",
 CellChangeTimes->{{3.6165053658799376`*^9, 3.6165054637389097`*^9}, {
   3.616566645708686*^9, 3.6165666542575006`*^9}, 3.6165667056439915`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"pseudosphere", "[", "a", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6165028578791323`*^9, 3.616502871778757*^9}, {
  3.6165029625865164`*^9, 3.616503026749429*^9}, {3.6165041297181664`*^9, 
  3.6165041330565724`*^9}, {3.6165667127420034`*^9, 3.6165667181864133`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", " ", 
    RowBox[{"Cos", "[", "u", "]"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"a", " ", 
    RowBox[{"Sin", "[", "u", "]"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", "v", "]"}], "+", 
      RowBox[{"Log", "[", 
       RowBox[{"Tan", "[", 
        FractionBox["v", "2"], "]"}], "]"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.616502874789562*^9, 3.616503027779031*^9, 
  3.6165041371281796`*^9, 3.616504453465535*^9, 3.6165667200116167`*^9}]
}, Closed]],

Cell["To get a parameter representation  in the form", "Text",
 CellChangeTimes->{{3.6165674048528194`*^9, 3.6165674411852827`*^9}, 
   3.6165674871585636`*^9, 3.618638587836862*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{"id", ",", "f"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6165674459900913`*^9, 3.616567471137336*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"u", " ", 
    RowBox[{"Cos", "[", "v", "]"}]}], ",", 
   RowBox[{"u", " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"f", "[", "u", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.616567462666521*^9, 3.616567471886137*^9}}]
}, Closed]],

Cell["we permute the variables u,v and consider", "Text",
 CellChangeTimes->{{3.616505550521862*^9, 3.616505557292274*^9}, {
   3.6165675014325886`*^9, 3.616567520293022*^9}, 3.6186386083970385`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"pseudosphere", "[", "a", "]"}], "[", 
  RowBox[{"0", ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.6165675315094414`*^9, 3.6165675827867317`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", " ", 
    RowBox[{"Sin", "[", "u", "]"}]}], ",", "0", ",", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", "u", "]"}], "+", 
      RowBox[{"Log", "[", 
       RowBox[{"Tan", "[", 
        FractionBox["u", "2"], "]"}], "]"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6165675884183416`*^9}]
}, Closed]],

Cell["\<\
transforming the variable u setting x = a*Sin[u] we obtain with x replaced by \
u again\
\>", "Text",
 CellChangeTimes->{{3.616567647168045*^9, 3.6165676902865205`*^9}, {
  3.616567724731381*^9, 3.6165677556350355`*^9}, {3.616567907080101*^9, 
  3.616567916174917*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fpssph", "[", "a_", "]"}], "[", "u_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"a", "^", "2"}], "-", 
     RowBox[{"u", "^", "2"}]}], "]"}], " ", "+", " ", 
   RowBox[{"a", "*", 
    RowBox[{"Log", "[", " ", 
     RowBox[{"u", "/", 
      RowBox[{"(", 
       RowBox[{"a", "+", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"a", "^", "2"}], " ", "-", " ", 
          RowBox[{"u", "^", "2"}]}], "]"}]}], ")"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.616504417148671*^9, 3.616504465087556*^9}, {
   3.616567776960273*^9, 3.6165678371139784`*^9}, 3.6165678964252825`*^9}],

Cell["This function generates the pseudospheres by", "Text",
 CellChangeTimes->{{3.6165679776858253`*^9, 3.616568022395504*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{"id", ",", 
    RowBox[{"fpssph", "[", "a", "]"}]}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6165680314435196`*^9, 3.6165680611459723`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"u", " ", 
    RowBox[{"Cos", "[", "v", "]"}]}], ",", 
   RowBox[{"u", " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["u", "2"]}]], "+", 
    RowBox[{"a", " ", 
     RowBox[{"Log", "[", 
      FractionBox["u", 
       RowBox[{"a", "+", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          SuperscriptBox["u", "2"]}]]}]], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6165680664967813`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{"id", ",", 
      RowBox[{"fpssph", "[", "1", "]"}]}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6165660142663765`*^9, 3.616566114028552*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{"id", ",", 
      RowBox[{"(", 
       RowBox[{"-", 
        RowBox[{"fpssph", "[", "1", "]"}]}], ")"}]}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6165660142663765`*^9, 3.6165662161619315`*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"%", ",", "%%"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "4"}], ",", "4"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616566249935991*^9, 3.61656627787564*^9}, 
   3.616566325674124*^9, {3.616566392411041*^9, 3.616566402129858*^9}, {
   3.616566463983967*^9, 3.6165664749195857`*^9}, {3.6165681795314384`*^9, 
   3.616568184476647*^9}}],

Cell["The function fpssph satisfies the initial conditions", "Text",
 CellChangeTimes->{{3.6165683003692503`*^9, 3.6165683577773514`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fpssph", "[", "a", "]"}], "[", "a", "]"}]], "Input",
 CellChangeTimes->{{3.616568367574168*^9, 3.6165683886186056`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6165683902410083`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"fpssph", "[", "a", "]"}], "[", "u", "]"}], ",", "u"}], "]"}], "/.", 
  RowBox[{"u", "\[Rule]", "a"}]}]], "Input",
 CellChangeTimes->{{3.616568393485814*^9, 3.616568457258726*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Power", "::", "infy"}], "MessageName"], ":", 
  " ", "\<\"Infinite expression \[NoBreak]\\!\\(1\\/\\@0\\)\[NoBreak] \
encountered. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/infy\\\", ButtonNote -> \
\\\"Power::infy\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.616568459910731*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Power", "::", "infy"}], "MessageName"], ":", 
  " ", "\<\"Infinite expression \[NoBreak]\\!\\(1\\/\\@0\\)\[NoBreak] \
encountered. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/infy\\\", ButtonNote -> \
\\\"Power::infy\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6165684599731307`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Infinity", "::", "indet"}], "MessageName"], ":", 
  " ", "\<\"Indeterminate expression \[NoBreak]\\!\\(ComplexInfinity + \
ComplexInfinity\\)\[NoBreak] encountered. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/indet\\\", ButtonNote -> \
\\\"Infinity::indet\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.616568460019931*^9}],

Cell[BoxData["Indeterminate"], "Output",
 CellChangeTimes->{3.616568460035531*^9}]
}, Closed]],

Cell["Consider the limit instead:", "Text",
 CellChangeTimes->{{3.6165687093083687`*^9, 3.616568729994005*^9}, 
   3.61656876122526*^9}],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"fpssph", "[", "a", "]"}], "[", "u", "]"}], ",", "u"}], "]"}], 
    "]"}], ",", 
   RowBox[{"u", "->", "a"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616568495400793*^9, 3.616568499332*^9}, {
   3.6165685328564587`*^9, 3.6165686361442404`*^9}, 3.6165686718059025`*^9}],

Cell["Of course, it solves the differential equation", "Text",
 CellChangeTimes->{3.6165688647470417`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"diff", "[", 
     RowBox[{
      RowBox[{"fpssph", "[", "a", "]"}], ",", 
      RowBox[{
       RowBox[{"-", "1"}], "/", 
       RowBox[{"a", "^", "2"}]}]}], "]"}], "[", "u", "]"}], ",", 
   RowBox[{"a", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6165688696298504`*^9, 3.616568946491185*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.616568919144337*^9, 3.6165689476143875`*^9}}]
}, Closed]],

Cell["\<\
But it is not contained in the families defined by fpos,fneg:\
\>", "Text",
 CellChangeTimes->{{3.616505712902547*^9, 3.616505779826665*^9}, {
  3.616568977098439*^9, 3.616568979142043*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fpos", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "/", 
     RowBox[{"a", "^", "2"}]}], ",", " ", "0", ",", "a"}], "]"}], "[", "u", 
  "]"}]], "Input",
 CellChangeTimes->{{3.6165048110805635`*^9, 3.6165048262437897`*^9}, {
  3.616504861593452*^9, 3.6165048756490765`*^9}, {3.6165689908732634`*^9, 
  3.616569003072485*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Power", "::", "infy"}], "MessageName"], ":", 
  " ", "\<\"Infinite expression \[NoBreak]\\!\\(1\\/0\\)\[NoBreak] \
encountered. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/infy\\\", ButtonNote -> \
\\\"Power::infy\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6165048766630783`*^9, 3.6165690102016973`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Power", "::", "infy"}], "MessageName"], ":", 
  " ", "\<\"Infinite expression \[NoBreak]\\!\\(1\\/0\\)\[NoBreak] \
encountered. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/infy\\\", ButtonNote -> \
\\\"Power::infy\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6165048766630783`*^9, 3.616569010248497*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Power", "::", "infy"}], "MessageName"], ":", 
  " ", "\<\"Infinite expression \[NoBreak]\\!\\(1\\/0\\)\[NoBreak] \
encountered. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/infy\\\", ButtonNote -> \
\\\"Power::infy\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6165048766630783`*^9, 3.6165690103108974`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], ":", 
  " ", "\<\"Further output of \[NoBreak]\\!\\(\\*StyleBox[\\(Power :: \
infy\\), \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6165048766630783`*^9, 3.6165690103420973`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Infinity", "::", "indet"}], "MessageName"], ":", 
  " ", "\<\"Indeterminate expression \[NoBreak]\\!\\(ComplexInfinity + \
ComplexInfinity\\)\[NoBreak] encountered. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/indet\\\", ButtonNote -> \
\\\"Infinity::indet\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6165048766630783`*^9, 3.6165690104044976`*^9}],

Cell[BoxData["Indeterminate"], "Output",
 CellChangeTimes->{3.616504876881479*^9, 3.6165690104044976`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"gauss", "[", 
   RowBox[{"sfrev", "[", 
    RowBox[{"id", ",", " ", 
     RowBox[{"fpssph", "[", "a", "]"}]}], "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6165033554732065`*^9, 3.616503377469245*^9}, 
   3.616503425361329*^9, {3.616503627818485*^9, 3.6165036492685223`*^9}, {
   3.6165040282711887`*^9, 3.616504038239606*^9}, {3.6165690695598016`*^9, 
   3.6165691004322557`*^9}, 3.6165691331455135`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["u", "2"], "+", 
      RowBox[{"a", " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["u", "2"]}]]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"]}], "-", 
      SuperscriptBox["u", "2"], "+", 
      RowBox[{"2", " ", "a", " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["u", "2"]}]]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["u", "2"]}], "+", 
      SuperscriptBox["u", "4"], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["u", "2"]}]]}], "-", 
      RowBox[{"3", " ", "a", " ", 
       SuperscriptBox["u", "2"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["u", "2"]}]]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "8"}], " ", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["u", "2"]}], "-", 
      SuperscriptBox["u", "4"], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["u", "2"]}]]}], "+", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["u", "2"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["u", "2"]}]]}]}], ")"}], " ", 
    RowBox[{"\[Sqrt]", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox["u", "2"], " ", 
            RowBox[{"Cos", "[", "v", "]"}]}], 
           SqrtBox[
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             SuperscriptBox["u", "2"]}]]], "-", 
          FractionBox[
           RowBox[{"a", " ", 
            SuperscriptBox["u", "2"], " ", 
            RowBox[{"Cos", "[", "v", "]"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "+", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["a", "2"], "-", 
                SuperscriptBox["u", "2"]}]]}], ")"}], "2"]], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["u", "2"], " ", 
            RowBox[{"Cos", "[", "v", "]"}]}], 
           RowBox[{
            SqrtBox[
             RowBox[{
              SuperscriptBox["a", "2"], "-", 
              SuperscriptBox["u", "2"]}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "+", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["a", "2"], "-", 
                 SuperscriptBox["u", "2"]}]]}], ")"}], "2"]}]], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            RowBox[{"Cos", "[", "v", "]"}]}], 
           RowBox[{"a", "+", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["a", "2"], "-", 
              SuperscriptBox["u", "2"]}]]}]], "-", 
          FractionBox[
           RowBox[{"a", " ", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["a", "2"], "-", 
              SuperscriptBox["u", "2"]}]], " ", 
            RowBox[{"Cos", "[", "v", "]"}]}], 
           RowBox[{"a", "+", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["a", "2"], "-", 
              SuperscriptBox["u", "2"]}]]}]]}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox["u", "2"], " ", 
            RowBox[{"Sin", "[", "v", "]"}]}], 
           SqrtBox[
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             SuperscriptBox["u", "2"]}]]], "-", 
          FractionBox[
           RowBox[{"a", " ", 
            SuperscriptBox["u", "2"], " ", 
            RowBox[{"Sin", "[", "v", "]"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "+", 
              SqrtBox[
               RowBox[{
                SuperscriptBox["a", "2"], "-", 
                SuperscriptBox["u", "2"]}]]}], ")"}], "2"]], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["u", "2"], " ", 
            RowBox[{"Sin", "[", "v", "]"}]}], 
           RowBox[{
            SqrtBox[
             RowBox[{
              SuperscriptBox["a", "2"], "-", 
              SuperscriptBox["u", "2"]}]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "+", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["a", "2"], "-", 
                 SuperscriptBox["u", "2"]}]]}], ")"}], "2"]}]], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            RowBox[{"Sin", "[", "v", "]"}]}], 
           RowBox[{"a", "+", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["a", "2"], "-", 
              SuperscriptBox["u", "2"]}]]}]], "-", 
          FractionBox[
           RowBox[{"a", " ", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["a", "2"], "-", 
              SuperscriptBox["u", "2"]}]], " ", 
            RowBox[{"Sin", "[", "v", "]"}]}], 
           RowBox[{"a", "+", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["a", "2"], "-", 
              SuperscriptBox["u", "2"]}]]}]]}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"u", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", "v", "]"}], "2"]}], "+", 
          RowBox[{"u", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "v", "]"}], "2"]}]}], ")"}], "2"]}], 
      ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{
    SqrtBox[
     SuperscriptBox["a", "2"]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["u", "2"]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["u", "2"]}]]}], ")"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SuperscriptBox["a", "2"]}], "+", 
       SuperscriptBox["u", "2"], "-", 
       RowBox[{"2", " ", "a", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          SuperscriptBox["u", "2"]}]]}]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"8", " ", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["u", "2"]}], "+", 
      SuperscriptBox["u", "4"], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "3"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["u", "2"]}]]}], "-", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["u", "2"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["u", "2"]}]]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Cos", "[", "v", "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "v", "]"}], "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["u", "2"], "+", 
      RowBox[{
       SuperscriptBox["u", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "v", "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox["u", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "v", "]"}], "2"]}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.616503436562149*^9, 3.6165036377245026`*^9, 
  3.6165038009319887`*^9, 3.616504043153614*^9, 3.616569151350745*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", ",", " ", 
   RowBox[{"v", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616503449276171*^9, 3.6165034784170227`*^9}, 
   3.6165040615460467`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["1", 
   SuperscriptBox["a", "2"]]}]], "Output",
 CellChangeTimes->{
  3.6165034801018257`*^9, 3.616503900007763*^9, {3.6165040497212257`*^9, 
   3.6165040656020536`*^9}, 3.616569161521963*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"meancurvature", "[", 
     RowBox[{"sfrev", "[", 
      RowBox[{"id", ",", " ", 
       RowBox[{"fpssph", "[", "a", "]"}]}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{"a", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6165033554732065`*^9, 3.616503377469245*^9}, 
   3.616503425361329*^9, {3.616503627818485*^9, 3.6165036492685223`*^9}, {
   3.6165040282711887`*^9, 3.616504038239606*^9}, {3.6165690695598016`*^9, 
   3.6165691004322557`*^9}, 3.6165691331455135`*^9, {3.6166489395359545`*^9, 
   3.6166490211446223`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["a", "2"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["u", "2"]}]}], 
   RowBox[{"2", " ", "a", " ", "u", " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "-", "u"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "u"}], ")"}]}]]}]]}]], "Output",
 CellChangeTimes->{3.6166490585117598`*^9, 3.6166557145691576`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"%", "/.", " ", 
    RowBox[{"a", "\[Rule]", "1"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", ".0001", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616649090407584*^9, 3.616649167744007*^9}, {
  3.6166492201040025`*^9, 3.616649235935908*^9}, {3.6166556733628006`*^9, 
  3.6166556957920837`*^9}, {3.6166561977777953`*^9, 3.616656227289483*^9}, {
  3.616656471546454*^9, 3.616656516074001*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"prcurvatures", "[", 
     RowBox[{"sfrev", "[", 
      RowBox[{"id", ",", " ", 
       RowBox[{"fpssph", "[", "a", "]"}]}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{"a", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6165033554732065`*^9, 3.616503377469245*^9}, 
   3.616503425361329*^9, {3.616503627818485*^9, 3.6165036492685223`*^9}, {
   3.6165040282711887`*^9, 3.616504038239606*^9}, {3.6165690695598016`*^9, 
   3.6165691004322557`*^9}, 3.6165691331455135`*^9, {3.6166489395359545`*^9, 
   3.6166490211446223`*^9}, {3.6166493015136585`*^9, 3.616649308457056*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["u", 
    RowBox[{"a", " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "-", "u"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", "u"}], ")"}]}]]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     SqrtBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "-", "u"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", "u"}], ")"}]}]], 
     RowBox[{"a", " ", "u"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6166493411119237`*^9, 3.616650288627118*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{"a", "\[Rule]", "1"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", ".0001", ",", "1.5"}], "}"}], ",", " ", 
   RowBox[{"PlotStyle", " ", "\[Rule]", "Red"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616649858609523*^9, 3.6166499597283063`*^9}, {
  3.6166500054969244`*^9, 3.6166500197367387`*^9}, {3.6166500609120936`*^9, 
  3.6166501297290297`*^9}, {3.6166501853292103`*^9, 3.6166502075764823`*^9}, {
  3.6166502487998405`*^9, 3.616650253008081*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwV1Gk41fkbBnB7KLsUQwkZS0NSksr9DUmRMRgkUUybRBFJFFqN7LSckJp/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     "]], LineBox[CompressedData["
1:eJwVkGk81Gsfh2XJTsga4VRCC4U28lNOnVKn7CJli7KvI6GSpYiQ5dhpIWsq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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0.0001, 1.5}, {-8.547502222588749, 6.399089404667827}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.6166499621024423`*^9, 3.616650021946865*^9, 
  3.616650131119109*^9, 3.6166507073320665`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
3.8.4. Surfaces of Revolution of Constant Positive Gaussian Curvature\
\>", "Subsubsection",
 CellChangeTimes->{{3.592460039870927*^9, 3.592460088511812*^9}, {
   3.592460175341565*^9, 3.5924602045760164`*^9}, {3.592743295809393*^9, 
   3.5927433008794017`*^9}, 3.59341846877223*^9, {3.6166566434732876`*^9, 
   3.616656645879425*^9}, 3.6167420110361643`*^9, 3.6170153528088784`*^9, 
   3.620482334629857*^9}],

Cell["\<\
In this and the following subsection we shall find surfaces of revolution for \
all values c0 \[NotEqual] 0. We distinguish the cases u0 = 0 and u0 \
\[NotEqual] 0. In the first case the origin is a singular point of the \
surface, since it lies on the rotation axis  \
\>", "Text",
 CellChangeTimes->{{3.616669104636664*^9, 3.6166694203500185`*^9}, {
  3.616669476541317*^9, 3.616669536351822*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fpos", "[", 
     RowBox[{"k", ",", "c0", ",", "0"}], "]"}], "[", "u", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c0", "\[NotEqual]", "0"}], ",", " ", 
     RowBox[{"k", ">", "0"}], ",", " ", 
     RowBox[{"u", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616669555695856*^9, 3.6166696676728525`*^9}, {
  3.6166697333333683`*^9, 3.616669744144187*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SqrtBox[
    RowBox[{"1", "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
      SuperscriptBox["u", "2"]}]}]], " ", 
   SqrtBox[
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["c0", "2"]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
      SuperscriptBox["u", "2"]}]}]], " ", 
   RowBox[{"EllipticE", "[", 
    RowBox[{
     RowBox[{"ArcSin", "[", 
      RowBox[{
       SqrtBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}]], " ", "u"}], "]"}],
      ",", 
     RowBox[{"-", 
      FractionBox["1", 
       SuperscriptBox["c0", "2"]]}]}], "]"}]}], 
  RowBox[{
   SqrtBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}]], " ", 
   SqrtBox[
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
      SuperscriptBox["u", "2"]}]}]], " ", 
   SqrtBox[
    RowBox[{"1", "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
       SuperscriptBox["u", "2"]}], 
      SuperscriptBox["c0", "2"]]}]]}]]], "Output",
 CellChangeTimes->{3.616669673413663*^9, 3.616669748028594*^9}]
}, Closed]],

Cell["Manual simplification yields", "Text",
 CellChangeTimes->{{3.616670096564406*^9, 3.616670134612873*^9}, {
  3.6166702113771152`*^9, 3.6166702354174905`*^9}}],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fp0", "[", 
     RowBox[{"k_", ",", " ", "c0_"}], "]"}], "[", "u_", "]"}], " ", ":=", " ",
    "\n", "  ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{"c0", "/", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"k", "*", 
          RowBox[{"(", 
           RowBox[{"1", " ", "+", " ", 
            RowBox[{"c0", "^", "2"}]}], ")"}]}], "]"}]}], ")"}]}], ")"}], "*",
     "\n", "   ", 
    RowBox[{"EllipticE", "[", 
     RowBox[{
      RowBox[{"ArcSin", "[", 
       RowBox[{
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", " ", "+", " ", 
            RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k"}], "]"}], "*", "\n", 
        "      ", "u"}], "]"}], ",", " ", 
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"1", "/", 
         RowBox[{"c0", "^", "2"}]}], ")"}]}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6166702562526817`*^9, 3.6166704501657734`*^9}, {
  3.6166705339745665`*^9, 3.61667054015092*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", 
     RowBox[{"sfrev", "[", 
      RowBox[{"id", ",", " ", 
       RowBox[{"fp0", "[", 
        RowBox[{"k", ",", "c0"}], "]"}]}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c0", "\[NotEqual]", "0"}], ",", " ", 
     RowBox[{"k", ">", "0"}], ",", " ", 
     RowBox[{"u", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6166704583212395`*^9, 3.6166705232119513`*^9}, 
   3.6166705710216856`*^9, 3.616670617478343*^9}],

Cell[BoxData["k"], "Output",
 CellChangeTimes->{3.616670737099185*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{"id", ",", 
      RowBox[{"fp0", "[", 
       RowBox[{"2", ",", "2"}], "]"}]}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"PlotPoints", " ", "\[Rule]", " ", "100"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6166780151621265`*^9, 3.6166782994893894`*^9}, {
   3.6166783444659615`*^9, 3.6166783458900433`*^9}, 3.6166786841703916`*^9, 
   3.6166787147221394`*^9, {3.6166787502021685`*^9, 3.616678774457556*^9}, {
   3.6166788196831427`*^9, 3.616678821785263*^9}, {3.616678856666258*^9, 
   3.61667885896939*^9}, {3.616678890130172*^9, 3.616678945665348*^9}, {
   3.616678976538114*^9, 3.6166790022815866`*^9}}],

Cell["\<\
Try the last cell with distinct values of c0 and k.  You get surfaces of \
revolution with positive curvature k of the conical type. By definition \
clearly is\
\>", "Text",
 CellChangeTimes->{{3.616678530133581*^9, 3.61667867119765*^9}, {
  3.616679025684925*^9, 3.6166790431089215`*^9}, {3.6166791032693624`*^9, 
  3.616679131340968*^9}, {3.61863870244693*^9, 3.6186387048230658`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fp0", "[", 
    RowBox[{"k", ",", 
     RowBox[{"-", "c0"}]}], "]"}], "[", "u", "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"fp0", "[", 
    RowBox[{"k", ",", 
     RowBox[{"-", "c0"}]}], "]"}], "[", "u", "]"}]}]], "Input",
 CellChangeTimes->{{3.6166791549483185`*^9, 3.616679225512355*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.6166792270884447`*^9}]
}, Closed]],

Cell["Case u0 \[NotEqual] 0", "Text",
 CellChangeTimes->{{3.616679901846039*^9, 3.6166799211331415`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fpos", "[", 
     RowBox[{"k", ",", "c0", ",", "u0"}], "]"}], "[", "u", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u0", ">", "0"}], ",", 
     RowBox[{"c0", ">", "0"}], ",", " ", 
     RowBox[{"k", ">", "0"}], ",", " ", 
     RowBox[{"u", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616669555695856*^9, 3.6166696676728525`*^9}, {
  3.6166697333333683`*^9, 3.616669744144187*^9}, {3.6166799831776905`*^9, 
  3.616680007937107*^9}, {3.616680485873443*^9, 3.616680487080512*^9}, {
  3.616730007161146*^9, 3.61673001505476*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "k"}], " ", 
        SuperscriptBox["u", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["c0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u", "2"]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
        SuperscriptBox["u0", "2"]}]}]], " ", 
     SqrtBox[
      FractionBox[
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
         RowBox[{"(", 
          RowBox[{"u", "-", "u0"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"u", "+", "u0"}], ")"}]}]}], 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
         SuperscriptBox["u0", "2"]}]}]]], " ", 
     RowBox[{"EllipticE", "[", 
      RowBox[{
       RowBox[{"ArcSin", "[", 
        RowBox[{"u", " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
           RowBox[{"1", "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
             SuperscriptBox["u0", "2"]}]}]]]}], "]"}], ",", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c0", "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}]]}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["c0", "2"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
        SuperscriptBox["u0", "2"]}]}], ")"}], " ", 
     SqrtBox[
      FractionBox["1", 
       RowBox[{
        SuperscriptBox["c0", "2"], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["c0", "4"]}], ")"}], " ", "k", " ", 
         SuperscriptBox["u0", "2"]}], "-", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["c0", "2"]}], ")"}], "2"], " ", 
         SuperscriptBox["k", "2"], " ", 
         SuperscriptBox["u0", "4"]}]}]]], " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
        RowBox[{"(", 
         RowBox[{"u", "-", "u0"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"u", "+", "u0"}], ")"}]}]}]], " ", 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
         SuperscriptBox["u", "2"]}], 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["c0", "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
          SuperscriptBox["u0", "2"]}]}]]}]], " ", 
     RowBox[{"EllipticE", "[", 
      RowBox[{
       RowBox[{"ArcSin", "[", 
        RowBox[{"u0", " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
           RowBox[{"1", "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
             SuperscriptBox["u0", "2"]}]}]]]}], "]"}], ",", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c0", "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}]]}]}], "]"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{
    SqrtBox[
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
          RowBox[{"(", 
           RowBox[{"u", "-", "u0"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"u", "+", "u0"}], ")"}]}]}], ")"}]}], 
      RowBox[{"1", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
        SuperscriptBox["u0", "2"]}]}]]], " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
        SuperscriptBox["u", "2"]}], 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["c0", "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
         SuperscriptBox["u0", "2"]}]}]]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.6166801153912525`*^9, 3.616680592534544*^9, 
  3.616730085208083*^9}]
}, Closed]],

Cell["We use this result to define", "Text",
 CellChangeTimes->{{3.6167304861131873`*^9, 3.6167304980784082`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fp1", "[", 
    RowBox[{"k_", ",", " ", "c0_", ",", " ", "u0_"}], "]"}], "[", "u_", "]"}],
   " ", ":=", " ", "\n", "  ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"-", "k"}], ")"}], "*", 
         RowBox[{"u", "^", "2"}]}], " ", "-", " ", 
        RowBox[{
         RowBox[{"c0", "^", "2"}], "*", "\n", "        ", 
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", 
           RowBox[{"k", "*", 
            RowBox[{"u", "^", "2"}]}]}], ")"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", 
           RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", "\n", "        ", 
         RowBox[{"u0", "^", "2"}]}]}], "]"}], "*", 
      RowBox[{"Sqrt", "[", "\n", "      ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", " ", "-", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "+", " ", 
             RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
           RowBox[{"(", 
            RowBox[{"u", " ", "-", " ", "u0"}], ")"}], "*", "\n", "         ", 
           RowBox[{"(", 
            RowBox[{"u", " ", "+", " ", "u0"}], ")"}]}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"1", " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "+", " ", 
             RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", "\n", 
           "         ", 
           RowBox[{"u0", "^", "2"}]}]}], ")"}]}], "]"}], "*", 
      RowBox[{"EllipticE", "[", "\n", "      ", 
       RowBox[{
        RowBox[{"ArcSin", "[", 
         RowBox[{"u", "*", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", " ", "+", " ", 
                RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k"}], ")"}], "/", 
            "\n", "          ", 
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", " ", "+", " ", 
                 RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
               RowBox[{"u0", "^", "2"}]}]}], ")"}]}], "]"}]}], "]"}], ",", 
        " ", "\n", "      ", 
        RowBox[{"1", " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", " ", "+", " ", 
            RowBox[{"c0", "^", "2"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"c0", "^", "2"}]}], " ", "+", " ", "\n", "         ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", " ", "+", " ", 
               RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
             RowBox[{"u0", "^", "2"}]}]}], ")"}]}]}]}], "]"}]}], " ", "+", 
     " ", "\n", "    ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"c0", "^", "2"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", 
           RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
         RowBox[{"u0", "^", "2"}]}]}], ")"}], "*", "\n", "     ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c0", "^", "2"}], " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], " ", "+", " ", 
             RowBox[{"c0", "^", "4"}]}], ")"}], "*", "k", "*", "\n", 
           "         ", 
           RowBox[{"u0", "^", "2"}]}], " ", "-", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{"c0", "^", "2"}]}], ")"}], "^", "2"}], "*", 
           RowBox[{"k", "^", "2"}], "*", "\n", "         ", 
           RowBox[{"u0", "^", "4"}]}]}], ")"}]}], "]"}], "*", 
      RowBox[{"Sqrt", "[", "\n", "      ", 
       RowBox[{
        RowBox[{"-", "1"}], " ", "+", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", 
           RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
         RowBox[{"(", 
          RowBox[{"u", " ", "-", " ", "u0"}], ")"}], "*", "\n", "        ", 
         RowBox[{"(", 
          RowBox[{"u", " ", "+", " ", "u0"}], ")"}]}]}], "]"}], "*", 
      RowBox[{"Sqrt", "[", "\n", "      ", 
       RowBox[{"1", " ", "-", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "+", " ", 
             RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
           RowBox[{"u", "^", "2"}]}], ")"}], "/", "\n", "        ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"c0", "^", "2"}]}], " ", "+", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
            RowBox[{"u0", "^", "2"}]}]}], ")"}]}]}], "]"}], "*", "\n", 
      "     ", 
      RowBox[{"EllipticE", "[", 
       RowBox[{
        RowBox[{"ArcSin", "[", "\n", "       ", 
         RowBox[{"u0", "*", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", " ", "+", " ", 
                RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k"}], ")"}], "/", 
            "\n", "          ", 
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", " ", "+", " ", 
                 RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
               RowBox[{"u0", "^", "2"}]}]}], ")"}]}], "]"}]}], "]"}], ",", 
        " ", "\n", "      ", 
        RowBox[{"1", " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", " ", "+", " ", 
            RowBox[{"c0", "^", "2"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"c0", "^", "2"}]}], " ", "+", " ", "\n", "         ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", " ", "+", " ", 
               RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
             RowBox[{"u0", "^", "2"}]}]}], ")"}]}]}]}], "]"}]}]}], ")"}], "/",
    "\n", "   ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", 
           RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], " ", "+", " ", "\n", "        ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
            RowBox[{"(", 
             RowBox[{"u", " ", "-", " ", "u0"}], ")"}], "*", "\n", 
            "         ", 
            RowBox[{"(", 
             RowBox[{"u", " ", "+", " ", "u0"}], ")"}]}]}], ")"}]}], ")"}], 
       "/", 
       RowBox[{"(", 
        RowBox[{"1", " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", " ", "+", " ", 
            RowBox[{"c0", "^", "2"}]}], ")"}], "*", "\n", "        ", "k", 
          "*", 
          RowBox[{"u0", "^", "2"}]}]}], ")"}]}], "]"}], "*", 
     RowBox[{"Sqrt", "[", "\n", "     ", 
      RowBox[{"1", " ", "-", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", " ", "+", " ", 
            RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
          RowBox[{"u", "^", "2"}]}], ")"}], "/", "\n", "       ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c0", "^", "2"}]}], " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "+", " ", 
             RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
           RowBox[{"u0", "^", "2"}]}]}], ")"}]}]}], "]"}]}], 
    ")"}]}]}]], "Input",
 CellChangeTimes->{{3.6167298286968327`*^9, 3.61672993555702*^9}, {
  3.6167304526511283`*^9, 3.6167304756923685`*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"sfrev", "[", 
      RowBox[{"id", ",", 
       RowBox[{"fp1", "[", 
        RowBox[{"1", ",", "2", ",", "1"}], "]"}]}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0.7", ",", "1.3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotPoints", " ", "\[Rule]", " ", "100"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6167305403076825`*^9, 3.6167307478972473`*^9}, {
  3.6167308107965574`*^9, 3.616730822480978*^9}, {3.616731196585235*^9, 
  3.616731217005671*^9}, {3.616731885373245*^9, 3.616731895684863*^9}, {
  3.6167420367706366`*^9, 3.6167420449371033`*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"sfrev", "[", 
      RowBox[{"id", ",", 
       RowBox[{"-", 
        RowBox[{"fp1", "[", 
         RowBox[{"1", ",", "1", ",", "1"}], "]"}]}]}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0.7", ",", "1.3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotPoints", " ", "\[Rule]", " ", "100"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6167305403076825`*^9, 3.6167307478972473`*^9}, {
   3.6167308107965574`*^9, 3.616730822480978*^9}, {3.616730915675542*^9, 
   3.6167309254723587`*^9}, 3.6167312361001043`*^9, {3.61673193398293*^9, 
   3.616731941361743*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"%", ",", "%%"}], "}"}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6167309502140026`*^9, 3.6167309896664715`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
3.8.5. Surfaces of Revolution of Constant Negative Gaussian Curvature\
\>", "Subsubsection",
 CellChangeTimes->{{3.592460039870927*^9, 3.592460088511812*^9}, {
   3.592460175341565*^9, 3.5924602045760164`*^9}, {3.592743295809393*^9, 
   3.5927433008794017`*^9}, 3.592743439329645*^9, {3.592743475989709*^9, 
   3.5927434804045167`*^9}, 3.5934185161963134`*^9, {3.6126938340250387`*^9, 
   3.612693841775482*^9}, 3.6128496103122997`*^9, 3.6170153609043417`*^9, {
   3.620482324521039*^9, 3.6204823404486666`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fpos", "[", 
     RowBox[{"k", ",", "c0", ",", "0"}], "]"}], "[", "u", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c0", ">", "0"}], ",", " ", 
     RowBox[{"k", "<", "0"}], ",", " ", 
     RowBox[{"u", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616669555695856*^9, 3.6166696676728525`*^9}, {
  3.6166697333333683`*^9, 3.616669744144187*^9}, {3.6167321924753847`*^9, 
  3.6167322001505976`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SqrtBox[
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["c0", "2"]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
       SuperscriptBox["u", "2"]}]}]], " ", 
    RowBox[{"EllipticE", "[", 
     RowBox[{
      RowBox[{"ArcSin", "[", 
       RowBox[{
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}]], " ", "u"}], 
       "]"}], ",", 
      RowBox[{"-", 
       FractionBox["1", 
        SuperscriptBox["c0", "2"]]}]}], "]"}]}], 
   SqrtBox[
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["c0", "2"]}], ")"}]}], " ", "k", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
         SuperscriptBox["u", "2"]}], 
        SuperscriptBox["c0", "2"]]}], ")"}]}]]]}]], "Output",
 CellChangeTimes->{3.61673220710821*^9}]
}, Closed]],

Cell["Manual simplification leads to", "Text",
 CellChangeTimes->{{3.616732738679144*^9, 3.616732753233969*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fn0", "[", 
    RowBox[{"k_", ",", " ", "c0_"}], "]"}], "[", "u_", "]"}], " ", ":=", " ", 
  "\n", "  ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"I", "*", 
     RowBox[{"(", 
      RowBox[{"c0", "/", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"-", "k"}], ")"}], "*", 
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", 
           RowBox[{"c0", "^", "2"}]}], ")"}]}], "]"}]}], ")"}]}], ")"}], "*", 
   "\n", "   ", 
   RowBox[{"EllipticE", "[", 
    RowBox[{
     RowBox[{"ArcSin", "[", "\n", "     ", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", 
           RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k"}], "]"}], "*", "u"}], 
      "]"}], ",", " ", "\n", "    ", 
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{"1", "/", 
        RowBox[{"c0", "^", "2"}]}], ")"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6167327637639875`*^9, 3.616733006672014*^9}, {
  3.616733986712536*^9, 3.6167341589992385`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", 
     RowBox[{"sfrev", "[", 
      RowBox[{"id", ",", 
       RowBox[{"fn0", "[", 
        RowBox[{"k", ",", "c0"}], "]"}]}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"k", "<", "0"}], ",", " ", 
     RowBox[{"c0", ">", "0"}], ",", " ", 
     RowBox[{"u", "\[Element]", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6167330199476376`*^9, 3.6167331565102777`*^9}, 
   3.616733240797226*^9, 3.6167345350846987`*^9}],

Cell[BoxData["k"], "Output",
 CellChangeTimes->{3.616733190471537*^9, 3.6167332675200725`*^9, 
  3.6167343304435396`*^9, 3.6167347031905937`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{"id", ",", 
      RowBox[{"fn0", "[", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "2"}], "]"}]}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"PlotPoints", " ", "\[Rule]", " ", "100"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6166780151621265`*^9, 3.6166782994893894`*^9}, {
   3.6166783444659615`*^9, 3.6166783458900433`*^9}, 3.6166786841703916`*^9, 
   3.6166787147221394`*^9, {3.6166787502021685`*^9, 3.616678774457556*^9}, {
   3.6166788196831427`*^9, 3.616678821785263*^9}, {3.616678856666258*^9, 
   3.61667885896939*^9}, {3.616678890130172*^9, 3.616678945665348*^9}, {
   3.616678976538114*^9, 3.6166790022815866`*^9}, {3.6167349679230595`*^9, 
   3.6167349745998707`*^9}}],

Cell["\<\
This is a surface of revolution of constant negative curvature of conical \
shape. Try with other parameters c0>0, k<0.\
\>", "Text",
 CellChangeTimes->{{3.616735074408846*^9, 3.6167352156982946`*^9}, {
  3.616736829817529*^9, 3.616736840097947*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fpos", "[", 
     RowBox[{"k", ",", "c0", ",", "u0"}], "]"}], "[", "u", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u0", ">", "0"}], ",", 
     RowBox[{"c0", ">", "0"}], ",", " ", 
     RowBox[{"k", "<", "0"}], ",", " ", 
     RowBox[{"u", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616669555695856*^9, 3.6166696676728525`*^9}, {
   3.6166697333333683`*^9, 3.616669744144187*^9}, {3.6166799831776905`*^9, 
   3.616680007937107*^9}, {3.616680485873443*^9, 3.616680487080512*^9}, {
   3.616730007161146*^9, 3.61673001505476*^9}, 3.61673585671902*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "k"}], " ", 
        SuperscriptBox["u", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["c0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["u", "2"]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
        SuperscriptBox["u0", "2"]}]}]], " ", 
     SqrtBox[
      FractionBox[
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
         RowBox[{"(", 
          RowBox[{"u", "-", "u0"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"u", "+", "u0"}], ")"}]}]}], 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
         SuperscriptBox["u0", "2"]}]}]]], " ", 
     RowBox[{"EllipticE", "[", 
      RowBox[{
       RowBox[{"ArcSin", "[", 
        RowBox[{"u", " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
           RowBox[{"1", "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
             SuperscriptBox["u0", "2"]}]}]]]}], "]"}], ",", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c0", "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}]]}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["c0", "2"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
        SuperscriptBox["u0", "2"]}]}], ")"}], " ", 
     SqrtBox[
      FractionBox["1", 
       RowBox[{
        SuperscriptBox["c0", "2"], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["c0", "4"]}], ")"}], " ", "k", " ", 
         SuperscriptBox["u0", "2"]}], "-", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["c0", "2"]}], ")"}], "2"], " ", 
         SuperscriptBox["k", "2"], " ", 
         SuperscriptBox["u0", "4"]}]}]]], " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
        RowBox[{"(", 
         RowBox[{"u", "-", "u0"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"u", "+", "u0"}], ")"}]}]}]], " ", 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
         SuperscriptBox["u", "2"]}], 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["c0", "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
          SuperscriptBox["u0", "2"]}]}]]}]], " ", 
     RowBox[{"EllipticE", "[", 
      RowBox[{
       RowBox[{"ArcSin", "[", 
        RowBox[{"u0", " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
           RowBox[{"1", "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
             SuperscriptBox["u0", "2"]}]}]]]}], "]"}], ",", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["c0", "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
           SuperscriptBox["u0", "2"]}]}]]}]}], "]"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{
    SqrtBox[
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["c0", "2"]}], ")"}], " ", "k"}], 
      RowBox[{"1", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
        SuperscriptBox["u0", "2"]}]}]]], " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
       RowBox[{"(", 
        RowBox[{"u", "-", "u0"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"u", "+", "u0"}], ")"}]}]}]], " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
        SuperscriptBox["u", "2"]}], 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["c0", "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["c0", "2"]}], ")"}], " ", "k", " ", 
         SuperscriptBox["u0", "2"]}]}]]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.6167359219427347`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fn1", "[", 
    RowBox[{"k_", ",", " ", "c0_", ",", " ", "u0_"}], "]"}], "[", "u_", "]"}],
   " ", ":=", " ", "\n", "  ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"-", "k"}], ")"}], "*", 
         RowBox[{"u", "^", "2"}]}], " ", "-", " ", 
        RowBox[{
         RowBox[{"c0", "^", "2"}], "*", "\n", "        ", 
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", 
           RowBox[{"k", "*", 
            RowBox[{"u", "^", "2"}]}]}], ")"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", 
           RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", "\n", "        ", 
         RowBox[{"u0", "^", "2"}]}]}], "]"}], "*", 
      RowBox[{"Sqrt", "[", "\n", "      ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", " ", "-", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "+", " ", 
             RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
           RowBox[{"(", 
            RowBox[{"u", " ", "-", " ", "u0"}], ")"}], "*", "\n", "         ", 
           RowBox[{"(", 
            RowBox[{"u", " ", "+", " ", "u0"}], ")"}]}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"1", " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "+", " ", 
             RowBox[{"c0", "^", "2"}]}], ")"}], "*", "\n", "         ", "k", 
           "*", 
           RowBox[{"u0", "^", "2"}]}]}], ")"}]}], "]"}], "*", 
      RowBox[{"EllipticE", "[", "\n", "      ", 
       RowBox[{
        RowBox[{"ArcSin", "[", 
         RowBox[{"u", "*", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", " ", "+", " ", 
                RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k"}], ")"}], "/", 
            "\n", "          ", 
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", " ", "+", " ", 
                 RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", "\n", 
               "            ", 
               RowBox[{"u0", "^", "2"}]}]}], ")"}]}], "]"}]}], "]"}], ",", 
        " ", "\n", "      ", 
        RowBox[{"1", " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", " ", "+", " ", 
            RowBox[{"c0", "^", "2"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"c0", "^", "2"}]}], " ", "+", " ", "\n", "         ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", " ", "+", " ", 
               RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
             RowBox[{"u0", "^", "2"}]}]}], ")"}]}]}]}], "]"}]}], " ", "+", 
     " ", "\n", "    ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"c0", "^", "2"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", 
           RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
         RowBox[{"u0", "^", "2"}]}]}], ")"}], "*", "\n", "     ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c0", "^", "2"}], " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], " ", "+", " ", 
             RowBox[{"c0", "^", "4"}]}], ")"}], "*", "k", "*", "\n", 
           "         ", 
           RowBox[{"u0", "^", "2"}]}], " ", "-", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{"c0", "^", "2"}]}], ")"}], "^", "2"}], "*", 
           RowBox[{"k", "^", "2"}], "*", "\n", "         ", 
           RowBox[{"u0", "^", "4"}]}]}], ")"}]}], "]"}], "*", 
      RowBox[{"Sqrt", "[", "\n", "      ", 
       RowBox[{
        RowBox[{"-", "1"}], " ", "+", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", 
           RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
         RowBox[{"(", 
          RowBox[{"u", " ", "-", " ", "u0"}], ")"}], "*", "\n", "        ", 
         RowBox[{"(", 
          RowBox[{"u", " ", "+", " ", "u0"}], ")"}]}]}], "]"}], "*", 
      RowBox[{"Sqrt", "[", "\n", "      ", 
       RowBox[{"1", " ", "-", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "+", " ", 
             RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
           RowBox[{"u", "^", "2"}]}], ")"}], "/", "\n", "        ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"c0", "^", "2"}]}], " ", "+", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", "\n", 
            "          ", 
            RowBox[{"u0", "^", "2"}]}]}], ")"}]}]}], "]"}], "*", 
      RowBox[{"EllipticE", "[", "\n", "      ", 
       RowBox[{
        RowBox[{"ArcSin", "[", 
         RowBox[{"u0", "*", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", " ", "+", " ", 
                RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k"}], ")"}], "/", 
            "\n", "          ", 
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", " ", "+", " ", 
                 RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", "\n", 
               "            ", 
               RowBox[{"u0", "^", "2"}]}]}], ")"}]}], "]"}]}], "]"}], ",", 
        " ", "\n", "      ", 
        RowBox[{"1", " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", " ", "+", " ", 
            RowBox[{"c0", "^", "2"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"c0", "^", "2"}]}], " ", "+", " ", "\n", "         ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", " ", "+", " ", 
               RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
             RowBox[{"u0", "^", "2"}]}]}], ")"}]}]}]}], "]"}]}]}], ")"}], "/",
    "\n", "   ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", 
           RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k"}], ")"}], "/", "\n", 
       "      ", 
       RowBox[{"(", 
        RowBox[{"1", " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", " ", "+", " ", 
            RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
          RowBox[{"u0", "^", "2"}]}]}], ")"}]}], "]"}], "*", "\n", "    ", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"-", "1"}], " ", "+", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", " ", "+", " ", 
          RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
        RowBox[{"(", 
         RowBox[{"u", " ", "-", " ", "u0"}], ")"}], "*", "\n", "       ", 
        RowBox[{"(", 
         RowBox[{"u", " ", "+", " ", "u0"}], ")"}]}]}], "]"}], "*", 
     RowBox[{"Sqrt", "[", "\n", "     ", 
      RowBox[{"1", " ", "-", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", " ", "+", " ", 
            RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
          RowBox[{"u", "^", "2"}]}], ")"}], "/", "\n", "       ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"c0", "^", "2"}]}], " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", "+", " ", 
             RowBox[{"c0", "^", "2"}]}], ")"}], "*", "k", "*", 
           RowBox[{"u0", "^", "2"}]}]}], ")"}]}]}], "]"}]}], 
    ")"}]}]}]], "Input",
 CellChangeTimes->{{3.6167360784734097`*^9, 3.616736126459094*^9}, {
  3.6167361616995564`*^9, 3.6167361899824057`*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"Chop", "[", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"sfrev", "[", 
       RowBox[{"id", ",", 
        RowBox[{"-", 
         RowBox[{"fn1", "[", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}]}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "]"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0.6", ",", "1.5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotPoints", " ", "\[Rule]", " ", "100"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6167305403076825`*^9, 3.6167307478972473`*^9}, {
   3.6167308107965574`*^9, 3.616730822480978*^9}, {3.616730915675542*^9, 
   3.6167309254723587`*^9}, 3.6167312361001043`*^9, {3.61673193398293*^9, 
   3.616731941361743*^9}, {3.616736247187706*^9, 3.6167362531781163`*^9}, 
   3.6167372556982775`*^9, {3.6167374562522297`*^9, 3.616737462866641*^9}, {
   3.6167393375375338`*^9, 3.6167393469131503`*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"Chop", "[", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"sfrev", "[", 
       RowBox[{"id", ",", 
        RowBox[{"fn1", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "]"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0.6", ",", "1.5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotPoints", " ", "\[Rule]", " ", "100"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6167305403076825`*^9, 3.6167307478972473`*^9}, {
   3.6167308107965574`*^9, 3.616730822480978*^9}, {3.616730915675542*^9, 
   3.6167309254723587`*^9}, 3.6167312361001043`*^9, {3.61673193398293*^9, 
   3.616731941361743*^9}, {3.616736247187706*^9, 3.6167362531781163`*^9}, {
   3.616736370864723*^9, 3.616736383141945*^9}, {3.6167375152359333`*^9, 
   3.616737521881545*^9}, {3.6167392356849546`*^9, 3.616739283530239*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"%", ",", "%%"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.61673673333136*^9, 3.6167367761222353`*^9}}],

Cell["\<\
This is a surface of revolution of constant negative curvature of cylindrical \
shape.\
\>", "Text",
 CellChangeTimes->{{3.616735074408846*^9, 3.6167352156982946`*^9}, {
   3.616736829817529*^9, 3.616736840097947*^9}, {3.616736877569213*^9, 
   3.6167368943860426`*^9}, 3.6167409857665224`*^9}],

Cell["\<\
Remark. Without Chop we get a small  gap in the near of u = 1:\
\>", "Text",
 CellChangeTimes->{{3.616739512538641*^9, 3.616739547155102*^9}, {
  3.6167396324041147`*^9, 3.6167396676201286`*^9}}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fn1", "[", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], "[", "u", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616736917396083*^9, 3.6167369687669735`*^9}, 
   3.616737339564025*^9}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fn1", "[", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], "[", "u", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", ".8", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616736917396083*^9, 3.6167369687669735`*^9}, 
   3.616737339564025*^9, {3.616738112280182*^9, 3.6167381739938903`*^9}, {
   3.6167382061299467`*^9, 3.6167382144759617`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fn1", "[", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], "[", "u", "]"}], ",", 
   " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", ".980", ",", "1", ",", ".002"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.616738267718855*^9, 3.616738352520604*^9}, {
  3.616738443577964*^9, 3.616738516352092*^9}, {3.616738649919526*^9, 
  3.616738679559578*^9}, {3.616738758012116*^9, 3.616738786372966*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "0.020816994395399923`"}], "-", 
    RowBox[{"8.184148219245243`*^-16", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "0.01866031401947544`"}], "+", 
    RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "0.016520596324592313`"}], "-", 
    RowBox[{"2.7249772747780407`*^-16", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "0.014397724152646417`"}], "+", 
    RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "0.012291583014290888`"}], "-", 
    RowBox[{"5.445161130808806`*^-16", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "0.01020206103668608`"}], "-", 
    RowBox[{"2.721636355759656`*^-16", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "0.008129048913260386`"}], "-", 
    RowBox[{"5.441724442502533`*^-16", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "0.006072439855459583`"}], "+", 
    RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "0.004032129546389206`"}], "-", 
    RowBox[{"2.7198266797832655`*^-16", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "0.002008016096323402`"}], "+", 
    RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "1.3597399555105182`*^-16"}], "-", 
    RowBox[{"2.7194799110210365`*^-16", " ", "\[ImaginaryI]"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.61673868065158*^9, 3.6167387872153673`*^9}]
}, Closed]],

Cell["\<\
The reason for this are small numerical disturbances appearing as non-zero \
values of the imaginary part of fn1.  With Chop this gap vanishes:\
\>", "Text",
 CellChangeTimes->{{3.6167396986199017`*^9, 3.6167398206358805`*^9}, {
  3.6167403088608055`*^9, 3.616740313197054*^9}}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Chop", "[", 
    RowBox[{
     RowBox[{"fn1", "[", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], "[", "u", "]"}], 
    "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", ".8", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616736917396083*^9, 3.6167369687669735`*^9}, 
   3.616737339564025*^9, {3.616738112280182*^9, 3.6167381739938903`*^9}, {
   3.6167382061299467`*^9, 3.6167382144759617`*^9}, {3.616739853455758*^9, 
   3.616739864927414*^9}}],

Cell["", "Text",
 CellChangeTimes->{{3.6167398968282385`*^9, 3.6167399110120497`*^9}, 
   3.6167403030844755`*^9}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Re", "[", 
    RowBox[{
     RowBox[{"fn1", "[", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], "[", "u", "]"}], 
    "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616736917396083*^9, 3.6167369687669735`*^9}, {
   3.61673701240025*^9, 3.616737027750677*^9}, 3.6167373803892965`*^9}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Im", "[", 
    RowBox[{
     RowBox[{"fn1", "[", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], "[", "u", "]"}], 
    "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616736917396083*^9, 3.6167369687669735`*^9}, {
   3.61673701240025*^9, 3.616737027750677*^9}, {3.616737059200332*^9, 
   3.61673706916875*^9}, 3.6167373899989133`*^9}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Re", "[", 
    RowBox[{
     RowBox[{"fn1", "[", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], "[", "u", "]"}], 
    "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", ".7", ",", "1.2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616736917396083*^9, 3.6167369687669735`*^9}, {
   3.61673701240025*^9, 3.616737027750677*^9}, {3.616737059200332*^9, 
   3.61673706916875*^9}, 3.6167373899989133`*^9, {3.6167389102683835`*^9, 
   3.6167389627936754`*^9}, {3.6167390099525585`*^9, 3.616739015989769*^9}, {
   3.6167390809170833`*^9, 3.6167390811822834`*^9}}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Im", "[", 
    RowBox[{
     RowBox[{"fn1", "[", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], "[", "u", "]"}], 
    "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", ".7", ",", "1.2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616736917396083*^9, 3.6167369687669735`*^9}, {
   3.61673701240025*^9, 3.616737027750677*^9}, {3.616737059200332*^9, 
   3.61673706916875*^9}, 3.6167373899989133`*^9, {3.6167389102683835`*^9, 
   3.6167389627936754`*^9}, {3.6167390099525585`*^9, 3.616739015989769*^9}, {
   3.6167390809170833`*^9, 3.6167390811822834`*^9}, {3.6167403595017023`*^9, 
   3.616740370496331*^9}}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Chop", "[", 
    RowBox[{"Im", "[", 
     RowBox[{
      RowBox[{"fn1", "[", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], "[", "u", "]"}], 
     "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", ".7", ",", "1.2"}], "}"}], ",", 
   RowBox[{"PlotStyle", " ", "\[Rule]", " ", "Red"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616736917396083*^9, 3.6167369687669735`*^9}, {
   3.61673701240025*^9, 3.616737027750677*^9}, {3.616737059200332*^9, 
   3.61673706916875*^9}, 3.6167373899989133`*^9, {3.6167389102683835`*^9, 
   3.6167389627936754`*^9}, {3.6167390099525585`*^9, 3.616739015989769*^9}, {
   3.6167390809170833`*^9, 3.6167390811822834`*^9}, {3.6167403595017023`*^9, 
   3.6167404183920703`*^9}}],

Cell["\<\
 Try with other parameters c0>0, k<0, u0. Depending on the initial conditions \
there may  appear surfaces of conical type also in case u0 \[NotEqual] 0\
\>", "Text",
 CellChangeTimes->{{3.616741006620715*^9, 3.616741020948535*^9}, {
   3.616741824790512*^9, 3.6167418861000185`*^9}, {3.616741923404152*^9, 
   3.6167419729889884`*^9}, 3.6186387530688257`*^9}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"Chop", "[", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"sfrev", "[", 
       RowBox[{"id", ",", 
        RowBox[{"fn1", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", 
          RowBox[{"1", "/", "2"}]}], "]"}]}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "]"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", ".8"}], ",", ".8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotPoints", " ", "\[Rule]", " ", "100"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6167305403076825`*^9, 3.6167307478972473`*^9}, {
   3.6167308107965574`*^9, 3.616730822480978*^9}, {3.616730915675542*^9, 
   3.6167309254723587`*^9}, 3.6167312361001043`*^9, {3.61673193398293*^9, 
   3.616731941361743*^9}, {3.616736247187706*^9, 3.6167362531781163`*^9}, {
   3.616736370864723*^9, 3.616736383141945*^9}, {3.6167375152359333`*^9, 
   3.616737521881545*^9}, {3.6167392356849546`*^9, 3.616739283530239*^9}, {
   3.6167410807459545`*^9, 3.616741133896995*^9}, {3.616741182321765*^9, 
   3.616741183848852*^9}, {3.616741481537879*^9, 3.6167414850570803`*^9}, {
   3.6167415796664915`*^9, 3.616741601689751*^9}, {3.6167416397939305`*^9, 
   3.6167416450332303`*^9}}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Re", "[", 
    RowBox[{
     RowBox[{"fn1", "[", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"1", "/", "2"}]}], "]"}], "[", "u", "]"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6167413030396695`*^9, 3.6167413615190144`*^9}}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Im", "[", 
    RowBox[{
     RowBox[{"fn1", "[", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"1", "/", "2"}]}], "]"}], "[", "u", "]"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6167413030396695`*^9, 3.6167413615190144`*^9}, {
  3.616741413770003*^9, 3.6167414366163096`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["3.8.6. Alfred Gray\[CloseCurlyQuote]s Exposition", "Subsubsection",
 CellChangeTimes->{{3.616761707824889*^9, 3.616761725544903*^9}, {
  3.6167618514484744`*^9, 3.616761855888728*^9}}],

Cell[TextData[{
 "In this subsection we reproduce Alfred Gray\[CloseCurlyQuote]s exposition, \
see [",
 ButtonBox["G94",
  BaseStyle->"Hyperlink",
  ButtonData->"Gray3"],
 "], p. 331-351. He considers surfaces of revolution in the form"
}], "Text",
 CellChangeTimes->{{3.616761864977248*^9, 3.6167619121849484`*^9}, {
  3.616762256056617*^9, 3.616762268648337*^9}, {3.616762315433013*^9, 
  3.6167623634807615`*^9}, {3.6167623992378063`*^9, 3.6167624170408244`*^9}, {
  3.616762447824585*^9, 3.616762528984227*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{"f", ",", "h"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6167625563717937`*^9, 3.616762562882166*^9}, {
  3.616762596579094*^9, 3.6167626241226687`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", "v", "]"}], " ", 
    RowBox[{"f", "[", "u", "]"}]}], ",", 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"h", "[", "u", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6167626258617687`*^9, 3.6168175045409517`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"gauss", "[", 
   RowBox[{"sfrev", "[", 
    RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6168156415232797`*^9, 3.616815663410118*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"f", "[", "u", "]"}], " ", 
     RowBox[{
      SuperscriptBox["h", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["h", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "-", 
       RowBox[{
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["h", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["h", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"]}], ")"}], " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "u", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["f", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["h", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], "2"]}], ")"}]}]], " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "u", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", "v", "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "v", "]"}], "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["f", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Sin", "[", "v", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["f", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["h", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}], "2"]}], ")"}]}]]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.616815670913731*^9, 3.6168161255921297`*^9, 
  3.6168169151563168`*^9, 3.616817513167767*^9}]
}, Closed]],

Cell[TextData[{
 "assuming that u is the arc length of the meridians: ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["f", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}], "2"], " "}]],
  CellChangeTimes->{{3.616763093942541*^9, 3.616763101653982*^9}}],
 " + ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["h", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}], "2"], " "}]],
  CellChangeTimes->{{3.616763093942541*^9, 3.616763101653982*^9}}],
 " = 1, we simplify"
}], "Text",
 CellChangeTimes->{{3.6167627698730054`*^9, 3.616762832176569*^9}, {
   3.61676314952072*^9, 3.616763207233021*^9}, {3.616763618840564*^9, 
   3.6167636504333706`*^9}, 3.616766019912897*^9, 3.616817422687608*^9, {
   3.616817534851805*^9, 3.6168175393758135`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     RowBox[{
      SuperscriptBox["h", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}], "->", " ", 
     RowBox[{
      RowBox[{"-", " ", 
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], "*", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "/", 
       RowBox[{
        SuperscriptBox["h", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}]}]}], ",", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"], " ", "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["h", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"]}], "  ", "==", 
      "1"}], ",", 
     RowBox[{"v", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616815692441769*^9, 3.616815734140642*^9}, {
   3.6168157725947104`*^9, 3.6168158224523973`*^9}, 3.6168158754300904`*^9, 
   3.616816933080748*^9, {3.6168169756220226`*^9, 3.61681703093972*^9}, {
   3.6168170698461885`*^9, 3.616817077193801*^9}, {3.616817155552739*^9, 
   3.6168172066272287`*^9}, 3.6168172513681073`*^9, {3.6168173069198046`*^9, 
   3.6168173135810165`*^9}, {3.6168173795067325`*^9, 3.6168173808639345`*^9}, 
   3.6168174826229134`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["f", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "u", "]"}], 
   RowBox[{"f", "[", "u", "]"}]]}]], "Output",
 CellChangeTimes->{3.6168175203125796`*^9}]
}, Closed]],

Cell["\<\
We define simplification rules completed with the regularity condition f[u]>0\
\>", "Text",
 CellChangeTimes->{
  3.6168174336700277`*^9, {3.616817814872297*^9, 3.6168178310495253`*^9}, 
   3.618638761429304*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hfrules", " ", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], 
       RowBox[{"2", " "}]], " ", "+", " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["h", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "^", "2"}]}], " ", "==", 
     " ", "1"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["h", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "*", 
       RowBox[{
        SuperscriptBox["h", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], "+", " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "*", 
       RowBox[{
        SuperscriptBox["f", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], "\[Equal]", " ", 
     "0"}], ",", 
    RowBox[{
     RowBox[{"f", "[", "u", "]"}], ">", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.616763093942541*^9, 3.616763101653982*^9}, {
  3.6167632193497143`*^9, 3.616763225317055*^9}, {3.616763584790616*^9, 
  3.616763593167095*^9}, {3.6167637325750685`*^9, 3.616763746788882*^9}, {
  3.616763851589876*^9, 3.616763855941125*^9}, {3.616766029566449*^9, 
  3.616766055494932*^9}, {3.6168168060341253`*^9, 3.6168168365945787`*^9}, {
  3.6168175677210627`*^9, 3.616817576035877*^9}, {3.6168176380615864`*^9, 
  3.6168177407253666`*^9}, {3.6168177737506247`*^9, 3.6168177833914413`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["h", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], "2"]}], "\[Equal]", "1"}], 
   ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["h", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], " ", 
      RowBox[{
       SuperscriptBox["h", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], ">", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6168168953130817`*^9, 3.6168178394891405`*^9}]
}, Closed]],

Cell["Corollary 18.9, p.333, is proved by the formulas", "Text",
 CellChangeTimes->{{3.616763273112789*^9, 3.6167633640009875`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", 
      RowBox[{"sfrev", "[", 
       RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], ",", "hfrules"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6167633769727297`*^9, 3.616763411850724*^9}, {
   3.6167634592524357`*^9, 3.616763542812215*^9}, 3.6167636682603903`*^9, {
   3.6167637805648136`*^9, 3.616763782700936*^9}, 3.616766130622229*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["s1", "2"], "+", 
  RowBox[{
   SuperscriptBox["s2", "2"], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", "u", "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{
  3.616763672891655*^9, {3.616763758245537*^9, 3.6167637849680653`*^9}, 
   3.6167638247083387`*^9, 3.6167638635985627`*^9, 3.6167661387346935`*^9, 
   3.6168178985820436`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", 
      RowBox[{"sfrev", "[", 
       RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], ",", "hfrules"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6167633769727297`*^9, 3.616763411850724*^9}, {
   3.6167634592524357`*^9, 3.616763542812215*^9}, 3.6167636682603903`*^9, {
   3.6167637805648136`*^9, 3.616763782700936*^9}, {3.6167638833616934`*^9, 
   3.616763891758174*^9}, {3.6167639523656397`*^9, 3.616763959157028*^9}, 
   3.6167640369744797`*^9, {3.6167661529985094`*^9, 3.6167661920377417`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["s2", "2"]}], " ", 
   RowBox[{"f", "[", "u", "]"}], " ", 
   RowBox[{
    SuperscriptBox["h", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["s1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["h", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], "-", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], " ", 
      RowBox[{
       SuperscriptBox["h", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.6167661934658237`*^9, 3.616817910016864*^9}]
}, Closed]],

Cell["Indeed, remember that we permuted u,v.", "Text",
 CellChangeTimes->{{3.6167658674081745`*^9, 3.61676593342495*^9}, 
   3.6167664090331535`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"prcurvatures", "[", 
     RowBox[{"sfrev", "[", 
      RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", "hfrules"}], "]"}]], "Input",
 CellChangeTimes->{{3.6167633769727297`*^9, 3.616763411850724*^9}, {
   3.6167634592524357`*^9, 3.616763542812215*^9}, 3.6167636682603903`*^9, {
   3.6167637805648136`*^9, 3.616763782700936*^9}, {3.6167638833616934`*^9, 
   3.616763891758174*^9}, {3.6167639523656397`*^9, 3.616763959157028*^9}, 
   3.6167640369744797`*^9, {3.616764252801824*^9, 3.6167642858527145`*^9}, {
   3.6167663533249674`*^9, 3.6167663604363737`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["h", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}], 
     RowBox[{"f", "[", "u", "]"}]]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["h", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}], "-", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}], " ", 
     RowBox[{
      SuperscriptBox["h", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.616764288764881*^9, {3.61676634533651*^9, 3.616766362253478*^9}, 
   3.6168179363653107`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"meancurvature", "[", 
     RowBox[{"sfrev", "[", 
      RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", "hfrules"}], "]"}]], "Input",
 CellChangeTimes->{{3.6167633769727297`*^9, 3.616763411850724*^9}, {
   3.6167634592524357`*^9, 3.616763542812215*^9}, 3.6167636682603903`*^9, {
   3.6167637805648136`*^9, 3.616763782700936*^9}, {3.6167638833616934`*^9, 
   3.616763891758174*^9}, {3.6167639523656397`*^9, 3.616763959157028*^9}, 
   3.6167640369744797`*^9, {3.616764252801824*^9, 3.6167642858527145`*^9}, {
   3.6167663533249674`*^9, 3.6167663604363737`*^9}, {3.61676642925731*^9, 
   3.6167664451882215`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{
       SuperscriptBox["h", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{
         RowBox[{"f", "[", "u", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], 
     RowBox[{"f", "[", "u", "]"}]], "-", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}], " ", 
     RowBox[{
      SuperscriptBox["h", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.6167664498254867`*^9, 3.616817944789325*^9}]
}, Closed]],

Cell["Consider", "Text",
 CellChangeTimes->{{3.6167671612251763`*^9, 3.6167671647043753`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{
       SuperscriptBox["h", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{
         RowBox[{"f", "[", "u", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], 
     RowBox[{"f", "[", "u", "]"}]], "\[Equal]", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["f", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], "*", 
      RowBox[{
       SuperscriptBox["h", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["h", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      RowBox[{"f", "[", "u", "]"}]]}]}], ",", " ", "hfrules"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6167633769727297`*^9, 3.616763411850724*^9}, {
   3.6167634592524357`*^9, 3.616763542812215*^9}, 3.6167636682603903`*^9, {
   3.6167637805648136`*^9, 3.616763782700936*^9}, {3.6167638833616934`*^9, 
   3.616763891758174*^9}, {3.6167639523656397`*^9, 3.616763959157028*^9}, 
   3.6167640369744797`*^9, {3.616764252801824*^9, 3.6167642858527145`*^9}, {
   3.6167663533249674`*^9, 3.6167663604363737`*^9}, {3.61676642925731*^9, 
   3.6167664451882215`*^9}, {3.6167669272437935`*^9, 
   3.6167669744854956`*^9}, {3.616767010878577*^9, 3.616767044479499*^9}, 
   3.616767126944216*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.616767129022334*^9, 3.6168179766913815`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", 
     RowBox[{"sfrev", "[", 
      RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", "hfrules"}], "]"}]], "Input",
 CellChangeTimes->{{3.6167633769727297`*^9, 3.616763411850724*^9}, {
   3.6167634592524357`*^9, 3.616763542812215*^9}, 3.6167636682603903`*^9, {
   3.6167637805648136`*^9, 3.616763782700936*^9}, {3.6167638833616934`*^9, 
   3.616763891758174*^9}, {3.6167639523656397`*^9, 3.616763959157028*^9}, 
   3.6167640369744797`*^9, {3.616764252801824*^9, 3.6167642858527145`*^9}, {
   3.6167663533249674`*^9, 3.6167663604363737`*^9}, {3.61676642925731*^9, 
   3.6167664451882215`*^9}, {3.616767194901102*^9, 3.6167672153722734`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["f", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "u", "]"}], 
   RowBox[{"f", "[", "u", "]"}]]}]], "Output",
 CellChangeTimes->{3.6167672191014867`*^9, 3.616767516153477*^9, 
  3.6167675489143505`*^9, 3.616768389004401*^9, 3.6168182251842175`*^9}]
}, Closed]],

Cell["\<\
\[FilledSquare]
Now we apply the last formula ans solve\
\>", "Text",
 CellChangeTimes->{{3.616819049895266*^9, 3.616819089846936*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["f", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "u", "]"}], "\[Equal]", " ", 
    RowBox[{
     RowBox[{"-", "k"}], "*", 
     RowBox[{"f", "[", "u", "]"}]}]}], ",", 
   RowBox[{"f", "[", "u", "]"}], ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.6168183087535644`*^9, 3.6168183645548625`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"C", "[", "1", "]"}], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        SqrtBox["k"], " ", "u"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"C", "[", "2", "]"}], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{
        SqrtBox["k"], " ", "u"}], "]"}]}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.6168183656936646`*^9}]
}, Closed]],

Cell["Setting", "Text",
 CellChangeTimes->{{3.6168217096187725`*^9, 3.6168217128323784`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Sqrt", "[", "k", "]"}], " ", "=", 
   RowBox[{"1", "/", "a"}]}], ";", 
  RowBox[{
   RowBox[{"C", "[", "1", "]"}], " ", "=", 
   RowBox[{"b", "*", 
    RowBox[{"Cos", "[", "c", "]"}]}]}], ";", " ", 
  RowBox[{
   RowBox[{"C", "[", "2", "]"}], "=", " ", 
   RowBox[{
    RowBox[{"-", "b"}], "*", 
    RowBox[{"Sin", "[", "c", "]"}]}]}], ";"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6168217372464213`*^9, 3.6168218967567015`*^9}}],

Cell["\<\
leads to the general solution f[u] = b*Cos[u/a +c]; since the additive \
constant c means a translation along the z-axis  only, we may assume c = 0 \
and define as the solution for f\
\>", "Text",
 CellChangeTimes->{{3.616822046454564*^9, 3.61682214638834*^9}, {
   3.6168222017060375`*^9, 3.616822233389693*^9}, {3.6168222749682674`*^9, 
   3.616822329784403*^9}, {3.616822380673313*^9, 3.61682239320903*^9}, {
   3.616822686496805*^9, 3.6168227043848286`*^9}, 3.618638772788954*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fsol", "[", 
    RowBox[{"k_", ",", "b_"}], "]"}], "[", "u_", "]"}], " ", ":=", " ", 
  RowBox[{"b", "*", 
   RowBox[{"Cos", "[", 
    RowBox[{"u", "*", 
     RowBox[{"Sqrt", "[", "k", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.616822420616598*^9, 3.6168225175151405`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"fsol", "[", 
     RowBox[{"k", ",", "b"}], "]"}], "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "u", "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{"-", "k"}], "*", 
   RowBox[{
    RowBox[{"fsol", "[", 
     RowBox[{"k", ",", "b"}], "]"}], "[", "u", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.616822784435407*^9, 3.616822831668109*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.6168228338232317`*^9}]
}, Closed]],

Cell["\<\
Since changing the sign of fsol means a reflection at the y,z-plane only we \
may assume b>0;
the case b=0  degenerates to the z-axis, since h\.b4[u] = \[PlusMinus]1, h[u] \
= \[PlusMinus]u + c0:\
\>", "Text",
 CellChangeTimes->{{3.616822955943217*^9, 3.616823088680809*^9}, {
   3.6168232351451864`*^9, 3.616823284248995*^9}, 3.616823402856779*^9, {
   3.6168235962008376`*^9, 3.6168237090572925`*^9}, {3.616823977353638*^9, 
   3.616824004769206*^9}, {3.6168240378730993`*^9, 3.6168240444164743`*^9}, {
   3.6168240905691137`*^9, 3.61682411900174*^9}, {3.6168241508565617`*^9, 
   3.616824269849368*^9}, {3.616824377489525*^9, 3.6168243914573236`*^9}, {
   3.616824577209948*^9, 3.616824633353159*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"h1", "[", "u_", "]"}], " ", ":=", " ", 
   RowBox[{"u", "+", "1"}]}], ";", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sfrev", "[", 
      RowBox[{"zero", ",", "h1"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"u", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6168237141345825`*^9, 3.616823839297742*^9}, {
  3.616823883861291*^9, 3.61682393560425*^9}, {3.616824280708989*^9, 
  3.6168243321969337`*^9}}],

Cell["Analogously, the case k = 0  leads to ", "Text",
 CellChangeTimes->{{3.616824671409336*^9, 3.6168247003769927`*^9}, {
  3.6168247342969327`*^9, 3.6168247391772118`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"f0", "[", "b_", "]"}], "[", "u_", "]"}], " ", ":=", " ", "b"}], 
  ";", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"h0", "[", "c0_", "]"}], "[", "u_", "]"}], " ", ":=", " ", 
   RowBox[{"u", " ", "+", " ", "c0"}]}]}]], "Input",
 CellChangeTimes->{{3.616824747833707*^9, 3.6168248737079067`*^9}}],

Cell["and gives a circular cylinder", "Text",
 CellChangeTimes->{{3.616825074441388*^9, 3.6168250879691615`*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{
      RowBox[{"f0", "[", 
       RowBox[{"1", "/", "2"}], "]"}], ",", 
      RowBox[{"h0", "[", "1", "]"}]}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6168237141345825`*^9, 3.616823839297742*^9}, {
  3.616823883861291*^9, 3.61682393560425*^9}, {3.616824280708989*^9, 
  3.6168243321969337`*^9}, {3.6168249119320927`*^9, 3.6168250119328127`*^9}}],

Cell["\<\
Remember the discussion of the developable surfaces of revolution at the \
beginning subsection 3.8.3. Thus we will suppose b>0 in the following, b ten \
is the maximal distance of the meridian to the z_axis. To find h[u] we \
remember\
\>", "Text",
 CellChangeTimes->{{3.6168257166171184`*^9, 3.616825794936598*^9}, {
  3.6168258277774763`*^9, 3.6168258771372995`*^9}, {3.6168266438661537`*^9, 
  3.6168266721447716`*^9}, {3.616826897673671*^9, 3.6168269301615295`*^9}, {
  3.6186387818694725`*^9, 3.6186388047167797`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"h\.b4", "[", "u", "]"}], " ", "\[Equal]", "  ", 
  RowBox[{"Sqrt", "[", 
   RowBox[{"1", "-", 
    RowBox[{
     RowBox[{"f\.b4", "[", "u", "]"}], "^", "2"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.616826684975505*^9, 3.6168267685152836`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"h\.b4", "[", "u", "]"}], "\[Equal]", 
  SqrtBox[
   RowBox[{"1", "-", 
    SuperscriptBox[
     RowBox[{"f\.b4", "[", "u", "]"}], "2"]}]]}]], "Output",
 CellChangeTimes->{3.616826786429308*^9}]
}, Closed]],

Cell["with f\.b4[u] equal", "Text",
 CellChangeTimes->{{3.6168276321506805`*^9, 3.6168276803534374`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"fsol", "[", 
      RowBox[{"k", ",", "b"}], "]"}], "[", "t", "]"}], ",", "t"}], "]"}], "/.",
   " ", 
  RowBox[{"t", "\[Rule]", " ", "u"}]}]], "Input",
 CellChangeTimes->{{3.6168275053584285`*^9, 3.616827562586702*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "b"}], " ", 
  SqrtBox["k"], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{
    SqrtBox["k"], " ", "u"}], "]"}]}]], "Output",
 CellChangeTimes->{3.6168275639247785`*^9}]
}, Closed]],

Cell["\<\
We assume h\.b4[u] \[GreaterEqual] 0; this can be reached always substituting \
u .> -u, if necessary.  Integration  \
\>", "Text",
 CellChangeTimes->{{3.6168273598091035`*^9, 3.6168274930327234`*^9}, 
   3.6168277062729197`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{"Sqrt", "[", 
    RowBox[{"1", "-", 
     RowBox[{"k", "*", 
      RowBox[{"b", "^", "2"}], "*", 
      RowBox[{
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"Sqrt", "[", "k", "]"}], "*", "t"}], "]"}], "^", "2"}]}]}], 
    "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "u"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6168275053584285`*^9, 3.616827562586702*^9}, {
  3.6168277151474276`*^9, 3.616827777011966*^9}, {3.6168278227725835`*^9, 
  3.616827859483683*^9}, {3.61682790208412*^9, 3.616827911220642*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"EllipticE", "[", 
   RowBox[{
    RowBox[{
     SqrtBox["k"], " ", "u"}], ",", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", "k"}]}], "]"}], 
  SqrtBox["k"]]], "Output",
 CellChangeTimes->{3.6168275639247785`*^9, 3.6168279497528467`*^9}]
}, Closed]],

Cell["\<\
We set the additive integration constant equal zero; another constant acts as \
a translation along the z-axis only, and define \
\>", "Text",
 CellChangeTimes->{{3.616828038160903*^9, 3.616828084720566*^9}, {
  3.616828184393267*^9, 3.616828257961475*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hsol", "[", 
    RowBox[{"k_", ",", " ", "b_"}], "]"}], "[", "u_", "]"}], " ", ":=", " ", 
  "\n", "  ", 
  RowBox[{
   RowBox[{"EllipticE", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Sqrt", "[", "k", "]"}], "*", "u"}], ",", " ", 
     RowBox[{
      RowBox[{"b", "^", "2"}], "*", "k"}]}], "]"}], "/", 
   RowBox[{"Sqrt", "[", "k", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.616828268317067*^9, 3.6168283557230663`*^9}}],

Cell["Control:", "Text",
 CellChangeTimes->{{3.616828630960809*^9, 3.616828636009098*^9}, {
  3.6168286713051167`*^9, 3.616828702768916*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", 
     RowBox[{"sfrev", "[", 
      RowBox[{
       RowBox[{"fsol", "[", 
        RowBox[{"k", ",", "b"}], "]"}], ",", 
       RowBox[{"hsol", "[", 
        RowBox[{"k", ",", "b"}], "]"}]}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", "Reals"}], ",", 
     RowBox[{"v", "\[Element]", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616828375117176*^9, 3.6168284650523195`*^9}, {
  3.6168285000513215`*^9, 3.6168285465979843`*^9}}],

Cell[BoxData["k"], "Output",
 CellChangeTimes->{
  3.616828442221014*^9, {3.6168285373964577`*^9, 3.616828547739049*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{
    RowBox[{"fsol", "[", 
     RowBox[{"0", ",", "b"}], "]"}], ",", 
    RowBox[{"hsol", "[", 
     RowBox[{"0", ",", "b"}], "]"}]}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{3.616828801107541*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Power", "::", "infy"}], "MessageName"], ":", 
  " ", "\<\"Infinite expression \[NoBreak]\\!\\(1\\/0\\)\[NoBreak] \
encountered. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/infy\\\", ButtonNote -> \
\\\"Power::infy\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6168288038746996`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Infinity", "::", "indet"}], "MessageName"], ":", 
  " ", "\<\"Indeterminate expression \[NoBreak]\\!\\(0\\\\ ComplexInfinity\\)\
\[NoBreak] encountered. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/indet\\\", ButtonNote -> \
\\\"Infinity::indet\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6168288039407034`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"b", " ", 
    RowBox[{"Cos", "[", "v", "]"}]}], ",", 
   RowBox[{"b", " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", "Indeterminate"}], "}"}]], "Output",
 CellChangeTimes->{3.616828803943703*^9}]
}, Closed]],

Cell["\<\
The developable surfaces are not contained in this family; the case k = b= 1 \
yields the unit sphere:\
\>", "Text",
 CellChangeTimes->{{3.616829005569236*^9, 3.6168290587852793`*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{
      RowBox[{"fsol", "[", 
       RowBox[{"1", ",", "1"}], "]"}], ",", 
      RowBox[{"hsol", "[", 
       RowBox[{"1", ",", "1"}], "]"}]}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6168287071561675`*^9, 3.6168287474044695`*^9}, {
  3.61682882626898*^9, 3.6168289348461905`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
3.8.6.a. Surfaces of Revolution of Constant Positive Constant Gaussian \
Curvature\
\>", "Subsubsection",
 CellChangeTimes->{{3.6168293520900555`*^9, 3.6168294026009445`*^9}, {
  3.6168445489178305`*^9, 3.6168445611545305`*^9}, {3.617015288424196*^9, 
  3.6170153146076937`*^9}, {3.6170153724870043`*^9, 3.6170153975684385`*^9}}],

Cell["\<\
We assume k > 0 and distinguish three cases to obtain real solutions:\
\>", "Text",
 CellChangeTimes->{{3.616829477278216*^9, 3.6168295357855625`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"1.", " ", "b"}], "\[Equal]", 
   FractionBox["1", 
    SqrtBox["k"]]}], ",", " ", 
  RowBox[{
   RowBox[{"2.", "  ", "0"}], "<", "b", "<", 
   FractionBox["1", 
    SqrtBox["k"]]}], ",", 
  RowBox[{
   RowBox[{"3.", "  ", "b"}], ">", 
   SqrtBox["k"]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6168299083288703`*^9, 3.616829965910164*^9}}],

Cell["This integral must be real:", "Text",
 CellChangeTimes->{{3.616833170721469*^9, 3.616833187457426*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", "u"], 
   RowBox[{
    SqrtBox[
     RowBox[{"1", "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "k", " ", 
       RowBox[{
        SuperscriptBox["sin", "2"], "(", 
        RowBox[{
         SqrtBox["k"], " ", "t"}], ")"}]}]}]], 
    RowBox[{"\[DifferentialD]", "t"}]}]}], TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{3.6168301032840214`*^9}],

Cell[TextData[{
 StyleBox["Case 1. ",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["b", "2"], " ", "k"}]],
  Evaluatable->False,
  CellChangeTimes->{3.6168301032840214`*^9},
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["= 1. ",
  FontColor->RGBColor[0, 0, 1]],
 "\nThe integral is real for all values of t. In this case we have"
}], "Text",
 CellChangeTimes->{{3.616833199884137*^9, 3.616833220898339*^9}, {
   3.61683335012973*^9, 3.616833371824971*^9}, {3.6168335148811536`*^9, 
   3.616833533841238*^9}, {3.61683481034625*^9, 3.6168348377698183`*^9}, 
   3.6168350450976768`*^9, {3.616835086377038*^9, 3.6168351081372824`*^9}, 
   3.6168471838425083`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"Sqrt", "[", "k", "]"}], "*", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "u"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.61683355485244*^9, 3.6168335917955527`*^9}, {
  3.6168336859399376`*^9, 3.6168337029559107`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"Sin", "[", 
   RowBox[{
    SqrtBox["k"], " ", "u"}], "]"}], 
  SqrtBox["k"]]], "Output",
 CellChangeTimes->{3.616833704065974*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"EllipticE", "[", 
     RowBox[{"u", ",", "1"}], "]"}], "-", 
    RowBox[{"Sin", "[", "u", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "2"}], "<", "u"}], ",", 
     RowBox[{"u", "<", 
      RowBox[{"Pi", "/", "2"}]}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616834449300599*^9, 3.6168345502833753`*^9}, {
  3.616834647315925*^9, 3.6168347160528564`*^9}, {3.6168347565251713`*^9, 
  3.616834757942252*^9}, {3.6168349378215413`*^9, 3.6168350062374544`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.6168347171499195`*^9, 3.6168347594063363`*^9, 3.6168349398056545`*^9, {
   3.616834975691707*^9, 3.616835007176508*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{
      RowBox[{"fsol", "[", 
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"r", "^", "2"}]}], ",", "r"}], "]"}], ",", 
      RowBox[{"hsol", "[", 
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"r", "^", "2"}]}], ",", "r"}], "]"}]}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "1"}], " ", "<", "u"}], ",", " ", 
     RowBox[{"u", "<", 
      RowBox[{"Pi", "/", "2"}]}], ",", " ", 
     RowBox[{"v", "\[Element]", "Reals"}], ",", 
     RowBox[{"r", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6168301493156543`*^9, 3.6168302037477674`*^9}, {
   3.6168302402198534`*^9, 3.6168303768376675`*^9}, 3.6168315516728644`*^9, {
   3.616832109871792*^9, 3.61683215251023*^9}, 3.616832244134471*^9, {
   3.6168323161585903`*^9, 3.6168323190147543`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", 
     FractionBox["u", "r"], "]"}], " ", 
    RowBox[{"Cos", "[", "v", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", 
     FractionBox["u", "r"], "]"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"EllipticE", "[", 
     RowBox[{
      FractionBox["u", "r"], ",", "1"}], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.61683224533854*^9, 3.616832320112817*^9, 
  3.6168324172073703`*^9}]
}, Closed]],

Cell["here u has to be considered for  -Pi/2 < u/r <Pi/2.", "Text",
 CellChangeTimes->{{3.6168325282897234`*^9, 3.616832636000884*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//.", "  ", 
  RowBox[{"r", "\[Rule]", "2"}]}]], "Input",
 CellChangeTimes->{
  3.6168307265556707`*^9, 3.6168308348368635`*^9, 3.616830966524396*^9, {
   3.616830997092144*^9, 3.6168310186793785`*^9}, {3.61683105260732*^9, 
   3.6168310789158244`*^9}, {3.616832403811604*^9, 3.6168324092029123`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2", " ", 
    RowBox[{"Cos", "[", 
     FractionBox["u", "2"], "]"}], " ", 
    RowBox[{"Cos", "[", "v", "]"}]}], ",", 
   RowBox[{"2", " ", 
    RowBox[{"Cos", "[", 
     FractionBox["u", "2"], "]"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"2", " ", 
    RowBox[{"EllipticE", "[", 
     RowBox[{
      FractionBox["u", "2"], ",", "1"}], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.616831029385991*^9, 3.6168310892914176`*^9}, 
   3.6168315690138564`*^9, 3.6168323413250303`*^9, 3.616832420806576*^9}]
}, Closed]],

Cell["The solutions are spheres of radius r (=b).", "Text",
 CellChangeTimes->{{3.616832671361907*^9, 3.616832704545805*^9}}],

Cell[TextData[{
 StyleBox["Case 2.  ",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["b", "2"], " ", "k"}], "<", "1"}], TraditionalForm]],
  CellChangeTimes->{{3.6168447609059553`*^9, 3.6168447853933563`*^9}},
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.6168446858536625`*^9, 3.616844702922639*^9}, {
  3.616844742825921*^9, 3.6168447467141438`*^9}, {3.61684479280978*^9, 
  3.616844810883814*^9}}],

Cell["\<\
In this case the integrand and the Integral are real for all values of t, \
resp. u.\
\>", "Text",
 CellChangeTimes->{{3.616844897241753*^9, 3.616844938938138*^9}, 
   3.6168451400106387`*^9}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{
      RowBox[{"fsol", "[", 
       RowBox[{"1", ",", 
        RowBox[{"1", "/", "2"}]}], "]"}], ",", 
      RowBox[{"hsol", "[", 
       RowBox[{"1", ",", 
        RowBox[{"1", "/", "2"}]}], "]"}]}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"3", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6168304350179954`*^9, 3.6168305159716253`*^9}, 
   3.6168306246138396`*^9, 3.616830700981208*^9, {3.61683123811693*^9, 
   3.6168312828994913`*^9}, {3.616831485061054*^9, 3.6168314905633693`*^9}, 
   3.6168316288302774`*^9, {3.616831870246086*^9, 3.6168318809086957`*^9}, 
   3.6168319324366426`*^9, {3.6168319719739046`*^9, 3.6168320241508884`*^9}, 
   3.616832444068907*^9, 3.616845214575904*^9, {3.616845276031419*^9, 
   3.6168453394710474`*^9}, 3.616845373118972*^9}],

Cell["\<\
These surfaces are infinite strings whose links have the shape of a spindle \
(or American football).
Experiment with other values of k,b.\
\>", "Text",
 CellChangeTimes->{{3.6168461611130114`*^9, 3.6168462607227087`*^9}, {
  3.6168462990349007`*^9, 3.616846328698597*^9}}],

Cell[TextData[{
 StyleBox["Case 3.  ",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["b", "2"], " ", "k"}], ">", "1"}], TraditionalForm]],
  CellChangeTimes->{{3.6168447609059553`*^9, 3.6168447853933563`*^9}},
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.6168463583232913`*^9, 3.616846375572278*^9}}],

Cell["In this case the integrand is real for values t with", "Text",
 CellChangeTimes->{{3.616847201088495*^9, 3.616847246578097*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"ArcSin", "[", 
     FractionBox["1", 
      RowBox[{"b", 
       SqrtBox["k"]}]], "]"}], 
    SqrtBox["k"]]}], "<", "t", "<", 
  FractionBox[
   RowBox[{"ArcSin", "[", 
    FractionBox["1", 
     RowBox[{"b", 
      SqrtBox["k"]}]], "]"}], 
   SqrtBox["k"]]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{
  3.6168475139593897`*^9, {3.616847759740448*^9, 3.6168477836828175`*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", "\n", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{
      RowBox[{"fsol", "[", 
       RowBox[{"1", ",", " ", "1.5"}], "]"}], ",", " ", 
      RowBox[{"hsol", "[", 
       RowBox[{"1", ",", " ", "1.5"}], "]"}]}], "]"}], "[", "\n", "   ", 
    RowBox[{"u", ",", " ", "v"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", " ", 
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{"ArcSin", "[", 
        RowBox[{"1", "/", "1.5"}], "]"}], ")"}]}], ",", " ", "\n", "   ", 
     RowBox[{"ArcSin", "[", 
      RowBox[{"1", "/", "1.5"}], "]"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", " ", "0", ",", " ", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6168304350179954`*^9, 3.6168305159716253`*^9}, 
   3.6168306246138396`*^9, 3.616830700981208*^9, {3.61683123811693*^9, 
   3.6168312828994913`*^9}, {3.616831485061054*^9, 3.6168314905633693`*^9}, 
   3.6168316288302774`*^9, {3.616831870246086*^9, 3.6168318809086957`*^9}, 
   3.6168319324366426`*^9, {3.6168319719739046`*^9, 3.6168320241508884`*^9}, 
   3.616832444068907*^9, 3.616845214575904*^9, {3.616845276031419*^9, 
   3.6168453394710474`*^9}, 3.616845373118972*^9, {3.616847657623607*^9, 
   3.6168476918065624`*^9}, {3.616847927586048*^9, 3.616847970522504*^9}, {
   3.6168486582318387`*^9, 3.6168486806661215`*^9}, {3.616849296034319*^9, 
   3.616849394718963*^9}}],

Cell["\<\
Entering larger limits for u  doesn't change the figure since only real \
points are plotted:\
\>", "Text",
 CellChangeTimes->{{3.616849593778349*^9, 3.616849646162345*^9}, {
  3.6186388573087873`*^9, 3.6186388846473513`*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", "\n", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{
      RowBox[{"fsol", "[", 
       RowBox[{"1", ",", " ", "1.5"}], "]"}], ",", " ", 
      RowBox[{"hsol", "[", 
       RowBox[{"1", ",", " ", "1.5"}], "]"}]}], "]"}], "[", " ", 
    RowBox[{"u", ",", " ", "v"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", " ", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], " ", ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", " ", "0", ",", " ", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.61684941687123*^9, 3.616849416921233*^9}, {
  3.6168494526232753`*^9, 3.616849541086335*^9}, {3.61684995066333*^9, 
  3.6168499651191573`*^9}}],

Cell["\<\
In this case the surface doesn\[CloseCurlyQuote]t meet the z-axis. The \
surfaces have the shape of a barrel.\
\>", "Text",
 CellChangeTimes->{{3.616849694275097*^9, 3.6168497543625336`*^9}, {
  3.616849820738899*^9, 3.616849824155094*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
3.8.6.b. Surfaces of Revolution of Constant Positive Constant Gaussian \
Curvature\
\>", "Subsubsection",
 CellChangeTimes->{{3.6168293520900555`*^9, 3.6168294026009445`*^9}, {
  3.6168445489178305`*^9, 3.6168445611545305`*^9}, {3.616849902363568*^9, 
  3.616849913674215*^9}, {3.6170154058879147`*^9, 3.617015418936661*^9}}],

Cell["\<\
Alfred Gray uses the following solution of the differential equation\
\>", "Text",
 CellChangeTimes->{{3.6169913911456676`*^9, 3.6169914250601273`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"f", "''"}], "[", "u", "]"}], "-", 
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], "/", 
      RowBox[{"a", "^", "2"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{"f", "[", "u", "]"}], ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.616899810646412*^9, 3.616899899722568*^9}, 
   3.616899996115137*^9, {3.616900109948537*^9, 3.6169001203849554`*^9}, {
   3.6169007813113165`*^9, 3.616900806692561*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       FractionBox["u", "a"]], " ", 
      RowBox[{"C", "[", "1", "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox["u", "a"]}]], " ", 
      RowBox[{"C", "[", "2", "]"}]}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.6169001237701616`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fsn", "[", 
    RowBox[{"a_", ",", "A_", ",", "B_"}], "]"}], "[", "u_", "]"}], " ", ":=", 
  " ", 
  RowBox[{
   RowBox[{"A", "*", 
    RowBox[{"Exp", "[", 
     RowBox[{"u", "/", "a"}], "]"}]}], " ", "+", " ", 
   RowBox[{"B", "*", 
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"-", "u"}], "/", "a"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6169389368467135`*^9, 3.6169390613788366`*^9}, {
  3.6169390930036454`*^9, 3.6169391115237045`*^9}, {3.616998034301736*^9, 
  3.6169980472497587`*^9}}],

Cell[TextData[StyleBox["Case A=0, B>0.",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.6169397692433243`*^9, 3.6169398291707516`*^9}, {
  3.6169977852940984`*^9, 3.6169977862145*^9}}],

Cell["We transform the variable u:", "Text",
 CellChangeTimes->{{3.6169914945894494`*^9, 3.6169915299859114`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"B", "*", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", "u"}], "/", "a"}], "]"}]}], "/.", " ", 
    RowBox[{"u", "\[Rule]", 
     RowBox[{"w", "+", 
      RowBox[{"a", "*", 
       RowBox[{"Log", "[", "B", "]"}]}], "-", 
      RowBox[{"a", "*", 
       RowBox[{"Log", "[", "a", "]"}]}]}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"B", ">", "0"}], ",", 
     RowBox[{"a", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6169398777015276`*^9, 3.6169400590218983`*^9}, 
   3.616940481063038*^9}],

Cell[BoxData[
 RowBox[{"a", " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"-", 
    FractionBox["w", "a"]}]]}]], "Output",
 CellChangeTimes->{3.6169400729446945`*^9, 3.6169405063734856`*^9}]
}, Closed]],

Cell["and set", "Text",
 CellChangeTimes->{{3.616991544103936*^9, 3.6169915524031506`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fsn1", "[", "a_", "]"}], "[", "u_", "]"}], ":=", 
  RowBox[{"a", "*", 
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"-", "u"}], "/", "a"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6169405658588877`*^9, 3.616940632564703*^9}, 
   3.6169409437174997`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fsn1", "[", "a", "]"}], "'"}], "[", "u", "]"}]], "Input",
 CellChangeTimes->{{3.6169408458189006`*^9, 3.6169408906134624`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"-", 
    FractionBox["u", "a"]}]]}]], "Output",
 CellChangeTimes->{{3.6169408657700415`*^9, 3.6169408915685177`*^9}, 
   3.6169409512959337`*^9}]
}, Closed]],

Cell["To obtain the h - function we calculate", "Text",
 CellChangeTimes->{{3.616991578002796*^9, 3.6169916349740963`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hsn1", "[", "a_", "]"}], "[", "u_", "]"}], " ", ":=", " ", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"Sqrt", "[", 
     RowBox[{"1", "-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", "*", "t"}], "a"]}]]}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "u"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.616907470301609*^9, 3.616907561087802*^9}, {
  3.6169407225198483`*^9, 3.616940779999136*^9}, {3.616941000447745*^9, 
  3.616941006096068*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"hsn1", "[", "a", "]"}], "[", "u", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", " ", 
     RowBox[{"u", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6169900368136888`*^9, 3.6169900521953163`*^9}, {
  3.616990255416873*^9, 3.616990312372573*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "a"}], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox["u", "a"]}]], " ", 
   SqrtBox[
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       RowBox[{"2", " ", "u"}], "a"]]}]]}], "+", "u", "+", 
  RowBox[{"a", " ", 
   RowBox[{"Log", "[", 
    RowBox[{"1", "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox["u", "a"]}]], " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "u"}], "a"]]}]]}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.6169903534942455`*^9}]
}, Closed]],

Cell["We redefine", "Text",
 CellChangeTimes->{{3.616990656290777*^9, 3.616990661345186*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hsn1", "[", "a_", "]"}], "[", "u_", "]"}], " ", ":=", " ", "\n", 
  "  ", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"-", "a"}], ")"}], "*", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"-", "1"}], " ", "+", " ", "\n", "       ", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "*", "u"}], ")"}], "/", "a"}], ")"}]}]}], "]"}]}], 
     ")"}], "/", "\n", "    ", 
    RowBox[{"E", "^", 
     RowBox[{"(", 
      RowBox[{"u", "/", "a"}], ")"}]}]}], " ", "+", " ", "u", " ", "+", " ", 
   "\n", "   ", 
   RowBox[{"a", "*", 
    RowBox[{"Log", "[", 
     RowBox[{"1", " ", "+", " ", "\n", "      ", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"-", "1"}], " ", "+", " ", 
         RowBox[{"E", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", "*", "u"}], ")"}], "/", "a"}], ")"}]}]}], "]"}], 
       "/", "\n", "       ", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"u", "/", "a"}], ")"}]}]}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6169907012500563`*^9, 3.616990715492881*^9}}],

Cell["Try with  distinct parameters a", "Text",
 CellChangeTimes->{{3.616991665269349*^9, 3.616991726546257*^9}}],

Cell[BoxData[
 RowBox[{"pss1", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sfrev", "[", 
      RowBox[{
       RowBox[{"fsn1", "[", ".2", "]"}], ",", 
       RowBox[{"hsn1", "[", ".2", "]"}]}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "0", ",", ".5"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6169076266495514`*^9, 3.6169077454233446`*^9}, {
   3.616941068335628*^9, 3.616941081603387*^9}, 3.6169902080239897`*^9, {
   3.61699079488142*^9, 3.6169909004156055`*^9}, {3.6169926328322487`*^9, 
   3.61699263938426*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", 
     RowBox[{"sfrev", "[", 
      RowBox[{
       RowBox[{"fsn1", "[", "a", "]"}], ",", 
       RowBox[{"hsn1", "[", "a", "]"}]}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", " ", 
     RowBox[{"u", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6169917639863224`*^9, 3.616991862796896*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["1", 
   SuperscriptBox["a", "2"]]}]], "Output",
 CellChangeTimes->{3.6169918758697195`*^9}]
}, Closed]],

Cell["\<\
Inverting the sign of the functions, clearly one gets a solution again\
\>", "Text",
 CellChangeTimes->{{3.616992879475482*^9, 3.616992947897202*^9}}],

Cell[BoxData[
 RowBox[{"pss2", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sfrev", "[", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"fsn1", "[", ".2", "]"}]}], ",", 
       RowBox[{"-", 
        RowBox[{"hsn1", "[", ".2", "]"}]}]}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "0", ",", ".5"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6169076266495514`*^9, 3.6169077454233446`*^9}, {
   3.616941068335628*^9, 3.616941081603387*^9}, 3.6169902080239897`*^9, {
   3.61699079488142*^9, 3.6169909004156055`*^9}, 3.616992481759183*^9, 
   3.6169926018349943`*^9, {3.6169926517706814`*^9, 3.6169926596018953`*^9}}],

Cell["<the surface is a pseudosphere:", "Text",
 CellChangeTimes->{{3.6169929865384703`*^9, 3.6169930012804956`*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"pss1", ",", "pss2"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616992687151544*^9, 3.616992702626771*^9}, {
  3.616992735059228*^9, 3.6169927677948856`*^9}}],

Cell["", "Text"],

Cell["Changing both signs  acts as a reflection at the origin:", "Text",
 CellChangeTimes->{{3.616995201804761*^9, 3.616995245375637*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sfrev", "[", 
    RowBox[{"f", ",", "h"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " ", "+", " ", 
  RowBox[{
   RowBox[{"sfrev", "[", 
    RowBox[{
     RowBox[{"-", "f"}], ",", 
     RowBox[{"-", "h"}]}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.6169949972104015`*^9, 3.616995011780827*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.6169950149164324`*^9}]
}, Closed]],

Cell["\<\
Changing the sign of f only acts as a reflection ib the x, y - plane and \
yields the same surface :\
\>", "Text",
 CellChangeTimes->{{3.616995598435457*^9, 3.616995667247178*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{"f", ",", "h"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", "v", "]"}], " ", 
    RowBox[{"f", "[", "u", "]"}]}], ",", 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"h", "[", "u", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6169954180055404`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{
    RowBox[{"-", "f"}], ",", "h"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6169954540104036`*^9, 3.616995462902419*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Cos", "[", "v", "]"}]}], " ", 
    RowBox[{"f", "[", "u", "]"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"f", "[", "u", "]"}]}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"h", "[", "u", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6169954638696213`*^9}]
}, Closed]],

Cell["\<\
Changing the sign at h only acts as a reflection at the x,y-plane:\
\>", "Text",
 CellChangeTimes->{{3.6169958078346252`*^9, 3.616995850719101*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sfrev", "[", 
    RowBox[{"f", ",", 
     RowBox[{"-", "h"}]}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.6169949972104015`*^9, 3.616995011780827*^9}, {
   3.616995091543767*^9, 3.616995097331377*^9}, {3.616995129389434*^9, 
   3.616995140683853*^9}, 3.6169957434845123`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", "v", "]"}], " ", 
    RowBox[{"f", "[", "u", "]"}]}], ",", 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"-", 
    RowBox[{"h", "[", "u", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6169951530702753`*^9, 3.616995744498514*^9}]
}, Closed]],

Cell["\<\
The case B\[NotEqual]0, A=0 yields the same results by the variable transform 
u -> -u.\
\>", "Text",
 CellChangeTimes->{{3.616994639720174*^9, 3.6169946467869864`*^9}, {
   3.616994681824648*^9, 3.6169947215423174`*^9}, {3.6169948441117325`*^9, 
   3.6169948840166025`*^9}, 3.6169979055235095`*^9}],

Cell[TextData[{
 StyleBox["Case A",
  FontColor->RGBColor[0, 0, 1]],
 "\[NotEqual]",
 StyleBox["0, B",
  FontColor->RGBColor[0, 0, 1]],
 "\[NotEqual]",
 StyleBox["0.",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.6169397692433243`*^9, 3.6169398291707516`*^9}, {
  3.6169977852940984`*^9, 3.6169977862145*^9}, {3.616997819770159*^9, 
  3.6169978304093776`*^9}}],

Cell["We transform the variable ", "Text",
 CellChangeTimes->{{3.61699786607104*^9, 3.616997880563466*^9}}],

Cell[BoxData[
 RowBox[{"u", " ", "\[Rule]", " ", 
  RowBox[{"w", " ", "+", 
   RowBox[{
    RowBox[{"a", "/", "2"}], "*", 
    RowBox[{"Log", "[", 
     RowBox[{
      RowBox[{"Abs", "[", "B", "]"}], "/", 
      RowBox[{"Abs", "[", "A", "]"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6169979139163246`*^9, 3.6169979917916613`*^9}, 
   3.6169981497419386`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fsn", "[", 
      RowBox[{"a", ",", "A", ",", "B"}], "]"}], "[", "u", "]"}], "/.", 
    RowBox[{"u", " ", "\[Rule]", " ", 
     RowBox[{"w", " ", "+", 
      RowBox[{
       RowBox[{"a", "/", "2"}], "*", 
       RowBox[{"Log", "[", 
        RowBox[{
         RowBox[{"Abs", "[", "B", "]"}], "/", 
         RowBox[{"Abs", "[", "A", "]"}]}], "]"}]}]}]}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", " ", 
     RowBox[{"A", "\[NotEqual]", "0"}], ",", 
     RowBox[{"B", "\[NotEqual]", "0"}], ",", " ", 
     RowBox[{"w", "\[Element]", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616998096826646*^9, 3.616998136216715*^9}, {
  3.616998170255975*^9, 3.616998278083364*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox["w", "a"]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"B", " ", 
      RowBox[{"Abs", "[", "A", "]"}]}], "+", 
     RowBox[{"A", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "w"}], "a"]], " ", 
      RowBox[{"Abs", "[", "B", "]"}]}]}], ")"}]}], 
  SqrtBox[
   RowBox[{"Abs", "[", 
    RowBox[{"A", " ", "B"}], "]"}]]]], "Output",
 CellChangeTimes->{3.6169982797057667`*^9}]
}, Closed]],

Cell[TextData[{
 "Thus we may assume Abs[A] == Abs[B].\n\n",
 StyleBox["Case A= B>0",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.6169983386894703`*^9, 3.6169983974703736`*^9}, {
   3.616998433646837*^9, 3.6169984349572396`*^9}, {3.616999099159606*^9, 
   3.6169991018428106`*^9}, 3.6170078639195557`*^9, 3.6170079205507946`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fsn", "[", 
     RowBox[{"a", ",", "A", ",", "A"}], "]"}], "[", "u", "]"}], "\[Equal]", 
   " ", 
   RowBox[{"2", "*", "A", "*", 
    RowBox[{"Cosh", "[", 
     RowBox[{"u", "/", "a"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616999248670269*^9, 3.616999372331686*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.6169992934579477`*^9, {3.616999332036815*^9, 3.6169993732832875`*^9}}]
}, Closed]],

Cell["Setting b= 2A we define", "Text",
 CellChangeTimes->{{3.6169994792074738`*^9, 3.616999497584306*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fsn2", "[", 
    RowBox[{"a_", ",", "b_"}], "]"}], "[", "u_", "]"}], " ", ":=", " ", 
  RowBox[{"b", "*", 
   RowBox[{"Cosh", "[", 
    RowBox[{"u", "/", "a"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6169993881501136`*^9, 3.6169994609554415`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fsn2", "[", 
    RowBox[{"a", ",", "b"}], "]"}], "'"}], "[", "u", "]"}]], "Input",
 CellChangeTimes->{{3.616999512232732*^9, 3.6169995416387835`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"b", " ", 
   RowBox[{"Sinh", "[", 
    FractionBox["u", "a"], "]"}]}], "a"]], "Output",
 CellChangeTimes->{3.616999544821189*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"Sqrt", "[", 
      RowBox[{"1", "-", 
       RowBox[{
        RowBox[{"b", "^", "2"}], "*", 
        RowBox[{
         RowBox[{
          RowBox[{"Sinh", "[", 
           RowBox[{"t", "/", "a"}], "]"}], "^", "2"}], "/", 
         RowBox[{"a", "^", "2"}]}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "u"}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], "*", 
       RowBox[{"ArcSinh", "[", 
        RowBox[{"a", "/", "b"}], "]"}]}], "<", "u"}], ",", 
     RowBox[{"u", "<", 
      RowBox[{"a", "*", 
       RowBox[{"ArcSinh", "[", 
        RowBox[{"a", "/", "b"}], "]"}]}]}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6169996601209917`*^9, 3.6169999512955027`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "\[ImaginaryI]"}], " ", "a", " ", 
  RowBox[{"EllipticE", "[", 
   RowBox[{
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", "u"}], "a"], ",", 
    RowBox[{"-", 
     FractionBox[
      SuperscriptBox["b", "2"], 
      SuperscriptBox["a", "2"]]}]}], "]"}]}]], "Output",
 CellChangeTimes->{3.6169999885639687`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hsn2", "[", 
    RowBox[{"a_", ",", " ", "b_"}], "]"}], "[", "u_", "]"}], " ", ":=", " ", 
  "\n", "  ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"-", "I"}], ")"}], "*", "a", "*", 
   RowBox[{"EllipticE", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"I", "*", "u"}], ")"}], "/", "a"}], ",", " ", "\n", "    ", 
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b", "^", "2"}], "/", 
        RowBox[{"a", "^", "2"}]}], ")"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6170004523059826`*^9, 3.6170005089340825`*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{
      RowBox[{"fsn2", "[", 
       RowBox[{"1", ",", ".2"}], "]"}], ",", 
      RowBox[{"hsn2", "[", 
       RowBox[{"1", ",", ".2"}], "]"}]}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", 
      RowBox[{"ArcSinh", "[", "5", "]"}]}], ",", 
     RowBox[{"ArcSinh", "[", "5", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6169076266495514`*^9, 3.6169077454233446`*^9}, {
   3.616941068335628*^9, 3.616941081603387*^9}, 3.6169902080239897`*^9, {
   3.61699079488142*^9, 3.6169909004156055`*^9}, 3.616992481759183*^9, 
   3.6169926018349943`*^9, {3.6169926517706814`*^9, 3.6169926596018953`*^9}, {
   3.617000567075384*^9, 3.6170006327359*^9}, {3.617000673888772*^9, 
   3.6170006823439865`*^9}, 3.617000763510929*^9, {3.6170007966297874`*^9, 
   3.6170008213246307`*^9}}],

Cell["This is a surface of hyperboloidal type of  curvature -1:", "Text",
 CellChangeTimes->{{3.6170008768295283`*^9, 3.617000926858816*^9}, 
   3.6186391924136333`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", 
     RowBox[{"sfrev", "[", 
      RowBox[{
       RowBox[{"fsn2", "[", 
        RowBox[{"1", ",", 
         RowBox[{"2", "/", "10"}]}], "]"}], ",", 
       RowBox[{"hsn2", "[", 
        RowBox[{"1", ",", 
         RowBox[{"2", "/", "10"}]}], "]"}]}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", "\[Element]", " ", "Reals"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6170009298072214`*^9, 3.6170009576688704`*^9}, {
   3.6170009942197347`*^9, 3.61700104857023*^9}, {3.6170021872745433`*^9, 
   3.617002200114278*^9}, 3.6170076753987727`*^9}],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output",
 CellChangeTimes->{3.617007834866894*^9}]
}, Closed]],

Cell[TextData[StyleBox["Case A = -B>0",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.6170078931032248`*^9, 3.617007928519251*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fsn", "[", 
     RowBox[{"a", ",", "A", ",", 
      RowBox[{"-", "A"}]}], "]"}], "[", "u", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", " ", 
     RowBox[{"A", ">", "0"}], ",", 
     RowBox[{"u", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.617008009144862*^9, 3.6170080423057585`*^9}, {
  3.6170081028262205`*^9, 3.6170081747313333`*^9}}],

Cell[BoxData[
 RowBox[{"2", " ", "A", " ", 
  RowBox[{"Sinh", "[", 
   FractionBox["u", "a"], "]"}]}]], "Output",
 CellChangeTimes->{{3.6170081579343724`*^9, 3.61700818183974*^9}}]
}, Closed]],

Cell["Setting 2A = b we define", "Text",
 CellChangeTimes->{{3.6170082573680596`*^9, 3.617008298823431*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fsn3", "[", 
    RowBox[{"a_", ",", "b_"}], "]"}], "[", "u_", "]"}], " ", ":=", " ", 
  RowBox[{"b", "*", 
   RowBox[{"Sinh", "[", 
    RowBox[{"u", "/", "a"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.617008308011956*^9, 3.617008385794405*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fsn3", "[", 
    RowBox[{"a", ",", "b"}], "]"}], "'"}], "[", "u", "]"}]], "Input",
 CellChangeTimes->{{3.6170083932528315`*^9, 3.617008410296807*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"b", " ", 
   RowBox[{"Cosh", "[", 
    FractionBox["u", "a"], "]"}]}], "a"]], "Output",
 CellChangeTimes->{3.617008413512991*^9, 3.617008735575412*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"Sqrt", "[", 
      RowBox[{"1", " ", "-", " ", 
       RowBox[{
        RowBox[{"b", "^", "2"}], "*", 
        RowBox[{
         RowBox[{
          RowBox[{"Cosh", "[", 
           RowBox[{"t", "/", "a"}], "]"}], "^", "2"}], "/", 
         RowBox[{"a", "^", "2"}]}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "u"}], "}"}]}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", " ", 
     RowBox[{"b", ">", "0"}], ",", 
     RowBox[{"b", "\[LessEqual]", "a"}], ",", 
     RowBox[{"u", "\[Element]", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6170084693691854`*^9, 3.6170086802052445`*^9}, {
   3.617008986420759*^9, 3.6170090293732157`*^9}, 3.617009075739868*^9}],

Cell[BoxData[
 RowBox[{"ConditionalExpression", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "-", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}]}]], " ", 
    RowBox[{"EllipticE", "[", 
     RowBox[{
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "u"}], "a"], ",", 
      FractionBox[
       SuperscriptBox["b", "2"], 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"]}]]}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"a", "\[NotEqual]", 
     RowBox[{"b", " ", 
      RowBox[{"Cosh", "[", 
       FractionBox["u", "a"], "]"}]}]}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"]}], 
           SuperscriptBox["b", "2"]], "+", 
          RowBox[{"Cosh", "[", 
           FractionBox[
            RowBox[{"2", " ", "u"}], "a"], "]"}]}], ")"}], " ", 
        RowBox[{"Re", "[", 
         SuperscriptBox[
          RowBox[{"Csch", "[", 
           FractionBox["u", "a"], "]"}], "2"], "]"}]}], ">", "2"}], "||", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["a", "2"]}], "+", 
          SuperscriptBox["b", "2"], "+", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", 
           RowBox[{"Cosh", "[", 
            FractionBox[
             RowBox[{"2", " ", "u"}], "a"], "]"}]}]}], ")"}], " ", 
        RowBox[{"Re", "[", 
         SuperscriptBox[
          RowBox[{"Csch", "[", 
           FractionBox["u", "a"], "]"}], "2"], "]"}]}], "<", "0"}], "||", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "+", "b"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"a", "+", "b"}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"Csch", "[", 
           FractionBox["u", "a"], "]"}], "2"]}], 
        SuperscriptBox["b", "2"]], "\[NotElement]", "Reals"}]}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "-", "b"}], ")"}], " ", 
        RowBox[{"Re", "[", 
         SuperscriptBox[
          RowBox[{"Csch", "[", 
           FractionBox["u", "a"], "]"}], "2"], "]"}]}], "<", "0"}], "||", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", "-", "b"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"a", "+", "b"}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"Csch", "[", 
           FractionBox["u", "a"], "]"}], "2"]}], 
        SuperscriptBox["b", "2"]], "\[NotElement]", "Reals"}], "||", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "-", "b"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"a", "+", "b"}], ")"}], " ", 
            RowBox[{"Re", "[", 
             SuperscriptBox[
              RowBox[{"Csch", "[", 
               FractionBox["u", "a"], "]"}], "2"], "]"}]}], "\[GreaterEqual]", 
           SuperscriptBox["b", "2"]}], "||", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "-", "b"}], ")"}], " ", 
            RowBox[{"Re", "[", 
             SuperscriptBox[
              RowBox[{"Csch", "[", 
               FractionBox["u", "a"], "]"}], "2"], "]"}]}], "\[LessEqual]", 
           "0"}]}], ")"}], "&&", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["a", "2"]}], "+", 
               SuperscriptBox["b", "2"]}], ")"}], " ", 
             RowBox[{"Re", "[", 
              SuperscriptBox[
               RowBox[{"Csch", "[", 
                FractionBox["u", "a"], "]"}], "2"], "]"}]}]}], "<", "0"}], "||", 
          RowBox[{
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "a"}], "+", "b"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"a", "+", "b"}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"Csch", "[", 
               FractionBox["u", "a"], "]"}], "2"]}], 
            SuperscriptBox["b", "2"]], "\[NotElement]", "Reals"}]}], ")"}]}], 
       ")"}]}], ")"}]}]}], "]"}]], "Output",
 CellChangeTimes->{3.6170091831560116`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hsn3", "[", 
    RowBox[{"a_", ",", " ", "b_"}], "]"}], "[", "u_", "]"}], " ", ":=", " ", 
  "\n", "  ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"-", "I"}], ")"}], "*", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"a", "^", "2"}], "-", 
     RowBox[{"b", "^", "2"}]}], "]"}], "*", "\n", "   ", 
   RowBox[{"EllipticE", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"I", "*", "u"}], ")"}], "/", "a"}], ",", " ", "\n", "    ", 
     RowBox[{
      RowBox[{"b", "^", "2"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"a", "^", "2"}]}], " ", "+", " ", 
        RowBox[{"b", "^", "2"}]}], ")"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6170131274146104`*^9, 3.6170131900961957`*^9}, {
   3.6170132542948675`*^9, 3.617013277140174*^9}, 3.617014579644656*^9}],

Cell["To get a real solution one has to regard the conditions", "Text",
 CellChangeTimes->{{3.6170133466241484`*^9, 3.617013365167209*^9}, {
  3.6170134139999847`*^9, 3.617013421839433*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", ">", "0"}], ",", 
   RowBox[{"b", ">", "0"}], ",", 
   RowBox[{"b", "\[LessEqual]", "a"}], ",", 
   RowBox[{"u", "\[LessEqual]", 
    RowBox[{"a", "*", 
     RowBox[{"ArcSinh", "[", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", "^", "2"}], "-", 
          RowBox[{"b", "^", "2"}]}], ")"}], "]"}], "/", "b"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a"}], "*", 
     RowBox[{"ArcSinh", "[", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", "^", "2"}], "-", 
          RowBox[{"b", "^", "2"}]}], ")"}], "]"}], "/", "b"}], "]"}]}], "<", 
    "u"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.6170084693691854`*^9, 3.6170086802052445`*^9}, {
   3.617008986420759*^9, 3.6170090293732157`*^9}, 3.617009075739868*^9, {
   3.6170092980325823`*^9, 3.6170093610641875`*^9}, 3.6170133012135515`*^9, {
   3.6170134490309887`*^9, 3.617013501571994*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", ">", "0"}], ",", 
   RowBox[{"b", ">", "0"}], ",", 
   RowBox[{"b", "\[LessEqual]", "a"}], ",", 
   RowBox[{"u", "\[LessEqual]", 
    RowBox[{"a", " ", 
     RowBox[{"ArcSinh", "[", 
      FractionBox[
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["b", "2"]}]], "b"], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a"}], " ", 
     RowBox[{"ArcSinh", "[", 
      FractionBox[
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["b", "2"]}]], "b"], "]"}]}], "<", "u"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.617015074765975*^9}]
}, Closed]],

Cell["Test with other parameters!", "Text",
 CellChangeTimes->{{3.617015088813779*^9, 3.6170151379445887`*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{
      RowBox[{"fsn3", "[", 
       RowBox[{"1", ",", 
        RowBox[{"1", "/", "5"}]}], "]"}], ",", 
      RowBox[{"hsn3", "[", 
       RowBox[{"1", ",", 
        RowBox[{"1", "/", "5"}]}], "]"}]}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", " ", 
      RowBox[{"ArcSinh", "[", 
       SqrtBox["24"], "]"}]}], ",", " ", 
     RowBox[{"ArcSinh", "[", 
      SqrtBox["24"], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6169076266495514`*^9, 3.6169077454233446`*^9}, {
   3.616941068335628*^9, 3.616941081603387*^9}, 3.6169902080239897`*^9, {
   3.61699079488142*^9, 3.6169909004156055`*^9}, 3.616992481759183*^9, 
   3.6169926018349943`*^9, {3.6169926517706814`*^9, 3.6169926596018953`*^9}, {
   3.617000567075384*^9, 3.6170006327359*^9}, {3.617000673888772*^9, 
   3.6170006823439865`*^9}, 3.617000763510929*^9, {3.6170007966297874`*^9, 
   3.6170008213246307`*^9}, 3.6170145219403553`*^9, 3.617014597532679*^9, {
   3.617014628692461*^9, 3.617014645420418*^9}, {3.617014863190874*^9, 
   3.617014908262452*^9}}],

Cell["This is a surface of conical type with constant curvature", "Text",
 CellChangeTimes->{{3.6170149456085877`*^9, 3.6170149795755305`*^9}, 
   3.6186392130848155`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", 
     RowBox[{"sfrev", "[", 
      RowBox[{
       RowBox[{"fsn3", "[", 
        RowBox[{"1", ",", 
         RowBox[{"2", "/", "10"}]}], "]"}], ",", 
       RowBox[{"hsn3", "[", 
        RowBox[{"1", ",", 
         RowBox[{"2", "/", "10"}]}], "]"}]}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", "\[Element]", " ", "Reals"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6170009298072214`*^9, 3.6170009576688704`*^9}, {
   3.6170009942197347`*^9, 3.61700104857023*^9}, {3.6170021872745433`*^9, 
   3.617002200114278*^9}, 3.6170076753987727`*^9, {3.617015016756657*^9, 
   3.617015040035989*^9}}],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output",
 CellChangeTimes->{3.6170150521986847`*^9}]
}, Closed]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. Absolute Differential and Christoffel Symbols", "Section",
 CellChangeTimes->{{3.5946282877913494`*^9, 3.594628341078397*^9}, 
   3.5946287521269073`*^9, {3.5947080886573257`*^9, 3.5947081111446123`*^9}, 
   3.598083945859253*^9, {3.598946107413493*^9, 3.598946113378834*^9}, {
   3.612849789938574*^9, 3.612849791376656*^9}, {3.6130221703369937`*^9, 
   3.613022178273448*^9}, 3.6130231613936787`*^9, {3.6167422011590385`*^9, 
   3.6167422040602045`*^9}, 3.617010591446561*^9, 3.6171012878039837`*^9}],

Cell[TextData[{
 "In general, the differential and the derivatives of a tangent vector field \
on a surface are not tangent to the surface. The tangential component of the \
differential  of the vector field is called its ",
 StyleBox["absolute differential",
  FontColor->RGBColor[0, 0, 1]],
 "; we will calculate it in this section. The calculation leads to the ",
 StyleBox["Christoffel symbols",
  FontColor->RGBColor[0, 0, 1]],
 " which depend on the metric of the surface only and so belong to the inner \
geometry. These concepts play a fundamental role in the n-dimensional \
differential geometry of Riemannian manifolds and in Einstein\
\[CloseCurlyQuote]s general relativity theory. Therefore we begin this \
section considering m-dimensional submanifolds as immersions of m-dimenional \
parameter manifolds into the n-dimensional Euclidean space."
}], "Text",
 CellChangeTimes->{{3.5947073216646147`*^9, 3.5947073544090724`*^9}, {
   3.5947074072803535`*^9, 3.594707416416876*^9}, {3.594707450000797*^9, 
   3.594707526440169*^9}, {3.5947075823123646`*^9, 3.5947076930887003`*^9}, {
   3.5947077549602394`*^9, 3.5947077900162444`*^9}, {3.5947079466812053`*^9, 
   3.594708039528516*^9}, {3.5947081384651747`*^9, 3.5947082368408012`*^9}, {
   3.594708283920494*^9, 3.594708429712833*^9}, 3.594708506376218*^9, {
   3.594708537489998*^9, 3.5947085395871177`*^9}, 3.5949729165971603`*^9, {
   3.595133846274932*^9, 3.595133848630536*^9}, {3.5951339368798914`*^9, 
   3.5951339615747347`*^9}, {3.6130240656604*^9, 3.613024071877756*^9}, 
   3.6170751047813716`*^9, 3.61744219818544*^9}],

Cell[CellGroupData[{

Cell["\<\
4.1. The First Fundamental Form of an Immersion. Riemannian Metric\
\>", "Subsection",
 CellChangeTimes->{{3.5947089791212573`*^9, 3.5947089976963196`*^9}, {
   3.594883589600548*^9, 3.594883617945798*^9}, {3.594971429937128*^9, 
   3.5949714379675875`*^9}, 3.5949729180552435`*^9}],

Cell[TextData[{
 "A smooth map f: ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"\[LongRightArrow]", " ", 
    SuperscriptBox["Y", "n"]}], TraditionalForm]]],
 ", m < n, of an m-dimensional manifold into an n-dimensional manifold is \
called an ",
 StyleBox["immersion",
  FontColor->RGBColor[0, 0, 1]],
 " if at any point x \[Element] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]]],
 " the differential "
}], "Text",
 CellChangeTimes->{{3.594709086392393*^9, 3.5947092776243305`*^9}, {
   3.5947093093291445`*^9, 3.5947095553792176`*^9}, {3.594709592893363*^9, 
   3.594709676260132*^9}, 3.594709830520955*^9, {3.594709960589394*^9, 
   3.594709960589394*^9}, {3.594710218598151*^9, 3.5947102185991516`*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["df", "x"], TraditionalForm]]],
 ": ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "x"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[LongRightArrow]", " ", 
     SubscriptBox["T", 
      RowBox[{"f", "(", "x", ")"}]]}], 
    SuperscriptBox["Y", "n"]}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.594709086392393*^9, 3.5947092776243305`*^9}, {
  3.5947093093291445`*^9, 3.5947095553792176`*^9}, {3.594709592893363*^9, 
  3.5947097207526765`*^9}}],

Cell[TextData[{
 "has maximal rank m. We name the image f(",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]]],
 ") of an immersion f  an ",
 StyleBox["m-dimensional submanifold",
  FontColor->RGBColor[0, 0, 1]],
 ", shortly an  ",
 StyleBox["m-surface",
  FontColor->RGBColor[0, 0, 1]],
 " in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Y", "n"], TraditionalForm]]],
 ". Of course, for m=1 we speak about curves, and for m=2 about surfaces; ",
 StyleBox["hypersurfaces",
  FontColor->RGBColor[0, 0, 1]],
 " are submanifolds with m = n-1. For the following local considerations we \
assume that ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Y", "n"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "n"], TraditionalForm]]],
 " is the n-dimensional Euclidean space, and that  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]]],
 " = U is an open subset of the real vector space ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "m"], TraditionalForm]]],
 " with Cartesian coordinates u[i], e.g."
}], "Text",
 CellChangeTimes->{{3.59470972972919*^9, 3.594709745073067*^9}, {
   3.59470993918517*^9, 3.594710073760867*^9}, {3.5947101193844767`*^9, 
   3.5947101879683995`*^9}, {3.59471027661747*^9, 3.5947103290484686`*^9}, {
   3.5947104053608336`*^9, 3.5947105040324774`*^9}, {3.5947105828459854`*^9, 
   3.5947106703929925`*^9}, {3.5947107725138335`*^9, 3.594710795201131*^9}, 
   3.59471086686523*^9, {3.594712076002389*^9, 3.5947120775364766`*^9}, {
   3.5947121190408506`*^9, 3.594712123329096*^9}, {3.5949713277202816`*^9, 
   3.594971351344633*^9}, 3.6174409203413515`*^9, {3.617442432065817*^9, 
   3.6174424531700244`*^9}, {3.617442959017957*^9, 3.6174429963860946`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"m", "=", "3"}], ";", 
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{"u", ",", "m"}], "]"}], " ", "\[Element]", " ", "U"}]}]], "Input",
 CellChangeTimes->{{3.594710822927717*^9, 3.5947108435468965`*^9}, {
  3.5947108983280296`*^9, 3.594710901706223*^9}, {3.5947109635867624`*^9, 
  3.594710990867323*^9}, {3.594711188715639*^9, 3.5947111972191253`*^9}, {
  3.5947112491310945`*^9, 3.594711271322364*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"u", "[", "1", "]"}], ",", 
    RowBox[{"u", "[", "2", "]"}], ",", 
    RowBox[{"u", "[", "3", "]"}]}], "}"}], "\[Element]", "U"}]], "Output",
 CellChangeTimes->{3.5947109939124966`*^9, 3.5947111996922665`*^9, 
  3.594711272808449*^9}]
}, Closed]],

Cell[TextData[{
 "For the dimension of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Y", "n"], TraditionalForm]]],
 " we set  dim = n and define the coordinate representation of the immersion"
}], "Text",
 CellChangeTimes->{{3.5947121549129024`*^9, 3.5947122693124456`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", " ", 
   RowBox[{"m", ",", "n", ",", "dim", ",", "f", ",", "smf"}], "]"}], ";", 
  RowBox[{
   RowBox[{"smf", "[", "f_", "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "[", "i", "]"}], "[", "##", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "dim"}], "}"}]}], "]"}], "&"}]}], ";", " ", 
  RowBox[{"dim", " ", "=", " ", "5"}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.594711374151245*^9, 3.5947114794592686`*^9}, {
   3.5947115852673206`*^9, 3.5947116073685846`*^9}, {3.594711639827441*^9, 
   3.594711671263239*^9}, {3.5947117575881767`*^9, 3.594711828853253*^9}, 
   3.594711998116934*^9, {3.5953194640529366`*^9, 3.5953194932676077`*^9}, {
   3.5953195538850746`*^9, 3.5953195709550505`*^9}, {3.5953196051960096`*^9, 
   3.5953196419811134`*^9}, {3.5955694749613805`*^9, 3.595569489786228*^9}, {
   3.5955695866347675`*^9, 3.5955696055618505`*^9}, {3.5955715900903587`*^9, 
   3.595571629682624*^9}, 3.614861861422343*^9, 3.614863501890024*^9, 
   3.617442593030024*^9, 3.6174431535420837`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"smf", "[", "f", "]"}], "[", 
  RowBox[{
   RowBox[{"t", "[", "1", "]"}], ",", 
   RowBox[{"t", "[", "2", "]"}], ",", 
   RowBox[{"t", "[", "3", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5955715213854294`*^9, 3.595571563568842*^9}, {
  3.5955716737611446`*^9, 3.595571675478243*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "1", "]"}], "[", 
    RowBox[{
     RowBox[{"t", "[", "1", "]"}], ",", 
     RowBox[{"t", "[", "2", "]"}], ",", 
     RowBox[{"t", "[", "3", "]"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "2", "]"}], "[", 
    RowBox[{
     RowBox[{"t", "[", "1", "]"}], ",", 
     RowBox[{"t", "[", "2", "]"}], ",", 
     RowBox[{"t", "[", "3", "]"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "3", "]"}], "[", 
    RowBox[{
     RowBox[{"t", "[", "1", "]"}], ",", 
     RowBox[{"t", "[", "2", "]"}], ",", 
     RowBox[{"t", "[", "3", "]"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "4", "]"}], "[", 
    RowBox[{
     RowBox[{"t", "[", "1", "]"}], ",", 
     RowBox[{"t", "[", "2", "]"}], ",", 
     RowBox[{"t", "[", "3", "]"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "5", "]"}], "[", 
    RowBox[{
     RowBox[{"t", "[", "1", "]"}], ",", 
     RowBox[{"t", "[", "2", "]"}], ",", 
     RowBox[{"t", "[", "3", "]"}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5955715295838985`*^9, 3.595571566175991*^9, 
  3.5955716778143764`*^9, 3.6170752628096495`*^9, 3.6174426110210533`*^9, 
  3.6174431594884233`*^9, 3.618640776007242*^9}]
}, Closed]],

Cell["This is a generalization of the surface definition:", "Text",
 CellChangeTimes->{{3.594712322440484*^9, 3.5947123420246043`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";", 
  RowBox[{
   RowBox[{"sf", "[", 
    RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", " ", 
   RowBox[{
    RowBox[{"smf", "[", "f", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.594711690724352*^9, 3.5947116972027225`*^9}, {
  3.5947118526666145`*^9, 3.5947119351953354`*^9}, {3.617442632540284*^9, 
  3.617442636636518*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.594711698466795*^9, 3.594711939962608*^9, 
  3.594712010949668*^9, 3.595319511397644*^9, 3.5953196669385405`*^9, 
  3.5955696290591946`*^9, 3.5955702602872987`*^9, 3.595571717984674*^9, 
  3.617442638903648*^9, 3.6174431663668165`*^9}]
}, Closed]],

Cell[TextData[{
 "The differential of the immersion smf[f]  at a point u has the matrix,  \
often named the ",
 StyleBox["Jacobian matrix",
  FontColor->RGBColor[0, 0, 1]],
 ":"
}], "Text",
 CellChangeTimes->{{3.5947126263848686`*^9, 3.594712689952505*^9}, {
   3.594713832024828*^9, 3.594713852521*^9}, 3.5947142700248795`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"jac", "[", "f_", "]"}], " ", ":=", 
  RowBox[{
   RowBox[{"Transpose", "[", " ", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"f", "[", "##", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"{", "##", "}"}], "}"}]}], "]"}], "]"}], "&"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.594713386074321*^9, 3.5947134565803537`*^9}, {
   3.5947136684854736`*^9, 3.5947136955560217`*^9}, {3.594878799409334*^9, 
   3.594878809003351*^9}, {3.59531976814933*^9, 3.5953197990600977`*^9}, {
   3.5955699854815807`*^9, 3.5955699916969357`*^9}, 3.5955700826891403`*^9, {
   3.595570128169742*^9, 3.595570177161544*^9}, {3.595570330490314*^9, 
   3.5955703838003635`*^9}, {3.595571733209545*^9, 3.595571767456504*^9}, 
   3.6148618614379425`*^9, 3.6149177932153635`*^9}],

Cell[TextData[{
 StyleBox["Examples",
  FontColor->RGBColor[0, 0, 1]],
 ":"
}], "Text",
 CellChangeTimes->{{3.594713944363253*^9, 3.5947139681286125`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sf", "[", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], ",", 
   RowBox[{"x", "[", "2", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5955700385656166`*^9, 3.5955700433108883`*^9}, {
  3.5955717961761465`*^9, 3.5955718060007086`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "1", "]"}], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "2", "]"}], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "3", "]"}], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.59557004421994*^9, 3.5955718112310076`*^9, 
  3.6130213913744397`*^9, 3.617075303775321*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"jac", "[", "sf", "]"}], "[", 
   RowBox[{
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.594713474555382*^9, 3.5947135063091974`*^9}, 
   3.594713705411586*^9, {3.5955718260968575`*^9, 3.595571832905247*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"x", "[", "1", "]"}], ",", 
        RowBox[{"x", "[", "2", "]"}]}], "]"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"x", "[", "1", "]"}], ",", 
        RowBox[{"x", "[", "2", "]"}]}], "]"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"x", "[", "1", "]"}], ",", 
        RowBox[{"x", "[", "2", "]"}]}], "]"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "4", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"x", "[", "1", "]"}], ",", 
        RowBox[{"x", "[", "2", "]"}]}], "]"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "5", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"x", "[", "1", "]"}], ",", 
        RowBox[{"x", "[", "2", "]"}]}], "]"}]},
     {
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"x", "[", "1", "]"}], ",", 
        RowBox[{"x", "[", "2", "]"}]}], "]"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"x", "[", "1", "]"}], ",", 
        RowBox[{"x", "[", "2", "]"}]}], "]"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"x", "[", "1", "]"}], ",", 
        RowBox[{"x", "[", "2", "]"}]}], "]"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "4", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"x", "[", "1", "]"}], ",", 
        RowBox[{"x", "[", "2", "]"}]}], "]"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "5", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"x", "[", "1", "]"}], ",", 
        RowBox[{"x", "[", "2", "]"}]}], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.5947135069842367`*^9, 3.5947137070486794`*^9, 
  3.594714045697049*^9, 3.594878821842174*^9, 3.5953198070845566`*^9, 
  3.5955696459131584`*^9, 3.595570003720624*^9, 3.5955701015192175`*^9, 
  3.595570192917445*^9, 3.5955702835946317`*^9, 3.5955703894986887`*^9, 
  3.595570624817148*^9, 3.595571778727148*^9, 3.5955718341523185`*^9, 
  3.613021397287778*^9, 3.617075308236929*^9, 3.6186408210938215`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "5"}], ";", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"smf", "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"u", ",", "v", ",", "w"}], "}"}], "}"}]}], "]"}], "//", 
   "MatrixForm"}]}]], "Input",
 CellChangeTimes->{
  3.5947126945287666`*^9, {3.594712843322277*^9, 3.5947128956392694`*^9}, {
   3.5947129485562963`*^9, 3.5947129858044267`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}]},
     {
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}]},
     {
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}]},
     {
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "4", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "4", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "4", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}]},
     {
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "5", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "5", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "5", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.5947128970243483`*^9, 3.5947129894616356`*^9, 
  3.5948788381754026`*^9, 3.5953198199222913`*^9, 3.595571849252182*^9, 
  3.6130214505608253`*^9, 3.6170753290629654`*^9}]
}, Closed]],

Cell[TextData[{
 "The strokes of  jac[smf[f]][u,...] are the coordinates of  mf = Length[{u}]",
 StyleBox[" tangent basis vectors",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.5948852693022985`*^9, 3.594885337053217*^9}, {
   3.594885368814873*^9, 3.5948853968481226`*^9}, {3.5948861634958687`*^9, 
   3.59488616987628*^9}, {3.5953198474808674`*^9, 3.595319851433093*^9}, 
   3.595596847808015*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"tt", ",", "f", ",", "i"}], "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"tt", "[", "i_", "]"}], "[", "f_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"jac", "[", "f", "]"}], "[", "##", "]"}], "[", 
     RowBox[{"[", "i", "]"}], "]"}], "&"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.594714541091384*^9, 3.5947145732912254`*^9}, {
   3.5947146047630253`*^9, 3.5947147040847063`*^9}, {3.5947147562046876`*^9, 
   3.5947148572694683`*^9}, {3.594878909670328*^9, 3.594878940402382*^9}, {
   3.594885417580559*^9, 3.594885424475771*^9}, {3.5953198901263065`*^9, 
   3.5953199276454525`*^9}, {3.5955706750110197`*^9, 
   3.5955707288821006`*^9}, {3.595571901346162*^9, 3.5955720037630196`*^9}, {
   3.5955720872657957`*^9, 3.595572121314743*^9}, {3.5955722913794703`*^9, 
   3.595572311092598*^9}, {3.595572402579831*^9, 3.5955724102522697`*^9}, {
   3.595572441820075*^9, 3.595572498956343*^9}, {3.5955725345643797`*^9, 
   3.595572831877385*^9}, 3.5955728836043434`*^9, 3.595572934572259*^9, {
   3.5955730768843985`*^9, 3.59557313163353*^9}, {3.595573173865946*^9, 
   3.5955731968172584`*^9}, {3.595573569185557*^9, 3.5955735798341656`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dim", "=", " ", "5"}]], "Input",
 CellChangeTimes->{{3.5947149667027273`*^9, 3.5947149683628225`*^9}, {
  3.594715035434659*^9, 3.594715036664729*^9}, {3.594877943981832*^9, 
  3.5948779458850355`*^9}}],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{3.594715038309823*^9, 3.5948779476946383`*^9, 
  3.5948789459247923`*^9, 3.594885431074582*^9, 3.595319941916269*^9, 
  3.5955720150226636`*^9, 3.59557213909476*^9, 3.5955736139681177`*^9, 
  3.6170754391835585`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tt", "[", "2", "]"}], "[", 
   RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v", ",", "w"}], "]"}]], "Input",
 CellChangeTimes->{{3.5947150536677017`*^9, 3.594715076507008*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "1", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "2", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "3", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "4", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "5", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.594715081178275*^9, 3.594877955057852*^9, 
  3.594878952336403*^9, 3.5948854346937885`*^9, 3.5953199463285213`*^9, 
  3.5955706621352825`*^9, 3.595572019589925*^9, 3.595572143508013*^9, 
  3.595572231137025*^9, 3.5955728969921093`*^9, 3.5955729433337603`*^9, 
  3.595573140519038*^9, 3.5955736174873195`*^9, 3.617075439277159*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tt", "[", 
    RowBox[{"-", "3"}], "]"}], "[", 
   RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v", ",", "w"}], "]"}]], "Input",
 CellChangeTimes->{{3.5947148725073395`*^9, 3.5947149377160697`*^9}, {
  3.5947149838037057`*^9, 3.5947149862728467`*^9}, {3.595573631609127*^9, 
  3.595573672792483*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "1", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "2", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "3", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "4", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "5", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5947149393091607`*^9, 3.594714987520918*^9, 
  3.594877969659477*^9, 3.5948789640208235`*^9, 3.594885447173811*^9, 
  3.5953199592842617`*^9, 3.595570739271695*^9, 3.595572222362523*^9, 
  3.5955736794208617`*^9, 3.617075463129601*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tt", "[", 
    RowBox[{"-", "4"}], "]"}], "[", 
   RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v", ",", "w"}], "]"}]], "Input",
 CellChangeTimes->{{3.5947148725073395`*^9, 3.5947149377160697`*^9}, {
   3.5947149838037057`*^9, 3.5947149862728467`*^9}, {3.595573209854004*^9, 
   3.5955732176404495`*^9}, {3.595573252945469*^9, 3.5955732532084837`*^9}, {
   3.595573344249691*^9, 3.5955733722482924`*^9}, {3.595573403440077*^9, 
   3.5955734201600327`*^9}, 3.5955734528969054`*^9, {3.5955734878489046`*^9, 
   3.595573527057147*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Part", "::", "partw"}], "MessageName"], ":", 
  " ", "\<\"Part \[NoBreak]\\!\\(-4\\)\[NoBreak] of \[NoBreak]\\!\\(\
\[LeftSkeleton] 1 \[RightSkeleton]\\)\[NoBreak] does not exist. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/partw\\\", \
ButtonNote -> \\\"Part::partw\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5955735274351687`*^9, 3.5955736861682477`*^9, 
  3.6170755411921377`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "4", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "5", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "4", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "5", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "4", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "5", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "}"}]}], "}"}], 
  "\[LeftDoubleBracket]", 
  RowBox[{"-", "4"}], "\[RightDoubleBracket]"}]], "Output",
 CellChangeTimes->{
  3.5955732186135054`*^9, 3.595573254520559*^9, {3.595573346412815*^9, 
   3.5955733731513443`*^9}, 3.595573421662119*^9, 3.5955734536039457`*^9, {
   3.5955734886129484`*^9, 3.5955735274381685`*^9}, 3.595573686172248*^9, 
   3.617075541207738*^9}]
}, Closed]],

Cell[TextData[{
 "A ",
 StyleBox["tangent vector",
  FontColor->RGBColor[0, 0, 1]],
 " is a linear combination of the tangent basis vectors with the coordinates \
{s1,s2,...} \[Element] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "m"], TraditionalForm]]],
 ". A ",
 StyleBox["tangent vector field",
  FontColor->RGBColor[0, 0, 1]],
 " is obtained if the coordinates are given as functions of the parameters :"
}], "Text",
 CellChangeTimes->{{3.594878538608076*^9, 3.5948785573125095`*^9}, {
   3.594886028196831*^9, 3.5948861049957657`*^9}, {3.5955967368876705`*^9, 
   3.5955967454471607`*^9}, {3.5959112371428165`*^9, 3.595911291181311*^9}, {
   3.5959113324745836`*^9, 3.595911408431117*^9}, {3.59591146137761*^9, 
   3.595911536491742*^9}, 3.5959116685147743`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "vv", "]"}], ";", 
  RowBox[{
   RowBox[{"vv", "[", "\[Xi]_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Xi]", "[", "i", "]"}], "[", "##", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", 
         RowBox[{"{", "##", "}"}], "]"}]}], "}"}]}], "]"}], 
    "&"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5955963089271927`*^9, 3.595596389983829*^9}, {
   3.59559642496883*^9, 3.5955964744026575`*^9}, {3.59559657706553*^9, 
   3.595596688818921*^9}, {3.595596899914995*^9, 3.595596910010573*^9}, {
   3.5955969406903276`*^9, 3.5955969705550356`*^9}, {3.5955970131314707`*^9, 
   3.5955970157876225`*^9}, 3.6148618615003433`*^9, 3.6148635019056244`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.595596485708304*^9, 3.595596552745138*^9}, {
  3.5955969877460194`*^9, 3.5955969919132576`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.595596554570243*^9, 3.595596701102624*^9, {3.5955969937083597`*^9, 
   3.5955970227130194`*^9}, 3.6130216184784293`*^9, 3.617075857638694*^9}]
}, Closed]],

Cell[TextData[{
 "Remark that this field is defined as a tangent vector field of the \
parameter manifold. Its image under the differential of the immersion is a \
vector function on  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "m"], TraditionalForm]]],
 " with values in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "n"], TraditionalForm]]],
 ", e. g."
}], "Text",
 CellChangeTimes->{{3.5959117538781238`*^9, 3.5959119023591843`*^9}, {
   3.595911954619276*^9, 3.595911975195712*^9}, {3.5959121801956725`*^9, 
   3.595912259677812*^9}, 3.5960892898931456`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"sf", ",", "u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "]"}], "\[Equal]", " ", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"tt", "[", "i", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "*", 
      RowBox[{
       RowBox[{"\[Xi]", "[", "i", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5959119820753245`*^9, 3.5959119820753245`*^9}, {
  3.595912052790249*^9, 3.5959121489800177`*^9}, {3.617779223413473*^9, 
  3.617779229123083*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5959120259114017`*^9, 3.595912152490024*^9, 
  3.613021653738446*^9, 3.6170759046259766`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"tvf", ",", "ff", ",", "f", ",", "x"}], "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"tvf", "[", "\[Xi]_", "]"}], "[", "ff_", "]"}], ":=", " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"tt", "[", "i", "]"}], "[", "ff", "]"}], "[", "##", "]"}], 
       "*", 
       RowBox[{
        RowBox[{"\[Xi]", "[", "i", "]"}], "[", "##", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", 
         RowBox[{"{", "##", "}"}], "]"}]}], "}"}]}], "]"}], 
    "&"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.594878617606615*^9, 3.5948787620316687`*^9}, 
   3.5948789981848836`*^9, {3.594879140737934*^9, 3.5948791442167397`*^9}, {
   3.594879176649197*^9, 3.5948793408394856`*^9}, {3.5948830153635397`*^9, 
   3.594883020963949*^9}, {3.594885506703515*^9, 3.594885512210325*^9}, {
   3.595322968315078*^9, 3.5953229945305777`*^9}, {3.59532303128568*^9, 
   3.595323059653302*^9}, {3.5955707720675707`*^9, 3.595570783931249*^9}, {
   3.5955708177081814`*^9, 3.5955708618827076`*^9}, {3.595570944371426*^9, 
   3.595570972020007*^9}, {3.5955737481397924`*^9, 3.5955738706988025`*^9}, {
   3.5955826733812866`*^9, 3.5955827043000555`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.594879354302309*^9, 3.594879363319125*^9}, {
   3.5948795443418427`*^9, 3.5948795935287294`*^9}, 3.5955708665119724`*^9, 
   3.6177792687627525`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5948795980215373`*^9, 3.594885535625966*^9, 
  3.595323105213908*^9, 3.595570758506795*^9, 3.5955708348121595`*^9, 
  3.595570979563439*^9, 3.595573878420244*^9, 3.5955740052194967`*^9, 
  3.5955827107244225`*^9, 3.6130216654041133`*^9, 3.6170759614724765`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tvf", "[", "\[Eta]", "]"}], "[", 
   RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], ",", 
   RowBox[{"x", "[", "2", "]"}], ",", 
   RowBox[{"x", "[", "3", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5948797188749495`*^9, 3.594879759622221*^9}, {
   3.5955739079919353`*^9, 3.595573957097744*^9}, 3.595574075881538*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Eta]", "[", "3", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Eta]", "[", "2", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Eta]", "[", "1", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Eta]", "[", "3", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Eta]", "[", "2", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Eta]", "[", "1", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Eta]", "[", "3", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Eta]", "[", "2", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Eta]", "[", "1", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}]}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.59557407958675*^9, 3.5955827170967875`*^9, 
  3.61302168667733*^9}]
}, Closed]],

Cell["\<\
Tangent vectors are contained in the Euclidean n-space;  thus their scalar \
square and scalar products are defined:\
\>", "Text",
 CellChangeTimes->{{3.59488630057331*^9, 3.5948863791818476`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tvf", "[", "\[Eta]", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], ".", 
  RowBox[{
   RowBox[{
    RowBox[{"tvf", "[", "\[Eta]", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5948797188749495`*^9, 3.594879784707065*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Eta]", "[", "2", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Eta]", "[", "1", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Eta]", "[", "2", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Eta]", "[", "1", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Eta]", "[", "2", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Eta]", "[", "1", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}]], "Output",
 CellChangeTimes->{3.5948797935678806`*^9, 3.594885556202402*^9, 
  3.595574208055098*^9, 3.59558272291112*^9, 3.6130216960558662`*^9, 
  3.6170761613088274`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], ".", 
  RowBox[{
   RowBox[{
    RowBox[{"tvf", "[", "\[Eta]", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5948797188749495`*^9, 3.594879784707065*^9}, {
  3.594879824565135*^9, 3.5948798413663645`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Eta]", "[", "2", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Eta]", "[", "1", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Eta]", "[", "2", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Eta]", "[", "1", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Eta]", "[", "2", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Eta]", "[", "1", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.594879844033969*^9, 3.5948855980104756`*^9, 
  3.5955742227339373`*^9, 3.595582730108532*^9, 3.613021711377743*^9, 
  3.6170761876728735`*^9}]
}, Closed]],

Cell[TextData[{
 "This scalar product may be expressed by the ",
 StyleBox["first fundamental form ",
  FontColor->RGBColor[0, 0, 1]],
 "of the immersion, whose coordinates are defined by"
}], "Text",
 CellChangeTimes->{{3.5948864658712*^9, 3.5948865299093122`*^9}},
 CellTags->"fund1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "rgT"}]], "Input",
 CellChangeTimes->{{3.618641453594998*^9, 3.6186414580102506`*^9}, 
   3.6186415127083793`*^9, 3.6186416655541215`*^9}],

Cell[BoxData[
 StyleBox["\<\"For the immersion f of a m-dimensional manifold \
\!\(\*SuperscriptBox[\(X\), \(m\)]\) into the n-dimensional Euclidean space, \
m\[LessEqual]n, the matrix {rgT[i,j][f][u1,...,um]}, 1\[LessEqual]i,j\
\[LessEqual]m, is the matrix of the coefficients of the Riemannian metric on \
\!\(\*SuperscriptBox[\(X\), \(m\)]\) induced by the immersion f.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.618641666511176*^9},
 CellTags->"Info3618648866-2375024"]
}, Closed]],

Cell["\<\
which we used already defining the first fundamental form of a surface.\
\>", "Text",
 CellChangeTimes->{{3.5948866048830442`*^9, 3.5948866612615433`*^9}, {
  3.596526134112959*^9, 3.596526134119959*^9}, {3.618641727448662*^9, 
  3.61864176011153*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rgT", "[", 
    RowBox[{"1", ",", "2"}], "]"}], "[", 
   RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], ",", 
   RowBox[{"x", "[", "2", "]"}], ",", 
   RowBox[{"x", "[", "3", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.595574517864818*^9, 3.5955745322806425`*^9}, 
   3.5955746182335587`*^9, {3.6186415960341454`*^9, 3.6186415985062866`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "1", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}], ",", 
     RowBox[{"x", "[", "3", "]"}]}], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "1", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}], ",", 
     RowBox[{"x", "[", "3", "]"}]}], "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "2", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}], ",", 
     RowBox[{"x", "[", "3", "]"}]}], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "2", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}], ",", 
     RowBox[{"x", "[", "3", "]"}]}], "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "3", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}], ",", 
     RowBox[{"x", "[", "3", "]"}]}], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "3", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}], ",", 
     RowBox[{"x", "[", "3", "]"}]}], "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "4", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}], ",", 
     RowBox[{"x", "[", "3", "]"}]}], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "4", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}], ",", 
     RowBox[{"x", "[", "3", "]"}]}], "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "5", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}], ",", 
     RowBox[{"x", "[", "3", "]"}]}], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "5", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}], ",", 
     RowBox[{"x", "[", "3", "]"}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.5955746235608635`*^9, 3.595575010967022*^9, 
  3.6170762570929956`*^9, 3.6186416021594954`*^9}]
}, Closed]],

Cell[TextData[{
 "The ",
 StyleBox["first fundamental form",
  FontColor->RGBColor[0, 0, 1]],
 " of the immersion is defined already in context of the surfaces"
}], "Text",
 CellChangeTimes->{{3.594886746484493*^9, 3.5948868134866104`*^9}, {
  3.618641968400443*^9, 3.6186419953279834`*^9}, {3.618642102568117*^9, 
  3.618642120904166*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"??", "fund1"}]], "Input",
 CellChangeTimes->{{3.618641875834149*^9, 3.618641879318348*^9}}],

Cell[CellGroupData[{

Cell["Global`fund1", "Print", "PrintUsage",
 CellChangeTimes->{3.618641893757174*^9},
 CellTags->"Info3618649093-2375024"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {GridBox[{
       {
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"fund1", "[", "f_", "]"}], "[", "u__", "]"}], "[", 
          RowBox[{"x_List", ",", "y_List"}], "]"}], ":=", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "x", "]"}], "\[Equal]", 
             RowBox[{"Length", "[", 
              RowBox[{"{", "u", "}"}], "]"}]}], "&&", 
            RowBox[{
             RowBox[{"Length", "[", "y", "]"}], "\[Equal]", 
             RowBox[{"Length", "[", 
              RowBox[{"{", "u", "}"}], "]"}]}]}], ",", 
           RowBox[{
            UnderoverscriptBox["\[Sum]", "i", 
             RowBox[{"Length", "[", 
              RowBox[{"{", "u", "}"}], "]"}]], 
            RowBox[{
             UnderoverscriptBox["\[Sum]", "j", 
              RowBox[{"Length", "[", 
               RowBox[{"{", "u", "}"}], "]"}]], 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"rgT", "[", 
                 RowBox[{"i", ",", "j"}], "]"}], "[", "f", "]"}], "[", "u", 
               "]"}], " ", 
              RowBox[{
              "x", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
              " ", 
              RowBox[{
              "y", "\[LeftDoubleBracket]", "j", 
               "\[RightDoubleBracket]"}]}]}]}], ",", 
           RowBox[{
            RowBox[{"Print", "[", "\<\"Wrong arguments!\"\>", "]"}], ";", 
            RowBox[{"Return", "[", "]"}]}]}], "]"}]}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[$CellContext`fund1],
  Editable->False]], "Print",
 CellChangeTimes->{3.6186418937841754`*^9},
 CellTags->"Info3618649093-2375024"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fund1", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "[", 
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{"s", ",", "2"}], "]"}], ",", 
   RowBox[{"vec", "[", 
    RowBox[{"t", ",", "2"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5948833076300526`*^9, 3.594883417126645*^9}, {
   3.5955757454070296`*^9, 3.5955757569936924`*^9}, 3.6186420187383223`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"s", "[", "2", "]"}], " ", 
   RowBox[{"t", "[", "2", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "4", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"s", "[", "2", "]"}], " ", 
   RowBox[{"t", "[", "1", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "4", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "4", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"s", "[", "1", "]"}], " ", 
   RowBox[{"t", "[", "2", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "4", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "4", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"s", "[", "1", "]"}], " ", 
   RowBox[{"t", "[", "1", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "4", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.5948834213230524`*^9, 3.5948860004911823`*^9, 
  3.594964353210894*^9, 3.59557548858534*^9, 3.595575593812359*^9, 
  3.595575980548479*^9, 3.5955760640332537`*^9, 3.5955763473564587`*^9, 
  3.595576498342095*^9, 3.5955768299560623`*^9, 3.595576881094987*^9, 
  3.595576943868578*^9, 3.5955827817144833`*^9, 3.6130217999638095`*^9, 
  3.617076333111929*^9, 3.6186427237826486`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fund1", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "[", 
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{"s", ",", "4"}], "]"}], ",", 
   RowBox[{"vec", "[", 
    RowBox[{"t", ",", "2"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{3.5955757777128773`*^9, 3.5955767298893385`*^9, 
  3.5955769062254243`*^9, 3.6186426934259124`*^9}],

Cell[BoxData["\<\"Wrong arguments!\"\>"], "Print",
 CellChangeTimes->{
  3.5955759858097796`*^9, 3.595576068455507*^9, 3.5955767346856127`*^9, {
   3.5955768917275953`*^9, 3.595576907844517*^9}, 3.5955769483108315`*^9, 
   3.613021807635248*^9, 3.6170763460131516`*^9, 3.6186427411416416`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "4"}], ";", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ".", 
     RowBox[{
      RowBox[{
       RowBox[{"tvf", "[", "\[Eta]", "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], " ", "\[Equal]", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"fund1", "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "i", "]"}], "[", 
         RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}]}], "]"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Eta]", "[", "i", "]"}], "[", 
         RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.594881401478305*^9, 3.594881598647051*^9}, {
   3.5948856462925606`*^9, 3.594885672282206*^9}, {3.594886933372821*^9, 
   3.594887200928891*^9}, {3.595576973645281*^9, 3.595576983931869*^9}, {
   3.5955828729667025`*^9, 3.595582949996108*^9}, {3.614861861547143*^9, 
   3.614861861547143*^9}, {3.614863501921224*^9, 3.614863501921224*^9}, 
   3.618642037261382*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.5948872022704935`*^9, 3.5955756285813475`*^9, {3.595576960798546*^9, 
   3.5955769852169423`*^9}, 3.595582803700741*^9, 3.595582959592657*^9, 
   3.61302181290355*^9, 3.6170763743896017`*^9, 3.6186420555224266`*^9, 
   3.6186427515922394`*^9}]
}, Closed]],

Cell["or", "Text",
 CellChangeTimes->{{3.5959125121018553`*^9, 3.5959125125698566`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "4"}], ";", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ".", 
     RowBox[{
      RowBox[{
       RowBox[{"tvf", "[", "\[Eta]", "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], " ", "\[Equal]", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"fund1", "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], "[", 
     RowBox[{
      RowBox[{
       RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
      RowBox[{
       RowBox[{"vv", "[", "\[Eta]", "]"}], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.594881401478305*^9, 3.594881598647051*^9}, {
   3.5948856462925606`*^9, 3.594885672282206*^9}, {3.594886933372821*^9, 
   3.594887200928891*^9}, {3.595576973645281*^9, 3.595576983931869*^9}, {
   3.5955828729667025`*^9, 3.595582949996108*^9}, {3.595912402636463*^9, 
   3.5959124815258017`*^9}, 3.61864269513101*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5959124852386084`*^9, 3.6130218452674007`*^9, 
  3.6170764393325157`*^9, 3.6186427641899595`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ".", 
    RowBox[{
     RowBox[{
      RowBox[{"tvf", "[", "\[Eta]", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], " ", "-", " ", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "*", 
      RowBox[{
       RowBox[{"\[Xi]", "[", "i", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "*", 
      RowBox[{
       RowBox[{"\[Eta]", "[", "j", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "2"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.594881754257324*^9, 3.594881769311351*^9}, 
   3.594881800776606*^9, {3.594885713918679*^9, 3.5948857475367384`*^9}, {
   3.595582978069714*^9, 3.595582994405648*^9}, 3.6186421700129747`*^9, 
   3.6186423423618326`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.594881801915408*^9, 3.5948818827547503`*^9, 
  3.594885748956341*^9, 3.5948872377761555`*^9, 3.5955756523167048`*^9, 
  3.5955829969087915`*^9, 3.6130218491896253`*^9, 3.6170764521869383`*^9, 
  3.618642778096755*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{"vv", "[", "\[Eta]", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ".", 
    RowBox[{
     RowBox[{
      RowBox[{"tvf", "[", "\[Eta]", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}], " ", "]"}]], "Input",
 CellChangeTimes->{{3.594881903097186*^9, 3.594881929071232*^9}, {
   3.594882044995035*^9, 3.59488209889313*^9}, {3.5948821483140163`*^9, 
   3.594882356324782*^9}, {3.5948857787367935`*^9, 3.5948858214808683`*^9}, 
   3.5948858581253324`*^9, {3.5948859196674404`*^9, 3.5948859277326546`*^9}, {
   3.5948859703207293`*^9, 3.594885975078738*^9}, {3.5955830629015665`*^9, 
   3.59558310002969*^9}, {3.595912582457979*^9, 3.595912628056859*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.5948823036902895`*^9, 3.5948823263883295`*^9}, 
   3.594882358087585*^9, 3.5948858614325385`*^9, 3.594885928481456*^9, 
   3.594885977699542*^9, 3.594887263734601*^9, 3.595575664734415*^9, 
   3.5955831026268387`*^9, 3.595912630303263*^9, 3.613021866300604*^9, 
   3.617076472092573*^9, 3.6186427874562902`*^9}]
}, Closed]],

Cell[TextData[{
 "The first fundamental form is a field of positive definite symmetric \
bilinear forms {\[Gamma]\[Gamma][i,j][u]}, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"u", "\[Element]", 
    SuperscriptBox["X", "m"]}], TraditionalForm]]],
 ", on the manifold ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]]],
 "; it defines a Riemannian metric on ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]]],
 "; ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]]],
 "  provided with such a metric is named a ",
 StyleBox["Riemannian manifold",
  FontColor->RGBColor[0, 0, 1]],
 ". With the scalar product defined by {\[Gamma]\[Gamma][i,j][u]}, any \
tangent space ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "u"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]]],
 " becomes an m-dimensional Euclidean space; length of vectors and angles \
between vectors are defined by this scalar product. By definition, for an \
immersion f the Riemannian metric"
}], "Text",
 CellChangeTimes->{{3.5948875759067497`*^9, 3.5948877670538855`*^9}, 
   3.5949654316930485`*^9, 3.59496549099144*^9, {3.5949655491507664`*^9, 
   3.594965571823063*^9}, {3.594965717170377*^9, 3.5949657764947696`*^9}, {
   3.5949658208473063`*^9, 3.5949658766384974`*^9}, {3.5949659519598055`*^9, 
   3.5949659549429765`*^9}, {3.5949659930951586`*^9, 3.594966157918586*^9}, {
   3.5949661988769283`*^9, 3.59496644716713*^9}, {3.594966913414798*^9, 
   3.5949669701430426`*^9}, {3.5949716038810773`*^9, 
   3.5949716559840574`*^9}, {3.594971695811335*^9, 3.594971695811335*^9}, {
   3.5949717640392375`*^9, 3.594971771551667*^9}, {3.594971806319656*^9, 
   3.5949718596817083`*^9}, 3.5949729245216136`*^9, {3.595912681892554*^9, 
   3.5959127142470107`*^9}, {3.6130225413702154`*^9, 
   3.6130226045328283`*^9}, {3.6130226479333105`*^9, 
   3.6130227443038225`*^9}, {3.6130227886943617`*^9, 3.613022899241685*^9}, {
   3.613023003626655*^9, 3.613023014945303*^9}, {3.6170765536963167`*^9, 
   3.617076559561927*^9}, {3.6170773490949135`*^9, 3.617077383617774*^9}, {
   3.6170774835983496`*^9, 3.6170775130668015`*^9}}],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Gamma]\[Gamma]", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "[", "u", "]"}], "}"}], " ", ":"}], 
    " ", "=", "  ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "[", "f", "]"}], "[", "u", "]"}], 
     "}"}]}], ",", "     ", 
   FormBox[
    RowBox[{"u", "\[Element]", 
     SuperscriptBox["X", "m"]}],
    TraditionalForm], ",", " "}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.617077552878072*^9, 3.617077649535841*^9}, 
   3.6186421722731037`*^9, 3.6186423423668327`*^9}],

Cell[TextData[{
 "is the  pulling back of the Euclidean  metric  from the m-subspace ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["df", "u"], TraditionalForm]]],
 "(",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "u"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{")", " ", "\[Subset]", " ", 
    RowBox[{
     SubscriptBox["T", 
      RowBox[{"f", "(", "u", ")"}]], 
     SuperscriptBox["Y", "n"]}]}], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "n"], TraditionalForm]]],
 " with the differential ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["df", "u"], TraditionalForm]]],
 ". Also the ",
 StyleBox["volume element  ",
  FontColor->RGBColor[0, 0, 1]],
 "dV",
 StyleBox[" ",
  FontColor->RGBColor[0, 0, 1]],
 "of an immersion ff resp. a Riemannian manifold {",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Y", "m"], TraditionalForm]]],
 ", \[Gamma]",
 "\[Gamma]} ",
 " is defined in a natural way:"
}], "Text",
 CellChangeTimes->{{3.5948875759067497`*^9, 3.5948877670538855`*^9}, 
   3.5949654316930485`*^9, 3.59496549099144*^9, {3.5949655491507664`*^9, 
   3.594965571823063*^9}, {3.594965717170377*^9, 3.5949657764947696`*^9}, {
   3.5949658208473063`*^9, 3.5949658766384974`*^9}, {3.5949659519598055`*^9, 
   3.5949659549429765`*^9}, {3.5949659930951586`*^9, 3.594966157918586*^9}, {
   3.5949661988769283`*^9, 3.59496644716713*^9}, {3.594966913414798*^9, 
   3.5949669701430426`*^9}, {3.5949716038810773`*^9, 
   3.5949716559840574`*^9}, {3.594971695811335*^9, 3.594971695811335*^9}, {
   3.5949717640392375`*^9, 3.594971771551667*^9}, {3.594971806319656*^9, 
   3.5949718596817083`*^9}, 3.5949729245216136`*^9, {3.595912681892554*^9, 
   3.5959127142470107`*^9}, {3.6130225413702154`*^9, 
   3.6130226045328283`*^9}, {3.6130226479333105`*^9, 
   3.6130227443038225`*^9}, {3.6130227886943617`*^9, 3.613022899241685*^9}, {
   3.613023003626655*^9, 3.613023014945303*^9}, {3.6170765536963167`*^9, 
   3.617076559561927*^9}, {3.6170773490949135`*^9, 3.617077383617774*^9}, 
   3.6170774835983496`*^9, {3.6170777038083363`*^9, 3.617077761263238*^9}, {
   3.6170784969761295`*^9, 3.617078513543359*^9}, {3.617078545913416*^9, 
   3.6170786173303413`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dVol", "[", "\[Gamma]\[Gamma]_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m", ",", "i", ",", "j"}], "}"}], ",", 
     RowBox[{
      RowBox[{"m", " ", "=", " ", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "##", "}"}], "]"}]}], ";", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Det", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Gamma]\[Gamma]", "[", 
            RowBox[{"i", ",", "j"}], "]"}], "[", "##", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "m"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "m"}], "}"}]}], "]"}], "]"}], "]"}]}]}], "]"}], 
   "&"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5721028398629103`*^9, 3.5721030771549273`*^9}, 
   3.5721031379326334`*^9, {3.586074746853404*^9, 3.5860747605491877`*^9}, {
   3.5860748158453503`*^9, 3.586074825492902*^9}, {3.5861549510774903`*^9, 
   3.586154964603264*^9}, {3.5862629631854534`*^9, 3.586262985017702*^9}, {
   3.5862630295142474`*^9, 3.5862630744648185`*^9}, {3.586604010786734*^9, 
   3.5866040355439777`*^9}, {3.594966564323831*^9, 3.5949665841789665`*^9}, {
   3.5949666975964537`*^9, 3.5949667458112116`*^9}, 3.5949668161242332`*^9, 
   3.594966903781247*^9, {3.595577348814739*^9, 3.5955774292283382`*^9}, {
   3.5955775238277493`*^9, 3.5955775729545593`*^9}, 3.5955776895562286`*^9, {
   3.614861861562743*^9, 3.614861861562743*^9}, 3.614863501936824*^9, 
   3.6149177932621636`*^9, {3.6170779225207205`*^9, 3.6170779402423515`*^9}, {
   3.6170779947644477`*^9, 3.617078006308468*^9}}],

Cell["or for an immersion", "Text",
 CellChangeTimes->{{3.617078649513198*^9, 3.617078658857614*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dV", "[", "ff_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m", ",", "i", ",", "j"}], "}"}], ",", 
     RowBox[{
      RowBox[{"m", " ", "=", " ", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "##", "}"}], "]"}]}], ";", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Det", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"rgT", "[", 
             RowBox[{"i", ",", "j"}], "]"}], "[", "ff", "]"}], "[", "##", 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "m"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "m"}], "}"}]}], "]"}], "]"}], "]"}]}]}], "]"}], 
   "&"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5721028398629103`*^9, 3.5721030771549273`*^9}, 
   3.5721031379326334`*^9, {3.586074746853404*^9, 3.5860747605491877`*^9}, {
   3.5860748158453503`*^9, 3.586074825492902*^9}, {3.5861549510774903`*^9, 
   3.586154964603264*^9}, {3.5862629631854534`*^9, 3.586262985017702*^9}, {
   3.5862630295142474`*^9, 3.5862630744648185`*^9}, {3.586604010786734*^9, 
   3.5866040355439777`*^9}, {3.594966564323831*^9, 3.5949665841789665`*^9}, {
   3.5949666975964537`*^9, 3.5949667458112116`*^9}, 3.5949668161242332`*^9, 
   3.594966903781247*^9, {3.595577348814739*^9, 3.5955774292283382`*^9}, {
   3.5955775238277493`*^9, 3.5955775729545593`*^9}, 3.5955776895562286`*^9, {
   3.614861861562743*^9, 3.614861861562743*^9}, 3.614863501936824*^9, 
   3.6149177932621636`*^9, 3.6186421734671726`*^9, 3.6186423423708334`*^9}],

Cell["Indeed, if \[Gamma]\[Gamma] is induced by an immersion f:", "Text",
 CellChangeTimes->{{3.617078676626045*^9, 3.617078760897393*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]\[Gamma]", "[", 
    RowBox[{"i_", ",", "j_"}], "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{"rgT", "[", 
     RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6170782340688677`*^9, 3.617078330508237*^9}, 
   3.6186421747842474`*^9, 3.618642342374833*^9}],

Cell["then one has", "Text",
 CellChangeTimes->{{3.6170787827530317`*^9, 3.617078809553879*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dVol", "[", "\[Gamma]\[Gamma]", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"dV", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6170783477618675`*^9, 3.617078415216386*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.6170784173223896`*^9, 3.6186429517826896`*^9}]
}, Closed]],

Cell["and this coincides with the area element i case of a surface", "Text",
 CellChangeTimes->{{3.6170788288355126`*^9, 3.617078860394368*^9}, 
   3.617079026144659*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dV", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", " ", 
   RowBox[{
    RowBox[{"dA", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6170789222952766`*^9, 3.6170789370061026`*^9}, {
  3.617078990623397*^9, 3.6170790012158155`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.617078965725753*^9, 3.6170790024326177`*^9, 
  3.618642960985216*^9}]
}, Closed]],

Cell["\<\
Since the first fundamental form is positive definite the determinant in this \
definition is always positive.\
\>", "Text",
 CellChangeTimes->{{3.5949670370548697`*^9, 3.5949670884468093`*^9}}],

Cell[BoxData[
 RowBox[{"Clear", "[", "\[Gamma]\[Gamma]", "]"}]], "Input",
 CellChangeTimes->{{3.617079143394465*^9, 3.617079156467288*^9}}],

Cell[TextData[{
 StyleBox["Example. ",
  FontColor->RGBColor[0, 0, 1]],
 "The volume of a 3-sphere in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "4"], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.5949671433639503`*^9, 3.594967173390668*^9}, {
  3.5949684739990582`*^9, 3.5949685574148293`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "unit"}]], "Input",
 CellChangeTimes->{{3.5949685635881824`*^9, 3.594968565453289*^9}}],

Cell[BoxData[
 StyleBox["\<\"unit[n][s_List] generates a parameter representation of the \
unit \\nn-sphere with centre o in the euclidean (n+1)-space. The parameters \
are\\nthe first n elements of the list s, which must have length at least n. \
The\\nparameter ranges  0 <s[[1]]<=2Pi, -Pi/2 <= s[[j]] <= Pi/2 give the \
whole\\nn-sphere. unit[s_List] = unit[Length[s]][s_list]; unit[u,v] = \
unit[{u,v}]. \"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6170767324258304`*^9},
 CellTags->"Info3617083932-1439888"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"unit", "[", "3", "]"}], "[", 
  RowBox[{"{", 
   RowBox[{"u", ",", "v", ",", "w"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.5949674880876675`*^9, 3.5949675122890515`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", "u", "]"}], " ", 
    RowBox[{"Cos", "[", "v", "]"}], " ", 
    RowBox[{"Cos", "[", "w", "]"}]}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", "v", "]"}], " ", 
    RowBox[{"Cos", "[", "w", "]"}], " ", 
    RowBox[{"Sin", "[", "u", "]"}]}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", "w", "]"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"Sin", "[", "w", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.594967514813196*^9, 3.595578363803793*^9, 
  3.6170767876343274`*^9, 3.6186448743776517`*^9}]
}, Closed]],

Cell[TextData[{
 "The hypersphere of radius r in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "4"], TraditionalForm]]],
 " has the parameter representation"
}], "Text",
 CellChangeTimes->{{3.5949719474467278`*^9, 3.594972008231205*^9}, {
   3.5950507705444202`*^9, 3.5950507770028315`*^9}, 3.617441114508457*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"smh", "[", 
   RowBox[{"u_", ",", "v_", ",", "w_"}], "]"}], " ", "=", " ", 
  RowBox[{"r", "*", 
   RowBox[{
    RowBox[{"unit", "[", "3", "]"}], "[", 
    RowBox[{"{", 
     RowBox[{"u", ",", "v", ",", "w"}], "}"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5949675673111987`*^9, 3.594967639842347*^9}, {
  3.5955784262413645`*^9, 3.59557843927311*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "u", "]"}], " ", 
    RowBox[{"Cos", "[", "v", "]"}], " ", 
    RowBox[{"Cos", "[", "w", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "v", "]"}], " ", 
    RowBox[{"Cos", "[", "w", "]"}], " ", 
    RowBox[{"Sin", "[", "u", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "w", "]"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", "w", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5949676436935673`*^9, 3.5950508919750333`*^9, 
  3.5955783764705176`*^9, 3.595578441987265*^9, 3.6130220185893145`*^9, 
  3.617076816026377*^9, 3.6186448814160547`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Det", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "[", "smh", "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "3"}], "}"}]}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.594967668807004*^9, 3.5949677562520056`*^9}, 
   3.5955784605383263`*^9, 3.6148618615783434`*^9, 3.614863501952424*^9, 
   3.618642175840308*^9, 3.618642342378834*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["r", "6"], " ", 
  SuperscriptBox[
   RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
  SuperscriptBox[
   RowBox[{"Cos", "[", "w", "]"}], "4"]}]], "Output",
 CellChangeTimes->{3.594967757286064*^9, 3.5955784744201202`*^9, 
  3.6130220303909893`*^9, 3.6170768217983875`*^9, 3.618644893300734*^9}]
}, Closed]],

Cell[TextData[{
 "Indeed, all the upper - left submatrices have positive determinants, see ",
 ButtonBox["Math World",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/PositiveDefiniteMatrix.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/PositiveDefiniteMatrix.html"],
 "."
}], "Text",
 CellChangeTimes->{{3.5949682501832566`*^9, 3.594968307255521*^9}, 
   3.5949683821998076`*^9, {3.5949684253162737`*^9, 3.594968425324274*^9}, 
   3.6174411573479075`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Det", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "[", "smh", "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1"}], "}"}]}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5948873343559256`*^9, 3.5948874290636916`*^9}, 
   3.5949677892268915`*^9, {3.594967824028882*^9, 3.5949678300432262`*^9}, 
   3.5955785446821384`*^9, 3.614861861593943*^9, 3.6148635019680243`*^9, 
   3.6186421768573666`*^9, 3.6186423423828335`*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["r", "2"], " ", 
  SuperscriptBox[
   RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
  SuperscriptBox[
   RowBox[{"Cos", "[", "w", "]"}], "2"]}]], "Output",
 CellChangeTimes->{3.5948874308576946`*^9, 3.594967793850156*^9, 
  3.5949678324873657`*^9, 3.5955785761729403`*^9, 3.6130220739644814`*^9, 
  3.618644907162527*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Det", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "[", "smh", "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5948873343559256`*^9, 3.5948874290636916`*^9}, {
   3.5948874685785613`*^9, 3.5948875091386323`*^9}, 3.5949678425159397`*^9, 
   3.59557854662525*^9, 3.614861861609543*^9, 3.6148635019836245`*^9, 
   3.6186421777854195`*^9, 3.618642342387834*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["r", "4"], " ", 
  SuperscriptBox[
   RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
  SuperscriptBox[
   RowBox[{"Cos", "[", "w", "]"}], "4"]}]], "Output",
 CellChangeTimes->{3.5948874780789776`*^9, 3.5948875105270348`*^9, 
  3.5949678545736294`*^9, 3.595578601486388*^9, 3.613022084695095*^9, 
  3.618644911285763*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dV", "[", "smh", "]"}], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
   RowBox[{"r", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5950508613521795`*^9, 3.5950508830986176`*^9}, {
   3.5950509142830725`*^9, 3.5950509198678827`*^9}, 3.5955785474242954`*^9}],

Cell[BoxData[
 SqrtBox[
  RowBox[{
   SuperscriptBox["r", "6"], " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", "w", "]"}], "4"]}]]], "Output",
 CellChangeTimes->{{3.595050904439455*^9, 3.5950509222546864`*^9}, 
   3.595578612348009*^9, 3.613022095576718*^9, 3.6186449176881285`*^9}]
}, Closed]],

Cell["The volume of the 3-sphere is obtained by an Integration:", "Text",
 CellChangeTimes->{{3.595051020410059*^9, 3.595051070501747*^9}, {
  3.6170769795926647`*^9, 3.6170769810434675`*^9}}],

Cell[BoxData[
 RowBox[{"?", "Integrate"}]], "Input",
 CellChangeTimes->{{3.5949685955800123`*^9, 3.5949686029754353`*^9}, 
   3.594970020744527*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"r", ">", "0"}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", 
     RowBox[{"2", "*", "Pi"}]], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "2"}], 
      RowBox[{"Pi", "/", "2"}]], 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{
        RowBox[{"-", "Pi"}], "/", "2"}], 
       RowBox[{"Pi", "/", "2"}]], 
      RowBox[{
       RowBox[{
        RowBox[{"dV", "[", "smh", "]"}], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}], 
       RowBox[{"\[DifferentialD]", "u"}], 
       RowBox[{"\[DifferentialD]", "v"}], 
       RowBox[{"\[DifferentialD]", "w"}]}]}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5949688159786186`*^9, 3.5949688817713814`*^9}, {
   3.5949689981080356`*^9, 3.5949690241395245`*^9}, {3.594969101804967*^9, 
   3.594969106379228*^9}, {3.5949691409732065`*^9, 3.594969173772083*^9}, 
   3.595578548961384*^9, {3.6130230655571976`*^9, 3.613023096004939*^9}}],

Cell[BoxData[
 RowBox[{"2", " ", 
  SuperscriptBox["\[Pi]", "2"], " ", 
  SuperscriptBox["r", "3"]}]], "Output",
 CellChangeTimes->{3.594969176884261*^9, 3.5950509535015416`*^9, 
  3.595578626896841*^9, 3.613022128527602*^9, 3.6130230985290833`*^9, 
  3.6170768953525167`*^9, 3.61864492749969*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2. Absolute  Differential of Tangent Vector Fields", "Subsection",
 CellChangeTimes->{{3.5949730418953266`*^9, 3.5949731082711234`*^9}, {
   3.595077070522224*^9, 3.5950771362139397`*^9}, 3.613023169371135*^9, 
   3.6130232430183477`*^9, 3.6132201257627344`*^9, {3.6186449363901987`*^9, 
   3.6186449391503563`*^9}, 3.618719499291278*^9}],

Cell["\<\
We consider a general immersion smf[f[u...] into the n-dimensional Euclidean \
space, n = dim, e.g.\
\>", "Text",
 CellChangeTimes->{{3.595077178240413*^9, 3.595077208239266*^9}, {
   3.5951342404834337`*^9, 3.595134291859373*^9}, {3.595134540339585*^9, 
   3.595134634923995*^9}, {3.5953172126101613`*^9, 3.5953174521128597`*^9}, 
   3.596550784997245*^9, {3.596550826181317*^9, 3.596550833123329*^9}, {
   3.6128504259769535`*^9, 3.6128504380646443`*^9}, 3.6130232789364023`*^9, {
   3.6205365554152803`*^9, 3.620536569598091*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "smf"}]], "Input",
 CellChangeTimes->{{3.6128502638746815`*^9, 3.612850266340822*^9}}],

Cell[CellGroupData[{

Cell["Global`smf", "Print", "PrintUsage",
 CellChangeTimes->{3.620536593403453*^9},
 CellTags->"Info3620543793-1087837"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {GridBox[{
       {
        RowBox[{
         RowBox[{"smf", "[", "f_", "]"}], ":=", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"f", "[", "i", "]"}], "[", "##1", "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "dim"}], "}"}]}], "]"}], "&"}]}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[$CellContext`smf],
  Editable->False]], "Print",
 CellChangeTimes->{3.6205365934124537`*^9},
 CellTags->"Info3620543793-1087837"]
}, Open  ]]
}, Open  ]],

Cell[TextData[StyleBox["Example.",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.613023386200537*^9, 3.6130233920648727`*^9}, {
  3.6205367297662525`*^9, 3.6205367311263304`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dim", " ", "=", " ", "4"}]], "Input",
 CellChangeTimes->{{3.612850385798655*^9, 3.6128503914899807`*^9}, 
   3.617087255984108*^9}],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{3.6128503985793858`*^9, 3.617087219945047*^9, 
  3.617087260056341*^9, 3.6187188908902087`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"smf", "[", "f", "]"}], "[", 
  RowBox[{"u", ",", "v", ",", "w"}], "]"}]], "Input",
 CellChangeTimes->{{3.612850301110811*^9, 3.612850367250594*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "1", "]"}], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "2", "]"}], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "3", "]"}], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "4", "]"}], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.61285032242003*^9, 3.612850368197648*^9}, 
   3.6128504062998276`*^9, 3.617087219984049*^9, 3.6170872639715652`*^9, {
   3.6187188856642*^9, 3.6187188946186156`*^9}}]
}, Closed]],

Cell["\<\
We fix the necessary assumptions and notations:  The immersion is \
smf[f][x[1],...,x[m]].\
\>", "Text",
 CellChangeTimes->{{3.595317712857774*^9, 3.595317728777684*^9}, {
  3.5953178514006977`*^9, 3.595317878616255*^9}, {3.5953179185605392`*^9, 
  3.595317922904788*^9}, {3.595318255584816*^9, 3.5953182694406085`*^9}, {
  3.5953234026079183`*^9, 3.5953234510956917`*^9}, {3.6130233386968203`*^9, 
  3.61302335163256*^9}, {3.62053664247826*^9, 3.620536666990662*^9}}],

Cell["\<\
The dimension of the parameter manifold is  mf = Length[{x}]. For the \
symbolic calculation we fix\
\>", "Text",
 CellChangeTimes->{{3.5953183285019865`*^9, 3.5953183859602733`*^9}, {
   3.5953185961762967`*^9, 3.5953186704725466`*^9}, {3.595319175793449*^9, 
   3.5953191760804653`*^9}, 3.595323351848015*^9, 3.5955692179186783`*^9, 
   3.612855570867403*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"dim", ",", "f"}], "]"}], ";", 
  RowBox[{"dim", "  ", "=", " ", "4"}], ";", 
  RowBox[{"mf", " ", "=", "2"}], ";", 
  RowBox[{
   RowBox[{"smf", "[", "f", "]"}], "[", 
   RowBox[{
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5953179973180437`*^9, 3.595318037226327*^9}, {
   3.595318077618637*^9, 3.5953182349966383`*^9}, {3.5953190274689655`*^9, 
   3.5953190679322796`*^9}, {3.5953233167050047`*^9, 3.595323324640459*^9}, 
   3.595918668773734*^9, {3.5959188539148593`*^9, 3.59591887143369*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "1", "]"}], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "2", "]"}], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "3", "]"}], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "4", "]"}], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.595918873508494*^9, 3.596089513613138*^9, 
  3.6128516891492023`*^9, 3.6131268039607573`*^9, 3.6170872868648744`*^9, 
  3.618718926754672*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2.1. The Total Differential of a Tangent Vector Field", \
"Subsubsection",
 CellChangeTimes->{{3.595076945363204*^9, 3.5950769905720835`*^9}, 
   3.5953174793534184`*^9, {3.5953175263051033`*^9, 3.595317587064579*^9}, {
   3.595600920663969*^9, 3.5956009641674576`*^9}, {3.59560157753554*^9, 
   3.595601600231838*^9}, 3.613023249569722*^9, 3.613127844538868*^9}],

Cell["We  consider the tangent vector field", "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.5953235604669476`*^9, 3.595323569649472*^9}, {
   3.5953236189212904`*^9, 3.5953236679780965`*^9}, 3.595323711259572*^9, {
   3.5953239422667847`*^9, 3.5953239750656605`*^9}, {3.5955788337836742`*^9, 
   3.5955788569419994`*^9}, 3.613023988817005*^9}],

Cell[BoxData[
 RowBox[{"vx", ":=", " ", 
  RowBox[{
   RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", 
   RowBox[{"smf", "[", "f", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5958287448867464`*^9, 3.595828758252511*^9}, {
  3.595828837669053*^9, 3.5958288760612493`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vx", "[", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], ",", 
   RowBox[{"x", "[", "2", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5953239886694393`*^9, 3.595324018282133*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "4", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "4", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.595324020426255*^9, 3.5955710277781963`*^9, 3.5955787780084844`*^9, 
   3.5955831508485966`*^9, {3.5958289300543375`*^9, 3.595828949490449*^9}, 
   3.5959189368290052`*^9, 3.5960895136911383`*^9, 3.5964624452465754`*^9, 
   3.6128517055761423`*^9, 3.612855911078862*^9, {3.61312675438387*^9, 
   3.613126770763899*^9}, 3.6131268228055906`*^9, 3.617091810844631*^9, 
   3.61871898824998*^9}]
}, Closed]],

Cell["\<\
The differentials of the coordinates form a field of cobasis vectors:\
\>", "Text",
 CellChangeTimes->{{3.595324078111555*^9, 3.5953241174318037`*^9}, {
  3.595578890141898*^9, 3.5955789016865587`*^9}, {3.5955790255986457`*^9, 
  3.595579027053729*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dx", "[", "i_Integer", "]"}], "[", "v_List", "]"}], " ", ":=", 
  " ", 
  RowBox[{"v", "[", 
   RowBox[{"[", "i", "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5951346562192125`*^9, 3.595134747870455*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dx", "[", "1", "]"}], "[", 
  RowBox[{"vec", "[", "u", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5951347602771645`*^9, 3.5951347844375467`*^9}, 
   3.5953240580574074`*^9}],

Cell[BoxData[
 RowBox[{"u", "[", "1", "]"}]], "Output",
 CellChangeTimes->{3.5951347869356894`*^9, 3.59557895190143*^9, 
  3.5959189666562576`*^9, 3.5960232209396095`*^9, 3.612851788816903*^9, 
  3.6131268667040677`*^9, 3.617091899234687*^9, 3.6187190442384787`*^9}]
}, Closed]],

Cell[TextData[{
 "The  ",
 StyleBox["total differential",
  FontColor->RGBColor[0, 0, 1]],
 " of the vector field vx is not tangential since it contains derivatives of \
second order of the immersion smf[f]:"
}], "Text",
 CellChangeTimes->{{3.5955793572066126`*^9, 3.5955793920946083`*^9}, {
   3.595579591878035*^9, 3.595579659893925*^9}, {3.595918977841477*^9, 
   3.595919013191139*^9}, {3.6131269223805656`*^9, 3.6131269457806063`*^9}, 
   3.61744117906815*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "vx", "]"}], "[", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], ",", 
   RowBox[{"x", "[", "2", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.595324180746425*^9, 3.5953242505304165`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.595324252423525*^9, 3.595583162165244*^9, 
  3.5959190243451586`*^9, 3.596089836377705*^9, 3.5964426811079793`*^9, 
  3.6128518246659536`*^9, 3.613126886672103*^9, 3.617091921699972*^9, 
  3.6187190621317096`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.596089846720524*^9, 3.5960898684981613`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", "2"}], "}"}]], "Output",
 CellChangeTimes->{3.596089870026964*^9, 3.596442686692789*^9, 
  3.6128518395188026`*^9, 3.617091943665228*^9, 3.6187190701345234`*^9}]
}, Closed]],

Cell[TextData[{
 "The",
 StyleBox[" total differential ",
  FontColor->RGBColor[0, 0, 1]],
 "of the tangent vector field vx is"
}], "Text",
 CellChangeTimes->{{3.612856097673535*^9, 3.6128561379208364`*^9}, {
  3.6128563706971507`*^9, 3.612856373881333*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "vx", "]"}], "[", 
   RowBox[{
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}]}], "]"}], "==", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"vx", "[", 
     RowBox[{
      RowBox[{"x", "[", "1", "]"}], ",", 
      RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "}"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.595324180746425*^9, 3.5953242505304165`*^9}, {
  3.595324337972418*^9, 3.5953243435797386`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5953243460338793`*^9, 3.5955796812781487`*^9, 
  3.5955831837594786`*^9, 3.5958290059356775`*^9, 3.595919057308017*^9, 
  3.612851856981802*^9, 3.617091957671029*^9, 3.6187190940181656`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"vx", ",", 
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}]}], "]"}], "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"dx", "[", "1", "]"}], ",", 
    RowBox[{"dx", "[", "2", "]"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.595324180746425*^9, 3.5953242505304165`*^9}, {
  3.595324337972418*^9, 3.5953243435797386`*^9}, {3.595579779459764*^9, 
  3.595579848568717*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"dx", "[", "2", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"dx", "[", "1", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"dx", "[", "2", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"dx", "[", "1", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"dx", "[", "2", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"dx", "[", "1", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"dx", "[", "2", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"dx", "[", "1", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.595579850417823*^9, 3.595583192641987*^9, 
  3.5958290150221977`*^9, 3.5959192570975676`*^9, 3.612851864235217*^9, 
  3.617092007934904*^9, 3.6187191155306034`*^9}]
}, Closed]],

Cell["This coincides with", "Text",
 CellChangeTimes->{{3.5959193430693183`*^9, 3.5959193578893447`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "vx", "]"}], "[", 
   RowBox[{
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}]}], "]"}], ".", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"dx", "[", "1", "]"}], ",", 
    RowBox[{"dx", "[", "2", "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.595324180746425*^9, 3.5953242505304165`*^9}, {
  3.595324337972418*^9, 3.5953243435797386`*^9}, {3.595579779459764*^9, 
  3.595579848568717*^9}, {3.595919143201768*^9, 3.59591915610299*^9}, {
  3.595919197489863*^9, 3.5959192019358706`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"dx", "[", "2", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"dx", "[", "1", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"dx", "[", "2", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"dx", "[", "1", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"dx", "[", "2", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"dx", "[", "1", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"dx", "[", "2", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"dx", "[", "1", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.59591920719308*^9, 3.5959192620583763`*^9, 
  3.6128519529832926`*^9, 3.6170920142672663`*^9, 3.6187191392582455`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "==", "%%"}]], "Input",
 CellChangeTimes->{{3.595919220655904*^9, 3.595919232387124*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5959192335727262`*^9, 3.595919266863185*^9, 
  3.612851959160646*^9, 3.6170920198235846`*^9, 3.6187191443282537`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", "%%", "]"}]], "Input",
 CellChangeTimes->{{3.595579998667302*^9, 3.5955800060637255`*^9}, 
   3.5959192788128057`*^9}],

Cell[BoxData[
 RowBox[{"{", "4", "}"}]], "Output",
 CellChangeTimes->{3.5958290368444457`*^9, 3.595919280076408*^9, 
  3.612851963140874*^9, 3.6170920229857655`*^9, 3.618719148181461*^9}]
}, Closed]],

Cell[TextData[{
 "This is a vector in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "4"], TraditionalForm]]],
 " depending on the point smf[f][x[1],x[2]] of the immersion and on the \
tangent vector of the immersion defined by {dx[1],dx[2]} at this point"
}], "Text",
 CellChangeTimes->{{3.5955801071185055`*^9, 3.5955803651262627`*^9}, {
  3.613127181434941*^9, 3.6131271871302667`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{
    RowBox[{"smf", "[", "f", "]"}], ",", 
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}]}], "]"}], "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"dx", "[", "1", "]"}], ",", 
    RowBox[{"dx", "[", "2", "]"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.5955803793400755`*^9, 3.595580438282447*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"dx", "[", "2", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"dx", "[", "1", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"dx", "[", "2", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"dx", "[", "1", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"dx", "[", "2", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"dx", "[", "1", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"dx", "[", "2", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "4", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"dx", "[", "1", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "4", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5955804402785606`*^9, 3.595583207174818*^9, 
  3.6128519846411037`*^9, 3.613127207157412*^9, 3.617092052495453*^9, 
  3.6187192057299623`*^9}]
}, Closed]],

Cell[TextData[{
 "Applying the differentiation rules we obtain the formal ",
 StyleBox["formula",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.5955984005678277`*^9, 3.595598438158978*^9}},
 CellTags->"dtt(1)"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", "1", ")"}], "   ", 
   RowBox[{"d", "[", "vx", "]"}]}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", "1", "mf"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"d", "[", 
       RowBox[{
        RowBox[{"tt", "[", "i", "]"}], "[", 
        RowBox[{"smf", "[", "f", "]"}], "]"}], "]"}], ")"}], "*", 
     RowBox[{"\[Xi]", "[", "i", "]"}]}]}], " ", "+", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"tt", "[", "i", "]"}], "[", 
     RowBox[{"smf", "[", "f", "]"}], "]"}], "*", 
    RowBox[{"d", "[", 
     RowBox[{"\[Xi]", "[", "i", "]"}], "]"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.595598463490427*^9, 3.5955984931051207`*^9}, {
   3.5955985511484404`*^9, 3.595598594362912*^9}, {3.5955986327071056`*^9, 
   3.5955986452108207`*^9}, {3.595598683170992*^9, 3.595598691723481*^9}, {
   3.595598737060074*^9, 3.595598913628173*^9}, 3.595599919420701*^9, 
   3.5956003320353017`*^9, {3.595920206461307*^9, 3.595920210028511*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"vv", "[", "s", "]"}], "[", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], ",", 
   RowBox[{"x", "[", "2", "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"s", "[", "1", "]"}], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"s", "[", "2", "]"}], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6128521171636834`*^9, 3.613127297790596*^9, 
  3.6170921086966677`*^9, 3.6187192883165073`*^9}]
}, Closed]],

Cell["\<\
The left side of this equation evaluated for the tangent vector vv[s] is\
\>", "Text",
 CellChangeTimes->{{3.59559905624033*^9, 3.595599109839396*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "vx", "]"}], "[", 
   RowBox[{
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}]}], "]"}], ".", 
  RowBox[{
   RowBox[{"vv", "[", "s", "]"}], "[", 
   RowBox[{
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5955923058844066`*^9, 3.595592346404724*^9}, {
  3.595597506634698*^9, 3.5955975114579735`*^9}, {3.595597557706619*^9, 
  3.595597587746337*^9}, {3.5955977418511515`*^9, 3.595597757699058*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"s", "[", "2", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"s", "[", "1", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"s", "[", "2", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"s", "[", "1", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"s", "[", "2", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"s", "[", "1", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"s", "[", "2", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"s", "[", "1", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5955977770131626`*^9, 3.5955998750821652`*^9, 
  3.6128520485197573`*^9, 3.613127361374233*^9, 3.617092125921653*^9, 
  3.6187193003441277`*^9}]
}, Closed]],

Cell["The sum of the first terms at the right side equals", "Text",
 CellChangeTimes->{{3.595599813111621*^9, 3.595599843183341*^9}, 
   3.5959198499349146`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Sum", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{
         RowBox[{"tt", "[", "i", "]"}], "[", 
         RowBox[{"smf", "[", "f", "]"}], "]"}], "]"}], "[", 
       RowBox[{
        RowBox[{"x", "[", "1", "]"}], ",", 
        RowBox[{"x", "[", "2", "]"}]}], "]"}], ".", 
      RowBox[{
       RowBox[{"vv", "[", "s", "]"}], "[", 
       RowBox[{
        RowBox[{"x", "[", "1", "]"}], ",", 
        RowBox[{"x", "[", "2", "]"}]}], "]"}]}], ")"}], "*", 
    RowBox[{
     RowBox[{"\[Xi]", "[", "i", "]"}], "[", 
     RowBox[{
      RowBox[{"x", "[", "1", "]"}], ",", 
      RowBox[{"x", "[", "2", "]"}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "mf"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5956025399965897`*^9, 3.595602620998223*^9}, 
   3.595602703351933*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5956021973919935`*^9, 3.595602729891451*^9, 
  3.5956028106270685`*^9, 3.6128521755390224`*^9, 3.6170921374953146`*^9, 
  3.618719322511767*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.5956022073735647`*^9, 3.5956022187932177`*^9}}],

Cell[BoxData[
 RowBox[{"{", "4", "}"}]], "Output",
 CellChangeTimes->{3.595602220294304*^9, 3.5956028167174172`*^9, 
  3.6128521824464173`*^9, 3.6170921556093507`*^9, 3.618719387298681*^9}]
}, Closed]],

Cell["The second terms at the right side add up to", "Text",
 CellChangeTimes->{{3.5955999483073535`*^9, 3.595599979224122*^9}, {
   3.5956002120964413`*^9, 3.5956002139675484`*^9}, 3.5959199142395926`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Sum", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tt", "[", "i", "]"}], "[", 
      RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
     RowBox[{
      RowBox[{"x", "[", "1", "]"}], ",", 
      RowBox[{"x", "[", "2", "]"}]}], "]"}], "*", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"\[Xi]", "[", "i", "]"}], "]"}], "[", 
       RowBox[{
        RowBox[{"x", "[", "1", "]"}], ",", 
        RowBox[{"x", "[", "2", "]"}]}], "]"}], ")"}], ".", 
     RowBox[{
      RowBox[{"vv", "[", "s", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "mf"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5956002571300173`*^9, 3.5956002597231655`*^9}, {
  3.5956003018525753`*^9, 3.595600311251113*^9}, {3.5956003819321556`*^9, 
  3.5956005168058696`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "4", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "4", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "2", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"s", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.5956005026070576`*^9, 3.5956005177839255`*^9}, 
   3.6128522108950443`*^9, 3.613127594518568*^9, 3.617092163006774*^9, 
   3.6187193982031*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.5956005282575245`*^9, 3.595600535904962*^9}}],

Cell[BoxData[
 RowBox[{"{", "4", "}"}]], "Output",
 CellChangeTimes->{3.595600536406991*^9, 3.61285221814946*^9, 
  3.6170921809217987`*^9, 3.618719408280718*^9}]
}, Closed]],

Cell[TextData[{
 "We check\n",
 StyleBox["Lemma",
  FontColor->RGBColor[0, 0, 1]],
 ". The total differential of a tangent vector field vx satisfies formula (1) \
above, for example"
}], "Text",
 CellChangeTimes->{{3.595600549015712*^9, 3.5956005533359594`*^9}, {
  3.5959200264320097`*^9, 3.5959200392477427`*^9}, {3.595920071487587*^9, 
  3.5959201138950124`*^9}, {3.5959202427443824`*^9, 3.5959202716950383`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "vx", "]"}], "[", 
     RowBox[{
      RowBox[{"x", "[", "1", "]"}], ",", 
      RowBox[{"x", "[", "2", "]"}]}], "]"}], ".", 
    RowBox[{
     RowBox[{"vv", "[", "s", "]"}], "[", 
     RowBox[{
      RowBox[{"x", "[", "1", "]"}], ",", 
      RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "\[Equal]", "  ", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{
            RowBox[{"tt", "[", "i", "]"}], "[", 
            RowBox[{"smf", "[", "f", "]"}], "]"}], "]"}], "[", 
          RowBox[{
           RowBox[{"x", "[", "1", "]"}], ",", 
           RowBox[{"x", "[", "2", "]"}]}], "]"}], ".", 
         RowBox[{
          RowBox[{"vv", "[", "s", "]"}], "[", 
          RowBox[{
           RowBox[{"x", "[", "1", "]"}], ",", 
           RowBox[{"x", "[", "2", "]"}]}], "]"}]}], ")"}], "*", 
       RowBox[{
        RowBox[{"\[Xi]", "[", "i", "]"}], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "mf"}], "}"}]}], "]"}], "+", " ", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"tt", "[", "i", "]"}], "[", 
         RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"\[Xi]", "[", "i", "]"}], "]"}], "[", 
          RowBox[{
           RowBox[{"x", "[", "1", "]"}], ",", 
           RowBox[{"x", "[", "2", "]"}]}], "]"}], ")"}], ".", 
        RowBox[{
         RowBox[{"vv", "[", "s", "]"}], "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "mf"}], "}"}]}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.595600564172579*^9, 3.5956005686658363`*^9}, {
   3.5956006043608775`*^9, 3.595600618411681*^9}, {3.595600654358737*^9, 
   3.5956006852045016`*^9}, 3.5956028655232086`*^9, 3.5956028962919683`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.595600686783592*^9, 3.59560290085923*^9, 
  3.595659384954177*^9, 3.5956595889168425`*^9, 3.595659681564142*^9, 
  3.5956597685411167`*^9, 3.595670883601818*^9, 3.6131276321287193`*^9, 
  3.6170921928464804`*^9, 3.6187194459391837`*^9}]
}, Closed]],

Cell["\<\
 In this formula the second derivatives of the immersion  are hidden, e,g,\
\>", "Text",
 CellChangeTimes->{{3.596090908988789*^9, 3.596090974852105*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{
     RowBox[{"tt", "[", "1", "]"}], "[", 
     RowBox[{"smf", "[", "f", "]"}], "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v", ",", "w"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5960904708776197`*^9, 3.5960905722621975`*^9}, {
  3.596090780007763*^9, 3.5960908043126054`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "4", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "4", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "4", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5960905731981993`*^9, 3.5960908129862204`*^9, 
  3.6128522497302656`*^9, 3.6131277633572245`*^9, 3.6170922305056343`*^9, 
  3.618719465486018*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2.2. The Absolute Differential of a Tangent Vector Field", \
"Subsubsection",
 CellChangeTimes->{{3.595076945363204*^9, 3.5950769905720835`*^9}, 
   3.5953174793534184`*^9, {3.5953175263051033`*^9, 3.595317587064579*^9}, 
   3.5956008724322104`*^9, {3.5965213907316623`*^9, 3.5965214041788855`*^9}, 
   3.613127853739394*^9, 3.6132229815716324`*^9, 3.618719633997514*^9, 
   3.6187568869796286`*^9}],

Cell[TextData[{
 "For immersions the absolute differential will be defined as the orthogonal \
projection of the total differential of the vector field into the tangent \
space of the immersion at each point. First we describe this projection \
algebraically. Let ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["T", "x", "m"], TraditionalForm]]],
 " \[Subset] ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["E", "n"], " "}], TraditionalForm]]],
 "be an m.dimensional subspace of the Euclidean n-space, and {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "i"], TraditionalForm]]],
 "},  i = 1,...,m, an arbitrary basis of  ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["T", "x", "m"], TraditionalForm]]],
 " with scalar products"
}], "Text",
 CellChangeTimes->{{3.5956512820004816`*^9, 3.5956514597471943`*^9}, {
  3.59565153142932*^9, 3.595651640785512*^9}, {3.5956516917040014`*^9, 
  3.595651910665986*^9}, {3.5956520363086066`*^9, 3.595652063702255*^9}, {
  3.5956521682536383`*^9, 3.5956522065673056`*^9}, {3.5959237048705378`*^9, 
  3.595923706157612*^9}, {3.596521616120858*^9, 3.5965216273216777`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["mf"], "Input",
 CellChangeTimes->{{3.618738922430699*^9, 3.6187389258939047`*^9}}],

Cell[BoxData["2"], "Output",
 CellChangeTimes->{3.6187389298407116`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  SubscriptBox["g", "ij"], ":=", " ", 
  RowBox[{
   FormBox[
    SubscriptBox["b", "i"],
    TraditionalForm], ".", 
   FormBox[
    SubscriptBox["b", "j"],
    TraditionalForm]}]}]], "Input",
 CellChangeTimes->{{3.5956521183335505`*^9, 3.595652155602016*^9}, {
  3.595652235962557*^9, 3.595652270813018*^9}, {3.5956523113418894`*^9, 
  3.595652327425517*^9}}],

Cell[TextData[{
 "Since the matrix {",
 Cell[BoxData[
  SubscriptBox["g", "ij"]],
  CellChangeTimes->{{3.5956521183335505`*^9, 3.595652155602016*^9}, {
   3.595652235962557*^9, 3.595652270813018*^9}, {3.5956523113418894`*^9, 
   3.595652327425517*^9}}],
 "} is symmetric and positive definite it has positive determinant: "
}], "Text",
 CellChangeTimes->{{3.5956523740071993`*^9, 3.5956524288724957`*^9}, 
   3.595652518980466*^9, {3.5956526437956047`*^9, 3.595652659380496*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Det", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     SubscriptBox["g", "ij"], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "mf"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"j", ",", "mf"}], "}"}]}], "]"}], "]"}], ">", "0"}]], "Input",
 CellChangeTimes->{{3.5956525363104568`*^9, 3.5956526283587217`*^9}, 
   3.614861861687543*^9, 3.6148635019836245`*^9, {3.6187389427887344`*^9, 
   3.6187389469851418`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      SubscriptBox["b", "1"], ".", 
      SubscriptBox["b", "2"]}]}], " ", 
    RowBox[{
     SubscriptBox["b", "2"], ".", 
     SubscriptBox["b", "1"]}]}], "+", 
   RowBox[{
    RowBox[{
     SubscriptBox["b", "1"], ".", 
     SubscriptBox["b", "1"]}], " ", 
    RowBox[{
     SubscriptBox["b", "2"], ".", 
     SubscriptBox["b", "2"]}]}]}], ">", "0"}]], "Output",
 CellChangeTimes->{3.6187388987030573`*^9, 3.618738988372014*^9}]
}, Closed]],

Cell[TextData[{
 "Let vy = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "T"], TraditionalForm]]],
 "[vw]  \[Element] ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["T", "x", "m"], TraditionalForm]]],
 " be the orthogonal projection  of the vector  vw \[Element] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "n"], TraditionalForm]]],
 ". Then the vector \nvy - vw is orthogonal to ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["T", "x", "m"], TraditionalForm]]],
 " :"
}], "Text",
 CellChangeTimes->{{3.595653006355342*^9, 3.595653056932235*^9}, {
   3.5956530998836913`*^9, 3.595653233396328*^9}, 3.595653599732281*^9, {
   3.5956536758766365`*^9, 3.5956537832277765`*^9}, {3.595830077103945*^9, 
   3.5958300802491245`*^9}, 3.597207643518685*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"vy", "-", "vw"}], ")"}], ".", 
    SubscriptBox["b", "i"]}], " ", "\[Equal]", " ", "0"}], ",", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"or", "  ", 
     RowBox[{"vy", ".", 
      SubscriptBox["b", "i"]}]}], " ", "\[Equal]", " ", 
    RowBox[{
     RowBox[{"vw", ".", 
      SubscriptBox["b", "i"]}], "  ", "for", " ", "i"}]}], " ", "=", " ", 
   "1"}], ",", "  ", "...", ",", " ", 
  RowBox[{"mf", "."}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.595653794627428*^9, 3.5956538074371614`*^9}, {
   3.595653843238209*^9, 3.595653924069832*^9}, {3.5958300813321867`*^9, 
   3.5958300830922875`*^9}, 3.6187390440329123`*^9}],

Cell["Let the basis decomposition of vy be", "Text",
 CellChangeTimes->{{3.595654502819935*^9, 3.595654532756647*^9}}],

Cell[BoxData[
 RowBox[{"vy", " ", ":=", " ", 
  RowBox[{
   SubsuperscriptBox["\[Sum]", "1", "mf"], " ", 
   RowBox[{
    SubscriptBox["b", "i"], " ", 
    SubscriptBox["\[Eta]", "i"]}]}]}]], "Input",
 CellChangeTimes->{{3.5956545443553104`*^9, 3.595654548765563*^9}, {
  3.595654614775338*^9, 3.595654647116188*^9}, {3.5956547153400903`*^9, 
  3.595654823176258*^9}, {3.618739087650589*^9, 3.618739097431806*^9}, {
  3.618739128663061*^9, 3.618739144497089*^9}}],

Cell["Then vy is defined by the linear system", "Text",
 CellChangeTimes->{{3.5956548684278464`*^9, 3.595654892356215*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"vy", ".", 
   SubscriptBox["b", "j"]}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["\[CapitalSigma]", "1", "m"], " ", 
     SubscriptBox["b", "i"], " ", 
     SubscriptBox["\[Eta]", "i"]}], ")"}], ".", 
   SubscriptBox["b", "j"]}], " ", "\[Equal]", " ", 
  RowBox[{"vw", ".", 
   SubscriptBox["b", "j"]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{
  3.595654941781042*^9, {3.595654975757985*^9, 3.5956550229336834`*^9}, {
   3.595655087159357*^9, 3.595655097189931*^9}, 3.5958300846603775`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[CapitalSigma]", "1", "m"], " ", 
    SubscriptBox["g", "ji"], " ", 
    SubscriptBox["\[Eta]", "i"]}], " ", "\[Equal]", " ", 
   RowBox[{"vw", ".", 
    SubscriptBox["b", "j"]}]}], ",", " ", 
  RowBox[{"j", " ", "=", " ", "1"}], ",", "  ", "...", ",", " ", 
  RowBox[{"m", "."}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{
  3.595655150854*^9, {3.595655192325372*^9, 3.595655205189108*^9}, {
   3.595655252685825*^9, 3.595655302854694*^9}, {3.595655373710747*^9, 
   3.5956553766539154`*^9}, 3.5958300860184546`*^9}],

Cell[TextData[{
 "Now let {",
 Cell[BoxData[
  SubscriptBox["h", "ki"]],
  CellChangeTimes->{
   3.595655150854*^9, {3.595655192325372*^9, 3.595655205189108*^9}, {
    3.595655252685825*^9, 3.595655302854694*^9}, {3.595655373710747*^9, 
    3.5956553766539154`*^9}}],
 "} = Invers",
 "e[",
 "{",
 Cell[BoxData[
  SubscriptBox["g", "ji"]],
  CellChangeTimes->{
   3.595655150854*^9, {3.595655192325372*^9, 3.595655205189108*^9}, {
    3.595655252685825*^9, 3.595655302854694*^9}, {3.595655373710747*^9, 
    3.5956553766539154`*^9}}],
 "}] be the inverse matrix:"
}], "Text",
 CellChangeTimes->{{3.595655385316411*^9, 3.5956555192920732`*^9}, 
   3.6148618617187433`*^9, 3.6149177933713636`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[CapitalSigma]", 
     RowBox[{"j", "=", "1"}], "m"], " ", 
    SubscriptBox["h", "kj"], " ", 
    SubscriptBox["g", "ji"]}], " ", "\[Equal]", " ", 
   SubscriptBox["\[Delta]", "ki"]}], ",", " ", "k", ",", 
  RowBox[{"i", " ", "=", " ", "1"}], ",", "...", ",", "m", ","}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5956555563181915`*^9, 3.5956556989513493`*^9}, {
  3.597207858081462*^9, 3.5972078683930798`*^9}}],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  SubscriptBox["\[Delta]", "ki"]],
  CellChangeTimes->{{3.595655736429493*^9, 3.595655758124734*^9}, {
   3.595655816518074*^9, 3.5956558518540955`*^9}}],
 " are the coefficients of the identity matrix"
}], "Text",
 CellChangeTimes->{{3.5956562970605593`*^9, 3.5956563376038785`*^9}, {
  3.5972078829323053`*^9, 3.5972078829323053`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Delta]", "ki"], " ", ":=", " ", 
   RowBox[{"KroneckerDelta", "[", 
    RowBox[{"k", ",", "i"}], "]"}]}], ","}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.595655736429493*^9, 3.595655758124734*^9}, {
  3.595655816518074*^9, 3.5956558518540955`*^9}, {3.597207915848363*^9, 
  3.5972079246779785`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"KroneckerDelta", "[", 
  RowBox[{"k", ",", "k"}], "]"}]], "Input",
 CellChangeTimes->{3.595655988030884*^9}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.5956559560480547`*^9, 3.595655989482967*^9, 
  3.5972079377664013`*^9, 3.6187392024199905`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"k", " ", "\[NotEqual]", " ", "j"}], ",", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"KroneckerDelta", "[", 
     RowBox[{"k", ",", "j"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5956560378387327`*^9, 3.595656081358222*^9}, {
  3.5956561420766945`*^9, 3.5956562544131203`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.5956561584806333`*^9, 3.5956561701673017`*^9}, 
   3.595656255656191*^9, 3.597207942228009*^9, 3.618739207333999*^9}]
}, Closed]],

Cell["Then it follows", "Text",
 CellChangeTimes->{{3.595656395755204*^9, 3.5956564124361587`*^9}}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Eta]", "k"], " ", "\[Equal]", " ", 
  RowBox[{
   SubsuperscriptBox["\[CapitalSigma]", 
    RowBox[{"j", "=", "1"}], "mf"], " ", 
   SubsuperscriptBox["\[CapitalSigma]", 
    RowBox[{"i", "=", "1"}], "mf"], 
   SubscriptBox["h", "kj"], " ", 
   SubscriptBox["g", "ji"], 
   SubscriptBox["\[Eta]", "i"]}], " ", "\[Equal]", " ", 
  RowBox[{
   SubsuperscriptBox["\[CapitalSigma]", 
    RowBox[{"j", "=", "1"}], "mf"], " ", 
   SubscriptBox["h", "kj"], 
   RowBox[{"(", 
    RowBox[{"vw", ".", 
     SubscriptBox["b", "j"]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.595656458933818*^9, 3.595656464461134*^9}, {
  3.595656501646261*^9, 3.595656551702124*^9}, {3.5956565823028746`*^9, 
  3.5956566318537083`*^9}, {3.595656665518634*^9, 3.5956566976144695`*^9}, {
  3.5958299906780014`*^9, 3.5958299933341537`*^9}, {3.618739232044442*^9, 
  3.6187392404840574`*^9}}],

Cell[TextData[{
 StyleBox["Lemma 1.",
  FontColor->RGBColor[0, 0, 1]],
 " With the notations fixed above the orthogonal projection of vw \[Element] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "n"], TraditionalForm]]],
 "into ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["T", "x", "m"], TraditionalForm]]],
 "   has the parameter representation"
}], "Text",
 CellChangeTimes->{{3.5956567484743786`*^9, 3.5956567748518877`*^9}, {
   3.5956569489718466`*^9, 3.5956569986676893`*^9}, {3.5956570412541246`*^9, 
   3.5956570613162727`*^9}, {3.595658913543214*^9, 3.595658946260085*^9}, 
   3.5958299735670233`*^9, {3.5964511553473406`*^9, 3.596451158732547*^9}}],

Cell[BoxData[
 RowBox[{"vy", " ", "\[Equal]", " ", 
  RowBox[{
   SubscriptBox["p", 
    RowBox[{"T", Cell[""]}]], "[", "vw", "]"}], " ", "\[Equal]", "   ", 
  RowBox[{
   SubsuperscriptBox["\[CapitalSigma]", 
    RowBox[{"k", "=", "1"}], "m"], 
   SubscriptBox["b", "k"], 
   SubsuperscriptBox["\[CapitalSigma]", 
    RowBox[{"j", "=", "1"}], "m"], " ", 
   SubscriptBox["h", "kj"], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"vw", ".", 
      SubscriptBox["b", "j"]}], ")"}], ".", 
    StyleBox["\[FilledSquare]",
     FontColor->GrayLevel[0]]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5956570679866543`*^9, 3.595657161678013*^9}, 
   3.5956572516071568`*^9, {3.595657289167305*^9, 3.595657366046702*^9}, {
   3.5958300874755383`*^9, 3.595830088452594*^9}, {3.5964511915706043`*^9, 
   3.596451239915089*^9}, {3.5964513203956304`*^9, 3.596451327946044*^9}}],

Cell["\<\
We need the inverse matrix of the {rgT[i,j][sf]} to define the projections \
into the tangent spaces:\
\>", "Text",
 CellChangeTimes->{
  3.5960911255015697`*^9, {3.5965226917583475`*^9, 3.596522735204424*^9}, {
   3.5965227667944794`*^9, 3.5965227936733265`*^9}, 3.613128297635784*^9, 
   3.6186421820496635`*^9, 3.618642342405835*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"invrgT", "[", 
     RowBox[{"i_", ",", "j_"}], "]"}], "[", "ff_", "]"}], " ", "[", "u__", 
   "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "u", "}"}], "]"}]}], ",", "k", ",", "h"}], "}"}], ",", 
    RowBox[{
     RowBox[{"Inverse", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"rgT", "[", 
           RowBox[{"h", ",", "k"}], "]"}], "[", "ff", "]"}], "[", "u", "]"}], 
        ",", " ", 
        RowBox[{"{", 
         RowBox[{"h", ",", "m"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "m"}], "}"}]}], "]"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5956601565633106`*^9, 3.5956604017693357`*^9}, {
   3.5956604347452216`*^9, 3.5956605759853*^9}, {3.598946323183834*^9, 
   3.5989463604489655`*^9}, {3.598946418832305*^9, 3.5989464229125385`*^9}, 
   3.5989464572645035`*^9, {3.5989464948246517`*^9, 3.5989465489377465`*^9}, {
   3.6148618617343435`*^9, 3.6148618617499437`*^9}, 3.6148635019992247`*^9, {
   3.6149177933713636`*^9, 3.614917793386964*^9}, 3.61864219003412*^9, 
   3.618642342423836*^9, 3.618739487916092*^9, 3.618739556603012*^9}],

Cell[TextData[{
 StyleBox["Example.",
  FontColor->RGBColor[0, 0, 1]],
 " The sphere of radius r>0:"
}], "Text",
 CellChangeTimes->{{3.5965221197053423`*^9, 3.596522145663788*^9}, {
  3.596522200887885*^9, 3.596522218531516*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", 
        RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "2"}], "}"}]}], "]"}], ",", 
    RowBox[{"r", ">", "0"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.595660633590595*^9, 3.595660656702917*^9}, {
   3.595660697216234*^9, 3.595660726782925*^9}, {3.5956608079675684`*^9, 
   3.595660835895166*^9}, {3.596451415196997*^9, 3.5964514249782143`*^9}, {
   3.5965217603899117`*^9, 3.5965217906227646`*^9}, {3.5965219904279156`*^9, 
   3.5965220433744087`*^9}, {3.596522159454212*^9, 3.5965221709046326`*^9}, {
   3.5965222567671833`*^9, 3.5965222569387836`*^9}, 3.6148618617655435`*^9, 
   3.6148635020148244`*^9, 3.61864220699609*^9, 3.6186423424318366`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "v", "]"}], "2"]}], "0"},
     {"0", 
      SuperscriptBox["r", "2"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.59652226055799*^9, 3.6131284619401817`*^9, 
  3.617100307102891*^9, 3.618739592763876*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"invrgT", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", 
        RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "2"}], "}"}]}], "]"}], ",", 
    RowBox[{"r", ">", "0"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.595660633590595*^9, 3.595660656702917*^9}, {
   3.595660697216234*^9, 3.595660726782925*^9}, {3.5956608079675684`*^9, 
   3.595660835895166*^9}, {3.596451415196997*^9, 3.5964514249782143`*^9}, {
   3.5965217603899117`*^9, 3.5965217906227646`*^9}, {3.5965219904279156`*^9, 
   3.5965220433744087`*^9}, {3.596522159454212*^9, 3.5965221709046326`*^9}, 
   3.6148618617811437`*^9, 3.614863502030424*^9, 3.6187394898816953`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       SuperscriptBox[
        RowBox[{"Sec", "[", "v", "]"}], "2"], 
       SuperscriptBox["r", "2"]], "0"},
     {"0", 
      FractionBox["1", 
       SuperscriptBox["r", "2"]]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.5965220455896125`*^9, 3.596522178314646*^9, 
  3.613128477190054*^9, 3.6171003133552485`*^9, 3.6187396006262903`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"%", ".", "%%"}], ",", 
    RowBox[{"r", ">", "0"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.595660633590595*^9, 3.595660656702917*^9}, {
  3.595660697216234*^9, 3.595660726782925*^9}, {3.5956608079675684`*^9, 
  3.595660835895166*^9}, {3.596451415196997*^9, 3.5964514249782143`*^9}, {
  3.5965217603899117`*^9, 3.5965217906227646`*^9}, {3.5965219904279156`*^9, 
  3.5965220433744087`*^9}, {3.596522159454212*^9, 3.5965221709046326`*^9}, {
  3.5965222864852357`*^9, 3.5965223097448764`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0"},
     {"0", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.596522316936489*^9, 3.613128488298689*^9, 
  3.617100324109864*^9, 3.6187396054622984`*^9}]
}, Closed]],

Cell["\<\
OK. \[FilledRectangle]
\
\>", "Text",
 CellChangeTimes->{{3.596522418243067*^9, 3.596522439427904*^9}}],

Cell[TextData[{
 "Here is the definition of the ",
 StyleBox["field of tangent projections",
  FontColor->RGBColor[0, 0, 1]],
 " of the immersion ff[x...]:"
}], "Text",
 CellChangeTimes->{{3.5965229764900475`*^9, 3.596522995631281*^9}, {
  3.596523070556733*^9, 3.596523132165257*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pT", "[", "ff_", "]"}], "[", "x__", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"tt", "[", "k", "]"}], "[", "ff", "]"}], "[", "x", "]"}], "*", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"invrgT", "[", 
            RowBox[{"k", ",", "j"}], "]"}], "[", "ff", "]"}], "[", "x", "]"}],
          "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"tt", "[", "j", "]"}], "[", "ff", "]"}], "[", "x", "]"}],
            ".", "#"}], ")"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"{", "x", "}"}], "]"}]}], "}"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "x", "}"}], "]"}]}], "}"}]}], "]"}], "&"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5956711982508154`*^9, 3.5956714584426975`*^9}, {
   3.5956714915405903`*^9, 3.5956715370841956`*^9}, {3.595671585747979*^9, 
   3.595671613340557*^9}, {3.595671665565544*^9, 3.595671740565834*^9}, 
   3.6187394924557*^9}],

Cell[TextData[{
 "Now we return to the surface in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "4"], TraditionalForm]]],
 " considered in the previous subsection: "
}], "Text",
 CellChangeTimes->{{3.595658977275859*^9, 3.59565902746873*^9}, {
  3.595660122941387*^9, 3.5956601380842533`*^9}, {3.59609110855994*^9, 
  3.5960911150339513`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "4"}], ";", " ", 
  RowBox[{"mf", " ", "=", " ", "2"}], ";", " ", 
  RowBox[{"vx", " ", ":=", " ", 
   RowBox[{
    RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", 
    RowBox[{"smf", "[", "f", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5956590461387978`*^9, 3.5956590587255173`*^9}, 
   3.595924528295635*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"vv", "[", "s", "]"}], "[", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], ",", 
   RowBox[{"x", "[", "2", "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"s", "[", "1", "]"}], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"s", "[", "2", "]"}], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5958302032431593`*^9, 3.596523225616602*^9, 
  3.5972990243024807`*^9, 3.6131289822039385`*^9, 3.61322055437525*^9, 
  3.6171004373523407`*^9, 3.6187396504995775`*^9}]
}, Closed]],

Cell["\<\
The orthogonal projection of the total differential yields hardly to handle \
expressions:\
\>", "Text",
 CellChangeTimes->{{3.595924809229704*^9, 3.595924857997493*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pT", "[", 
    RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
   RowBox[{
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}]}], "]"}], "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "vx", "]"}], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}], ".", 
   RowBox[{
    RowBox[{"vv", "[", "s", "]"}], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5956718156521287`*^9, 3.595671916986925*^9}, {
  3.595924878553669*^9, 3.5959248845610123`*^9}, {3.5959249303306303`*^9, 
  3.5959249361379623`*^9}}],

Cell[TextData[{
 "The simplification of this Output needs much time and brings little \
insight. Therefore we return to ",
 ButtonBox["formula (1)",
  BaseStyle->"Hyperlink",
  ButtonData->"dtt(1)"],
 " of the last subsection and first calculate the tangential components of \
the total differentials of the  tangent basis vectors:"
}], "Text",
 CellChangeTimes->{{3.5965233231091785`*^9, 3.5965233415892353`*^9}, {
  3.5965234585939274`*^9, 3.5965234706766186`*^9}, {3.5965236058293495`*^9, 
  3.5965236548851547`*^9}, {3.5965239391284127`*^9, 3.5965240097254505`*^9}, {
  3.596524051661849*^9, 3.5965240656206474`*^9}, {3.596524116821576*^9, 
  3.596524116826576*^9}, {3.596524164133282*^9, 3.596524171508704*^9}, {
  3.5965243170540285`*^9, 3.5965243252935*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Gamma]", "[", 
     RowBox[{"i_", ",", "j_", ",", "k_"}], "]"}], "[", "ff_", "]"}], "[", 
   "x__", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"tt", "[", "i", "]"}], "[", "ff", "]"}], "[", "x", "]"}], 
      ")"}], ".", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{
        RowBox[{"tt", "[", "j", "]"}], "[", "ff", "]"}], "]"}], "[", "x", 
      "]"}]}], ")"}], "[", 
   RowBox[{"[", "k", "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.595832267149208*^9, 3.5958323721202126`*^9}, {
   3.595832428807455*^9, 3.595832442513239*^9}, {3.595832489464924*^9, 
   3.5958325992172017`*^9}, {3.5958328395459476`*^9, 
   3.5958329541655035`*^9}, {3.5958329857303085`*^9, 3.5958329927137084`*^9}, 
   3.595833066441925*^9, {3.595833151066766*^9, 3.595833202040681*^9}, {
   3.595833410761619*^9, 3.595833418537064*^9}, {3.5958337753454723`*^9, 
   3.5958337836169453`*^9}, 3.5958373746493406`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", 
    RowBox[{"1", ",", "2", ",", "1"}], "]"}], "[", 
   RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], ",", 
   RowBox[{"x", "[", "2", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5958326835090227`*^9, 3.5958327630155706`*^9}, {
  3.595832965609158*^9, 3.5958329706304455`*^9}, {3.5958330067045083`*^9, 
  3.5958330097426825`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "1", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "1", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "2", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "2", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "3", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "3", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "4", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "4", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.5958327676888375`*^9, 3.595832852558692*^9, {3.5958330137439113`*^9, 
   3.5958330354841547`*^9}, 3.5958330733443203`*^9, 3.5958332205437393`*^9, 
   3.595833426246505*^9, 3.59583379366152*^9, 3.595939833746538*^9, 
   3.613220746649247*^9, 3.6187446336084585`*^9}]
}, Closed]],

Cell["\[Gamma][i,j,k] is symmetric with respect to the last two indices:", \
"Text",
 CellChangeTimes->{{3.5958375539165945`*^9, 3.595837581947198*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]", "[", 
        RowBox[{"k", ",", "j", ",", "i"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], "-", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]", "[", 
        RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "mf"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "mf"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "mf"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.59583346776388*^9, 3.595833575697053*^9}, {
   3.5958336323142915`*^9, 3.5958336479051833`*^9}, {3.5958336849463015`*^9, 
   3.5958337057534924`*^9}, {3.5958338055792017`*^9, 
   3.5958338282264967`*^9}, {3.596466574435828*^9, 3.5964666093798895`*^9}, 
   3.6148618620151443`*^9, 3.6148635020460243`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.595833577195139*^9, 3.595833656364667*^9, 
  3.595833714135971*^9, 3.5958338311516643`*^9, 3.595939846400262*^9, 
  3.5959398893307176`*^9, 3.596466610799492*^9, 3.59720909252723*^9, 
  3.5972091247724867`*^9, 3.5973822429632874`*^9, 3.6132208834150696`*^9, 
  3.6187446655261145`*^9}]
}, Closed]],

Cell["\<\
The \[Gamma][i,j,k] may be expressed as the scalar product of the derivatives\
\>", "Text",
 CellChangeTimes->{{3.5958376134359984`*^9, 3.595837671195302*^9}, 
   3.596466437498788*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]", "[", 
        RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], "-", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"f", "[", "l", "]"}], "[", 
           RowBox[{
            RowBox[{"x", "[", "1", "]"}], ",", 
            RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
          RowBox[{"x", "[", "i", "]"}]}], "]"}], "*", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"f", "[", "l", "]"}], "[", 
           RowBox[{
            RowBox[{"x", "[", "1", "]"}], ",", 
            RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
          RowBox[{"x", "[", "j", "]"}], ",", 
          RowBox[{"x", "[", "k", "]"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"l", ",", "dim"}], "}"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "mf"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "mf"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "mf"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.595834301153547*^9, 3.595834330847245*^9}, {
   3.5958344074156246`*^9, 3.5958344117198706`*^9}, {3.595834470991261*^9, 
   3.595834498791851*^9}, {3.5958345504088035`*^9, 3.5958346806322517`*^9}, {
   3.5958347237637186`*^9, 3.5958347699433603`*^9}, {3.5958348271236305`*^9, 
   3.5958348924843693`*^9}, 3.614861862030744*^9, 3.6148635020616245`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5958347920706253`*^9, 3.595834893739441*^9, 
  3.595939916566275*^9, 3.596466455345219*^9, 3.5964665365121613`*^9, 
  3.6132210353427596`*^9, 3.6171006876696587`*^9, 3.6187447389710436`*^9}]
}, Closed]],

Cell["It follows that \[Gamma][i,j,k] may be defined by", "Text",
 CellChangeTimes->{{3.595835714644394*^9, 3.595835766867381*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Gamma]\[Gamma]\[Gamma]", "[", 
     RowBox[{"i_", ",", "j_", ",", "k_"}], "]"}], "[", "ff_", "]"}], " ", "[",
    "x__", "]"}], ":=", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"ff", "[", "x", "]"}], ",", 
     RowBox[{
      RowBox[{"{", "x", "}"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ".", " ", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"ff", "[", "x", "]"}], ",", 
     RowBox[{
      RowBox[{"{", "x", "}"}], "[", 
      RowBox[{"[", "j", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"{", "x", "}"}], "[", 
      RowBox[{"[", "k", "]"}], "]"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.5958360751920156`*^9, {3.5958362670469894`*^9, 3.595836268018045*^9}, {
   3.595836315208744*^9, 3.59583637003388*^9}, {3.5958366145528655`*^9, 
   3.595836615136899*^9}, {3.595836913992993*^9, 3.595837072362051*^9}, 
   3.595837191258851*^9, 3.5958373185941343`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]\[Gamma]\[Gamma]", "[", 
    RowBox[{"1", ",", "1", ",", "2"}], "]"}], "[", 
   RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], ",", 
   RowBox[{"x", "[", "2", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.59583648699857*^9, 3.5958364893347034`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "1", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "1", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "2", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "2", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "3", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "3", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "4", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "4", "]"}], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.5958364910488014`*^9, {3.59583708213761*^9, 3.595837111457287*^9}, 
   3.595837197061183*^9, 3.5959399760796795`*^9, 3.5965245102580795`*^9, 
   3.6132211273180203`*^9, 3.61874478831393*^9}]
}, Closed]],

Cell["Check the statement:", "Text",
 CellChangeTimes->{{3.5965245375496407`*^9, 3.5965245477652245`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]", "[", 
        RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], "-", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]\[Gamma]\[Gamma]", "[", 
        RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "mf"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "mf"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "mf"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.595834301153547*^9, 3.595834330847245*^9}, {
   3.5958344074156246`*^9, 3.5958344117198706`*^9}, {3.595834470991261*^9, 
   3.595834498791851*^9}, {3.5958345504088035`*^9, 3.5958346806322517`*^9}, {
   3.5958347237637186`*^9, 3.5958347699433603`*^9}, {3.5958348271236305`*^9, 
   3.5958348924843693`*^9}, {3.5958361198955727`*^9, 
   3.5958361451940203`*^9}, {3.5958361819391212`*^9, 3.5958361936667924`*^9}, 
   3.5958362941475396`*^9, 3.614861862046344*^9, 3.6148635020616245`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.595836195216881*^9, 3.5958362967746897`*^9, 
  3.595836380011451*^9, 3.5958370897920475`*^9, 3.5958372010344105`*^9, 
  3.5959399838381233`*^9, 3.5960921513905716`*^9, 3.596524583162249*^9, 
  3.613221176196816*^9, 3.6171007336352873`*^9, 3.618744795458743*^9}]
}, Closed]],

Cell[TextData[{
 "Now we remember the definition of the",
 ButtonBox[" first fundamental form",
  BaseStyle->"Hyperlink",
  ButtonData->"fund1"],
 " and  verify"
}], "Text",
 CellChangeTimes->{{3.595941251019602*^9, 3.5959412698656797`*^9}, {
  3.5964666958040414`*^9, 3.596466724040091*^9}, {3.596526324159829*^9, 
  3.5965263241648293`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Table", " ", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", 
         RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
       RowBox[{"x", "[", "k", "]"}]}], "]"}], "-", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]", "[", 
        RowBox[{"i", ",", "k", ",", "j"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], "-", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]", "[", 
        RowBox[{"j", ",", "k", ",", "i"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "2"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5959412900918365`*^9, 3.595941430860888*^9}, {
   3.5959414627807136`*^9, 3.5959414712411976`*^9}, {3.5959415379840155`*^9, 
   3.595941634457533*^9}, 3.6186423861793385`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5959416446041136`*^9, 3.596526426085658*^9, 
  3.6132212724303203`*^9, 3.6171008199232225`*^9, 3.6187448154891777`*^9}]
}, Closed]],

Cell["Thus we have the relation (omitting the arguments)", "Text",
 CellChangeTimes->{{3.5959417091768064`*^9, 3.595941736120348*^9}, 
   3.5959433441283207`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[PartialD]", "k"], 
   SubscriptBox["g", 
    RowBox[{"ij", " "}]]}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"\[Gamma]", "[", 
    RowBox[{"i", ",", "k", ",", "j"}], "]"}], " ", "+", 
   RowBox[{"\[Gamma]", "[", 
    RowBox[{"j", ",", "k", ",", "i"}], "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5959417619478254`*^9, 3.5959417867222424`*^9}, {
  3.595941835226016*^9, 3.5959418868279676`*^9}}],

Cell["\<\
Permuting in this identity the indices i, j, k twice cyclically and calculate\
\>", "Text",
 CellChangeTimes->{{3.5959428318930225`*^9, 3.5959429012729907`*^9}, 
   3.595943368160695*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "k"], 
     SubscriptBox["g", 
      RowBox[{"ij", " "}]]}], " ", "+", 
    RowBox[{
     SubscriptBox["\[PartialD]", "i"], 
     SubscriptBox["g", 
      RowBox[{"jk", " "}]]}], " ", "-", 
    RowBox[{
     SubscriptBox["\[PartialD]", "j"], 
     SubscriptBox["g", 
      RowBox[{"ki", " "}]]}]}], ")"}], "/", "2"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.595942934100868*^9, 3.5959429691548734`*^9}, {
  3.5959429992345943`*^9, 3.5959430300903587`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Table", " ", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"rgT", "[", 
             RowBox[{"i", ",", "j"}], "]"}], "[", 
            RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
           RowBox[{
            RowBox[{"x", "[", "1", "]"}], ",", 
            RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
          RowBox[{"x", "[", "k", "]"}]}], "]"}], " ", "+", " ", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"rgT", "[", 
             RowBox[{"j", ",", "k"}], "]"}], "[", 
            RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
           RowBox[{
            RowBox[{"x", "[", "1", "]"}], ",", 
            RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
          RowBox[{"x", "[", "i", "]"}]}], "]"}], "-", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"rgT", "[", 
             RowBox[{"k", ",", "i"}], "]"}], "[", 
            RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
           RowBox[{
            RowBox[{"x", "[", "1", "]"}], ",", 
            RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
          RowBox[{"x", "[", "j", "]"}]}], "]"}]}], ")"}], "/", "2"}], " ", 
     "-", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]", "[", 
        RowBox[{"j", ",", "k", ",", "i"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "2"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5959412900918365`*^9, 3.595941430860888*^9}, {
  3.5959414627807136`*^9, 3.5959414712411976`*^9}, {3.5959415379840155`*^9, 
  3.595941634457533*^9}, {3.595941961554242*^9, 3.595942003374634*^9}, {
  3.595942053413496*^9, 3.595942106702544*^9}, {3.5959421530311937`*^9, 
  3.595942184531996*^9}, {3.5959422245002813`*^9, 3.595942227412448*^9}, {
  3.5959423193967094`*^9, 3.5959423524365993`*^9}, {3.595943123101679*^9, 
  3.5959431250367894`*^9}, {3.6186423875404167`*^9, 3.6186423896215353`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.59594236573236*^9, 3.5959431280669627`*^9, 
  3.613221374829177*^9, 3.618744865222065*^9}]
}, Closed]],

Cell["We obtain ", "Text",
 CellChangeTimes->{{3.5959430503845196`*^9, 3.59594305948804*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Gamma]", "[", 
   RowBox[{"j", ",", "k", ",", "i"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "k"], 
      SubscriptBox["g", 
       RowBox[{"ij", " "}]]}], " ", "+", 
     RowBox[{
      SubscriptBox["\[PartialD]", "i"], 
      SubscriptBox["g", 
       RowBox[{"jk", " "}]]}], " ", "-", 
     RowBox[{
      SubscriptBox["\[PartialD]", "j"], 
      SubscriptBox["g", 
       RowBox[{"ki", " "}]]}]}], ")"}], "/", "2"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.595943183946159*^9, 3.5959431903385243`*^9}, 
   3.5959432283076963`*^9}],

Cell["This may be used for a third definition of the \[Gamma]-symbols", "Text",
 CellChangeTimes->{{3.595943419848652*^9, 3.5959434605369787`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "\[Gamma]\[Gamma]", "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Gamma]\[Gamma]", "[", 
      RowBox[{"j_", ",", "k_", ",", "i_"}], "]"}], "[", "ff_", "]"}], "[", 
    "x__", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"rgT", "[", 
           RowBox[{"i", ",", "j"}], "]"}], "[", "ff", "]"}], "[", "x", "]"}], 
        ",", 
        RowBox[{
         RowBox[{"{", "x", "}"}], "[", 
         RowBox[{"[", "k", "]"}], "]"}]}], "]"}], " ", "+", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"rgT", "[", 
           RowBox[{"j", ",", "k"}], "]"}], "[", "ff", "]"}], "[", "x", "]"}], 
        ",", 
        RowBox[{
         RowBox[{"{", "x", "}"}], "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "]"}], " ", "-", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"rgT", "[", 
           RowBox[{"k", ",", "i"}], "]"}], "[", "ff", "]"}], "[", "x", "]"}], 
        ",", 
        RowBox[{
         RowBox[{"{", "x", "}"}], "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], "]"}]}], ")"}], "/", 
    "2"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.595943691303178*^9, 3.595943720562852*^9}, {
  3.595943755629857*^9, 3.5959438156432896`*^9}, {3.5959438577156963`*^9, 
  3.5959439199962587`*^9}, {3.595943963596752*^9, 3.5959440729940095`*^9}, {
  3.5959453340161357`*^9, 3.59594563392929*^9}, {3.5959456985059834`*^9, 
  3.5959457283136883`*^9}, {3.5959460610257187`*^9, 3.5959460813358803`*^9}, {
  3.618642390708598*^9, 3.6186423931307364`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]\[Gamma]", "[", 
    RowBox[{"1", ",", "1", ",", "2"}], "]"}], "[", 
   RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], ",", 
   RowBox[{"x", "[", "2", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5959443675718584`*^9, 3.5959443703800187`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "4", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "4", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.595944372010112*^9, 3.5959454714159946`*^9, 
  3.595945512584349*^9, 3.595945737178195*^9, 3.595946088189272*^9, 
  3.5960922608247633`*^9, 3.5965265401091805`*^9, 3.6132214770120215`*^9, 
  3.6171009580891256`*^9, 3.6187449558426247`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Table", " ", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]\[Gamma]", "[", 
        RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], "-", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]", "[", 
        RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "2"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5959440956543055`*^9, 3.595944199291233*^9}, {
   3.595944229936986*^9, 3.595944247207974*^9}, 3.5959443002400074`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.595944302775152*^9, 3.595946114656786*^9, 
  3.596092271713583*^9, 3.5965265734170856`*^9, 3.597382311026207*^9, 
  3.61710096516253*^9, 3.618744968088646*^9}]
}, Closed]],

Cell[TextData[{
 "The ",
 StyleBox["Christoffel symbols",
  FontColor->RGBColor[0, 0, 1]],
 " ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[CapitalGamma]", "ij", "k"], TraditionalForm]]],
 " (== \[CapitalGamma][k,i,j]) are defined by",
 StyleBox[" raising the index ",
  FontColor->RGBColor[0, 0, 1]],
 "k of \[Gamma][k, i, j]:"
}], "Text",
 CellChangeTimes->{{3.5962632168845243`*^9, 3.59626338482813*^9}, {
   3.596263485246873*^9, 3.596263521619954*^9}, 3.596263699773144*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalGamma]", "[", 
    RowBox[{"k_", ",", "i_", ",", "j_"}], "]"}], "[", "ff_", "]"}], ":=", 
  RowBox[{
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"invrgT", "[", 
         RowBox[{"k", ",", "l"}], "]"}], "[", "ff", "]"}], "[", "##", "]"}], 
      "*", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Gamma]\[Gamma]", "[", 
         RowBox[{"l", ",", "i", ",", "j"}], "]"}], "[", "ff", "]"}], "[", 
       "##", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "##", "}"}], "]"}]}], "}"}]}], "]"}], "&"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5960018598938203`*^9, 3.596002000216067*^9}, {
   3.5960020444421444`*^9, 3.5960021548903384`*^9}, 3.596002568119464*^9, {
   3.5962627214502306`*^9, 3.5962627274874415`*^9}, {3.5962627993099675`*^9, 
   3.5962628115559893`*^9}, {3.59626286325448*^9, 3.596262865719284*^9}, 
   3.596355750517495*^9, 3.618739494686504*^9}],

Cell[TextData[{
 StyleBox["Lemma 2. ",
  FontColor->RGBColor[0, 0, 1]],
 "The Christoffel symbols are defined  by the Riemannian metric ",
 "rgT[",
 "i,j] only: isometric Riemannian manifolds (or immersions) have the same \
Christoffel symbols. They are symmetric with respect to the last two indices:"
}], "Text",
 CellChangeTimes->{{3.596263795220603*^9, 3.5962638134276443`*^9}, {
   3.5962638465165367`*^9, 3.596263997252158*^9}, {3.5964667908862085`*^9, 
   3.596466795909417*^9}, 3.6186423947728305`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[CapitalGamma]", "[", 
        RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", "-", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"\[CapitalGamma]", "[", 
        RowBox[{"k", ",", "j", ",", "i"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "2"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.596092519613618*^9, 3.596092710557954*^9}, {
   3.5960927565312347`*^9, 3.5960927874972887`*^9}, {3.5960928282913604`*^9, 
   3.596092857510212*^9}, {3.5962629222849836`*^9, 3.596262936371808*^9}, 
   3.614861862061944*^9, 3.6148635020772247`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.596092714832361*^9, 3.5960927941897*^9, 
  3.596092861691019*^9, 3.5962629378070107`*^9, 3.596355768161126*^9, 
  3.597382394174353*^9, 3.6132216563493047`*^9, 3.618750132479765*^9}]
}, Closed]],

Cell["\[FilledRectangle]", "Text",
 CellChangeTimes->{{3.596526684213423*^9, 3.596526684219423*^9}}],

Cell[TextData[{
 StyleBox["Example",
  FontColor->RGBColor[0, 0, 1]],
 ": The unit sphere:"
}], "Text",
 CellChangeTimes->{{3.596264188339088*^9, 3.5962642170837317`*^9}, {
  3.5964670000357757`*^9, 3.5964670129369984`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k"}], "}"}], " ", "\[Rule]", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"\[CapitalGamma]", "[", 
         RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", 
        RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "2"}], "}"}]}], "]"}], "]"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.5964375688386*^9, 3.59643760902427*^9}, {
   3.5964376738579845`*^9, 3.596437674918786*^9}, {3.5964377439645076`*^9, 
   3.5964377584257326`*^9}, {3.5964378236026473`*^9, 3.5964378310594606`*^9}, 
   3.614861862077544*^9, 3.6148635020928245`*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "1"}], "}"}], "\[Rule]", "0"}]},
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "2"}], "}"}], "\[Rule]", 
          RowBox[{"-", 
           RowBox[{"Tan", "[", "v", "]"}]}]}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {{
            Offset[0.2]}}, "RowsIndexed" -> {}}],
      Column], 
     TagBox[GridBox[{
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "1"}], "}"}], "\[Rule]", 
          RowBox[{"-", 
           RowBox[{"Tan", "[", "v", "]"}]}]}]},
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "2"}], "}"}], "\[Rule]", "0"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {{
            Offset[0.2]}}, "RowsIndexed" -> {}}],
      Column]},
    {
     TagBox[GridBox[{
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "1", ",", "1"}], "}"}], "\[Rule]", 
          RowBox[{
           RowBox[{"Cos", "[", "v", "]"}], " ", 
           RowBox[{"Sin", "[", "v", "]"}]}]}]},
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "1", ",", "2"}], "}"}], "\[Rule]", "0"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {{
            Offset[0.2]}}, "RowsIndexed" -> {}}],
      Column], 
     TagBox[GridBox[{
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "2", ",", "1"}], "}"}], "\[Rule]", "0"}]},
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "2", ",", "2"}], "}"}], "\[Rule]", "0"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {{
            Offset[0.2]}}, "RowsIndexed" -> {}}],
      Column]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.5964376785223923`*^9, 3.5964377689557514`*^9, 
  3.5964378338518653`*^9, 3.5965267192054243`*^9, 3.597382467915683*^9, 
  3.613221678236143*^9, 3.618750140388979*^9}]
}, Closed]],

Cell[TextData[{
 "\[FilledRectangle]\n",
 StyleBox["Example",
  FontColor->RGBColor[0, 0, 1]],
 ". A general surface:"
}], "Text",
 CellChangeTimes->{{3.596467059924281*^9, 3.5964670689566965`*^9}, {
  3.5965268092775755`*^9, 3.5965268485568223`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", " ", "3"}], ";", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalGamma]", "[", 
      RowBox[{"1", ",", "2", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.596002193906007*^9, 3.596002239302087*^9}, {
   3.596002307755007*^9, 3.5960023288774443`*^9}, 3.5960023753967257`*^9, {
   3.59600297016337*^9, 3.596002973298976*^9}, {3.596003011160242*^9, 
   3.5960030221738615`*^9}, {3.6187502576699853`*^9, 3.6187502629271946`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.596002984952196*^9, 3.596003023499864*^9, 
  3.596092457509909*^9, 3.5962628927073317`*^9, 3.5962642713738375`*^9, 
  3.59635580432199*^9, 3.5965267832640877`*^9, 3.61322173347584*^9, 
  3.618750185769459*^9, 3.6187502653295984`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalGamma]", "[", 
      RowBox[{"1", ",", "1", ",", "2"}], "]"}], "[", 
     RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.596002193906007*^9, 3.596002239302087*^9}, {
   3.596002307755007*^9, 3.5960023288774443`*^9}, 3.5960023753967257`*^9, {
   3.59600297016337*^9, 3.596002973298976*^9}, {3.596003011160242*^9, 
   3.5960030221738615`*^9}, {3.5960030787083607`*^9, 3.5960031412332706`*^9}, 
   3.596003187549752*^9, {3.596264292944071*^9, 3.5962643306622286`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.596003109846016*^9, 3.5960031480816827`*^9, 3.5960031893281555`*^9, {
   3.5960924874463615`*^9, 3.5960924923447704`*^9}, 3.59626290326855*^9, 
   3.596264333162371*^9, 3.5963558087679977`*^9, 3.596526787645338*^9, 
   3.6132217781387186`*^9, 3.618750196689478*^9, 3.6187502411183558`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "\[Equal]", "%%"}]], "Input",
 CellChangeTimes->{{3.5962643468541546`*^9, 3.5962643502293477`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5962643513874135`*^9, 3.596355813151605*^9, 
  3.596526791909582*^9, 3.6132217861883326`*^9, 3.618750200807885*^9, 
  3.618750271382409*^9}]
}, Closed]],

Cell[TextData[{
 "\[FilledRectangle]",
 StyleBox["\nExample",
  FontColor->RGBColor[0, 0, 1]],
 ". The Euclidean space :"
}], "Text",
 CellChangeTimes->{{3.596438847572846*^9, 3.5964388776808987`*^9}, {
  3.5965269169567347`*^9, 3.5965269247021775`*^9}}],

Cell["\<\
The Euclidean space is immersed onto itself by the identity map\
\>", "Text",
 CellChangeTimes->{{3.596439093117277*^9, 3.596439130713343*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"euclid", "[", "x__", "]"}], ":=", " ", 
  RowBox[{"{", "x", "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.5964385438403125`*^9, {3.596438581217978*^9, 3.596438596708805*^9}}],

Cell["The metric has the standard orthonormal shape", "Text",
 CellChangeTimes->{{3.5964391499637775`*^9, 3.596439188792245*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"rgT", "[", 
       RowBox[{"i", ",", "j"}], "]"}], "[", "euclid", "]"}], "[", 
     RowBox[{
      RowBox[{"x", "[", "1", "]"}], ",", 
      RowBox[{"x", "[", "2", "]"}], ",", 
      RowBox[{"x", "[", "3", "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "3"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.5964381997037077`*^9, 3.596438289575466*^9}, {
   3.5964383447839627`*^9, 3.596438428010109*^9}, 3.5964384869314127`*^9, {
   3.5964386078784246`*^9, 3.596438784392735*^9}, {3.5965269616812925`*^9, 
   3.5965269678126435`*^9}, 3.6148618621087437`*^9, 3.614863502108424*^9, 
   3.6186423963049183`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", "0"},
     {"0", "1", "0"},
     {"0", "0", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.596438298701482*^9, 3.596438432190916*^9, 3.59643849115902*^9, 
   3.596438728685037*^9, 3.596438785812338*^9, {3.5965269700767727`*^9, 
   3.596526977331188*^9}, 3.6132218072483697`*^9, 3.618750321021696*^9}]
}, Closed]],

Cell["All the Christoffel symbols are zero:", "Text",
 CellChangeTimes->{{3.5964392202731004`*^9, 3.5964392394299345`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k"}], "}"}], " ", "\[Rule]", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"\[CapitalGamma]", "[", 
         RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", "euclid", "]"}], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "3"}], "}"}]}], "]"}], "]"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.5964375688386*^9, 3.59643760902427*^9}, {
   3.5964376738579845`*^9, 3.596437674918786*^9}, {3.5964377439645076`*^9, 
   3.5964377584257326`*^9}, {3.5964378236026473`*^9, 
   3.5964378310594606`*^9}, {3.596438962045847*^9, 3.596438993760703*^9}, 
   3.614861862124344*^9, 3.614863502108424*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "1"}], "}"}], "\[Rule]", "0"}]},
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "2"}], "}"}], "\[Rule]", "0"}]},
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "3"}], "}"}], "\[Rule]", "0"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {{
            Offset[0.2]}}, "RowsIndexed" -> {}}],
      Column], 
     TagBox[GridBox[{
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "1"}], "}"}], "\[Rule]", "0"}]},
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "2"}], "}"}], "\[Rule]", "0"}]},
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "3"}], "}"}], "\[Rule]", "0"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {{
            Offset[0.2]}}, "RowsIndexed" -> {}}],
      Column], 
     TagBox[GridBox[{
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "3", ",", "1"}], "}"}], "\[Rule]", "0"}]},
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "3", ",", "2"}], "}"}], "\[Rule]", "0"}]},
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "3", ",", "3"}], "}"}], "\[Rule]", "0"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {{
            Offset[0.2]}}, "RowsIndexed" -> {}}],
      Column]},
    {
     TagBox[GridBox[{
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "1", ",", "1"}], "}"}], "\[Rule]", "0"}]},
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "1", ",", "2"}], "}"}], "\[Rule]", "0"}]},
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "1", ",", "3"}], "}"}], "\[Rule]", "0"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {{
            Offset[0.2]}}, "RowsIndexed" -> {}}],
      Column], 
     TagBox[GridBox[{
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "2", ",", "1"}], "}"}], "\[Rule]", "0"}]},
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "2", ",", "2"}], "}"}], "\[Rule]", "0"}]},
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "2", ",", "3"}], "}"}], "\[Rule]", "0"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {{
            Offset[0.2]}}, "RowsIndexed" -> {}}],
      Column], 
     TagBox[GridBox[{
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "3", ",", "1"}], "}"}], "\[Rule]", "0"}]},
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "3", ",", "2"}], "}"}], "\[Rule]", "0"}]},
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "3", ",", "3"}], "}"}], "\[Rule]", "0"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {{
            Offset[0.2]}}, "RowsIndexed" -> {}}],
      Column]},
    {
     TagBox[GridBox[{
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"3", ",", "1", ",", "1"}], "}"}], "\[Rule]", "0"}]},
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"3", ",", "1", ",", "2"}], "}"}], "\[Rule]", "0"}]},
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"3", ",", "1", ",", "3"}], "}"}], "\[Rule]", "0"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {{
            Offset[0.2]}}, "RowsIndexed" -> {}}],
      Column], 
     TagBox[GridBox[{
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"3", ",", "2", ",", "1"}], "}"}], "\[Rule]", "0"}]},
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"3", ",", "2", ",", "2"}], "}"}], "\[Rule]", "0"}]},
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"3", ",", "2", ",", "3"}], "}"}], "\[Rule]", "0"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {{
            Offset[0.2]}}, "RowsIndexed" -> {}}],
      Column], 
     TagBox[GridBox[{
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"3", ",", "3", ",", "1"}], "}"}], "\[Rule]", "0"}]},
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"3", ",", "3", ",", "2"}], "}"}], "\[Rule]", "0"}]},
        {
         RowBox[{
          RowBox[{"{", 
           RowBox[{"3", ",", "3", ",", "3"}], "}"}], "\[Rule]", "0"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {{
            Offset[0.2]}}, "RowsIndexed" -> {}}],
      Column]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.596438997255109*^9, 3.59652699381013*^9, 
  3.6132218139719815`*^9, 3.6187503289465103`*^9},
 TextJustification->1.]
}, Closed]],

Cell[TextData[{
 "\[FilledRectangle]\nNow we define the ",
 StyleBox["absolute differential",
  FontColor->RGBColor[0, 0, 1]],
 "  of a tangent vector field vw[x[1], x[2,...] ] on the immersion ff[x[1], \
x[2],...] or on the Riemannian manifold ff with local coordinates x[1], \
x[2],...:"
}], "Text",
 CellChangeTimes->{{3.5964393669757586`*^9, 3.5964394522767076`*^9}, {
   3.5964394822911606`*^9, 3.5964395605564985`*^9}, {3.596439649164654*^9, 
   3.5964396694290895`*^9}, {3.5964397029067483`*^9, 
   3.5964397744796743`*^9}, {3.596441447099012*^9, 3.596441496660299*^9}, {
   3.5964615275749636`*^9, 3.596461551396206*^9}, {3.5965270574777718`*^9, 
   3.5965270926457834`*^9}, 3.61744122138057*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "4"}], ";"}]], "Input",
 CellChangeTimes->{{3.596264357809781*^9, 3.596264365077197*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"DD", ",", "vw", ",", "x"}], "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"DD", "[", "ff_", "]"}], "[", "vw_", "]"}], "[", "x__", "]"}], ":=",
    " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"vw", "[", "x", "]"}], "[", 
          RowBox[{"[", "k", "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"{", "x", "}"}], "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "+", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"\[CapitalGamma]", "[", 
             RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", "ff", "]"}], "[", 
           "x", "]"}], "*", 
          RowBox[{
           RowBox[{"vw", "[", "x", "]"}], "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Length", "[", 
            RowBox[{"{", "x", "}"}], "]"}]}], "}"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", 
        RowBox[{"Length", "[", 
         RowBox[{"{", "x", "}"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", 
        RowBox[{"Length", "[", 
         RowBox[{"{", "x", "}"}], "]"}]}], "}"}]}], "]"}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.596267909001898*^9, 3.596268002502246*^9}, {
   3.596268233767473*^9, 3.5962682417899323`*^9}, 3.596268272390682*^9, {
   3.5962683739424906`*^9, 3.596268434579959*^9}, {3.596268467832861*^9, 
   3.596268467847862*^9}, {3.596268546079336*^9, 3.59626858233541*^9}, {
   3.5962686311192007`*^9, 3.596268685327301*^9}, {3.596268721063345*^9, 
   3.5962687800967216`*^9}, {3.5962688200340056`*^9, 3.5962689711946516`*^9}, 
   3.596270942293791*^9, {3.5962709724375153`*^9, 3.5962709908775697`*^9}, {
   3.5962711252152534`*^9, 3.596271142601248*^9}, {3.5962712161694555`*^9, 
   3.5962712481452847`*^9}, {3.596271295953019*^9, 3.5962712978171253`*^9}, {
   3.5962714903281364`*^9, 3.5962715032818775`*^9}, {3.5962715560498953`*^9, 
   3.5962715738429136`*^9}, {3.5963609856954927`*^9, 
   3.5963610055046253`*^9}, {3.596361147280734*^9, 3.5963611482237883`*^9}, 
   3.5963690709758096`*^9, {3.59636910944601*^9, 3.5963691235168147`*^9}, {
   3.5963691564216967`*^9, 3.5963691658852386`*^9}, {3.5963695531093864`*^9, 
   3.5963695911245604`*^9}, {3.596369833029397*^9, 3.596369836182577*^9}, {
   3.5963701344546375`*^9, 3.5963701758290033`*^9}, {3.5963707897741194`*^9, 
   3.5963708379418745`*^9}, {3.5963708850625696`*^9, 
   3.5963709097469816`*^9}, {3.5963733257331676`*^9, 3.5963733297783995`*^9}, 
   3.614861862139944*^9, 3.6148635021240244`*^9}],

Cell[TextData[{
 "The ",
 StyleBox["outer form of a ",
  FontColor->RGBColor[0, 0, 1]],
 "tangent",
 StyleBox[" vector field",
  FontColor->RGBColor[0, 0, 1]],
 " on a surface in the Euclidean space is"
}], "Text",
 CellChangeTimes->{{3.5964653794113293`*^9, 3.5964654199402003`*^9}, 
   3.6130241204895363`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{
  3.5963696782625446`*^9, 3.596370011736618*^9, {3.596370260543849*^9, 
   3.5963702620869374`*^9}, 3.5963713146021376`*^9, 3.5963734001034217`*^9, 
   3.59643714724786*^9, {3.5964415386243725`*^9, 3.596441564068017*^9}, {
   3.5964625091130877`*^9, 3.596462532559929*^9}, {3.5964647726950636`*^9, 
   3.5964647751910677`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "4", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "4", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5963696853039474`*^9, 3.596369914082033*^9, 3.5963700132637053`*^9, 
   3.596370263668028*^9, 3.5963720073587613`*^9, 3.596372286888749*^9, 
   3.5963734365435057`*^9, 3.596437021667639*^9, 3.5964415675468235`*^9, 
   3.59646186681316*^9, {3.596462512794694*^9, 3.596462533776731*^9}, 
   3.5964647765638704`*^9, 3.596527377138056*^9, 3.61322207506964*^9, 
   3.6171011361913123`*^9, 3.6187504507983246`*^9}]
}, Closed]],

Cell["\<\
This is the image of the tangent vector field vv[\[Xi]][u,v] under the \
differential of the immersion:\
\>", "Text",
 CellChangeTimes->{{3.5964655028543463`*^9, 3.5964655765332756`*^9}, 
   3.6130241253778157`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], ".", 
  RowBox[{
   RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5964629299238267`*^9, 3.5964629384414415`*^9}, {
  3.596464531128639*^9, 3.596464582265529*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "4", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "4", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5964629411870465`*^9, 3.5964630718216763`*^9, 
  3.5964642803893986`*^9, 3.596464585947136*^9, 3.5964646731980886`*^9, 
  3.596464783708683*^9, 3.6132220969096785`*^9, 3.6171011531882844`*^9, 
  3.6187504620615444`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5964645962899537`*^9, 3.5964646521848516`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.5964646223107996`*^9, {3.59646465705206*^9, 3.5964646766924953`*^9}, 
   3.596464789496293*^9, 3.613222102244888*^9, 3.6171011587716036`*^9, 
   3.618750467755554*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example",
  FontColor->RGBColor[0, 0, 1]],
 ". A tangent vector field on the unit sphere.\nWe calculate its total \
differential"
}], "Text",
 CellChangeTimes->{{3.5964656072653294`*^9, 3.59646561355214*^9}, {
   3.5964671233539925`*^9, 3.596467138548419*^9}, 3.5964671699824743`*^9, {
   3.5964673422847767`*^9, 3.596467345123982*^9}, 3.5965274369334755`*^9, {
   3.5965274799579363`*^9, 3.5965274962528687`*^9}, 3.6132221202317195`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{
      RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", 
      RowBox[{"sphero", "[", "1", "]"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ")"}], ".", 
  RowBox[{"{", 
   RowBox[{"s1", ",", "s2"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"s2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Sin", "[", "u", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"Cos", "[", "u", "]"}], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"Cos", "[", "u", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"s1", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", "u", "]"}]}], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"Sin", "[", "u", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"Cos", "[", "u", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"s2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", "u", "]"}]}], " ", 
        RowBox[{"Sin", "[", "v", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "u", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", "u", "]"}], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"Sin", "[", "u", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"s1", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", "v", "]"}]}], " ", 
        RowBox[{"Sin", "[", "u", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"Cos", "[", "u", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", "u", "]"}], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"Sin", "[", "u", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"s2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", "v", "]"}]}], " ", 
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"s1", " ", 
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"\[Xi]", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.596464906262498*^9, 3.6132221370329485`*^9, 
  3.618750476117169*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Statement.",
  FontVariations->{"Underline"->True}],
 "\n",
 StyleBox["The outer form of the absolute differential coincides with the \
tangent projection of the total differential:",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.5965275477568145`*^9, 3.5965275515490313`*^9}, {
  3.5965276068371935`*^9, 3.5965277272290792`*^9}, {3.5965280286613207`*^9, 
  3.5965280371008034`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pdv", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"pT", "[", 
      RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{
         RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", 
         RowBox[{"sphero", "[", "1", "]"}], "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ")"}], ".", 
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.596461679628431*^9, {3.596461809795059*^9, 3.5964618218694806`*^9}, {
   3.596461958931321*^9, 3.5964619847337666`*^9}, {3.596462552715164*^9, 
   3.596462554743168*^9}, {3.5964636994287786`*^9, 3.5964637060743904`*^9}, {
   3.596463879593495*^9, 3.596463881980299*^9}, 3.5964639847844796`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", "u", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"s2", " ", 
        RowBox[{"Sin", "[", "v", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"s1", " ", 
        RowBox[{"Sin", "[", "v", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"s2", " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"\[Xi]", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}], "+", 
          RowBox[{"s1", " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"\[Xi]", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"Cos", "[", "u", "]"}], " ", 
     RowBox[{"Sin", "[", "v", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"s1", " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"s2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"s1", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", "u", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", "v", "]"}]}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"s2", " ", 
           RowBox[{
            RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}], "+", 
          RowBox[{"s1", " ", 
           RowBox[{
            RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"s2", " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"\[Xi]", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}], "+", 
          RowBox[{"s1", " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"\[Xi]", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"Sin", "[", "u", "]"}], " ", 
     RowBox[{"Sin", "[", "v", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"s1", " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"s2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"s1", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", "v", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"s1", " ", 
       RowBox[{"Cos", "[", "v", "]"}], " ", 
       RowBox[{"Sin", "[", "v", "]"}], " ", 
       RowBox[{
        RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{"s2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{"s1", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5964619939689827`*^9, 3.5964625593139763`*^9, 3.596463708398794*^9, {
   3.5964639658616467`*^9, 3.5964639892460876`*^9}, 3.596465000127863*^9, 
   3.613222172273411*^9, 3.618750549156497*^9}]
}, Closed]],

Cell["Calculate now the inner form of the absolute differential", "Text",
 CellChangeTimes->{{3.596527770333545*^9, 3.596527809484784*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DD", "[", 
    RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
   RowBox[{"vv", "[", "\[Xi]", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5962709980749817`*^9, 3.5962711091643353`*^9}, {
   3.59627160561073*^9, 3.596271620220566*^9}, {3.596370417199809*^9, 
   3.5963704177608414`*^9}, 3.5963713429137573`*^9, 3.596373557527426*^9, 
   3.596437289161309*^9, 3.5964418711857567`*^9, {3.596441937485873*^9, 
   3.596441940169078*^9}, {3.5964626737089767`*^9, 3.596462691680208*^9}, {
   3.5964640216941442`*^9, 3.5964640283085566`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Tan", "[", "v", "]"}]}], " ", 
       RowBox[{
        RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"\[Xi]", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Cos", "[", "v", "]"}], " ", 
       RowBox[{"Sin", "[", "v", "]"}], " ", 
       RowBox[{
        RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"\[Xi]", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Tan", "[", "v", "]"}]}], " ", 
       RowBox[{
        RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"\[Xi]", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"\[Xi]", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.596271625477867*^9, 3.596355967841477*^9, 
  3.596356019727168*^9, 3.596361195033466*^9, 3.596370340497422*^9, 
  3.5963704187088957`*^9, 3.596371001424225*^9, 3.5963721256285257`*^9, 
  3.596372225653247*^9, 3.59637229808539*^9, 3.5963732860038958`*^9, 
  3.5963735584984818`*^9, 3.5964372904405107`*^9, 3.5964418616697397`*^9, 
  3.5964419425714817`*^9, 3.5964626943946133`*^9, 3.5964640348761673`*^9, 
  3.5964650330439205`*^9, 3.6132221806662254`*^9, 3.6187505590781145`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Transpose", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"DD", "[", 
      RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
     RowBox[{"vv", "[", "\[Xi]", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "]"}], ".", 
  RowBox[{"{", 
   RowBox[{"s1", ",", "s2"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5964627858575735`*^9, 3.5964628284456487`*^9}, 
   3.59646406489062*^9, {3.5964641314715376`*^9, 3.5964641589587855`*^9}, {
   3.596465191508999*^9, 3.5964652077018275`*^9}, 3.6148618621711445`*^9, 
   3.6149177936677647`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"s2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Tan", "[", "v", "]"}]}], " ", 
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], ")"}]}], "+", 
    RowBox[{"s1", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Tan", "[", "v", "]"}]}], " ", 
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"s2", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"\[Xi]", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "+", 
    RowBox[{"s1", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.596462833032057*^9, 3.5964640817386503`*^9, 
  3.596464160206788*^9, 3.5964651049444475`*^9, 3.5964652093398304`*^9, 
  3.6132222382303267`*^9, 3.618750570154134*^9}]
}, Closed]],

Cell["\<\
Its outer form is obtained using the differential of the immersion\
\>", "Text",
 CellChangeTimes->{{3.5965278541893415`*^9, 3.5965279038131795`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ".", "%"}], "]"}]], "Input",
 CellChangeTimes->{{3.596462848039283*^9, 3.5964628573992996`*^9}, {
   3.596462905369384*^9, 3.596462918832207*^9}, {3.5964629656010895`*^9, 
   3.5964630031659555`*^9}, 3.5964633152157035`*^9, {3.5964641983800545`*^9, 
   3.5964642202824936`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"Sin", "[", "u", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"s2", " ", 
        RowBox[{"Tan", "[", "v", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"s1", " ", 
        RowBox[{"Tan", "[", "v", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "-", 
       RowBox[{"s2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "-", 
       RowBox[{"s1", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"Cos", "[", "u", "]"}], " ", 
     RowBox[{"Sin", "[", "v", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"s1", " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"s2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"s1", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", "u", "]"}], " ", 
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "s2"}], " ", 
        RowBox[{"Tan", "[", "v", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "-", 
       RowBox[{"s1", " ", 
        RowBox[{"Tan", "[", "v", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"s2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"s1", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"Sin", "[", "u", "]"}], " ", 
     RowBox[{"Sin", "[", "v", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"s1", " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"s2", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{"s1", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", "v", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"s1", " ", 
       RowBox[{"Cos", "[", "v", "]"}], " ", 
       RowBox[{"Sin", "[", "v", "]"}], " ", 
       RowBox[{
        RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{"s2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{"s1", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5964628601761045`*^9, 3.5964629208758106`*^9, 
  3.5964630043827577`*^9, 3.5964642259765034`*^9, 3.596465155488536*^9, 
  3.5964652184190464`*^9, 3.6132222599455647`*^9, 3.618750587220564*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"diff\[Xi]", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.5964630273147984`*^9, 3.596463049482437*^9}}],

Cell["Check the statement:", "Text",
 CellChangeTimes->{{3.596528165477146*^9, 3.5965281754927187`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", " ", 
  RowBox[{"diff\[Xi]", " ", "-", "pdv"}], "]"}]], "Input",
 CellChangeTimes->{{3.596463140479797*^9, 3.5964631670622435`*^9}, {
  3.5964632076067147`*^9, 3.596463212895124*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.5964635431633043`*^9, 3.59646425282415*^9, 
  3.596465167204157*^9, 3.596465227311062*^9, 3.613222276777994*^9, 
  3.6187505975009823`*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["\n",
  FontColor->RGBColor[0, 0, 1]],
 "\[FilledRectangle]",
 StyleBox["\nExample",
  FontColor->RGBColor[0, 0, 1]],
 ". An arbitrary tangent vector field on a general surface\nWe repeat the \
last example for a general surface."
}], "Text",
 CellChangeTimes->{{3.5964656072653294`*^9, 3.59646561355214*^9}, {
  3.596467189139308*^9, 3.5964672158777547`*^9}, {3.5964673572296033`*^9, 
  3.596467407992092*^9}, {3.5965281927807074`*^9, 3.5965281982890224`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{
      RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", "sf", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ")"}], ".", 
  RowBox[{"{", 
   RowBox[{"s1", ",", "s2"}], "}"}]}]], "Input",
 CellChangeTimes->{3.596465746994775*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"s2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"s1", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"s2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"s1", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"s2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"s1", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"s2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"s1", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[Xi]", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.596464906262498*^9, 3.596465810658487*^9, 
  3.6132223900809937`*^9, 3.6187506160182147`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pdv", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"pT", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{
         RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", "sf", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ")"}], ".", 
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.596461679628431*^9, {3.596461809795059*^9, 3.5964618218694806`*^9}, {
   3.596461958931321*^9, 3.5964619847337666`*^9}, {3.596462552715164*^9, 
   3.596462554743168*^9}, {3.5964636994287786`*^9, 3.5964637060743904`*^9}, {
   3.596463879593495*^9, 3.596463881980299*^9}, 3.5964639847844796`*^9, {
   3.5964657542643876`*^9, 3.596465755200389*^9}}],

Cell[BoxData[
 InterpretationBox[
  TagBox[
   FrameBox[GridBox[{
      {
       ItemBox[
        TagBox[
         RowBox[{"{", 
          TemplateBox[{"1"},
           "OutputSizeLimit`Skeleton",
           DisplayFunction->(FrameBox[
             RowBox[{"\" \[CenterEllipsis]\"", #, "\"\[CenterEllipsis] \""}], 
             Background -> GrayLevel[0.75], 
             BaseStyle -> {
              "Deploy", FontColor -> GrayLevel[1], FontSize -> Smaller, 
               ShowStringCharacters -> False}, BaselinePosition -> Baseline, 
             ContentPadding -> False, FrameMargins -> 1, FrameStyle -> 
             GrayLevel[0.75], RoundingRadius -> 7]& )], "}"}],
         Short[#, 5]& ],
        BaseStyle->{Deployed -> False},
        StripOnInput->False]},
      {GridBox[{
         {
          TagBox[
           TooltipBox[
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource[
                "FEStrings", "sizeBriefExplanation"], StandardForm],
               ImageSizeCache->{183., {7., 26.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarCategory",
             StripOnInput->False],
            StyleBox[
             DynamicBox[
              ToBoxes[
               FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
               StandardForm]], DynamicUpdating -> True, StripOnInput -> 
             False]],
           Annotation[#, 
            Style[
             Dynamic[
              FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"]], 
             DynamicUpdating -> True], "Tooltip"]& ], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm],
               ImageSizeCache->{167., {1., 26.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Identity, 217, 7887630465827131025, 5/2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm],
               ImageSizeCache->{189., {1., 26.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm],
               ImageSizeCache->{189., {1., 26.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Identity, 217, 7887630465827131025, 5 2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm],
               ImageSizeCache->{141., {1., 26.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm],
               ImageSizeCache->{141., {1., 26.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Identity, 217, 7887630465827131025, Infinity],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm],
               ImageSizeCache->{247., {1., 27.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm],
               ImageSizeCache->{247., {1., 27.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           ButtonFunction:>FrontEndExecute[{
              FrontEnd`SetOptions[
              FrontEnd`$FrontEnd, 
               FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
              FrontEnd`FrontEndToken["PreferencesDialog"]}],
           Evaluator->None,
           Method->"Preemptive"]}
        },
        AutoDelete->False,
        FrameStyle->GrayLevel[0.85],
        GridBoxDividers->{"Columns" -> {False, {True}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {{2}}}]}
     },
     DefaultBaseStyle->"Column",
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], 
         Offset[1.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Background->RGBColor[0.9657, 0.9753, 0.9802],
    FrameMargins->{{12, 12}, {0, 15}},
    FrameStyle->GrayLevel[0.85],
    RoundingRadius->5,
    StripOnInput->False],
   Deploy,
   DefaultBaseStyle->"Deploy"],
  Out[217]]], "Output",
 CellChangeTimes->{
  3.5964619939689827`*^9, 3.5964625593139763`*^9, 3.596463708398794*^9, {
   3.5964639658616467`*^9, 3.5964639892460876`*^9}, 3.596465000127863*^9, 
   3.596465838644936*^9, 3.613222448908697*^9, 3.6187511898652225`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DD", "[", "sf", "]"}], "[", 
   RowBox[{"vv", "[", "\[Xi]", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5962709980749817`*^9, 3.5962711091643353`*^9}, {
   3.59627160561073*^9, 3.596271620220566*^9}, {3.596370417199809*^9, 
   3.5963704177608414`*^9}, 3.5963713429137573`*^9, 3.596373557527426*^9, 
   3.596437289161309*^9, 3.5964418711857567`*^9, {3.596441937485873*^9, 
   3.596441940169078*^9}, {3.5964626737089767`*^9, 3.596462691680208*^9}, {
   3.5964640216941442`*^9, 3.5964640283085566`*^9}, 3.596465760769599*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"\[Xi]", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], ")"}],
        "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], 
        ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], ")"}],
        "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], 
        ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"\[Xi]", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], ")"}],
        "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], 
        ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], ")"}],
        "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], 
        ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"\[Xi]", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], ")"}],
        "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], 
        ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], ")"}],
        "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], 
        ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"\[Xi]", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "2"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], 
        ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], 
        ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], ")"}],
        "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], 
        ")"}]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.596271625477867*^9, 3.596355967841477*^9, 
  3.596356019727168*^9, 3.596361195033466*^9, 3.596370340497422*^9, 
  3.5963704187088957`*^9, 3.596371001424225*^9, 3.5963721256285257`*^9, 
  3.596372225653247*^9, 3.59637229808539*^9, 3.5963732860038958`*^9, 
  3.5963735584984818`*^9, 3.5964372904405107`*^9, 3.5964418616697397`*^9, 
  3.5964419425714817`*^9, 3.5964626943946133`*^9, 3.5964640348761673`*^9, 
  3.5964650330439205`*^9, 3.5964658604537745`*^9, 3.6132224740559406`*^9, 
  3.618751604825951*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Transpose", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"DD", "[", "sf", "]"}], "[", 
     RowBox[{"vv", "[", "\[Xi]", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "]"}], ".", 
  RowBox[{"{", 
   RowBox[{"s1", ",", "s2"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5964627858575735`*^9, 3.5964628284456487`*^9}, 
   3.59646406489062*^9, {3.5964641314715376`*^9, 3.5964641589587855`*^9}, {
   3.596465191508999*^9, 3.5964652077018275`*^9}, 3.596465764420006*^9, 
   3.6148618623271446`*^9, 3.6149177938081646`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"s2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], 
         ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], 
         ")"}]}]}], ")"}]}], "+", 
    RowBox[{"s1", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], 
         ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], 
         ")"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"s2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], 
         ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], 
         ")"}]}]}], ")"}]}], "+", 
    RowBox[{"s1", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], 
         ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], 
         ")"}]}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.596462833032057*^9, 3.5964640817386503`*^9, 
  3.596464160206788*^9, 3.5964651049444475`*^9, 3.5964652093398304`*^9, 
  3.596465873261397*^9, 3.6132224846171594`*^9, 3.6187516166819725`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"resa", " ", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6187544272921085`*^9, 3.618754491829422*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", "resa", "]"}]], "Input",
 CellChangeTimes->{{3.6187544994890356`*^9, 3.6187545076634502`*^9}}],

Cell[BoxData[
 RowBox[{"{", "2", "}"}]], "Output",
 CellChangeTimes->{3.6187545101906548`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", 
  RowBox[{
   RowBox[{"d", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6187545853515863`*^9, 3.6187546150072384`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", "2"}], "}"}]], "Output",
 CellChangeTimes->{3.6187546162708406`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"d", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ")"}], ".", "resa"}], "]"}]], "Input",
 CellChangeTimes->{{3.596462848039283*^9, 3.5964628573992996`*^9}, {
   3.596462905369384*^9, 3.596462918832207*^9}, {3.5964629656010895`*^9, 
   3.5964630031659555`*^9}, 3.5964633152157035`*^9, {3.5964641983800545`*^9, 
   3.5964642202824936`*^9}, 3.5964657672904105`*^9, {3.6187545440739136`*^9, 
   3.6187545479583206`*^9}, {3.6187546327444696`*^9, 3.618754654662508*^9}}],

Cell[BoxData[
 InterpretationBox[
  TagBox[
   FrameBox[GridBox[{
      {
       ItemBox[
        TagBox[
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              TemplateBox[{"1"},
               "OutputSizeLimit`Skeleton",
               DisplayFunction->(FrameBox[
                 
                 RowBox[{
                  "\" \[CenterEllipsis]\"", #, "\"\[CenterEllipsis] \""}], 
                 Background -> GrayLevel[0.75], 
                 BaseStyle -> {
                  "Deploy", FontColor -> GrayLevel[1], FontSize -> Smaller, 
                   ShowStringCharacters -> False}, BaselinePosition -> 
                 Baseline, ContentPadding -> False, FrameMargins -> 1, 
                 FrameStyle -> GrayLevel[0.75], RoundingRadius -> 7]& )], 
              ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{"(", 
                 TemplateBox[{"1"},
                  "OutputSizeLimit`Skeleton",
                  DisplayFunction->(FrameBox[
                    
                    RowBox[{
                    "\" \[CenterEllipsis]\"", #, "\"\[CenterEllipsis] \""}], 
                    Background -> GrayLevel[0.75], 
                    BaseStyle -> {
                    "Deploy", FontColor -> GrayLevel[1], FontSize -> Smaller, 
                    ShowStringCharacters -> False}, BaselinePosition -> 
                    Baseline, ContentPadding -> False, FrameMargins -> 1, 
                    FrameStyle -> GrayLevel[0.75], RoundingRadius -> 7]& )], 
                 ")"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{"(", 
                 TemplateBox[{"1"},
                  "OutputSizeLimit`Skeleton",
                  DisplayFunction->(FrameBox[
                    
                    RowBox[{
                    "\" \[CenterEllipsis]\"", #, "\"\[CenterEllipsis] \""}], 
                    Background -> GrayLevel[0.75], 
                    BaseStyle -> {
                    "Deploy", FontColor -> GrayLevel[1], FontSize -> Smaller, 
                    ShowStringCharacters -> False}, BaselinePosition -> 
                    Baseline, ContentPadding -> False, FrameMargins -> 1, 
                    FrameStyle -> GrayLevel[0.75], RoundingRadius -> 7]& )], 
                 ")"}]}]}], ")"}]}]}], ",", 
           RowBox[{
            RowBox[{
             TemplateBox[{"1"},
              "OutputSizeLimit`Skeleton",
              DisplayFunction->(FrameBox[
                
                RowBox[{
                 "\" \[CenterEllipsis]\"", #, "\"\[CenterEllipsis] \""}], 
                Background -> GrayLevel[0.75], 
                BaseStyle -> {
                 "Deploy", FontColor -> GrayLevel[1], FontSize -> Smaller, 
                  ShowStringCharacters -> False}, BaselinePosition -> 
                Baseline, ContentPadding -> False, FrameMargins -> 1, 
                FrameStyle -> GrayLevel[0.75], RoundingRadius -> 7]& )], " ", 
             TemplateBox[{"1"},
              "OutputSizeLimit`Skeleton",
              DisplayFunction->(FrameBox[
                
                RowBox[{
                 "\" \[CenterEllipsis]\"", #, "\"\[CenterEllipsis] \""}], 
                Background -> GrayLevel[0.75], 
                BaseStyle -> {
                 "Deploy", FontColor -> GrayLevel[1], FontSize -> Smaller, 
                  ShowStringCharacters -> False}, BaselinePosition -> 
                Baseline, ContentPadding -> False, FrameMargins -> 1, 
                FrameStyle -> GrayLevel[0.75], RoundingRadius -> 7]& )]}], 
            "+", 
            TemplateBox[{"1"},
             "OutputSizeLimit`Skeleton",
             DisplayFunction->(FrameBox[
               
               RowBox[{
                "\" \[CenterEllipsis]\"", #, "\"\[CenterEllipsis] \""}], 
               Background -> GrayLevel[0.75], 
               BaseStyle -> {
                "Deploy", FontColor -> GrayLevel[1], FontSize -> Smaller, 
                 ShowStringCharacters -> False}, BaselinePosition -> Baseline,
                ContentPadding -> False, FrameMargins -> 1, FrameStyle -> 
               GrayLevel[0.75], RoundingRadius -> 7]& )]}], ",", 
           TemplateBox[{"1"},
            "OutputSizeLimit`Skeleton",
            DisplayFunction->(FrameBox[
              RowBox[{"\" \[CenterEllipsis]\"", #, "\"\[CenterEllipsis] \""}],
               Background -> GrayLevel[0.75], 
              BaseStyle -> {
               "Deploy", FontColor -> GrayLevel[1], FontSize -> Smaller, 
                ShowStringCharacters -> False}, BaselinePosition -> Baseline, 
              ContentPadding -> False, FrameMargins -> 1, FrameStyle -> 
              GrayLevel[0.75], RoundingRadius -> 7]& )], ",", 
           TemplateBox[{"1"},
            "OutputSizeLimit`Skeleton",
            DisplayFunction->(FrameBox[
              RowBox[{"\" \[CenterEllipsis]\"", #, "\"\[CenterEllipsis] \""}],
               Background -> GrayLevel[0.75], 
              BaseStyle -> {
               "Deploy", FontColor -> GrayLevel[1], FontSize -> Smaller, 
                ShowStringCharacters -> False}, BaselinePosition -> Baseline, 
              ContentPadding -> False, FrameMargins -> 1, FrameStyle -> 
              GrayLevel[0.75], RoundingRadius -> 7]& )]}], "}"}],
         Short[#, 5]& ],
        BaseStyle->{Deployed -> False},
        StripOnInput->False]},
      {GridBox[{
         {
          TagBox[
           TooltipBox[
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource[
                "FEStrings", "sizeBriefExplanation"], StandardForm],
               ImageSizeCache->{183., {7., 26.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarCategory",
             StripOnInput->False],
            StyleBox[
             DynamicBox[
              ToBoxes[
               FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
               StandardForm]], DynamicUpdating -> True, StripOnInput -> 
             False]],
           Annotation[#, 
            Style[
             Dynamic[
              FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"]], 
             DynamicUpdating -> True], "Tooltip"]& ], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm],
               ImageSizeCache->{167., {1., 26.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm],
               ImageSizeCache->{167., {1., 26.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Identity, 226, 7887630465827131025, 5/2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm],
               ImageSizeCache->{189., {1., 26.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Identity, 226, 7887630465827131025, 5 2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm],
               ImageSizeCache->{141., {1., 26.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Identity, 226, 7887630465827131025, Infinity],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm],
               ImageSizeCache->{247., {1., 27.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm],
               ImageSizeCache->{247., {1., 27.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           ButtonFunction:>FrontEndExecute[{
              FrontEnd`SetOptions[
              FrontEnd`$FrontEnd, 
               FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
              FrontEnd`FrontEndToken["PreferencesDialog"]}],
           Evaluator->None,
           Method->"Preemptive"]}
        },
        AutoDelete->False,
        FrameStyle->GrayLevel[0.85],
        GridBoxDividers->{"Columns" -> {False, {True}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {{2}}}]}
     },
     DefaultBaseStyle->"Column",
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], 
         Offset[1.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Background->RGBColor[0.9657, 0.9753, 0.9802],
    FrameMargins->{{12, 12}, {0, 15}},
    FrameStyle->GrayLevel[0.85],
    RoundingRadius->5,
    StripOnInput->False],
   Deploy,
   DefaultBaseStyle->"Deploy"],
  Out[226]]], "Output",
 CellChangeTimes->{3.5964628601761045`*^9, 3.5964629208758106`*^9, 
  3.5964630043827577`*^9, 3.5964642259765034`*^9, 3.596465155488536*^9, 
  3.5964652184190464`*^9, 3.5964659045394516`*^9, 3.6132225529608793`*^9, 
  3.6187536418307295`*^9, 3.6187543484183702`*^9, 3.618756635460387*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"diff\[Xi]", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.5964630273147984`*^9, 3.596463049482437*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", " ", 
  RowBox[{"diff\[Xi]", " ", "-", "pdv"}], "]"}]], "Input",
 CellChangeTimes->{{3.596463140479797*^9, 3.5964631670622435`*^9}, {
  3.5964632076067147`*^9, 3.596463212895124*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.5964635431633043`*^9, 3.59646425282415*^9, 
  3.596465167204157*^9, 3.596465227311062*^9, 3.5964659247258873`*^9, 
  3.613222572133313*^9, 3.6187567796514406`*^9}]
}, Closed]],

Cell[TextData[{
 "\[FilledRectangle]\n",
 StyleBox["Example",
  FontColor->RGBColor[0, 0, 1]],
 ". For the ",
 StyleBox["Euclidean space",
  FontColor->RGBColor[0, 0, 1]],
 " the absolute differential coincides with the total differential."
}], "Text",
 CellChangeTimes->{{3.5965283114394946`*^9, 3.5965283970773926`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DD", "[", "euclid", "]"}], "[", 
   RowBox[{"vv", "[", "\[Xi]", "]"}], "]"}], "[", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], ",", 
   RowBox[{"x", "[", "2", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5962709980749817`*^9, 3.5962711091643353`*^9}, {
   3.59627160561073*^9, 3.596271620220566*^9}, {3.596370417199809*^9, 
   3.5963704177608414`*^9}, 3.5963713429137573`*^9, 3.596373557527426*^9, 
   3.596437289161309*^9, 3.5964418711857567`*^9, {3.596441937485873*^9, 
   3.596441940169078*^9}, {3.5964420402276535`*^9, 3.596442052458075*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"\[Xi]", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"\[Xi]", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"\[Xi]", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"\[Xi]", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.596442059852488*^9, 3.596442180113099*^9, 
  3.613222579090925*^9, 3.618803252500284*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Transpose", "[", 
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"vv", "[", "\[Xi]", "]"}], "]"}], "[", 
   RowBox[{
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5962709980749817`*^9, 3.5962711091643353`*^9}, {
   3.59627160561073*^9, 3.596271620220566*^9}, {3.596370417199809*^9, 
   3.5963704177608414`*^9}, 3.5963713429137573`*^9, 3.596373557527426*^9, 
   3.596437289161309*^9, 3.5964418711857567`*^9, {3.596441937485873*^9, 
   3.596441940169078*^9}, {3.5964420402276535`*^9, 3.596442052458075*^9}, {
   3.596442085155732*^9, 3.5964421143121834`*^9}, {3.596442167726678*^9, 
   3.5964421751678905`*^9}, 3.6148618624675446`*^9, 3.6149177939485645`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"\[Xi]", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"\[Xi]", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"\[Xi]", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"\[Xi]", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5964421183525906`*^9, 3.5964421834359055`*^9, 
  3.6132225884821415`*^9, 3.6188032576326933`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "\[Equal]", "%%"}]], "Input",
 CellChangeTimes->{{3.596442129756211*^9, 3.596442134295819*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.596442136542223*^9, 3.5964421878819127`*^9, 
  3.6132226054081717`*^9, 3.618803264730706*^9}]
}, Closed]],

Cell["\[FilledRectangle]", "Text",
 CellChangeTimes->{{3.5965284710236225`*^9, 3.596528471031623*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2.3. Absolute Parallel Vector Fields", "Subsubsection",
 CellChangeTimes->{{3.595076945363204*^9, 3.5950769905720835`*^9}, 
   3.5953174793534184`*^9, {3.5953175263051033`*^9, 3.595317587064579*^9}, 
   3.5956008724322104`*^9, {3.5965213907316623`*^9, 3.5965214041788855`*^9}, {
   3.5972984401750546`*^9, 3.59729846072029*^9}, {3.5972984954771514`*^9, 
   3.5972985062723703`*^9}, {3.5973320886172123`*^9, 3.5973320905123205`*^9}, 
   3.5973952636966553`*^9, 3.6132229905260477`*^9, 3.6132797959577127`*^9, 
   3.6171013236210327`*^9, 3.6171717453084965`*^9, {3.6188032063086033`*^9, 
   3.6188032409562645`*^9}, 3.618817261348339*^9}],

Cell["\<\
Considering immersions we often will omit the word \
\[OpenCurlyDoubleQuote]tangent\[CloseCurlyDoubleQuote]; if not emphasized \
explicitly, e.g. the normal vector field e{3][sf][u,v], a vector field on an \
immersion is always meant to be a tangent vector field. Such a vector field \
\>", "Text",
 CellChangeTimes->{{3.5972985733524885`*^9, 3.5972986623350444`*^9}, {
   3.5972987038467174`*^9, 3.597298884011434*^9}, 3.5972989562083607`*^9, 
   3.6132230395101337`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "4"}], ";", " ", 
  RowBox[{"mf", " ", "=", " ", "2"}], ";", " ", 
  RowBox[{
   RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
   RowBox[{
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5956590461387978`*^9, 3.5956590587255173`*^9}, 
   3.595924528295635*^9, {3.597299146747095*^9, 3.5972992078212023`*^9}, {
   3.597300291508306*^9, 3.5973003191827545`*^9}, {3.5973004499577847`*^9, 
   3.5973004648714104`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.597299193905978*^9, 3.597299209131605*^9}, 
   3.597300325438366*^9, 3.5973004658698125`*^9, 3.6132230545173607`*^9, 
   3.617168424203063*^9, 3.6188035237734385`*^9, 3.618823407476803*^9}]
}, Closed]],

Cell[TextData[{
 "is said to be ",
 StyleBox["absolute parallel",
  FontColor->RGBColor[0, 0, 1]],
 " if"
}], "Text",
 CellChangeTimes->{
  3.5972989670035796`*^9, {3.597299243826066*^9, 3.5972992583808913`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DD", "[", 
     RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
    RowBox[{"vv", "[", "\[Xi]", "]"}], "]"}], "[", 
   RowBox[{
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}], ",", 
    RowBox[{"x", "[", "3", "]"}]}], "]"}], "\[Equal]", " ", "0"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5972993146657906`*^9, 3.5972993494538517`*^9}, {
   3.597299402821545*^9, 3.597299430792394*^9}, 3.5972995294157677`*^9, 
   3.5973003459836016`*^9, 3.6132230887126207`*^9}],

Cell["\<\
Here the 0 at the right side stands for the corresponding \
\[OpenCurlyDoubleQuote]null tensor\[CloseCurlyDoubleQuote], appearing as the \
null square matrix of order mf:\
\>", "Text",
 CellChangeTimes->{{3.5973005157118998`*^9, 3.5973006704641714`*^9}, 
   3.5973830346646786`*^9, 3.6171684676959395`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"DD", "[", 
     RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
    RowBox[{"vv", "[", "\[Xi]", "]"}], "]"}], "[", 
   RowBox[{
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5973000987231674`*^9, 3.597300125648815*^9}, 
   3.597300366778438*^9, 3.597300478474634*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "2"}], "}"}]], "Output",
 CellChangeTimes->{3.597300129673622*^9, 3.5973004081341105`*^9, 
  3.5973004803310375`*^9, 3.613223275803749*^9, 3.6171684827499657`*^9, 
  3.618803552601087*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example",
  FontColor->RGBColor[0, 0, 1]],
 ". For the ",
 StyleBox["Euclidean space",
  FontColor->RGBColor[0, 0, 1]],
 " the absolute differential coincides with the total differential. Therefore \
the absolute parallel vector fields are the vector fields with constant \
Cartesian coordinates."
}], "Text",
 CellChangeTimes->{{3.5973040529501977`*^9, 3.597304222288495*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DD", "[", "euclid", "]"}], "[", 
   RowBox[{"vv", "[", "\[Xi]", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.59730430471904*^9, 3.5973043671191497`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"\[Xi]", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"\[Xi]", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"\[Xi]", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"\[Xi]", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.597304368273552*^9, 3.613223307222204*^9, 
  3.6171685022500005`*^9, 3.6188035713961625`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", "1", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", "a1"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", "2", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", "a2"}], ";", 
  RowBox[{
   RowBox[{"vv", "[", "c", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5972997287685175`*^9, 3.597299731280122*^9}, {
  3.597299801963846*^9, 3.5972999486041036`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"a1", ",", "a2"}], "}"}]], "Output",
 CellChangeTimes->{3.5972999513341084`*^9, 3.6132233117930126`*^9, 
  3.6171685207516327`*^9, 3.618803583682865*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DD", "[", "euclid", "]"}], "[", 
   RowBox[{"vv", "[", "c", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5972999616457267`*^9, 3.5972999994601927`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5973000004897947`*^9, 3.6132233215430293`*^9, 
  3.617168525462841*^9, 3.618803587229068*^9}]
}, Closed]],

Cell["\<\
\[FilledRectangle]
Now we consider the general case and ask whether there exist absolute \
parallel vector fields. The system of linear partial differential equations \
of first order to find them is:\
\>", "Text",
 CellChangeTimes->{{3.5973044572093077`*^9, 3.597304457224908*^9}, {
   3.597304491498168*^9, 3.59730455511508*^9}, 3.5973046113063784`*^9, {
   3.5973061652563076`*^9, 3.597306219747204*^9}, {3.597306396932315*^9, 
   3.597306402064724*^9}, 3.617441250860256*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"DD", "[", 
          RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
         RowBox[{"vv", "[", "\[Xi]", "]"}], "]"}], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "j"}], "]"}], "]"}], "\[Equal]", " ", "0"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "mf"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "mf"}], "}"}]}], "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.5973046678096776`*^9, 3.5973048127651324`*^9}, 
   3.597305117074867*^9, {3.5973055552952366`*^9, 3.597305559070443*^9}, 
   3.614861862498745*^9, 3.6148635021396246`*^9, 3.6188037315971227`*^9, 
   3.6188037658630824`*^9}],

Cell["\<\
Using the definition of the absolute differential we may rewrite this system \
as\
\>", "Text",
 CellChangeTimes->{{3.597306271258494*^9, 3.5973063053289537`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
          RowBox[{
           RowBox[{"x", "[", "1", "]"}], ",", 
           RowBox[{"x", "[", "2", "]"}]}], "]"}], "[", 
         RowBox[{"[", "k", "]"}], "]"}], ",", 
        RowBox[{"x", "[", "j", "]"}]}], "]"}], "\[Equal]", " ", 
      RowBox[{"-", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"\[CapitalGamma]", "[", 
             RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", 
            RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
           RowBox[{
            RowBox[{"x", "[", "1", "]"}], ",", 
            RowBox[{"x", "[", "2", "]"}]}], "]"}], "*", 
          RowBox[{
           RowBox[{
            RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
            RowBox[{
             RowBox[{"x", "[", "1", "]"}], ",", 
             RowBox[{"x", "[", "2", "]"}]}], "]"}], "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "mf"}], "}"}]}], "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "mf"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "mf"}], "}"}]}], "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.5973052297070646`*^9, 3.597305240642684*^9}, {
   3.5973052727631407`*^9, 3.5973053555524855`*^9}, {3.5973054039593706`*^9, 
   3.597305412757786*^9}, 3.5973054583410664`*^9, {3.597305510507558*^9, 
   3.5973055337047987`*^9}, {3.59730556880486*^9, 3.597305581394082*^9}, 
   3.597305692388277*^9, 3.6148618625143447`*^9, 3.614863502155225*^9}],

Cell[TextData[{
 "or, in traditional form, as a system of differential equations for the \
coordinates ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Xi]", "k"], "[", "x", "]"}]],
  Evaluatable->False,
  CellChangeTimes->{{3.5973058712737913`*^9, 3.5973059305226955`*^9}, {
   3.597305962658752*^9, 3.5973060124072394`*^9}, {3.5973060436228943`*^9, 
   3.5973060926225805`*^9}}],
 " of the vector field "
}], "Text",
 CellChangeTimes->{{3.5973063359986076`*^9, 3.597306379600684*^9}, {
  3.5973064171031504`*^9, 3.597306458396423*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "j"], 
    RowBox[{
     SuperscriptBox["\[Xi]", "k"], "[", "x", "]"}]}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{"-", " ", 
     SubsuperscriptBox["\[CapitalSigma]", 
      RowBox[{"i", "=", "1"}], "mf"]}], 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalGamma]", "[", 
       RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", 
      RowBox[{"smf", "[", "f", "]"}], "]"}], "[", "x", "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}]}]}], ",", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"k", ",", "j", ",", "1", ",", "..", ",", "mf"}], "}"}], ".", 
   "       ", 
   RowBox[{"(", "1", ")"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5973058712737913`*^9, 3.5973059305226955`*^9}, {
  3.597305962658752*^9, 3.5973060124072394`*^9}, {3.5973060436228943`*^9, 
  3.5973060926225805`*^9}, {3.5973064685364404`*^9, 3.597306522949336*^9}, {
  3.5973134928002768`*^9, 3.597313703088646*^9}}],

Cell[TextData[{
 "Assume that we found a solution (",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Xi]", "k"], "[", "x", "]"}], ",", " ", 
   RowBox[{"k", " ", "=", " ", "1"}], ",", "...", ",", "m"}]],
  Evaluatable->False,
  CellChangeTimes->{{3.5973058712737913`*^9, 3.5973059305226955`*^9}, {
   3.597305962658752*^9, 3.5973060124072394`*^9}, {3.5973060436228943`*^9, 
   3.5973060926225805`*^9}, {3.5973064685364404`*^9, 3.597306522949336*^9}}],
 "f) of this system. Then these functions satisfy also the following \
derivations of the equations:"
}], "Text",
 CellChangeTimes->{{3.5973065921510572`*^9, 3.5973067715513725`*^9}, 
   3.5973137235558815`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[PartialD]", "h"], 
   RowBox[{
    SubscriptBox["\[PartialD]", "j"], 
    RowBox[{
     SuperscriptBox["\[Xi]", "k"], "[", "x", "]"}]}]}], " ", "\[Equal]", " ", 
  RowBox[{"-", " ", 
   RowBox[{
    SubscriptBox["\[PartialD]", "h"], 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["\[CapitalSigma]", 
       RowBox[{"i", "=", "1"}], "mf"], 
      RowBox[{
       RowBox[{
        RowBox[{"\[CapitalGamma]", "[", 
         RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", 
        RowBox[{"smf", "[", "f", "]"}], "]"}], "[", "x", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}]}], ")"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5973058712737913`*^9, 3.5973059305226955`*^9}, {
  3.597305962658752*^9, 3.5973060124072394`*^9}, {3.5973060436228943`*^9, 
  3.5973060926225805`*^9}, {3.5973064685364404`*^9, 3.597306522949336*^9}, {
  3.597313407951728*^9, 3.5973134700554366`*^9}, {3.597313752103932*^9, 
  3.5973138567021155`*^9}, {3.5973138906945753`*^9, 3.5973138933309803`*^9}}],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"\[Equal]", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubsuperscriptBox["\[CapitalSigma]", 
       RowBox[{"i", "=", "1"}], "mf"]}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[PartialD]", "h"], 
       RowBox[{
        RowBox[{
         RowBox[{"\[CapitalGamma]", "[", 
          RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", 
         RowBox[{"smf", "[", "f", "]"}], "]"}], "[", "x", "]"}]}], ")"}], 
     RowBox[{
      SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}]}], "-", " ", 
    RowBox[{
     SubsuperscriptBox["\[CapitalSigma]", 
      RowBox[{"i", "=", "1"}], "mf"], 
     RowBox[{
      RowBox[{
       RowBox[{"\[CapitalGamma]", "[", 
        RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", "x", "]"}], " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "h"], 
      RowBox[{
       SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}]}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.597313955278689*^9, 3.5973139664483085`*^9}, {
   3.5973140016887703`*^9, 3.597314030439621*^9}, {3.5973140614368753`*^9, 
   3.597314082777713*^9}, 3.5973141235249844`*^9, 3.597314177547879*^9, {
   3.5973142101831365`*^9, 3.597314235361581*^9}, {3.597315982396927*^9, 
   3.5973159873392096`*^9}}],

Cell["\<\
for  j ,k ,h= 1,..,mf. Inserting equation (1) with renamed indices  \
\>", "Text",
 CellChangeTimes->{{3.5973139027065964`*^9, 3.597313937791058*^9}, {
   3.5973141374558086`*^9, 3.597314150653432*^9}, 3.5973145527441382`*^9, {
   3.597314592071807*^9, 3.597314653442315*^9}, 3.597314768898118*^9, 
   3.597315097138294*^9, {3.617168754455643*^9, 3.61716875815285*^9}, 
   3.6171688253109674`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[PartialD]", "h"], 
   RowBox[{
    SuperscriptBox["\[Xi]", "l"], "[", "x", "]"}]}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{"-", 
    SubsuperscriptBox["\[CapitalSigma]", 
     RowBox[{"i", "=", "1"}], "mf"]}], 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalGamma]", "[", 
      RowBox[{"l", ",", "i", ",", "h"}], "]"}], "[", 
     RowBox[{"smf", "[", "f", "]"}], "]"}], "[", "x", "]"}], 
   RowBox[{
    SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.597314922839188*^9, 3.597314928517598*^9}, 
   3.5973149670652657`*^9, {3.5973150064397354`*^9, 3.5973150128513465`*^9}, {
   3.597315389576408*^9, 3.5973154186548595`*^9}, 3.5973156631852884`*^9}],

Cell["into the second term we obtain for the this term", "Text",
 CellChangeTimes->{
  3.597315106404711*^9, {3.6171688319097795`*^9, 3.6171688324869804`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", " ", 
    SubsuperscriptBox["\[CapitalSigma]", 
     RowBox[{"l", "=", "1"}], "mf"]}], 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalGamma]", "[", 
      RowBox[{"k", ",", "l", ",", "j"}], "]"}], "[", 
     RowBox[{"smf", "[", "f", "]"}], "]"}], "[", "x", "]"}], " ", 
   RowBox[{
    SubscriptBox["\[PartialD]", "h"], 
    RowBox[{
     SuperscriptBox["\[Xi]", "l"], "[", "x", "]"}]}]}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{"+", 
    SubsuperscriptBox["\[CapitalSigma]", 
     RowBox[{"l", "=", "1"}], "mf"]}], 
   SubsuperscriptBox["\[CapitalSigma]", 
    RowBox[{"i", "=", "1"}], "mf"], 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalGamma]", "[", 
      RowBox[{"k", ",", "l", ",", "j"}], "]"}], "[", 
     RowBox[{"smf", "[", "f", "]"}], "]"}], "[", "x", "]"}], 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalGamma]", "[", 
      RowBox[{"l", ",", "i", ",", "h"}], "]"}], "[", 
     RowBox[{"smf", "[", "f", "]"}], "]"}], "[", "x", "]"}], 
   RowBox[{
    SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5973146918963823`*^9, 3.597314697137992*^9}, {
   3.5973147316608524`*^9, 3.597314749491684*^9}, 3.597314788897353*^9, {
   3.5973148208618093`*^9, 3.597314844620651*^9}, 3.5973150316181793`*^9, {
   3.5973154540045214`*^9, 3.5973154840501738`*^9}, {3.597315550833891*^9, 
   3.597315574561533*^9}, {3.5973156251212215`*^9, 3.597315676570112*^9}}],

Cell[TextData[{
 "Adding the results for the two terms and collecting the terms at ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}]],
  CellChangeTimes->{{3.5973146918963823`*^9, 3.597314697137992*^9}, {
    3.5973147316608524`*^9, 3.597314749491684*^9}, 3.597314788897353*^9, {
    3.5973148208618093`*^9, 3.597314844620651*^9}, 3.5973150316181793`*^9, {
    3.5973154540045214`*^9, 3.5973154840501738`*^9}, {3.597315550833891*^9, 
    3.597315574561533*^9}, {3.5973156251212215`*^9, 3.597315676570112*^9}}],
 " yields"
}], "Text",
 CellChangeTimes->{{3.597315754383049*^9, 3.5973157695774755`*^9}, {
  3.597315915735114*^9, 3.597315949999074*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[PartialD]", "h"], 
   RowBox[{
    SubscriptBox["\[PartialD]", "j"], 
    RowBox[{
     SuperscriptBox["\[Xi]", "k"], "[", "x", "]"}]}]}], " ", "\[Equal]", 
  RowBox[{
   RowBox[{"-", " ", 
    SubsuperscriptBox["\[CapitalSigma]", 
     RowBox[{"i", "=", "1"}], "mf"]}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "h"], 
      RowBox[{
       RowBox[{
        RowBox[{"\[CapitalGamma]", "[", 
         RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", 
        RowBox[{"smf", "[", "f", "]"}], "]"}], "[", "x", "]"}]}], "-", 
     RowBox[{
      SubsuperscriptBox["\[CapitalSigma]", 
       RowBox[{"l", "=", "1"}], "mf"], 
      RowBox[{
       RowBox[{
        RowBox[{"\[CapitalGamma]", "[", 
         RowBox[{"k", ",", "l", ",", "j"}], "]"}], "[", 
        RowBox[{"smf", "[", "f", "]"}], "]"}], "[", "x", "]"}], 
      RowBox[{
       RowBox[{
        RowBox[{"\[CapitalGamma]", "[", 
         RowBox[{"l", ",", "i", ",", "h"}], "]"}], "[", 
        RowBox[{"smf", "[", "f", "]"}], "]"}], "[", "x", "]"}]}]}], ")"}], 
   RowBox[{
    SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5973160039211583`*^9, 3.5973160378971014`*^9}, {
  3.5973160743631873`*^9, 3.5973160847617817`*^9}, {3.597316129803358*^9, 
  3.5973162206325536`*^9}, {3.5973162523453674`*^9, 3.5973163002021046`*^9}, {
  3.5973163303778305`*^9, 3.597316379267627*^9}}],

Cell[TextData[{
 "Permuting h and j and subtracting from the last equation the left side \
becomes zero, and we obtain a system of linear equations for the coordinates ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}]],
  CellChangeTimes->{{3.5973160039211583`*^9, 3.5973160378971014`*^9}, {
   3.5973160743631873`*^9, 3.5973160847617817`*^9}, {3.597316129803358*^9, 
   3.5973162206325536`*^9}, {3.5973162523453674`*^9, 
   3.5973163002021046`*^9}, {3.5973163303778305`*^9, 3.597316379267627*^9}}],
 ":"
}], "Text",
 CellChangeTimes->{{3.5973174735432158`*^9, 3.5973175753910413`*^9}, {
   3.5973176149943066`*^9, 3.597317622350727*^9}, 3.5973279986752806`*^9, 
   3.61744129428474*^9, {3.618804143009654*^9, 3.618804146752868*^9}, 
   3.6188232318984947`*^9}],

Cell[BoxData[
 RowBox[{"0", " ", "\[Equal]", " ", 
  RowBox[{
   SubsuperscriptBox["\[CapitalSigma]", 
    RowBox[{"i", "=", "1"}], "mf"], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "h"], 
      RowBox[{
       RowBox[{
        RowBox[{"\[CapitalGamma]", "[", 
         RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", 
        RowBox[{"smf", "[", "f", "]"}], "]"}], "[", "x", "]"}]}], "-", 
     RowBox[{
      SubscriptBox["\[PartialD]", "j"], 
      RowBox[{
       RowBox[{
        RowBox[{"\[CapitalGamma]", "[", 
         RowBox[{"k", ",", "i", ",", "h"}], "]"}], "[", 
        RowBox[{"smf", "[", "f", "]"}], "]"}], "[", "x", "]"}]}], " ", "-", 
     " ", 
     RowBox[{
      SubsuperscriptBox["\[CapitalSigma]", 
       RowBox[{"l", "=", "1"}], "mf"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"\[CapitalGamma]", "[", 
            RowBox[{"k", ",", "l", ",", "j"}], "]"}], "[", 
           RowBox[{"smf", "[", "f", "]"}], "]"}], "[", "x", "]"}], 
         RowBox[{
          RowBox[{
           RowBox[{"\[CapitalGamma]", "[", 
            RowBox[{"l", ",", "i", ",", "h"}], "]"}], "[", 
           RowBox[{"smf", "[", "f", "]"}], "]"}], "[", "x", "]"}]}], "-", " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"\[CapitalGamma]", "[", 
            RowBox[{"k", ",", "l", ",", "h"}], "]"}], "[", 
           RowBox[{"smf", "[", "f", "]"}], "]"}], "[", "x", "]"}], 
         RowBox[{
          RowBox[{
           RowBox[{"\[CapitalGamma]", "[", 
            RowBox[{"l", ",", "i", ",", "j"}], "]"}], "[", 
           RowBox[{"smf", "[", "f", "]"}], "]"}], "[", "x", "]"}]}]}], 
       ")"}]}]}], ")"}], 
   RowBox[{
    SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5973280116780243`*^9, 3.5973280157692585`*^9}, {
   3.597328075913699*^9, 3.5973280771907716`*^9}, {3.597328179819642*^9, 
   3.5973283575508075`*^9}, 3.597328398054124*^9}],

Cell[TextData[{
 "The coefficients of this linear system are the coordinates of the",
 StyleBox[" curvature tensor",
  FontColor->RGBColor[0, 0, 1]],
 ", defined as"
}], "Text",
 CellChangeTimes->{{3.5973884413774414`*^9, 3.597388472552224*^9}, {
   3.5973885165367403`*^9, 3.5973885696807795`*^9}, 3.5973913039921737`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"R", "[", 
     RowBox[{"k_", ",", "i_", ",", "h_", ",", "j_"}], "]"}], "[", "ff_", 
    "]"}], "[", "x__", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[CapitalGamma]", "[", 
        RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", "ff", "]"}], "[", "x", 
      "]"}], ",", 
     RowBox[{
      RowBox[{"{", "x", "}"}], "[", 
      RowBox[{"[", "h", "]"}], "]"}]}], "]"}], " ", "-", "  ", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[CapitalGamma]", "[", 
        RowBox[{"k", ",", "i", ",", "h"}], "]"}], "[", "ff", "]"}], "[", "x", 
      "]"}], ",", 
     RowBox[{
      RowBox[{"{", "x", "}"}], "[", 
      RowBox[{"[", "j", "]"}], "]"}]}], "]"}], " ", "-", " ", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalGamma]", "[", 
           RowBox[{"k", ",", "l", ",", "j"}], "]"}], "[", "ff", "]"}], "[", 
         "x", "]"}], "*", 
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalGamma]", "[", 
           RowBox[{"l", ",", "i", ",", "h"}], "]"}], "[", "ff", "]"}], "[", 
         "x", "]"}]}], "-", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalGamma]", "[", 
           RowBox[{"k", ",", "l", ",", "h"}], "]"}], "[", "ff", "]"}], "[", 
         "x", "]"}], "*", 
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalGamma]", "[", 
           RowBox[{"l", ",", "i", ",", "j"}], "]"}], "[", "ff", "]"}], "[", 
         "x", "]"}]}]}], ")"}], ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "x", "}"}], "]"}]}], "}"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5973286677245483`*^9, 3.5973289520468106`*^9}, {
   3.597328985941749*^9, 3.5973290042307954`*^9}, 3.5973290495683885`*^9, {
   3.597329079818119*^9, 3.597329268394905*^9}}],

Cell[TextData[{
 StyleBox["Remark",
  FontColor->RGBColor[0, 0, 1]],
 "; This definition coincides with the formula contained in Proposition 7.6, \
p.145 in \n",
 ButtonBox["S. Kobayashi, K. Nomizu I",
  BaseStyle->"Hyperlink",
  ButtonData->"K-N1"],
 ".\n\nThe integrability condition:"
}], "Text",
 CellChangeTimes->{{3.5973885997855015`*^9, 3.5973886194826283`*^9}, {
   3.5973886805381203`*^9, 3.597388763016838*^9}, {3.597388807320372*^9, 
   3.5973888593523483`*^9}, {3.5973892481165843`*^9, 3.597389248119584*^9}, {
   3.5974686722211447`*^9, 3.5974687529512863`*^9}, 3.597471054875729*^9}],

Cell[TextData[{
 StyleBox["Proposition 1",
  FontColor->RGBColor[0, 0, 1]],
 ". An absolute parallel vector field with coordinates ",
 Cell[BoxData[
  SubscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}], ")"}], 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"--", 
     RowBox[{",", "m"}]}]}]]],
  CellChangeTimes->{{3.5973280116780243`*^9, 3.5973280157692585`*^9}, {
    3.597328075913699*^9, 3.5973280771907716`*^9}, {3.597328179819642*^9, 
    3.5973283575508075`*^9}, 3.597328398054124*^9}],
 "  on an immersion (or on a Riemannian manifold)  satisfies the system of \
linear equations"
}], "Text",
 CellChangeTimes->{{3.597468651223508*^9, 3.5974686651231318`*^9}, {
  3.5974687616873016`*^9, 3.5974687668353105`*^9}, {3.59746886327468*^9, 
  3.5974690072941327`*^9}, {3.5974692417313447`*^9, 3.5974692445393496`*^9}, {
  3.59746943280048*^9, 3.59746948360977*^9}, {3.59747449972058*^9, 
  3.5974745004849815`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i", "=", "1"}], "m"], 
    RowBox[{
     RowBox[{"R", "[", 
      RowBox[{"k", ",", "i", ",", "j", ",", "h"}], "]"}], 
     RowBox[{
      SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}]}]}], "\[Equal]", " ", 
   "0"}], ",", "           ", 
  RowBox[{"(", 
   RowBox[{"k", ",", " ", "j", ",", " ", 
    RowBox[{"h", " ", "\[Equal]", " ", "1"}], ",", "...", ",", "m"}], 
   ")"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5974690605526266`*^9, 3.5974691322035522`*^9}, {
  3.597469170220819*^9, 3.5974692133236947`*^9}, {3.5974693011986494`*^9, 
  3.5974693148330727`*^9}}],

Cell["\<\
A necessary condition for the existence of such a non zero vector field is \
that the rank of this system is less the dimension m of the manifold. \
Obviously, the set of all absolute parallel vector fields is a finite \
dimensional vector space under pointwise addition and multiplication with \
real numbers. \[FilledRectangle]\
\>", "Text",
 CellChangeTimes->{{3.597469516494627*^9, 3.597469627332822*^9}, 
   3.597471074609764*^9, {3.597471155386706*^9, 3.5974713113089795`*^9}}],

Cell[TextData[{
 StyleBox["Example",
  FontColor->RGBColor[0, 0, 1]],
 ". The spheres"
}], "Text",
 CellChangeTimes->{{3.5973893009176044`*^9, 3.597389332593416*^9}, 
   3.597391353152985*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"R", "[", 
     RowBox[{"1", ",", "2", ",", "1", ",", "2"}], "]"}], "[", 
    RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5973293281183205`*^9, 3.5973294162033587`*^9}, {
   3.5973295020032663`*^9, 3.597329553733225*^9}, 3.597329586043073*^9, 
   3.5973303088194137`*^9, 3.5973304210758343`*^9, {3.5973306909162683`*^9, 
   3.597330716155712*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "2"], " ", 
        RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "2"], " ", 
        RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "v", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "v", "]"}], "2"]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"4", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "v", "]"}], "4"]}], "+", 
        RowBox[{
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "v", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "u", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "u", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "v", "]"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "u", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "v", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "u", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "v", "]"}], "2"]}]}], ")"}], "2"]}], ")"}]}], 
  "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
         RowBox[{"Cos", "[", "v", "]"}], " ", 
         RowBox[{"Sin", "[", "v", "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"Cos", "[", "v", "]"}], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "u", "]"}], "2"], " ", 
         RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "v", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "v", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "u", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "v", "]"}], "2"]}]}], ")"}], "2"]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"4", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "v", "]"}], "4"]}], "+", 
        RowBox[{
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "v", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "u", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "u", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "v", "]"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "u", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "v", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "u", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "v", "]"}], "2"]}]}], ")"}], "2"]}], ")"}]}], 
  "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "2"], " ", 
        RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "2"], " ", 
        RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "4"]}], "+", 
       RowBox[{
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "4"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "4"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "v", "]"}], "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "v", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "4"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "v", "]"}], "2"]}]}], ")"}]}], ")"}]}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "v", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "v", "]"}], "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "2"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "v", "]"}], "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "v", "]"}], "2"]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "4"]}], "+", 
       RowBox[{
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "4"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "4"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "v", "]"}], "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "v", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "4"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "v", "]"}], "2"]}]}], ")"}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "2"], " ", 
        RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "v", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "v", "]"}], "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "3"], " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "4"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "3"], " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "3"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "2"], " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "3"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "2"], " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "v", "]"}], "3"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "4"], " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "4"], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "v", "]"}], "3"]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "v", "]"}], "3"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "4"], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "u", "]"}], "4"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "v", "]"}], "3"]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "v", "]"}], "4"]}], "+", 
        RowBox[{
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "v", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "u", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "u", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "v", "]"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "u", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "u", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "v", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "v", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "u", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "v", "]"}], "2"]}]}], ")"}], "2"]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{{3.597329407032834*^9, 3.597329419347539*^9}, {
   3.597329534965152*^9, 3.597329557452438*^9}, 3.5973295885002136`*^9, {
   3.5973303100504837`*^9, 3.597330314314728*^9}, 3.597330424575034*^9, {
   3.597330698379695*^9, 3.5973307176687984`*^9}, 3.5973847802410364`*^9, 
   3.613223932981696*^9, 3.61716920219203*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.5973294266249547`*^9, 3.597329435034436*^9}, {
  3.5973307375309343`*^9, 3.597330738969017*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{
            RowBox[{"x", "[", "1", "]"}], ",", 
            RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}], "2"]}], 
            "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
           ")"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{
            RowBox[{"x", "[", "1", "]"}], ",", 
            RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}], "2"]}], 
            "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
           ")"}]}], ")"}]}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{
            RowBox[{"x", "[", "1", "]"}], ",", 
            RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}], "2"]}], 
            "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
           ")"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{
            RowBox[{"x", "[", "1", "]"}], ",", 
            RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}], "2"]}], 
            "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
           ")"}]}], ")"}]}]}], "\[Equal]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{
            RowBox[{"x", "[", "1", "]"}], ",", 
            RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}], "2"]}], 
            "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
           ")"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{
            RowBox[{"x", "[", "1", "]"}], ",", 
            RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}], "2"]}], 
            "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
           ")"}]}], ")"}]}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[Xi]", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{
            RowBox[{"x", "[", "1", "]"}], ",", 
            RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
           ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}], "2"]}], 
            "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
           ")"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{
            RowBox[{"x", "[", "1", "]"}], ",", 
            RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "4", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{
                   RowBox[{"x", "[", "1", "]"}], ",", 
                   RowBox[{"x", "[", "2", "]"}]}], "]"}]}]}], ")"}], "2"]}], 
            "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"x", "[", "1", "]"}], ",", 
                  RowBox[{"x", "[", "2", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
           ")"}]}], ")"}]}]}], "\[Equal]", "0"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5973294498202815`*^9, 3.5973295963656635`*^9, 
  3.5973303186419754`*^9, 3.5973304400359187`*^9, 3.5973307414181566`*^9, 
  3.5973847870814276`*^9, 3.613223938443009*^9, 3.61716920225443*^9, 
  3.618804524298463*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"R", "[", 
     RowBox[{"1", ",", "1", ",", "1", ",", "2"}], "]"}], "[", 
    RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5973307960902843`*^9, 3.597330833107401*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5973308347184935`*^9, 3.613223944813373*^9, 
  3.61716920230123*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"R", "[", 
     RowBox[{"1", ",", "2", ",", "1", ",", "2"}], "]"}], "[", 
    RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5973307960902843`*^9, 3.5973308471002016`*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.597330849185321*^9, 3.6132239485405865`*^9, 
  3.6171692023636303`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"R", "[", 
     RowBox[{"2", ",", "1", ",", "1", ",", "2"}], "]"}], "[", 
    RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5973307960902843`*^9, 3.597330869385476*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  SuperscriptBox[
   RowBox[{"Cos", "[", "v", "]"}], "2"]}]], "Output",
 CellChangeTimes->{3.597330871096574*^9, 3.6132239759391537`*^9, 
  3.617169202847231*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"R", "[", 
     RowBox[{"2", ",", "2", ",", "1", ",", "2"}], "]"}], "[", 
    RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5973307960902843`*^9, 3.597330869385476*^9}, {
  3.5973308994891977`*^9, 3.597330908523715*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5973309141870384`*^9, 3.613223980666424*^9, 
  3.617169202909631*^9}]
}, Closed]],

Cell["\<\
The coefficients  R[k, i, h, j] are anti-symmetric with respect to the last \
two  indices h, j:\
\>", "Text",
 CellChangeTimes->{{3.597389423456613*^9, 3.597389486240204*^9}, {
  3.5973895586333447`*^9, 3.5973896440652313`*^9}, {3.597389952256859*^9, 
  3.597389976545248*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"R", "[", 
        RowBox[{"1", ",", "2", ",", "h", ",", "j"}], "]"}], "[", 
       RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"R", "[", 
        RowBox[{"1", ",", "2", ",", "j", ",", "h"}], "]"}], "[", 
       RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"h", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.597330933249129*^9, 3.5973310703899727`*^9}, 
   3.597384757134715*^9, {3.5973896545658317`*^9, 3.5973896918149624`*^9}, 
   3.6148618625455446`*^9, 3.614863502170825*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.597331074377201*^9, 3.597384759539852*^9, 3.5973847966889772`*^9, {
   3.597389678694212*^9, 3.597389695164154*^9}, 3.6132239962753167`*^9, 
   3.6171692413636985`*^9, 3.6188045458676963`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"R", "[", 
        RowBox[{"h", ",", "j", ",", "1", ",", "2"}], "]"}], "[", 
       RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"h", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.597330933249129*^9, 3.5973310703899727`*^9}, 
   3.597384757134715*^9, {3.5973896545658317`*^9, 3.59738979650895*^9}, {
   3.597389835566184*^9, 3.5973898447817116`*^9}, 3.614861862561145*^9, 
   3.614863502170825*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "1"},
     {
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "v", "]"}], "2"]}], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.597389798017037*^9, 3.5973898507200513`*^9, 
  3.617169241535299*^9, 3.618804561026563*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"R", "[", 
         RowBox[{"1", ",", "i", ",", "1", ",", "2"}], "]"}], "[", 
        RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "]"}], "*", 
     RowBox[{"\[Xi]", "[", "i", "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2"}], "}"}]}], "]"}], "\[Equal]", "0"}]], "Input",
 CellChangeTimes->{{3.5974714282935853`*^9, 3.59747143094559*^9}, {
  3.597471488338091*^9, 3.5974715248577547`*^9}, {3.597471588677467*^9, 
  3.597471677597623*^9}, {3.597471867231556*^9, 3.597471873611967*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Xi]", "[", "2", "]"}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.5974716960056553`*^9, 3.5974717793410015`*^9, 
  3.5974718750939703`*^9, 3.617169241613299*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"R", "[", 
         RowBox[{"2", ",", "i", ",", "1", ",", "2"}], "]"}], "[", 
        RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "]"}], "*", 
     RowBox[{"\[Xi]", "[", "i", "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2"}], "}"}]}], "]"}], "\[Equal]", "0"}]], "Input",
 CellChangeTimes->{{3.5974714282935853`*^9, 3.59747143094559*^9}, {
   3.597471488338091*^9, 3.5974715248577547`*^9}, {3.597471588677467*^9, 
   3.597471677597623*^9}, {3.597471793537027*^9, 3.5974718058298483`*^9}, 
   3.597471891193198*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox[
     RowBox[{"Cos", "[", "v", "]"}], "2"]}], " ", 
   RowBox[{"\[Xi]", "[", "1", "]"}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.597471809776655*^9, 3.597471892987201*^9, 
  3.617169241691299*^9}]
}, Closed]],

Cell["\<\
It follows: The only absolute parallel vector field on the sphere of radius r \
is the zero vector field.\[FilledRectangle]\
\>", "Text",
 CellChangeTimes->{{3.59747198351416*^9, 3.597472062653099*^9}, {
  3.6132240301052513`*^9, 3.6132240472582326`*^9}}],

Cell[TextData[{
 "Often one uses the covariant form of the curvature tensor defined by",
 StyleBox[" lowering the index",
  FontColor->RGBColor[0, 0, 1]],
 " k:"
}], "Text",
 CellChangeTimes->{{3.5973901479610524`*^9, 3.5973902036652384`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"covR", "[", 
     RowBox[{"k_", ",", "i_", ",", "h_", ",", "j_"}], "]"}], "[", "ff_", 
    "]"}], "[", "x__", "]"}], " ", ":=", "  ", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"k", ",", "l"}], "]"}], "[", "ff", "]"}], "[", "x", "]"}], 
     "*", 
     RowBox[{
      RowBox[{
       RowBox[{"R", "[", 
        RowBox[{"l", ",", "i", ",", "h", ",", "j"}], "]"}], "[", "ff", "]"}], 
      "[", "x", "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"l", ",", 
      RowBox[{"Length", "[", 
       RowBox[{"{", "x", "}"}], "]"}]}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5973286677245483`*^9, 3.5973289520468106`*^9}, {
   3.597328985941749*^9, 3.5973290042307954`*^9}, 3.5973290495683885`*^9, {
   3.597329079818119*^9, 3.597329268394905*^9}, {3.5973312970269356`*^9, 
   3.5973313689200478`*^9}, {3.5973314099923973`*^9, 3.597331434333789*^9}, 
   3.6186424048824086`*^9}],

Cell["\<\
The coefficients covR[h, j, 1, 2] are also antisymmetric with respect to the \
first two indices:\
\>", "Text",
 CellChangeTimes->{{3.597391451864631*^9, 3.5973916154249864`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"covR", "[", 
        RowBox[{"h", ",", "j", ",", "1", ",", "2"}], "]"}], "[", 
       RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"h", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.597330933249129*^9, 3.5973310703899727`*^9}, 
   3.597384757134715*^9, {3.5973896545658317`*^9, 3.59738979650895*^9}, {
   3.597389835566184*^9, 3.5973898447817116`*^9}, {3.5973903233100815`*^9, 
   3.597390324033123*^9}, 3.614861862576745*^9, 3.6148635021864247`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "v", "]"}], "2"]}]},
     {
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["r", "2"]}], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "v", "]"}], "2"]}], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.5973903321655884`*^9, 3.613224087568538*^9, 
  3.618809373147684*^9}]
}, Closed]],

Cell["This is true for a general surface:", "Text",
 CellChangeTimes->{{3.597391626064595*^9, 3.59739163960837*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"covR", "[", 
         RowBox[{"h", ",", "j", ",", "1", ",", "2"}], "]"}], "[", "sf", "]"}],
        "[", 
       RowBox[{"u", ",", "v"}], "]"}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"covR", "[", 
         RowBox[{"j", ",", "h", ",", "1", ",", "2"}], "]"}], "[", "sf", "]"}],
        "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"h", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.597330933249129*^9, 3.5973310703899727`*^9}, 
   3.597384757134715*^9, {3.5973896545658317`*^9, 3.59738979650895*^9}, {
   3.597389835566184*^9, 3.5973898447817116`*^9}, {3.5973903233100815`*^9, 
   3.597390324033123*^9}, {3.5973904566657095`*^9, 3.597390511477844*^9}, 
   3.6148618625923448`*^9, 3.6148635022020245`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0"},
     {"0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.597390519324293*^9, 3.6132241150071077`*^9, 
  3.618809400447732*^9}]
}, Closed]],

Cell["also in the n-dimensional Euclidean space:", "Text",
 CellChangeTimes->{{3.597392845137322*^9, 3.597392874136981*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", "5"}], ";", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"covR", "[", 
          RowBox[{"h", ",", "j", ",", "1", ",", "2"}], "]"}], "[", 
         RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"covR", "[", 
          RowBox[{"j", ",", "h", ",", "1", ",", "2"}], "]"}], "[", 
         RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"h", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "//", 
   "MatrixForm"}]}]], "Input",
 CellChangeTimes->{{3.5973905920774546`*^9, 3.5973907262311277`*^9}, {
   3.5973927065273943`*^9, 3.5973927241184*^9}, 3.597392767086858*^9, {
   3.6132779599386983`*^9, 3.6132779817299447`*^9}, 3.6148618626079445`*^9, 
   3.6148635022176247`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0"},
     {"0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.5973926685862236`*^9, 3.5973927475907426`*^9, 
  3.5973928336706657`*^9, 3.6188094663890476`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", "4"}], ";", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"covR", "[", 
          RowBox[{"h", ",", "j", ",", "1", ",", "2"}], "]"}], "[", 
         RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"covR", "[", 
          RowBox[{"j", ",", "h", ",", "1", ",", "2"}], "]"}], "[", 
         RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"h", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "//", 
   "MatrixForm"}]}]], "Input",
 CellChangeTimes->{{3.5973905920774546`*^9, 3.5973907262311277`*^9}, {
   3.5973927065273943`*^9, 3.5973927241184*^9}, 3.597392767086858*^9, {
   3.6132779599386983`*^9, 3.6132779737894907`*^9}, 3.6148618626235447`*^9, 
   3.614863502233225*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0"},
     {"0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6132782558866253`*^9, 3.6188094771062665`*^9}]
}, Closed]],

Cell[TextData[{
 "It follows\n",
 StyleBox["Lemma 1",
  FontColor->RGBColor[0, 0, 1]],
 ". The only essential component of the covariant curvature tensor of a \
surface in the n-dimensional Euclidean space is"
}], "Text",
 CellChangeTimes->{{3.5973929512323904`*^9, 3.597393035953236*^9}, {
  3.5973930819938693`*^9, 3.5973930855450726`*^9}, {3.597474539173049*^9, 
  3.5974745400154505`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"covR", "[", 
    RowBox[{"1", ",", "2", ",", "1", ",", "2"}], " ", "]"}], "[", 
   RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.597393063024784*^9, 3.597393122723199*^9}, {
   3.5973931779243565`*^9, 3.597393198355525*^9}, {3.613224376315054*^9, 
   3.6132243795782404`*^9}, 3.61880996300032*^9}],

Cell[BoxData[
 InterpretationBox[
  TagBox[
   FrameBox[GridBox[{
      {
       ItemBox[
        TagBox[
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{
               TemplateBox[{"1"},
                "OutputSizeLimit`Skeleton",
                DisplayFunction->(FrameBox[
                  
                  RowBox[{
                   "\" \[CenterEllipsis]\"", #, "\"\[CenterEllipsis] \""}], 
                  Background -> GrayLevel[0.75], 
                  BaseStyle -> {
                   "Deploy", FontColor -> GrayLevel[1], FontSize -> Smaller, 
                    ShowStringCharacters -> False}, BaselinePosition -> 
                  Baseline, ContentPadding -> False, FrameMargins -> 1, 
                  FrameStyle -> GrayLevel[0.75], RoundingRadius -> 7]& )], 
               "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{
               TemplateBox[{"1"},
                "OutputSizeLimit`Skeleton",
                DisplayFunction->(FrameBox[
                  
                  RowBox[{
                   "\" \[CenterEllipsis]\"", #, "\"\[CenterEllipsis] \""}], 
                  Background -> GrayLevel[0.75], 
                  BaseStyle -> {
                   "Deploy", FontColor -> GrayLevel[1], FontSize -> Smaller, 
                    ShowStringCharacters -> False}, BaselinePosition -> 
                  Baseline, ContentPadding -> False, FrameMargins -> 1, 
                  FrameStyle -> GrayLevel[0.75], RoundingRadius -> 7]& )], 
               "[", 
               TemplateBox[{"1"},
                "OutputSizeLimit`Skeleton",
                DisplayFunction->(FrameBox[
                  
                  RowBox[{
                   "\" \[CenterEllipsis]\"", #, "\"\[CenterEllipsis] \""}], 
                  Background -> GrayLevel[0.75], 
                  BaseStyle -> {
                   "Deploy", FontColor -> GrayLevel[1], FontSize -> Smaller, 
                    ShowStringCharacters -> False}, BaselinePosition -> 
                  Baseline, ContentPadding -> False, FrameMargins -> 1, 
                  FrameStyle -> GrayLevel[0.75], RoundingRadius -> 7]& )], 
               "]"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "4", "]"}], 
                TagBox[
                 TemplateBox[{"1"},
                  "OutputSizeLimit`Skeleton",
                  DisplayFunction->(FrameBox[
                    
                    RowBox[{
                    "\" \[CenterEllipsis]\"", #, "\"\[CenterEllipsis] \""}], 
                    Background -> GrayLevel[0.75], 
                    BaseStyle -> {
                    "Deploy", FontColor -> GrayLevel[1], FontSize -> Smaller, 
                    ShowStringCharacters -> False}, BaselinePosition -> 
                    Baseline, ContentPadding -> False, FrameMargins -> 1, 
                    FrameStyle -> GrayLevel[0.75], RoundingRadius -> 7]& )],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
           RowBox[{"(", 
            TemplateBox[{"1"},
             "OutputSizeLimit`Skeleton",
             DisplayFunction->(FrameBox[
               
               RowBox[{
                "\" \[CenterEllipsis]\"", #, "\"\[CenterEllipsis] \""}], 
               Background -> GrayLevel[0.75], 
               BaseStyle -> {
                "Deploy", FontColor -> GrayLevel[1], FontSize -> Smaller, 
                 ShowStringCharacters -> False}, BaselinePosition -> Baseline,
                ContentPadding -> False, FrameMargins -> 1, FrameStyle -> 
               GrayLevel[0.75], RoundingRadius -> 7]& )], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            TemplateBox[{"1"},
             "OutputSizeLimit`Skeleton",
             DisplayFunction->(FrameBox[
               
               RowBox[{
                "\" \[CenterEllipsis]\"", #, "\"\[CenterEllipsis] \""}], 
               Background -> GrayLevel[0.75], 
               BaseStyle -> {
                "Deploy", FontColor -> GrayLevel[1], FontSize -> Smaller, 
                 ShowStringCharacters -> False}, BaselinePosition -> Baseline,
                ContentPadding -> False, FrameMargins -> 1, FrameStyle -> 
               GrayLevel[0.75], RoundingRadius -> 7]& )], ")"}], " ", 
           TemplateBox[{"1"},
            "OutputSizeLimit`Skeleton",
            DisplayFunction->(FrameBox[
              RowBox[{"\" \[CenterEllipsis]\"", #, "\"\[CenterEllipsis] \""}],
               Background -> GrayLevel[0.75], 
              BaseStyle -> {
               "Deploy", FontColor -> GrayLevel[1], FontSize -> Smaller, 
                ShowStringCharacters -> False}, BaselinePosition -> Baseline, 
              ContentPadding -> False, FrameMargins -> 1, FrameStyle -> 
              GrayLevel[0.75], RoundingRadius -> 7]& )]}]}],
         Short[#, 5]& ],
        BaseStyle->{Deployed -> False},
        StripOnInput->False]},
      {GridBox[{
         {
          TagBox[
           TooltipBox[
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource[
                "FEStrings", "sizeBriefExplanation"], StandardForm],
               ImageSizeCache->{183., {7., 26.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarCategory",
             StripOnInput->False],
            StyleBox[
             DynamicBox[
              ToBoxes[
               FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
               StandardForm]], DynamicUpdating -> True, StripOnInput -> 
             False]],
           Annotation[#, 
            Style[
             Dynamic[
              FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"]], 
             DynamicUpdating -> True], "Tooltip"]& ], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm],
               ImageSizeCache->{167., {1., 26.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Identity, 157, 7888182868771085226, 5/2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm],
               ImageSizeCache->{189., {1., 26.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm],
               ImageSizeCache->{189., {1., 26.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Identity, 157, 7888182868771085226, 5 2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm],
               ImageSizeCache->{141., {1., 26.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Identity, 157, 7888182868771085226, Infinity],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm],
               ImageSizeCache->{247., {1., 27.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           ButtonFunction:>FrontEndExecute[{
              FrontEnd`SetOptions[
              FrontEnd`$FrontEnd, 
               FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
              FrontEnd`FrontEndToken["PreferencesDialog"]}],
           Evaluator->None,
           Method->"Preemptive"]}
        },
        AutoDelete->False,
        FrameStyle->GrayLevel[0.85],
        GridBoxDividers->{"Columns" -> {False, {True}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {{2}}}]}
     },
     DefaultBaseStyle->"Column",
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], 
         Offset[1.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Background->RGBColor[0.9657, 0.9753, 0.9802],
    FrameMargins->{{12, 12}, {0, 15}},
    FrameStyle->GrayLevel[0.85],
    RoundingRadius->5,
    StripOnInput->False],
   Deploy,
   DefaultBaseStyle->"Deploy"],
  Out[157]]], "Output",
 CellChangeTimes->{3.6188099648567233`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.618809976151143*^9, 3.6188099995979843`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "4", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "-", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"]}]}], ")"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "-", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "-", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "4", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "4", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "4", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "4", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "4", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "4", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "4", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "4", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "4", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "4", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "4", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "4", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "4", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}], "-", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "-", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "-", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
            "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
            "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], "2"], "-", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "4", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "-", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "-", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
            "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], "2"], "-", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "4", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "4", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "-", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "-", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], "2"], "-", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
            "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "-", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "-", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "4", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
            "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], "2"], "-", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "-", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "-", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
            "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "4", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
            "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], "2"], "-", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "4", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "4", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "4", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "4", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "4", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "4", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "4", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "4", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "4", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.6188111584148197`*^9}]
}, Closed]],

Cell["\[FilledRectangle]", "Text",
 CellChangeTimes->{
  3.5973930498580313`*^9, {3.597393216582567*^9, 3.5973932327214904`*^9}}],

Cell[TextData[{
 "We return to dimension 3 and show\n",
 StyleBox["Lemma 2",
  FontColor->RGBColor[0, 0, 1]],
 ". The essential component of the curvature tensor is  related to the \
Gaussian curvature by the following formula"
}], "Text",
 CellChangeTimes->{{3.5973928878887672`*^9, 3.59739289807335*^9}, {
  3.5973932554967933`*^9, 3.597393345600947*^9}, {3.597393403425254*^9, 
  3.5973934148809094`*^9}, {3.597395110080869*^9, 3.5973951371294165`*^9}, {
  3.5974745575810814`*^9, 3.597474558517083*^9}, {3.613278341997551*^9, 
  3.613278344620701*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"covR", "[", 
         RowBox[{"1", ",", "2", ",", "1", ",", "2"}], "]"}], "[", "sf", "]"}],
        "[", 
       RowBox[{"u", ",", "v"}], "]"}], "/", 
      RowBox[{
       RowBox[{
        RowBox[{"dA", "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "^", "2"}]}], "\[Equal]", " ", 
     RowBox[{
      RowBox[{"gauss", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], ",", 
    RowBox[{"TimeConstraint", " ", "-", " ", "Infinity"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5973933860842624`*^9, 3.59739338866141*^9}, {
   3.597393435294077*^9, 3.597393445980688*^9}, 3.5973951782147665`*^9, {
   3.617169970290579*^9, 3.617170009321847*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.596442136542223*^9, 3.5964421878819127`*^9, 
  3.6132226054081717`*^9, 3.618803264730706*^9}]
}, Closed]],

Cell["\[FilledRectangle]", "Text",
 CellChangeTimes->{{3.5973951992669706`*^9, 3.5973951992739706`*^9}}],

Cell["For the spheres we have", "Text",
 CellChangeTimes->{{3.597395222457297*^9, 3.597395232160852*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"covR", "[", 
      RowBox[{"1", ",", "2", ",", "1", ",", "2"}], "]"}], "[", 
     RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "/", 
   RowBox[{
    RowBox[{
     RowBox[{"dA", "[", 
      RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "^", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5973866631347313`*^9, 3.5973866754074335`*^9}, {
   3.597386706204195*^9, 3.597386716163765*^9}, {3.5973867934351845`*^9, 
   3.597386821596795*^9}, 3.597386857140828*^9}],

Cell[BoxData[
 FractionBox["1", 
  SuperscriptBox["r", "2"]]], "Output",
 CellChangeTimes->{3.5973868615120783`*^9, 3.6132793910225515`*^9, 
  3.617171580899808*^9, 3.6188230510161767`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"gauss", "[", 
    RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5973307960902843`*^9, 3.597330833107401*^9}, {
  3.5973319086279173`*^9, 3.597331910039998*^9}}],

Cell[BoxData[
 FractionBox["1", 
  SuperscriptBox["r", "2"]]], "Output",
 CellChangeTimes->{3.5973319171664057`*^9}]
}, Closed]],

Cell["Now we consider a surface in the Euclidean 3-space.", "Text",
 CellChangeTimes->{{3.597472852045686*^9, 3.59747288294934*^9}}],

Cell[CellGroupData[{

Cell[BoxData["dim"], "Input",
 CellChangeTimes->{{3.597472196189334*^9, 3.5974721967977347`*^9}}],

Cell[BoxData["3"], "Output",
 CellChangeTimes->{3.597472197874137*^9, 3.613278386181078*^9, 
  3.613279398716992*^9, 3.617171606093852*^9, 3.6188230663198037`*^9}]
}, Closed]],

Cell["The necessary conditions of proposition 1 are equivalent to", "Text",
 CellChangeTimes->{{3.597473422710288*^9, 3.597473472006375*^9}, {
   3.6132796320523376`*^9, 3.613279636212576*^9}, 3.61744137208919*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"covR", "[", 
          RowBox[{"k", ",", "i", ",", "1", ",", "2"}], "]"}], "[", "sf", 
         "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "/", 
       RowBox[{
        RowBox[{
         RowBox[{"dA", "[", "sf", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "^", "2"}]}], "*", 
      RowBox[{"\[Xi]", "[", "i", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}]}], "]"}], "\[Equal]", " ", "0"}], ",", 
  " "}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.597472280023881*^9, 3.597472380628458*^9}, 
   3.5974726087632585`*^9, {3.597472647560527*^9, 3.5974726521625347`*^9}, {
   3.597472682535788*^9, 3.597472689774201*^9}, 3.597473403163454*^9, {
   3.5974734804459896`*^9, 3.5974735828601694`*^9}, 3.597473647475483*^9}],

Cell["\<\
k = 1, 2. Denote the Gaussian curvature of the surface by K[u,v].. Using the \
last two Lemmas the system of equations reduce to\
\>", "Text",
 CellChangeTimes->{{3.5974736605327063`*^9, 3.5974738002309513`*^9}, {
  3.6174414045010443`*^9, 3.6174414118204627`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"K", "[", 
     RowBox[{"u", ",", "v"}], "]"}], 
    RowBox[{"\[Xi]", "[", "2", "]"}]}], "\[Equal]", " ", "0"}], ",", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"K", "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], 
    RowBox[{"\[Xi]", "[", "1", "]"}]}], "\[Equal]", " ", "0"}], 
  ","}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5974738192629848`*^9, 3.597473901693529*^9}, 
   3.5974739416139994`*^9}],

Cell["and it follows:", "Text",
 CellChangeTimes->{{3.597474011439722*^9, 3.597474151465568*^9}, 
   3.6132794864470096`*^9}],

Cell[TextData[{
 StyleBox["Proposition 2",
  FontColor->RGBColor[0, 0, 1]],
 ". On a surface in the Euclidean 3-space exist non zero absolute parallel \
vector fields if and only if the surface is developable: K[u,v]\[Congruent] 0."
}], "Text",
 CellChangeTimes->{{3.597474011439722*^9, 3.597474151465568*^9}, {
  3.6132794864470096`*^9, 3.613279503380978*^9}, {3.613279693620859*^9, 
  3.613279711748896*^9}}],

Cell[TextData[{
 StyleBox["Proof.",
  FontColor->RGBColor[0, 0, 1]],
 " By Proposition 1 the condition is necessary. On the other hand, if it is \
satisfied, the surface is developable, thus locally isometric to an open \
region of the Euclidean plane; the images of constant vector fields are \
absolute parallel. \[FilledRectangle]"
}], "Text",
 CellChangeTimes->{{3.597474207298066*^9, 3.597474365856745*^9}, {
  3.597474445042484*^9, 3.5974744834809513`*^9}, {3.6174414537648616`*^9, 
  3.617441462916385*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2.4. Parallel Displacement Along Curves", "Subsubsection",
 CellChangeTimes->{{3.595076945363204*^9, 3.5950769905720835`*^9}, 
   3.5953174793534184`*^9, {3.5953175263051033`*^9, 3.595317587064579*^9}, 
   3.5956008724322104`*^9, {3.5965213907316623`*^9, 3.5965214041788855`*^9}, {
   3.5972984401750546`*^9, 3.59729846072029*^9}, {3.5972984954771514`*^9, 
   3.5972985062723703`*^9}, {3.5973320886172123`*^9, 3.5973320905123205`*^9}, 
   3.5973952636966553`*^9, {3.597729800827932*^9, 3.59772986233884*^9}, 
   3.6132798036301517`*^9, 3.6132847212454233`*^9, 3.6171717529369097`*^9, 
   3.61717393361794*^9, 3.6188231691395845`*^9, 3.6188258241208286`*^9}],

Cell["\<\
In the last subsection we have seen that non zero absolute parallel vector \
fields exist only under certain integrability conditions expressed in \
restrictions to the curvature tensor. In dimension 1 these conditions don\
\[CloseCurlyQuote]t appear, Thus it is possible to define parallel vector \
functions along curves on the immersion (or Riemannian manifold). Aiming at \
this we first define the absolute derivative of a tangent vector function \
along a curve. For simplicity we consider curves on surfaces; the definition \
can be adapted with little change to immersions of arbitrary, not too high,  \
finite dimensions.
Let\
\>", "Text",
 CellChangeTimes->{{3.597735507062501*^9, 3.5977355331009903`*^9}, {
  3.5977355962056*^9, 3.597735634300779*^9}, {3.5977358303089895`*^9, 
  3.5977359083014507`*^9}, {3.59773603346961*^9, 3.597736128501045*^9}, {
  3.5977362858940477`*^9, 3.5977364648612843`*^9}, {3.5978475796643496`*^9, 
  3.5978476595364895`*^9}, {3.6132799006777024`*^9, 3.613279904972948*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Gamma]", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"u", "[", "t", "]"}], ",", 
    RowBox[{"v", "[", "t", "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5977318613653574`*^9, 3.597731863773495*^9}, {
   3.597736504464549*^9, 3.597736506142645*^9}, 3.597736550155163*^9}],

Cell["be a smooth curve on the surface", "Text",
 CellChangeTimes->{{3.5977365672371397`*^9, 3.5977365831090474`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sf", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.597738312935988*^9, 3.597738318614313*^9}, {
  3.597817180004476*^9, 3.5978171949961023`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "1", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "2", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"f", "[", "3", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5978172162433395`*^9, 3.613280572794145*^9, 
  3.61717233943554*^9}]
}, Closed]],

Cell[TextData[{
 "We define the ",
 StyleBox["absolute derivative ",
  FontColor->RGBColor[0, 0, 1]],
 "DD1 of a vector function vw[t] given along a curve cc[t] of the surface:"
}], "Text",
 CellChangeTimes->{{3.5978243856151857`*^9, 3.597824491751256*^9}, 
   3.597847681766528*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DD1", "::", "usage"}], " ", "=", " ", 
   "\"\<DD1[ff,cc,vw][t] is the absolute derivative of a vector function \
vw[t] ={vw1[t],vw2[t]} defined along a curve with local coordinatess \
cc[t]={u[t],v[t]} of a surface ff[u,v] in the n-dimensional Euclidean space \
or a curve cc[t] in a 2-dimensional Riemannian space ff with local \
coordinates {u,v}. For higher dimensional immersions or Riemannian spaces \
create a new definition entering the coordinate presentations of cc[t] into \
the definition at \[CapitalGamma]\[CapitalGamma].\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.597847771310686*^9, 3.597847775990694*^9}, 
   3.597847810685155*^9, 3.597931689455128*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"cu", ",", "vw", ",", "ff", ",", "DD1", ",", "u", ",", "v"}], 
   "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"DD1", "[", 
     RowBox[{"ff_", ",", "cu_", ",", "vw_"}], "]"}], "[", "t_", "]"}], " ", ":=",
    " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "mf", ",", "\[CapitalGamma]\[CapitalGamma]", ",", "s", ",", " ", "i", 
       ",", "j", ",", "k", ",", "u", ",", "v"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"mf", " ", "=", " ", 
       RowBox[{"Length", "[", 
        RowBox[{"cu", "[", "t", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"\[CapitalGamma]\[CapitalGamma]", "[", 
         RowBox[{"i_", ",", "j_", ",", "k_"}], "]"}], "[", "s_", "]"}], ":=", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalGamma]", "[", 
           RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", "ff", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"u", "\[Rule]", " ", 
           RowBox[{
            RowBox[{"cu", "[", "s", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ",", 
          RowBox[{"v", "->", 
           RowBox[{
            RowBox[{"cu", "[", "s", "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"vw", "[", "t", "]"}], ",", "t"}], "]"}], " ", "+", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"\[CapitalGamma]\[CapitalGamma]", "[", 
              RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", "t", "]"}], "*", 
            RowBox[{
             RowBox[{"vw", "[", "t", "]"}], "[", 
             RowBox[{"[", "j", "]"}], "]"}], "*", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"cu", "[", "t", "]"}], "[", 
               RowBox[{"[", "k", "]"}], "]"}], ",", "t"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "mf"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "mf"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "mf"}], "}"}]}], "]"}]}]}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5977308704166784`*^9, 3.5977309528863955`*^9}, {
   3.597730990067522*^9, 3.5977310541191854`*^9}, {3.5977311130875587`*^9, 
   3.597731171388893*^9}, {3.5977312247049427`*^9, 3.5977316965809326`*^9}, {
   3.59773244291862*^9, 3.597732454294271*^9}, {3.597736676816407*^9, 
   3.5977366770154185`*^9}, 3.5977367373498697`*^9, {3.597736775207035*^9, 
   3.5977367948381577`*^9}, {3.597737366309844*^9, 3.5977374333886805`*^9}, 
   3.597737547742221*^9, {3.5977375864544353`*^9, 3.5977376044944677`*^9}, {
   3.5977379689903154`*^9, 3.5977380117027583`*^9}, {3.59773809127831*^9, 
   3.597738147071501*^9}, {3.597738183294573*^9, 3.5977381938471766`*^9}, {
   3.5977382930868526`*^9, 3.5977383028234096`*^9}, 3.597738333062139*^9, {
   3.59773856211124*^9, 3.597738563639327*^9}, {3.597738626846943*^9, 
   3.5977386858323164`*^9}, 3.597738739184368*^9, {3.597739039800562*^9, 
   3.597739048865081*^9}, 3.597739103775221*^9, {3.5977391974875813`*^9, 
   3.5977392430151854`*^9}, {3.5977416344573517`*^9, 
   3.5977416832421427`*^9}, {3.5977417284907303`*^9, 
   3.5977417331069946`*^9}, {3.597741787564109*^9, 3.5977418090453377`*^9}, 
   3.597742020350424*^9, {3.597742051182187*^9, 3.597742090246422*^9}, {
   3.5977421906331635`*^9, 3.5977421946103907`*^9}, 3.5977614023163023`*^9, 
   3.5977615118596945`*^9, {3.5977615457429543`*^9, 3.5977615563509727`*^9}, {
   3.5977616156154766`*^9, 3.597761781989769*^9}, {3.5977618977731724`*^9, 
   3.5977621593544316`*^9}, {3.5977621933936915`*^9, 3.597762210085721*^9}, {
   3.597762336165142*^9, 3.597762354136374*^9}, {3.597762521743068*^9, 
   3.597762586623582*^9}, 3.5977626705829296`*^9, 3.5977627045441895`*^9, 
   3.597762821466395*^9, {3.597762857174857*^9, 3.597762946890615*^9}, {
   3.597763103031289*^9, 3.597763144230962*^9}, 3.597763243556336*^9, {
   3.5977633091544514`*^9, 3.5977633095132523`*^9}, {3.597763359058939*^9, 
   3.5977635199420214`*^9}, {3.5977637409788094`*^9, 
   3.5977637779820747`*^9}, {3.597763824875757*^9, 3.5977638472461967`*^9}, {
   3.597763964184002*^9, 3.597764059406569*^9}, {3.5977641187802734`*^9, 
   3.5977641373911057`*^9}, 3.597764334138652*^9, 3.597764391999153*^9, {
   3.5977644843825154`*^9, 3.597764518515375*^9}, 3.5977645786378813`*^9, 
   3.5978143208626547`*^9, 3.597814672690072*^9, {3.5978148033247013`*^9, 
   3.5978148102199135`*^9}, {3.597814841201568*^9, 3.597814950963361*^9}, 
   3.5978151119556437`*^9, {3.5978152110938177`*^9, 3.5978152698903213`*^9}, {
   3.5978163646534443`*^9, 3.597816390253089*^9}, 3.5978164326227636`*^9, {
   3.5978164684872265`*^9, 3.5978164759596395`*^9}, {3.5978165061924925`*^9, 
   3.5978166048782663`*^9}, {3.597816688494413*^9, 3.5978167555121307`*^9}, 
   3.5978209977279816`*^9, {3.5978242016266623`*^9, 3.5978242030427427`*^9}, {
   3.5979349765451393`*^9, 3.5979350763378468`*^9}, {3.597935149242017*^9, 
   3.597935178465688*^9}, {3.61328063931495*^9, 3.613280694826125*^9}, {
   3.614861862639145*^9, 3.614861862654745*^9}, 3.614863502248825*^9, 
   3.614917793995365*^9}],

Cell[TextData[{
 StyleBox["Examples",
  FontColor->RGBColor[0, 0, 1]],
 " :"
}], "Text",
 CellChangeTimes->{{3.5978245313115187`*^9, 3.597824542687169*^9}, 
   3.5979097307832108`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "DD1"}]], "Input",
 CellChangeTimes->{{3.597847849061222*^9, 3.5978478509956255`*^9}}],

Cell[BoxData[
 StyleBox["\<\"DD1[ff,cc,vw][t] is the absolute derivative of a vector \
function vw[t] ={vw1[t],vw2[t]} defined along a curve with local coordinatess \
cc[t]={u[t],v[t]} of a surface ff[u,v] in the n-dimensional Euclidean space \
or a curve cc[t] in a 2-dimensional Riemannian space ff with local \
coordinates {u,v}. For higher dimensional immersions or Riemannian spaces \
create a new definition entering the coordinate presentations of cc[t] into \
the definition at \[CapitalGamma]\[CapitalGamma].\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.6132820262692795`*^9},
 CellTags->"Info3613289226-3398588"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"\[Xi]", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s1", "[", "t", "]"}], ",", 
     RowBox[{"s2", "[", "t", "]"}]}], "}"}]}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"DD1", "[", 
     RowBox[{
      RowBox[{"sphero", "[", "r", "]"}], ",", "\[Gamma]", ",", "\[Xi]"}], 
     "]"}], "[", "t", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5977317427255716`*^9, 3.5977317893472385`*^9}, {
   3.597731905438878*^9, 3.5977319912867885`*^9}, 3.5977320952957373`*^9, {
   3.5977321323428564`*^9, 3.5977321664548073`*^9}, {3.597732200380748*^9, 
   3.59773233731258*^9}, {3.5977323700014496`*^9, 3.5977323837522364`*^9}, 
   3.5977615795014133`*^9, {3.5977631817334275`*^9, 3.597763189424241*^9}, 
   3.597814977779808*^9, {3.5978168288634596`*^9, 3.5978168347290697`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["s1", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "-", 
    RowBox[{
     RowBox[{"Tan", "[", 
      RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"s2", "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["u", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        RowBox[{"s1", "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["v", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["s2", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
     RowBox[{"s1", "[", "t", "]"}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["u", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5978205451867867`*^9, 3.5978210041551933`*^9, 
  3.597935090505657*^9, 3.597935188378255*^9, 3.6132820761111298`*^9, 
  3.6171724986338196`*^9, 3.6188236131943645`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"\[Xi]", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s1", "[", "t", "]"}], ",", 
     RowBox[{"s2", "[", "t", "]"}]}], "}"}]}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"DD1", "[", 
     RowBox[{"sf", ",", "\[Gamma]", ",", "\[Xi]"}], "]"}], "[", "t", "]"}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.5977317427255716`*^9, 3.5977317893472385`*^9}, {
   3.597731905438878*^9, 3.5977319912867885`*^9}, 3.5977320952957373`*^9, {
   3.5977321323428564`*^9, 3.5977321664548073`*^9}, {3.597732200380748*^9, 
   3.59773233731258*^9}, {3.5977323700014496`*^9, 3.5977323837522364`*^9}, 
   3.5977615795014133`*^9, {3.5977631817334275`*^9, 3.597763189424241*^9}, 
   3.597814977779808*^9, {3.5978153495284615`*^9, 3.5978153652688885`*^9}, 
   3.5978169355832467`*^9, 3.5978170612258673`*^9, 3.5978210148724117`*^9, 
   3.5978210893157425`*^9, 3.6171725651055365`*^9, 3.6171730417487736`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"\[Xi]", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s1", "[", "t", "]"}], ",", 
     RowBox[{"s2", "[", "t", "]"}]}], "}"}]}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"DD1", "[", 
     RowBox[{"euclid", ",", "\[Gamma]", ",", "\[Xi]"}], "]"}], "[", "t", 
    "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5977317427255716`*^9, 3.5977317893472385`*^9}, {
   3.597731905438878*^9, 3.5977319912867885`*^9}, 3.5977320952957373`*^9, {
   3.5977321323428564`*^9, 3.5977321664548073`*^9}, {3.597732200380748*^9, 
   3.59773233731258*^9}, {3.5977323700014496`*^9, 3.5977323837522364`*^9}, 
   3.5977615795014133`*^9, {3.5977631817334275`*^9, 3.597763189424241*^9}, 
   3.597814977779808*^9, {3.5978153495284615`*^9, 3.5978153652688885`*^9}, {
   3.5978154316938057`*^9, 3.5978154432534256`*^9}, 3.597816947501668*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["s1", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], ",", 
   RowBox[{
    SuperscriptBox["s2", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.597815449493437*^9, 3.5978169800589247`*^9, 
  3.5978211268650084`*^9, 3.597935205143214*^9, 3.6132822715293074`*^9, 
  3.6171725406446934`*^9, 3.6188236486532264`*^9}]
}, Closed]],

Cell["\<\
In the Euclidean plane with Cartesian coordinates the absolute derivative \
coincides with the standard derivative.
\[FilledRectangle]\
\>", "Text",
 CellChangeTimes->{{3.597824599532421*^9, 3.5978246899355917`*^9}}],

Cell[TextData[{
 StyleBox["Definition",
  FontColor->RGBColor[0, 0, 1]],
 ". The vector vw[t] is said to be",
 StyleBox[" parallel displaced",
  FontColor->RGBColor[0, 0, 1]],
 " along the curve \[Gamma][t], if its absolute derivative is zero: DD1[ff,\
\[Gamma],vw][t] \[Congruent] 0."
}], "Text",
 CellChangeTimes->{{3.597824912191304*^9, 3.5978250944877305`*^9}, {
  3.5978251325839095`*^9, 3.5978253947519045`*^9}, {3.613282563068982*^9, 
  3.6132825845572114`*^9}}],

Cell[TextData[{
 StyleBox["Proposition",
  FontColor->RGBColor[0, 0, 1]],
 ". Let \[Gamma][t0, t1] be the arc of the curve \[Gamma] between \
\[Gamma][t0], \[Gamma][t1]. Then for any tangent vector \n\[Xi]  \[Element] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", 
    RowBox[{"ff", "[", 
     RowBox[{"\[Gamma]", "[", "t0", "]"}], "]"}]], TraditionalForm]]],
 " with coordinates {s1, s2} there exists a uniquely defined vector function \
\[Xi][t], parallel displaced along \[Gamma][t], with  \[Xi][t0] == \[Xi].  \
The map"
}], "Text",
 CellChangeTimes->{{3.5978254006782436`*^9, 3.597825430982977*^9}, {
   3.5978254653109407`*^9, 3.5978256295313334`*^9}, {3.597827809533633*^9, 
   3.5978281050655365`*^9}, {3.597828142609684*^9, 3.5978284203455696`*^9}, 
   3.597848111297683*^9, {3.5978482153030653`*^9, 3.5978482290622897`*^9}, {
   3.597909746031082*^9, 3.597909760134889*^9}, {3.6132826504209785`*^9, 
   3.6132826656368484`*^9}, 3.617441476236147*^9}],

Cell[TextData[{
 "\[Gamma][t0, t1]:   \[Xi]  \[Element] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", 
    RowBox[{"ff", "[", 
     RowBox[{"\[Gamma]", "[", "t0", "]"}], "]"}]], TraditionalForm]]],
 "  \[RightTeeArrow] \[Xi][t1] \[Element] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", 
    RowBox[{"ff", "[", 
     RowBox[{"\[Gamma]", "[", "t1", "]"}], "]"}]], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.5978254006782436`*^9, 3.597825430982977*^9}, {
  3.5978254653109407`*^9, 3.5978256295313334`*^9}, {3.597827809533633*^9, 
  3.5978281050655365`*^9}, {3.597828142609684*^9, 3.5978284203455696`*^9}, {
  3.597848111297683*^9, 3.5978481458205433`*^9}, {3.5978491789011583`*^9, 
  3.597849186342371*^9}}],

Cell["\<\
is an isometry of Euclidean vector spaces, depending on the curve \[Gamma].\
\>", "Text",
 CellChangeTimes->{{3.5978254006782436`*^9, 3.597825430982977*^9}, {
  3.5978254653109407`*^9, 3.5978256295313334`*^9}, {3.597827809533633*^9, 
  3.5978281050655365`*^9}, {3.597828142609684*^9, 3.5978284203455696`*^9}, {
  3.597848111297683*^9, 3.59784815508696*^9}}],

Cell[TextData[{
 StyleBox["Proof",
  FontColor->RGBColor[0, 0, 1]],
 ". Analyzing the definition or looking at the examples we see that the \
equation "
}], "Text",
 CellChangeTimes->{{3.5978482749731703`*^9, 3.5978482821647835`*^9}, {
  3.597848335095676*^9, 3.5978483637373266`*^9}, {3.5978484072926025`*^9, 
  3.597848416122218*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DD1", "[", 
    RowBox[{"ff", ",", "\[Gamma]", ",", "\[Xi]"}], "]"}], "[", "t", "]"}], 
  " ", "\[Equal]", "  ", "0"}]], "Input",
 CellChangeTimes->{{3.597848445029069*^9, 3.5978484840291376`*^9}}],

Cell["\<\
Is a homogeneous system of ordinary linear differential equations of first \
order for the coordinates s[i][t] of \[Xi][t}. Therefore the solutions are \
uniquely defined by the initial conditions. Since\
\>", "Text",
 CellChangeTimes->{{3.597848493233154*^9, 3.597848651495432*^9}, {
  3.597848698732315*^9, 3.597848732397174*^9}, {3.618824036118561*^9, 
  3.618824043533985*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DD1", "[", 
    RowBox[{"\[Xi]", "+", "\[Eta]"}], "]"}], "\[Equal]", 
   RowBox[{
    RowBox[{"DD1", "[", "\[Xi]", "]"}], "+", 
    RowBox[{
     RowBox[{"DD1", "[", "\[Eta]", "]"}], " ", "and", " ", 
     RowBox[{"DD1", "[", 
      RowBox[{"a", " ", "\[Xi]"}], "]"}]}]}], "\[Equal]", 
   RowBox[{"a", " ", 
    RowBox[{"DD1", "[", "\[Xi]", "]"}], " ", "for", " ", "a"}]}], 
  "\[Element]", "\[DoubleStruckCapitalR]"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.597848753691211*^9, 3.5978489453375483`*^9}, {
  3.5978490043368516`*^9, 3.59784902028008*^9}}],

Cell[TextData[{
 "the map \[Gamma][t0, t1] defined above is a linear isomorphism. First we \
calculate an  \n\n",
 StyleBox["Example",
  FontColor->RGBColor[0, 0, 1]],
 ". With"
}], "Text",
 CellChangeTimes->{{3.5978492407084665`*^9, 3.597849289240152*^9}, {
  3.597903092985965*^9, 3.597903098055974*^9}, {3.5979033790748672`*^9, 
  3.5979034785094423`*^9}, {3.597904186319085*^9, 3.597904199182821*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"\[Xi]", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s1", "[", "t", "]"}], ",", 
     RowBox[{"s2", "[", "t", "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.5978494117939672`*^9, 3.597849528528972*^9, {3.5978500298826528`*^9, 
   3.597850040709072*^9}, 3.5978504492269893`*^9}],

Cell["we calculate", "Text",
 CellChangeTimes->{3.5979035304575334`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"DD1", "[", 
    RowBox[{
     RowBox[{"sphero", "[", "r", "]"}], ",", "\[Gamma]", ",", "\[Xi]"}], 
    "]"}], "[", "t", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.597850718343062*^9, 3.59785075125912*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["s1", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "-", 
    RowBox[{
     RowBox[{"Tan", "[", 
      RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"s2", "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["u", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        RowBox[{"s1", "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["v", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["s2", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
     RowBox[{"s1", "[", "t", "]"}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["u", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.597850752928323*^9, 3.613284515520656*^9, 
  3.6171732131306744`*^9, 3.6188240940718756`*^9}]
}, Closed]],

Cell["Using this result we define the ReplaceAll rules", "Text",
 CellChangeTimes->{{3.597903833581666*^9, 3.597903862207716*^9}, {
  3.597905596638751*^9, 3.597905628239558*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"srule", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["s1", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", " ", 
      RowBox[{
       RowBox[{"Tan", "[", 
        RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"s2", "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["u", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{
          RowBox[{"s1", "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["v", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["s2", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Cos", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}]}], " ", 
       RowBox[{"s1", "[", "t", "]"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5979020770185804`*^9, 3.5979021128986435`*^9}, 
   3.597903879695347*^9}],

Cell["\<\
Now we get the stated result: The scalar square of a parallel transferred \
vector is constant:\
\>", "Text",
 CellChangeTimes->{{3.5979039146550083`*^9, 3.5979039775387187`*^9}, {
  3.59790405527059*^9, 3.5979040727025867`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"rgT", "[", 
            RowBox[{"i", ",", "j"}], "]"}], "[", 
           RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
          RowBox[{
           RowBox[{"u", "[", "t", "]"}], ",", 
           RowBox[{"v", "[", "t", "]"}]}], "]"}], "*", 
         RowBox[{
          RowBox[{"\[Xi]", "[", "t", "]"}], "[", 
          RowBox[{"[", "i", "]"}], "]"}], "*", 
         RowBox[{
          RowBox[{"\[Xi]", "[", "t", "]"}], "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], ",", "t"}], "]"}], "/.",
    "srule"}], "]"}]], "Input",
 CellChangeTimes->{{3.5978492968529654`*^9, 3.5978493357282333`*^9}, {
   3.597849486299698*^9, 3.597849492602109*^9}, {3.5978495746270533`*^9, 
   3.59784975499457*^9}, {3.597850066464717*^9, 3.5978502509506407`*^9}, {
   3.597850302680332*^9, 3.5978503672956457`*^9}, {3.59785081986804*^9, 
   3.5978508536888995`*^9}, {3.5978510248056*^9, 3.597851033338815*^9}, {
   3.597903144169655*^9, 3.5979031639816895`*^9}, {3.597903226725*^9, 
   3.5979032503122416`*^9}, 3.6186424061704826`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5979031652140923`*^9, 3.5979032544462485`*^9, 
  3.613284577063176*^9, 3.617173281427594*^9, 3.6188241468548946`*^9}]
}, Closed]],

Cell["\<\
\[FilledRectangle]
Now we consider the general case:\
\>", "Text",
 CellChangeTimes->{{3.597904117111127*^9, 3.597904155526324*^9}}],

Cell["\<\
We define the ReplaceAll rules, analyzing the definition of DD1 and using \
DD1[sf,\[Gamma],\[Xi]][t]== 0:\
\>", "Text",
 CellChangeTimes->{{3.597903833581666*^9, 3.597903862207716*^9}, 
   3.597904443750809*^9, {3.5979055757595563`*^9, 3.597905583951025*^9}, {
   3.597905758415004*^9, 3.5979057915028963`*^9}, {3.5979058467290554`*^9, 
   3.5979058754867*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sfrule", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["s1", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", " ", 
      RowBox[{"-", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"\[CapitalGamma]", "[", 
             RowBox[{"1", ",", "j", ",", "k"}], "]"}], "[", "sf", "]"}], "[", 
           RowBox[{
            RowBox[{"u", "[", "t", "]"}], ",", 
            RowBox[{"v", "[", "t", "]"}]}], "]"}], "*", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "t", "]"}], "[", 
           RowBox[{"[", "j", "]"}], "]"}], "*", 
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"\[Gamma]", "[", "t", "]"}], "[", 
             RowBox[{"[", "k", "]"}], "]"}], ",", "t"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "2"}], "}"}]}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["s2", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"\[CapitalGamma]", "[", 
             RowBox[{"2", ",", "j", ",", "k"}], "]"}], "[", "sf", "]"}], "[", 
           RowBox[{
            RowBox[{"u", "[", "t", "]"}], ",", 
            RowBox[{"v", "[", "t", "]"}]}], "]"}], "*", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "t", "]"}], "[", 
           RowBox[{"[", "j", "]"}], "]"}], "*", 
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"\[Gamma]", "[", "t", "]"}], "[", 
             RowBox[{"[", "k", "]"}], "]"}], ",", "t"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "2"}], "}"}]}], "]"}]}]}]}], "}"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5979020770185804`*^9, 3.5979021128986435`*^9}, 
   3.597903879695347*^9, {3.5979044647410097`*^9, 3.5979044846771502`*^9}, {
   3.597904582635753*^9, 3.5979045980226336`*^9}, {3.59790463887097*^9, 
   3.597904648016493*^9}, {3.5979047164724083`*^9, 3.5979047360215263`*^9}, {
   3.597904808967698*^9, 3.5979048424166117`*^9}, {3.5979049171378856`*^9, 
   3.5979049321717453`*^9}, {3.597904975754238*^9, 3.597904989111002*^9}, {
   3.597905042449053*^9, 3.5979051553695116`*^9}, {3.5979052400023527`*^9, 
   3.597905252930092*^9}, {3.597905312498499*^9, 3.597905345545389*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["s1", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"s2", "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["v", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          RowBox[{"s2", "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["u", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          RowBox[{"s1", "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["v", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          RowBox[{"s1", "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["u", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}], "2"]}], 
           "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"u", "[", "t", "]"}], ",", 
                 RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"u", "[", "t", "]"}], ",", 
                 RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"u", "[", "t", "]"}], ",", 
                 RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"u", "[", "t", "]"}], ",", 
                 RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"u", "[", "t", "]"}], ",", 
                 RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"u", "[", "t", "]"}], ",", 
                 RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"u", "[", "t", "]"}], ",", 
                 RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"u", "[", "t", "]"}], ",", 
                 RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
          ")"}]}], ")"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["s2", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"s2", "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["v", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          RowBox[{"s2", "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["u", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          RowBox[{"s1", "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["v", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          RowBox[{"s1", "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["u", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "4", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"u", "[", "t", "]"}], ",", 
                  RowBox[{"v", "[", "t", "]"}]}], "]"}]}]}], ")"}], "2"]}], 
           "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"u", "[", "t", "]"}], ",", 
                 RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"u", "[", "t", "]"}], ",", 
                 RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"u", "[", "t", "]"}], ",", 
                 RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"u", "[", "t", "]"}], ",", 
                 RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"u", "[", "t", "]"}], ",", 
                 RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"u", "[", "t", "]"}], ",", 
                 RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"u", "[", "t", "]"}], ",", 
                 RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "4", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"u", "[", "t", "]"}], ",", 
                 RowBox[{"v", "[", "t", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
          ")"}]}], ")"}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.613284620301649*^9, 3.6171733383208942`*^9, 
  3.6188253762552123`*^9}]
}, Closed]],

Cell[TextData[{
 "Now we get the stated result: ",
 StyleBox["The scalar square of a parallel transferred vector is constant:",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.5979039146550083`*^9, 3.5979039775387187`*^9}, {
  3.59790405527059*^9, 3.5979040727025867`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"rgT", "[", 
            RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
          RowBox[{
           RowBox[{"u", "[", "t", "]"}], ",", 
           RowBox[{"v", "[", "t", "]"}]}], "]"}], "*", 
         RowBox[{
          RowBox[{"\[Xi]", "[", "t", "]"}], "[", 
          RowBox[{"[", "i", "]"}], "]"}], "*", 
         RowBox[{
          RowBox[{"\[Xi]", "[", "t", "]"}], "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], ",", "t"}], "]"}], "/.",
    "sfrule"}], "]"}]], "Input",
 CellChangeTimes->{{3.5978492968529654`*^9, 3.5978493357282333`*^9}, {
   3.597849486299698*^9, 3.597849492602109*^9}, {3.5978495746270533`*^9, 
   3.59784975499457*^9}, {3.597850066464717*^9, 3.5978502509506407`*^9}, {
   3.597850302680332*^9, 3.5978503672956457`*^9}, {3.59785081986804*^9, 
   3.5978508536888995`*^9}, {3.5978510248056*^9, 3.597851033338815*^9}, {
   3.597903144169655*^9, 3.5979031639816895`*^9}, {3.597903226725*^9, 
   3.5979032503122416`*^9}, {3.5979053910299907`*^9, 3.59790541252422*^9}, 
   3.618642567905733*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5979054200316496`*^9, 3.6132846206336684`*^9, 
  3.6171738799694457`*^9, 3.618825754282834*^9}]
}, Closed]],

Cell["\<\
Thus the map \[Gamma][t0, t1] defined above is an isometry, and therefore an \
isomorphy of Euclidean vector spaces.  All the algebraic properties defined \
using the first fundamental form are preserved, Remember the general identity \
for bilinear symmetric biforms, e.g. the Dot product:\
\>", "Text",
 CellChangeTimes->{{3.5979059861190276`*^9, 3.5979059936304574`*^9}, {
  3.597906034262781*^9, 3.597906090607004*^9}, {3.5979061594869437`*^9, 
  3.59790626781514*^9}, {3.5979064815023623`*^9, 3.5979064905028768`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"vec", "[", "x", "]"}], ".", 
    RowBox[{"vec", "[", "y", "]"}]}], " ", "\[Equal]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"vec", "[", "x", "]"}], "+", 
         RowBox[{"vec", "[", "y", "]"}]}], ")"}], ".", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"vec", "[", "x", "]"}], "+", 
         RowBox[{"vec", "[", "y", "]"}]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"vec", "[", "x", "]"}], "-", 
         RowBox[{"vec", "[", "y", "]"}]}], ")"}], ".", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"vec", "[", "x", "]"}], "-", 
         RowBox[{"vec", "[", "y", "]"}]}], ")"}]}]}], ")"}], "/", "4"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.59790628075488*^9, 3.5979063105735855`*^9}, {
  3.5979063426894226`*^9, 3.5979064649564157`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.5979064470153894`*^9, 3.597906465960473*^9}, 
   3.613284662322053*^9}]
}, Closed]],

Cell[TextData[{
 "We conclude\n",
 StyleBox["Corollary.",
  FontColor->RGBColor[0, 0, 1]],
 " Norm, angle and determinant, i.e. the area of the parallelogram spanned by \
the vectors, are invariant under parallel displacements.\n\[FilledRectangle]\n\
This result is a special case of ",
 ButtonBox["Ricci\[CloseCurlyQuote]s Lemma, ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://cms.math.ca/cjm/v16/cjm1964v16.0549-0560.pdf"], None},
  ButtonNote->"http://cms.math.ca/cjm/v16/cjm1964v16.0549-0560.pdf"],
 "see also ",
 ButtonBox["[B-R] ",
  BaseStyle->"Hyperlink",
  ButtonData->"B-R"],
 ", p.154, ",
 ButtonBox["[Kr]",
  BaseStyle->"Hyperlink",
  ButtonData->"Kr"],
 ", p.272."
}], "Text",
 CellChangeTimes->{{3.5979066223184166`*^9, 3.5979066356951814`*^9}, {
   3.597906685975057*^9, 3.597906703455057*^9}, {3.5979067557670493`*^9, 
   3.5979067829666047`*^9}, {3.597906823142903*^9, 3.5979068499664373`*^9}, {
   3.5979068902067385`*^9, 3.5979069783297787`*^9}, {3.5979070671908617`*^9, 
   3.5979070893111267`*^9}, {3.5979075377137737`*^9, 3.597907537721774*^9}, 
   3.59790761091096*^9, {3.597909307655009*^9, 3.59790933652666*^9}, {
   3.597909476022639*^9, 3.597909526774542*^9}, {3.5979100570878735`*^9, 
   3.5979100798951783`*^9}, {3.5979101121640244`*^9, 3.597910112173024*^9}, {
   3.597929142213434*^9, 3.597929152244008*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2.5. Geodesics as Auto-Parallel Curves", "Subsubsection",
 CellChangeTimes->{{3.595076945363204*^9, 3.5950769905720835`*^9}, 
   3.5953174793534184`*^9, {3.5953175263051033`*^9, 3.595317587064579*^9}, 
   3.5956008724322104`*^9, {3.5965213907316623`*^9, 3.5965214041788855`*^9}, {
   3.5972984401750546`*^9, 3.59729846072029*^9}, {3.5972984954771514`*^9, 
   3.5972985062723703`*^9}, {3.5973320886172123`*^9, 3.5973320905123205`*^9}, 
   3.5973952636966553`*^9, {3.597729800827932*^9, 3.59772986233884*^9}, {
   3.597910399537461*^9, 3.597910436118553*^9}, {3.5979116271266747`*^9, 
   3.5979116482228813`*^9}, 3.613284728941863*^9, 3.6132874017987423`*^9, 
   3.6171739408407526`*^9, 3.617195815150076*^9, 3.6188258784059334`*^9, 
   3.618830173270586*^9}],

Cell[TextData[{
 StyleBox["Definition",
  FontColor->RGBColor[0, 0, 1]],
 ". A curve \[Gamma][t] on an immersion or in a Riemannian manifold is said \
to be ",
 StyleBox["auto-parallel",
  FontColor->RGBColor[0, 0, 1]],
 " or more commonly, a ",
 StyleBox["geodesic",
  FontColor->RGBColor[0, 0, 1]],
 ", if its tangent vector is parallel displaced along the curve.\n\n",
 StyleBox["Remark",
  FontColor->RGBColor[0, 0, 1]],
 ". Since the norm  of the   tangent vector depends on the parameter \
representation, the condition of the definition fixes also the type of the \
parameter t of the curve. In Riemannian geometry it is natural to assume that \
t is the arc length of the curve; remember that this is equivalent to the \
fact that the tangent vector has constant norm 1."
}], "Text",
 CellChangeTimes->{{3.597911657441409*^9, 3.597911675247427*^9}, {
   3.597911706147195*^9, 3.59791200922353*^9}, {3.597928848436631*^9, 
   3.5979288904770355`*^9}, {3.597928956356804*^9, 3.5979290724444437`*^9}, {
   3.6132847851830797`*^9, 3.6132847983008304`*^9}, 3.6132848615014453`*^9, 
   3.617441713205701*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Gamma]", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"u", "[", "t", "]"}], ",", 
    RowBox[{"v", "[", "t", "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5977318613653574`*^9, 3.597731863773495*^9}, {
   3.597736504464549*^9, 3.597736506142645*^9}, 3.597736550155163*^9}],

Cell[TextData[{
 StyleBox["Example",
  FontColor->RGBColor[0, 0, 1]],
 ". The Euclidean plane"
}], "Text",
 CellChangeTimes->{{3.5979304075968103`*^9, 3.5979304432118473`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"DD1", "[", 
    RowBox[{"euclid", ",", "\[Gamma]", ",", 
     SuperscriptBox["\[Gamma]", "\[Prime]",
      MultilineFunction->None]}], "]"}], "[", "t", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5979292059430795`*^9, 3.5979292420701456`*^9}, {
  3.597929272325876*^9, 3.597929298654382*^9}, {3.597929354638584*^9, 
  3.597929492815488*^9}, {3.597930356399882*^9, 3.597930367070492*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["u", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], ",", 
   RowBox[{
    SuperscriptBox["v", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5979294949286084`*^9, 3.597929864356738*^9, 
  3.5979299715758715`*^9, 3.5979303688455935`*^9, 3.598010301801846*^9, 
  3.6132848870989094`*^9, 3.618826434792757*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"%", "\[Equal]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.597929563264517*^9, 3.597929568107794*^9}, {
   3.5979298729262285`*^9, 3.597929965494523*^9}, 3.614861862717145*^9, 
   3.6148646599580584`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"C", "[", "1", "]"}], "+", 
      RowBox[{"t", " ", 
       RowBox[{"C", "[", "2", "]"}]}]}]}], ",", 
    RowBox[{
     RowBox[{"v", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"C", "[", "3", "]"}], "+", 
      RowBox[{"t", " ", 
       RowBox[{"C", "[", "4", "]"}]}]}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.597930386691614*^9, 3.6132848921051955`*^9, 
  3.6188264390460005`*^9}]
}, Closed]],

Cell["\<\
In the Euclidean plane the lines with natural affine parameter t are the \
geodesics. \[FilledRectangle]\
\>", "Text",
 CellChangeTimes->{{3.5979305555082703`*^9, 3.5979306105174165`*^9}, {
  3.597930665788578*^9, 3.597930668044707*^9}}],

Cell[TextData[{
 StyleBox["Example",
  FontColor->RGBColor[0, 0, 1]],
 ". The spheres."
}], "Text",
 CellChangeTimes->{{3.597930716372471*^9, 3.597930736028595*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"DD1", "[", 
    RowBox[{
     RowBox[{"sphero", "[", "r", "]"}], ",", "\[Gamma]", ",", 
     SuperscriptBox["\[Gamma]", "\[Prime]",
      MultilineFunction->None]}], "]"}], "[", "t", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5979292059430795`*^9, 3.5979292420701456`*^9}, {
  3.597929272325876*^9, 3.597929298654382*^9}, {3.597929354638584*^9, 
  3.597929492815488*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"Tan", "[", 
      RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["u", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["v", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["u", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{
     SuperscriptBox["v", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5979294949286084`*^9, 3.597929864356738*^9, 3.5979299715758715`*^9, {
   3.5989404773448277`*^9, 3.598940493684763*^9}, 3.6132849107062597`*^9, 
   3.617174040010127*^9, 3.6188265100440617`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"%", "\[Equal]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.597929563264517*^9, 3.597929568107794*^9}, {
   3.5979298729262285`*^9, 3.597929965494523*^9}, 3.614861862732745*^9, 
   3.614864659973658*^9}],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"Tan", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["u", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["v", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], "}"}], "\[Equal]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Output",
 CellChangeTimes->{3.617174048730542*^9, 3.6188265169884586`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"Tan", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["u", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["v", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], "}"}], "\[Equal]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.614861862732745*^9, 3.6148618627483454`*^9}, 
   3.6148646599892583`*^9}],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"Tan", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["u", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["v", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], "}"}], "\[Equal]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Output",
 CellChangeTimes->{3.617174090663416*^9, 3.6188265461501265`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"Tan", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["u", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["v", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", " ", "0"}], 
     ",", 
     RowBox[{
      RowBox[{"u", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"v", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], " ", "\[Equal]", " ", 
      "1"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["v", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.597930017299486*^9, 3.597930054979642*^9}, {
   3.5979301545233355`*^9, 3.5979301739564466`*^9}, 3.5989403761220384`*^9, 
   3.614861862763945*^9, 3.6148646599892583`*^9}],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"Tan", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["u", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["v", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"u", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"v", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["v", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Output",
 CellChangeTimes->{3.617174096154626*^9, 3.6188265557606764`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"Tan", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["u", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["v", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"u", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"v", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["v", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.614861862763945*^9, 3.6148618627795453`*^9}, 
   3.6148646600048585`*^9}],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"Tan", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["u", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["v", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"u", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"v", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["v", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Output",
 CellChangeTimes->{3.617174109711049*^9, 3.618826563063094*^9}]
}, Closed]],

Cell["DSolve cannot solve these equations, NDSolve can:", "Text",
 CellChangeTimes->{{3.598011256632723*^9, 3.5980113116540194`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NDSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"Tan", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["u", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["v", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", " ", "0"}], 
     ",", 
     RowBox[{
      RowBox[{"u", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"v", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], " ", "\[Equal]", " ", 
      "1"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["v", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.597930017299486*^9, 3.597930054979642*^9}, {
   3.5979301545233355`*^9, 3.5979302685808587`*^9}, 3.5980094359535255`*^9, {
   3.5980104154168453`*^9, 3.598010433559677*^9}, 3.598010516442623*^9, {
   3.598011025658717*^9, 3.598011037826739*^9}, {3.59894033925093*^9, 
   3.5989403593400784`*^9}, 3.6148618627795453`*^9, 3.614864660020458*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       TemplateBox[{RowBox[{
           StyleBox[
            TagBox["InterpolatingFunction", "SummaryHead"], 
            "NonInterpretableSummary"], 
           StyleBox["[", "NonInterpretableSummary"], 
           DynamicModuleBox[{Typeset`open$$ = False}, 
            PanelBox[
             PaneSelectorBox[{False -> GridBox[{{
                   PaneBox[
                    ButtonBox[
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                    ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                    None, Evaluator -> Automatic, Method -> "Preemptive"], 
                    Alignment -> {Center, Center}, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                   GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJxFxWtIk1EYAOBvK+9zbu6Sydh04UwzlEQwtO1ITcFtYi4h9qMikpaWTmyF
TQvSogjdMFlJTqS0DavZ0nVXMbxklmJKgReSnJpsrNJlG5Oo6PR+Px6e2KNl
BUVUgiAy//j7xBzfn2WsEhPz/36y53C1Jf255Cm+lk7TeQtG4ZjuRZFYPgWf
mYpRP3g3DesfSeuE7nlYbWfJRbsdcImmcm/vm2U4cfHt0n2ZEy5lPytTGtyw
u7olajj8O7w0lnQS2Vfhlxs2TtEBD2wOrJmZ5K7DH07FNPJf/ISjbCEnui76
4PSJletrWX74Vp7RFrGwAbMs9U6t+Rd8vDOBNisi0P/HvLaU22EUuO1hGiF2
kfNuCEaGe6hwS0ly63rrJri/tF3D0m6GlfNcV4A0AP4qsWpNokB459g9r9BH
rs0dv6qYC4KT0tyDip5guDavwp9RHwIvF/Il45pQ2HktuSp/Xxh8KCXzmJlF
g2delarueMh9NUG5dUPhsDB1KIfXQYddDKe46XwE3GC99E0bz4C7Ry2vy28y
UBdeRFwwOShMFIc37VD7Ek4zUTNeTh9PVDmYSIaXB68cpCgikQy/38eh63oj
UT7+LmW9r2Q7C7XjU/uVOTkGFtqFHzw7UPiDYKMBvEX65Uh0MRuZ8YZQwRpz
lo30+M7LkyqPjIOseEF0Rp+im7yxzd5RGceFVdkLDTw9edynbdQGyhY4Pvlz
9mo5+Tmj8srINPl7z8f8CnkUrCuO4DY+Jm9q5iv8sVvh3wt5owg=
                    "]]}}}, {
                    DisplayFunction -> Identity, AspectRatio -> 1, 
                    Axes -> {False, False}, AxesLabel -> {None, None}, 
                    AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                    Frame -> {{True, True}, {True, True}}, 
                    FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                    Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                    FrameTicks -> {{None, None}, {None, None}}, 
                    GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                    Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 6.283185307179586}, {0., 
                    6.28318520068492}}, PlotRangeClipping -> True, 
                    PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                   GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "6.283185307179586`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                    AutoDelete -> False, 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> {
                    ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
                 GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False,
                  GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaselinePosition -> {1, 1}], True -> GridBox[{{
                   PaneBox[
                    ButtonBox[
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                    ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                    None, Evaluator -> Automatic, Method -> "Preemptive"], 
                    Alignment -> {Center, Center}, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                   GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJxFxWtIk1EYAOBvK+9zbu6Sydh04UwzlEQwtO1ITcFtYi4h9qMikpaWTmyF
TQvSogjdMFlJTqS0DavZ0nVXMbxklmJKgReSnJpsrNJlG5Oo6PR+Px6e2KNl
BUVUgiAy//j7xBzfn2WsEhPz/36y53C1Jf255Cm+lk7TeQtG4ZjuRZFYPgWf
mYpRP3g3DesfSeuE7nlYbWfJRbsdcImmcm/vm2U4cfHt0n2ZEy5lPytTGtyw
u7olajj8O7w0lnQS2Vfhlxs2TtEBD2wOrJmZ5K7DH07FNPJf/ISjbCEnui76
4PSJletrWX74Vp7RFrGwAbMs9U6t+Rd8vDOBNisi0P/HvLaU22EUuO1hGiF2
kfNuCEaGe6hwS0ly63rrJri/tF3D0m6GlfNcV4A0AP4qsWpNokB459g9r9BH
rs0dv6qYC4KT0tyDip5guDavwp9RHwIvF/Il45pQ2HktuSp/Xxh8KCXzmJlF
g2delarueMh9NUG5dUPhsDB1KIfXQYddDKe46XwE3GC99E0bz4C7Ry2vy28y
UBdeRFwwOShMFIc37VD7Ek4zUTNeTh9PVDmYSIaXB68cpCgikQy/38eh63oj
UT7+LmW9r2Q7C7XjU/uVOTkGFtqFHzw7UPiDYKMBvEX65Uh0MRuZ8YZQwRpz
lo30+M7LkyqPjIOseEF0Rp+im7yxzd5RGceFVdkLDTw9edynbdQGyhY4Pvlz
9mo5+Tmj8srINPl7z8f8CnkUrCuO4DY+Jm9q5iv8sVvh3wt5owg=
                    "]]}}}, {
                    DisplayFunction -> Identity, AspectRatio -> 1, 
                    Axes -> {False, False}, AxesLabel -> {None, None}, 
                    AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                    Frame -> {{True, True}, {True, True}}, 
                    FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                    Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                    FrameTicks -> {{None, None}, {None, None}}, 
                    GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                    Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 6.283185307179586}, {0., 
                    6.28318520068492}}, PlotRangeClipping -> True, 
                    PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                   GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "6.283185307179586`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                    AutoDelete -> False, 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> {
                    ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
                 GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False,
                  GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaselinePosition -> {1, 1}]}, 
              Dynamic[Typeset`open$$], ImageSize -> Automatic], 
             BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
           StyleBox["]", "NonInterpretableSummary"]}]},
        "CopyTag",
        DisplayFunction->(#& ),
        InterpretationFunction->(
         "InterpolatingFunction[{{0., 6.28319}}, <>]"& )],
       False,
       Editable->False,
       SelectWithContents->True,
       Selectable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"v", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       TemplateBox[{RowBox[{
           StyleBox[
            TagBox["InterpolatingFunction", "SummaryHead"], 
            "NonInterpretableSummary"], 
           StyleBox["[", "NonInterpretableSummary"], 
           DynamicModuleBox[{Typeset`open$$ = False}, 
            PanelBox[
             PaneSelectorBox[{False -> GridBox[{{
                   PaneBox[
                    ButtonBox[
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                    ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                    None, Evaluator -> Automatic, Method -> "Preemptive"], 
                    Alignment -> {Center, Center}, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                   GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJxTTMoPSmViYGCwAWIQffGu3G/HaTV2DFCw3Ta+doXFLnsYv4WPp/pH0Gk4
X2HLUzU7nytwftkVhYy1Z2/B+f2bXHuV3j2A8zO2CvuoWT6B87MLKp33nXoO
52s9PfNsjfdrOD9PZGd+8IR3cP672nkSx3k/wvnPzunkOGz9BOfv+bNRNDXk
C5y/nK359mWxb3D+tVyFKXK7v8P5Ehs5Mzc3/YTzLS6+nPzZ8TecP9tv2kb+
x3/gfOEVfa9Ll/+D89PXa/LcUWNwgPHP/dhosIibEc5fssGUwe4Ngi8zXf7k
8b1McP68bP0F3xYww/kH85YWCJeywPnBD8TesLqywvnv7deVzlVjg/N1z63+
ofQTwS/1Ot/pe5cdztcxfXfUdy8HnN/iV/zbuo8Tzn8eKmd/voALzn/drV8T
4MIN58cZ2KQsF+aB828fyota/AXB/9nM7tV7jBfOVzI+5i6zig/OfyPw2m5m
HT+cP2ld64dSdQE4f8vpFScKZyD4agz1c58wCsL5c7UzfmqWIPg+fOe1op4g
8TleRjD6CsH5gT9F+ar3IfjLGL/tz9YQhvONDwa7u09A8I+WHwn9yiAC569w
fZEglYXgT+CS/yx4B8Ff33Y56ou3KJwvL2W933cLgj9lydZVlapicH6U2+NJ
Mv0Ivup9ZaZJjOJwvrr+I7dPhQh+1bTgjpO3EPxLX64HFPtIwPnVWfxiU7Yh
+DPnyPn+VpSE8wFw2tLe
                    "]]}}}, {
                    DisplayFunction -> Identity, AspectRatio -> 1, 
                    Axes -> {False, False}, AxesLabel -> {None, None}, 
                    AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                    Frame -> {{True, True}, {True, True}}, 
                    FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                    Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                    FrameTicks -> {{None, None}, {None, None}}, 
                    GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                    Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 6.283185307179586}, {-1., 1.}}, 
                    PlotRangeClipping -> True, PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                   GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "6.283185307179586`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                    AutoDelete -> False, 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> {
                    ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
                 GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False,
                  GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaselinePosition -> {1, 1}], True -> GridBox[{{
                   PaneBox[
                    ButtonBox[
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                    ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                    None, Evaluator -> Automatic, Method -> "Preemptive"], 
                    Alignment -> {Center, Center}, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                   GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJxTTMoPSmViYGCwAWIQffGu3G/HaTV2DFCw3Ta+doXFLnsYv4WPp/pH0Gk4
X2HLUzU7nytwftkVhYy1Z2/B+f2bXHuV3j2A8zO2CvuoWT6B87MLKp33nXoO
52s9PfNsjfdrOD9PZGd+8IR3cP672nkSx3k/wvnPzunkOGz9BOfv+bNRNDXk
C5y/nK359mWxb3D+tVyFKXK7v8P5Ehs5Mzc3/YTzLS6+nPzZ8TecP9tv2kb+
x3/gfOEVfa9Ll/+D89PXa/LcUWNwgPHP/dhosIibEc5fssGUwe4Ngi8zXf7k
8b1McP68bP0F3xYww/kH85YWCJeywPnBD8TesLqywvnv7deVzlVjg/N1z63+
ofQTwS/1Ot/pe5cdztcxfXfUdy8HnN/iV/zbuo8Tzn8eKmd/voALzn/drV8T
4MIN58cZ2KQsF+aB828fyota/AXB/9nM7tV7jBfOVzI+5i6zig/OfyPw2m5m
HT+cP2ld64dSdQE4f8vpFScKZyD4agz1c58wCsL5c7UzfmqWIPg+fOe1op4g
8TleRjD6CsH5gT9F+ar3IfjLGL/tz9YQhvONDwa7u09A8I+WHwn9yiAC569w
fZEglYXgT+CS/yx4B8Ff33Y56ou3KJwvL2W933cLgj9lydZVlapicH6U2+NJ
Mv0Ivup9ZaZJjOJwvrr+I7dPhQh+1bTgjpO3EPxLX64HFPtIwPnVWfxiU7Yh
+DPnyPn+VpSE8wFw2tLe
                    "]]}}}, {
                    DisplayFunction -> Identity, AspectRatio -> 1, 
                    Axes -> {False, False}, AxesLabel -> {None, None}, 
                    AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                    Frame -> {{True, True}, {True, True}}, 
                    FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                    Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                    FrameTicks -> {{None, None}, {None, None}}, 
                    GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                    Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 6.283185307179586}, {-1., 1.}}, 
                    PlotRangeClipping -> True, PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                   GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "6.283185307179586`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                    AutoDelete -> False, 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> {
                    ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
                 GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False,
                  GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaselinePosition -> {1, 1}]}, 
              Dynamic[Typeset`open$$], ImageSize -> Automatic], 
             BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
           StyleBox["]", "NonInterpretableSummary"]}]},
        "CopyTag",
        DisplayFunction->(#& ),
        InterpretationFunction->(
         "InterpolatingFunction[{{0., 6.28319}}, <>]"& )],
       False,
       Editable->False,
       SelectWithContents->True,
       Selectable->False], "[", "t", "]"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.597930272182065*^9, 3.598010436820083*^9, 
  3.5980105180182257`*^9, 3.598011039776742*^9, 3.5989405551492777`*^9, 
  3.6132849751199436`*^9, 3.617174146105913*^9, 3.618826571319566*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fu", "[", "t_", "]"}], " ", "=", 
  RowBox[{
   RowBox[{"u", "[", "t", "]"}], "/.", 
   RowBox[{
    RowBox[{"Flatten", "[", "%", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5980105673455124`*^9, 3.598010700881747*^9}, {
  3.5980110599163775`*^9, 3.59801106141398*^9}}],

Cell[BoxData[
 RowBox[{
  TagBox[
   TemplateBox[{RowBox[{
       StyleBox[
        TagBox["InterpolatingFunction", "SummaryHead"], 
        "NonInterpretableSummary"], 
       StyleBox["[", "NonInterpretableSummary"], 
       DynamicModuleBox[{Typeset`open$$ = False}, 
        PanelBox[
         PaneSelectorBox[{False -> GridBox[{{
               PaneBox[
                ButtonBox[
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "FEBitmaps", "SquarePlusIconMedium"]], 
                 ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                 None, Evaluator -> Automatic, Method -> "Preemptive"], 
                Alignment -> {Center, Center}, ImageSize -> 
                Dynamic[{
                  Automatic, 
                   3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
               GraphicsBox[{{{}, {}, {
                   Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                   LineBox[CompressedData["
1:eJxFxWtIk1EYAOBvK+9zbu6Sydh04UwzlEQwtO1ITcFtYi4h9qMikpaWTmyF
TQvSogjdMFlJTqS0DavZ0nVXMbxklmJKgReSnJpsrNJlG5Oo6PR+Px6e2KNl
BUVUgiAy//j7xBzfn2WsEhPz/36y53C1Jf255Cm+lk7TeQtG4ZjuRZFYPgWf
mYpRP3g3DesfSeuE7nlYbWfJRbsdcImmcm/vm2U4cfHt0n2ZEy5lPytTGtyw
u7olajj8O7w0lnQS2Vfhlxs2TtEBD2wOrJmZ5K7DH07FNPJf/ISjbCEnui76
4PSJletrWX74Vp7RFrGwAbMs9U6t+Rd8vDOBNisi0P/HvLaU22EUuO1hGiF2
kfNuCEaGe6hwS0ly63rrJri/tF3D0m6GlfNcV4A0AP4qsWpNokB459g9r9BH
rs0dv6qYC4KT0tyDip5guDavwp9RHwIvF/Il45pQ2HktuSp/Xxh8KCXzmJlF
g2delarueMh9NUG5dUPhsDB1KIfXQYddDKe46XwE3GC99E0bz4C7Ry2vy28y
UBdeRFwwOShMFIc37VD7Ek4zUTNeTh9PVDmYSIaXB68cpCgikQy/38eh63oj
UT7+LmW9r2Q7C7XjU/uVOTkGFtqFHzw7UPiDYKMBvEX65Uh0MRuZ8YZQwRpz
lo30+M7LkyqPjIOseEF0Rp+im7yxzd5RGceFVdkLDTw9edynbdQGyhY4Pvlz
9mo5+Tmj8srINPl7z8f8CnkUrCuO4DY+Jm9q5iv8sVvh3wt5owg=
                    "]]}}}, {
                DisplayFunction -> Identity, AspectRatio -> 1, 
                 Axes -> {False, False}, AxesLabel -> {None, None}, 
                 AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                 Frame -> {{True, True}, {True, True}}, 
                 FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                 Directive[
                   Opacity[0.5], 
                   Thickness[Tiny], 
                   RGBColor[0.368417, 0.506779, 0.709798]], 
                 FrameTicks -> {{None, None}, {None, None}}, 
                 GridLines -> {None, None}, GridLinesStyle -> Directive[
                   GrayLevel[0.5, 0.4]], ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                 Method -> {
                  "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                   None}, PlotRange -> {{0., 6.283185307179586}, {0., 
                  6.28318520068492}}, PlotRangeClipping -> True, 
                 PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
               GridBox[{{
                  RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "6.283185307179586`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {
                 "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                BaseStyle -> {
                 ShowStringCharacters -> False, NumberMarks -> False, 
                  PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
             GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             BaselinePosition -> {1, 1}], True -> GridBox[{{
               PaneBox[
                ButtonBox[
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "FEBitmaps", "SquareMinusIconMedium"]], 
                 ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                 None, Evaluator -> Automatic, Method -> "Preemptive"], 
                Alignment -> {Center, Center}, ImageSize -> 
                Dynamic[{
                  Automatic, 
                   3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
               GraphicsBox[{{{}, {}, {
                   Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                   LineBox[CompressedData["
1:eJxFxWtIk1EYAOBvK+9zbu6Sydh04UwzlEQwtO1ITcFtYi4h9qMikpaWTmyF
TQvSogjdMFlJTqS0DavZ0nVXMbxklmJKgReSnJpsrNJlG5Oo6PR+Px6e2KNl
BUVUgiAy//j7xBzfn2WsEhPz/36y53C1Jf255Cm+lk7TeQtG4ZjuRZFYPgWf
mYpRP3g3DesfSeuE7nlYbWfJRbsdcImmcm/vm2U4cfHt0n2ZEy5lPytTGtyw
u7olajj8O7w0lnQS2Vfhlxs2TtEBD2wOrJmZ5K7DH07FNPJf/ISjbCEnui76
4PSJletrWX74Vp7RFrGwAbMs9U6t+Rd8vDOBNisi0P/HvLaU22EUuO1hGiF2
kfNuCEaGe6hwS0ly63rrJri/tF3D0m6GlfNcV4A0AP4qsWpNokB459g9r9BH
rs0dv6qYC4KT0tyDip5guDavwp9RHwIvF/Il45pQ2HktuSp/Xxh8KCXzmJlF
g2delarueMh9NUG5dUPhsDB1KIfXQYddDKe46XwE3GC99E0bz4C7Ry2vy28y
UBdeRFwwOShMFIc37VD7Ek4zUTNeTh9PVDmYSIaXB68cpCgikQy/38eh63oj
UT7+LmW9r2Q7C7XjU/uVOTkGFtqFHzw7UPiDYKMBvEX65Uh0MRuZ8YZQwRpz
lo30+M7LkyqPjIOseEF0Rp+im7yxzd5RGceFVdkLDTw9edynbdQGyhY4Pvlz
9mo5+Tmj8srINPl7z8f8CnkUrCuO4DY+Jm9q5iv8sVvh3wt5owg=
                    "]]}}}, {
                DisplayFunction -> Identity, AspectRatio -> 1, 
                 Axes -> {False, False}, AxesLabel -> {None, None}, 
                 AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                 Frame -> {{True, True}, {True, True}}, 
                 FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                 Directive[
                   Opacity[0.5], 
                   Thickness[Tiny], 
                   RGBColor[0.368417, 0.506779, 0.709798]], 
                 FrameTicks -> {{None, None}, {None, None}}, 
                 GridLines -> {None, None}, GridLinesStyle -> Directive[
                   GrayLevel[0.5, 0.4]], ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                 Method -> {
                  "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                   None}, PlotRange -> {{0., 6.283185307179586}, {0., 
                  6.28318520068492}}, PlotRangeClipping -> True, 
                 PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
               GridBox[{{
                  RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "6.283185307179586`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {
                 "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                BaseStyle -> {
                 ShowStringCharacters -> False, NumberMarks -> False, 
                  PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
             GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             BaselinePosition -> {1, 1}]}, 
          Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
         Baseline], DynamicModuleValues :> {}], 
       StyleBox["]", "NonInterpretableSummary"]}]},
    "CopyTag",
    DisplayFunction->(#& ),
    InterpretationFunction->("InterpolatingFunction[{{0., 6.28319}}, <>]"& )],
   False,
   Editable->False,
   SelectWithContents->True,
   Selectable->False], "[", "t", "]"}]], "Output",
 CellChangeTimes->{3.598010704422953*^9, 3.5980110663903885`*^9, 
  3.6132849809372764`*^9, 3.61717414989672*^9, 3.6188265957209616`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"gu", "[", "t_", "]"}], " ", "=", 
  RowBox[{
   RowBox[{"v", "[", "t", "]"}], "/.", 
   RowBox[{
    RowBox[{"Flatten", "[", "%%", "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5980105673455124`*^9, 3.5980107410050173`*^9}, {
  3.598011081772016*^9, 3.598011083410019*^9}}],

Cell[BoxData[
 RowBox[{
  TagBox[
   TemplateBox[{RowBox[{
       StyleBox[
        TagBox["InterpolatingFunction", "SummaryHead"], 
        "NonInterpretableSummary"], 
       StyleBox["[", "NonInterpretableSummary"], 
       DynamicModuleBox[{Typeset`open$$ = False}, 
        PanelBox[
         PaneSelectorBox[{False -> GridBox[{{
               PaneBox[
                ButtonBox[
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "FEBitmaps", "SquarePlusIconMedium"]], 
                 ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                 None, Evaluator -> Automatic, Method -> "Preemptive"], 
                Alignment -> {Center, Center}, ImageSize -> 
                Dynamic[{
                  Automatic, 
                   3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
               GraphicsBox[{{{}, {}, {
                   Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                   LineBox[CompressedData["
1:eJxTTMoPSmViYGCwAWIQffGu3G/HaTV2DFCw3Ta+doXFLnsYv4WPp/pH0Gk4
X2HLUzU7nytwftkVhYy1Z2/B+f2bXHuV3j2A8zO2CvuoWT6B87MLKp33nXoO
52s9PfNsjfdrOD9PZGd+8IR3cP672nkSx3k/wvnPzunkOGz9BOfv+bNRNDXk
C5y/nK359mWxb3D+tVyFKXK7v8P5Ehs5Mzc3/YTzLS6+nPzZ8TecP9tv2kb+
x3/gfOEVfa9Ll/+D89PXa/LcUWNwgPHP/dhosIibEc5fssGUwe4Ngi8zXf7k
8b1McP68bP0F3xYww/kH85YWCJeywPnBD8TesLqywvnv7deVzlVjg/N1z63+
ofQTwS/1Ot/pe5cdztcxfXfUdy8HnN/iV/zbuo8Tzn8eKmd/voALzn/drV8T
4MIN58cZ2KQsF+aB828fyota/AXB/9nM7tV7jBfOVzI+5i6zig/OfyPw2m5m
HT+cP2ld64dSdQE4f8vpFScKZyD4agz1c58wCsL5c7UzfmqWIPg+fOe1op4g
8TleRjD6CsH5gT9F+ar3IfjLGL/tz9YQhvONDwa7u09A8I+WHwn9yiAC569w
fZEglYXgT+CS/yx4B8Ff33Y56ou3KJwvL2W933cLgj9lydZVlapicH6U2+NJ
Mv0Ivup9ZaZJjOJwvrr+I7dPhQh+1bTgjpO3EPxLX64HFPtIwPnVWfxiU7Yh
+DPnyPn+VpSE8wFw2tLe
                    "]]}}}, {
                DisplayFunction -> Identity, AspectRatio -> 1, 
                 Axes -> {False, False}, AxesLabel -> {None, None}, 
                 AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                 Frame -> {{True, True}, {True, True}}, 
                 FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                 Directive[
                   Opacity[0.5], 
                   Thickness[Tiny], 
                   RGBColor[0.368417, 0.506779, 0.709798]], 
                 FrameTicks -> {{None, None}, {None, None}}, 
                 GridLines -> {None, None}, GridLinesStyle -> Directive[
                   GrayLevel[0.5, 0.4]], ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                 Method -> {
                  "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                   None}, PlotRange -> {{0., 6.283185307179586}, {-1., 1.}}, 
                 PlotRangeClipping -> True, PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
               GridBox[{{
                  RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "6.283185307179586`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {
                 "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                BaseStyle -> {
                 ShowStringCharacters -> False, NumberMarks -> False, 
                  PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
             GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             BaselinePosition -> {1, 1}], True -> GridBox[{{
               PaneBox[
                ButtonBox[
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "FEBitmaps", "SquareMinusIconMedium"]], 
                 ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                 None, Evaluator -> Automatic, Method -> "Preemptive"], 
                Alignment -> {Center, Center}, ImageSize -> 
                Dynamic[{
                  Automatic, 
                   3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
               GraphicsBox[{{{}, {}, {
                   Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                   LineBox[CompressedData["
1:eJxTTMoPSmViYGCwAWIQffGu3G/HaTV2DFCw3Ta+doXFLnsYv4WPp/pH0Gk4
X2HLUzU7nytwftkVhYy1Z2/B+f2bXHuV3j2A8zO2CvuoWT6B87MLKp33nXoO
52s9PfNsjfdrOD9PZGd+8IR3cP672nkSx3k/wvnPzunkOGz9BOfv+bNRNDXk
C5y/nK359mWxb3D+tVyFKXK7v8P5Ehs5Mzc3/YTzLS6+nPzZ8TecP9tv2kb+
x3/gfOEVfa9Ll/+D89PXa/LcUWNwgPHP/dhosIibEc5fssGUwe4Ngi8zXf7k
8b1McP68bP0F3xYww/kH85YWCJeywPnBD8TesLqywvnv7deVzlVjg/N1z63+
ofQTwS/1Ot/pe5cdztcxfXfUdy8HnN/iV/zbuo8Tzn8eKmd/voALzn/drV8T
4MIN58cZ2KQsF+aB828fyota/AXB/9nM7tV7jBfOVzI+5i6zig/OfyPw2m5m
HT+cP2ld64dSdQE4f8vpFScKZyD4agz1c58wCsL5c7UzfmqWIPg+fOe1op4g
8TleRjD6CsH5gT9F+ar3IfjLGL/tz9YQhvONDwa7u09A8I+WHwn9yiAC569w
fZEglYXgT+CS/yx4B8Ff33Y56ou3KJwvL2W933cLgj9lydZVlapicH6U2+NJ
Mv0Ivup9ZaZJjOJwvrr+I7dPhQh+1bTgjpO3EPxLX64HFPtIwPnVWfxiU7Yh
+DPnyPn+VpSE8wFw2tLe
                    "]]}}}, {
                DisplayFunction -> Identity, AspectRatio -> 1, 
                 Axes -> {False, False}, AxesLabel -> {None, None}, 
                 AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                 Frame -> {{True, True}, {True, True}}, 
                 FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                 Directive[
                   Opacity[0.5], 
                   Thickness[Tiny], 
                   RGBColor[0.368417, 0.506779, 0.709798]], 
                 FrameTicks -> {{None, None}, {None, None}}, 
                 GridLines -> {None, None}, GridLinesStyle -> Directive[
                   GrayLevel[0.5, 0.4]], ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                 Method -> {
                  "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                   None}, PlotRange -> {{0., 6.283185307179586}, {-1., 1.}}, 
                 PlotRangeClipping -> True, PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
               GridBox[{{
                  RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "6.283185307179586`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {
                 "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                BaseStyle -> {
                 ShowStringCharacters -> False, NumberMarks -> False, 
                  PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
             GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             BaselinePosition -> {1, 1}]}, 
          Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
         Baseline], DynamicModuleValues :> {}], 
       StyleBox["]", "NonInterpretableSummary"]}]},
    "CopyTag",
    DisplayFunction->(#& ),
    InterpretationFunction->("InterpolatingFunction[{{0., 6.28319}}, <>]"& )],
   False,
   Editable->False,
   SelectWithContents->True,
   Selectable->False], "[", "t", "]"}]], "Output",
 CellChangeTimes->{3.598010747135828*^9, 3.598011085406822*^9, 
  3.613284988972736*^9, 3.617174156121131*^9, 3.618826602210333*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"r", "=", "1"}], ";", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sphero", "[", "r", "]"}], "[", 
     RowBox[{
      RowBox[{"fu", "[", "t", "]"}], ",", 
      RowBox[{"gu", "[", "t", "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.59793530857513*^9, 3.597935328999298*^9}, {
   3.597935372503786*^9, 3.597935416552306*^9}, 3.5979361503762784`*^9, {
   3.5980107984599185`*^9, 3.5980108206743574`*^9}, {3.5980108954452887`*^9, 
   3.5980109588282003`*^9}, {3.5980111031908536`*^9, 3.5980111599125533`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"equat1", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.618826674612474*^9, 3.618826692702509*^9}}],

Cell[TextData[{
 StyleBox["T",
  FontSlant->"Italic"],
 "he spherical geodesics are the great circles,e.g. the equator"
}], "Text",
 CellChangeTimes->{{3.5979308517002115`*^9, 3.597930938316166*^9}, {
  3.59793601385347*^9, 3.5979360207808657`*^9}, {3.598011469978698*^9, 
  3.598011482271519*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", "s_", "]"}], ":=", "t"}], ";", 
  RowBox[{
   RowBox[{"v", "[", "s_", "]"}], ":=", "0"}], ";", 
  RowBox[{"\[Gamma]", "[", "t", "]"}]}]], "Input",
 CellChangeTimes->{{3.597936287551124*^9, 3.5979362931424437`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"t", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.597936348096587*^9, 3.6132850344723387`*^9, 
  3.6171742016108108`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"r", "=", "1"}], ";", 
  RowBox[{
   RowBox[{"u", "[", "s_", "]"}], ":=", "t"}], ";", 
  RowBox[{
   RowBox[{"v", "[", "s_", "]"}], ":=", "0"}], ";", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sphero", "[", "r", "]"}], "[", 
     RowBox[{
      RowBox[{"u", "[", "t", "]"}], ",", 
      RowBox[{"v", "[", "t", "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
    RowBox[{"PlotStyle", " ", "\[Rule]", " ", "Red"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.59793530857513*^9, 3.597935328999298*^9}, {
   3.597935372503786*^9, 3.597935416552306*^9}, 3.5979361503762784`*^9, {
   3.618826730962697*^9, 3.618826739615192*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"%", ",", "equat1"}], "}"}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.618826747940668*^9, 3.618826776361294*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"r", "=", "1"}], ";", 
  RowBox[{
   RowBox[{"u", "[", "s_", "]"}], ":=", "t"}], ";", 
  RowBox[{
   RowBox[{"v", "[", "s_", "]"}], ":=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"norm", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"sphero", "[", "r", "]"}], "[", 
      RowBox[{
       RowBox[{"fu", "[", "t", "]"}], ",", 
       RowBox[{"gu", "[", "t", "]"}]}], "]"}], "-", 
     RowBox[{
      RowBox[{"sphero", "[", "r", "]"}], "[", 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], ",", 
       RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6188268763600135`*^9, 3.618826890079798*^9}, {
  3.6188269471670637`*^9, 3.618826984440195*^9}, {3.61882710743423*^9, 
  3.6188271184888625`*^9}, {3.6188271596792183`*^9, 3.6188271684097176`*^9}, {
  3.6188272292031946`*^9, 3.6188272362896004`*^9}},
 NumberMarks->False],

Cell["The numeric solution is quite near to the exact equator.", "Text",
 CellChangeTimes->{{3.618828015437165*^9, 3.618828058413623*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", "s_", "]"}], ":=", "s"}], ";", 
  RowBox[{
   RowBox[{"v", "[", "s_", "]"}], ":=", "0"}], ";", " ", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"DD1", "[", 
     RowBox[{
      RowBox[{"sphero", "[", "r", "]"}], ",", "\[Gamma]", ",", 
      SuperscriptBox["\[Gamma]", "\[Prime]",
       MultilineFunction->None]}], "]"}], "[", "t", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.597930990691161*^9, 3.597931042054099*^9}, {
   3.5979310726468487`*^9, 3.597931145472014*^9}, 3.5979312951205735`*^9, {
   3.597931409520117*^9, 3.5979314723207088`*^9}, {3.597931552368287*^9, 
   3.59793155713656*^9}, 3.598011520257586*^9, 3.6188279817532387`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.597931087614705*^9, {3.597931122085676*^9, 3.5979311475501328`*^9}, 
   3.597931298064742*^9, {3.597931432094408*^9, 3.5979314470342627`*^9}, 
   3.5979314829793186`*^9, 3.597931562643875*^9, 3.597935256686162*^9, {
   3.5980115023019543`*^9, 3.598011525265195*^9}, 3.6132850485601444`*^9, {
   3.617174223482049*^9, 3.6171742389728765`*^9}, 3.618827983121317*^9}]
}, Closed]],

Cell["\<\
It follows: The equator and therefore all the great circles, are the \
geodesics of the sphere, since the rotation group preserving the sphere acts \
transitively on the set of all great circles. \[FilledRectangle]\
\>", "Text",
 CellChangeTimes->{{3.5979354457009735`*^9, 3.5979355381972637`*^9}, {
   3.5979361835101733`*^9, 3.597936190844593*^9}, 3.597936521357497*^9}],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"r", ",", "u", ",", "v", ",", "s", ",", "t", ",", "fu", ",", "gu"}],
   "]"}]], "Input",
 CellChangeTimes->{{3.597935683989602*^9, 3.597935730415258*^9}, 
   3.597936386831803*^9, {3.59801155100524*^9, 3.598011556324849*^9}}],

Cell[TextData[{
 "Applying the existence and uniqueness theorem for differential equations, \
we may state\n\n",
 StyleBox["Proposition",
  FontColor->RGBColor[0, 0, 1]],
 ". Through any point x of an immersion (or a Riemannian manifold ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]]],
 ")  and any tangent unit vector vt \[Epsilon]",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SubscriptBox["T", "x"]}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]]],
 " there exists one and only one geodesic \[Gamma][t],  \[Gamma][0] = x, ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Prime]",
    MultilineFunction->None], "[", "0", "]"}]],
  CellChangeTimes->{{3.5979292059430795`*^9, 3.5979292420701456`*^9}, {
   3.597929272325876*^9, 3.597929298654382*^9}, {3.597929354638584*^9, 
   3.597929492815488*^9}}],
 " = vt, defined for a maximal interval of values t, t the arc length of \
\[Gamma]."
}], "Text",
 CellChangeTimes->{{3.598076949768775*^9, 3.598077205905425*^9}, {
   3.598077253769163*^9, 3.598077273273278*^9}, {3.598077357521097*^9, 
   3.598077557343526*^9}, {3.5980775930175667`*^9, 3.5980777053379908`*^9}, {
   3.5980777669065123`*^9, 3.598077838916631*^9}, {3.5980778699544067`*^9, 
   3.598077876921805*^9}, {3.598077921365347*^9, 3.598077950626021*^9}, 
   3.5980779864740715`*^9, 3.6132850698693633`*^9, 3.6174417193890543`*^9}],

Cell[TextData[{
 StyleBox[" Example",
  FontColor->RGBColor[0, 0, 1]],
 ". Ruled surfaces."
}], "Text",
 CellChangeTimes->{{3.598013618960472*^9, 3.5980136605033455`*^9}, {
   3.5980775178572674`*^9, 3.5980775195133624`*^9}, 3.5980780173128347`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";"}]], "Input",
 CellChangeTimes->{{3.618828782127017*^9, 3.6188287890304117`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ruled", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{"x", "[", "v", "]"}], "]"}], " ", "+", " ", 
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"y", "[", "v", "]"}], "]"}], "*", " ", "u"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5872799484616065`*^9, 3.5872801346102533`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsf", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"ruled", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5980123012573576`*^9, 3.598012356419055*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rsf", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.598012474604862*^9, 3.598012479799671*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "v", "]"}], "[", "1", "]"}], "+", 
    RowBox[{"u", " ", 
     RowBox[{
      RowBox[{"y", "[", "v", "]"}], "[", "1", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "v", "]"}], "[", "2", "]"}], "+", 
    RowBox[{"u", " ", 
     RowBox[{
      RowBox[{"y", "[", "v", "]"}], "[", "2", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "v", "]"}], "[", "3", "]"}], "+", 
    RowBox[{"u", " ", 
     RowBox[{
      RowBox[{"y", "[", "v", "]"}], "[", "3", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "v", "]"}], "[", "4", "]"}], "+", 
    RowBox[{"u", " ", 
     RowBox[{
      RowBox[{"y", "[", "v", "]"}], "[", "4", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.598012480735673*^9, 3.6132851333019915`*^9, 
  3.6171743166298127`*^9, 3.6188281309887743`*^9}]
}, Closed]],

Cell["\<\
The generating lines are geodesics; later we shall see that any line \
contained in a surface is a geodesic.\
\>", "Text",
 CellChangeTimes->{{3.598013751248705*^9, 3.5980138273924384`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0"}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"DD1", "[", 
    RowBox[{"rsf", ",", "\[Gamma]", ",", 
     SuperscriptBox["\[Gamma]", "\[Prime]",
      MultilineFunction->None]}], "]"}], "[", "t", "]"}]}]], "Input",
 CellChangeTimes->{{3.5980125593598113`*^9, 3.598012620574319*^9}, {
  3.5980126618363914`*^9, 3.598012676874818*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.598012680993225*^9, 3.6132851494759164`*^9, 
  3.6171743412622557`*^9, 3.6188281448235655`*^9}]
}, Closed]],

Cell["\<\
Now we calculate the absolute derivative of the tangent vector at the \
directrix vec[x[v]]:\
\>", "Text",
 CellChangeTimes->{{3.5980139213202033`*^9, 3.598013941553439*^9}, {
   3.598015594407542*^9, 3.598015602878357*^9}, {3.5980744477356434`*^9, 
   3.5980745343625956`*^9}, 3.6174417367160454`*^9, {3.6188281664378014`*^9, 
   3.6188281699900045`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", "t"}], "}"}]}], ";", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"DD1", "[", 
     RowBox[{"rsf", ",", "\[Gamma]", ",", 
      SuperscriptBox["\[Gamma]", "\[Prime]",
       MultilineFunction->None]}], "]"}], "[", "t", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5980125593598113`*^9, 3.598012620574319*^9}, {
   3.5980126618363914`*^9, 3.598012676874818*^9}, {3.598012716576887*^9, 
   3.5980127313969135`*^9}, {3.5980139548914623`*^9, 3.598013988774722*^9}, 
   3.598015612097973*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
          "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
        ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
            "+", 
            RowBox[{
             RowBox[{
              RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
            "+", 
            RowBox[{
             RowBox[{
              RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "3", 
              "]"}]}]}], ")"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "2"]}], ")"}], 
         " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
            "2"], "+", 
           SuperscriptBox[
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
            "2"], "+", 
           SuperscriptBox[
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
            "2"]}], ")"}]}]}], ")"}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
        ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
            "+", 
            RowBox[{
             RowBox[{
              RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
            "+", 
            RowBox[{
             RowBox[{
              RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "3", 
              "]"}]}]}], ")"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "2"]}], ")"}], 
         " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
            "2"], "+", 
           SuperscriptBox[
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
            "2"], "+", 
           SuperscriptBox[
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
            "2"]}], ")"}]}]}], ")"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5980127349537196`*^9, 3.5980139595090704`*^9, 
  3.598013990241124*^9, 3.5980148846998954`*^9, 3.598014976740057*^9, 
  3.598015618447184*^9, 3.598015728442977*^9, 3.613285192627384*^9, 
  3.6171743581570854`*^9, 3.618828233880659*^9, 3.6188288147428827`*^9}]
}, Closed]],

Cell["\<\
We assume that v= t is the arc length of x, that y[v] is orthogonal to x\
\[CloseCurlyQuote], and that y.y ==1 is a unit vector, i.e. that the ruled \
surface is generated by a family of normals of the curve x[v]. This is \
equivalent to the Conditions\
\>", "Text",
 CellChangeTimes->{{3.598014139954587*^9, 3.5980141739002466`*^9}, {
   3.5980142117459135`*^9, 3.598014350960558*^9}, {3.598015630428005*^9, 
   3.598015689708109*^9}, 3.5980745908658953`*^9, 3.617174467076477*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"conds", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
         "2"]}], ")"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "2"]}], ")"}], 
      "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
       ")"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
       ")"}], "\[Equal]", "0"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.598014358713772*^9, 3.5980144816731873`*^9}, {
   3.5980145294872713`*^9, 3.5980145784713573`*^9}, {3.5980146324630527`*^9, 
   3.59801463676866*^9}, {3.5980146712447205`*^9, 3.5980146860647464`*^9}, 
   3.598014725454816*^9, {3.5980147633784823`*^9, 3.5980147646732845`*^9}, {
   3.598014867867466*^9, 3.598014871814273*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%%", ",", "conds"}], "]"}]], "Input",
 CellChangeTimes->{{3.598012757495759*^9, 3.5980127705529823`*^9}, {
   3.5980128218770723`*^9, 3.5980128789263725`*^9}, {3.5980148996915216`*^9, 
   3.5980149121091433`*^9}, 3.5980150010449*^9, {3.5980150367065625`*^9, 
   3.5980150390309663`*^9}, {3.5980157411413994`*^9, 
   3.5980157424830017`*^9}, {3.613285257919119*^9, 3.613285263830457*^9}, {
   3.6171931026017113`*^9, 3.6171931109477262`*^9}, {3.618828710063895*^9, 
   3.618828731983149*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["x", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["x", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["x", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], ",", 
   "0"}], "}"}]], "Output",
 CellChangeTimes->{3.5980128814223766`*^9, 3.5980149406259937`*^9, 
  3.5980150582970004`*^9, 3.5980157449790063`*^9, 3.6132852658055696`*^9, 
  3.61717441163398*^9, 3.617193113708931*^9, 3.618828738786538*^9, 
  3.618828853433096*^9}]
}, Closed]],

Cell[TextData[{
 "Now vec[",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["x", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]],
  CellChangeTimes->{{3.598015889934461*^9, 3.598015935782942*^9}}],
 "] == k[t] *n[t] is the curvature vector of the curve vec[x[t]]; it is \
proportional to the principal normal vector n[t] with the curvature k[t] as \
factor; remember: t is the arc length. Since vec[y[t] is a unit normal \
vector. we have the interpretation where \[Alpha][t] denotes the angle \
between n[t] and vec[y[t]:"
}], "Text",
 CellChangeTimes->{{3.59801595197577*^9, 3.598016040630726*^9}, {
   3.5980160729071827`*^9, 3.598016191560991*^9}, {3.598016348949667*^9, 
   3.5980163923177433`*^9}, {3.5980746508636007`*^9, 3.598074668429231*^9}, 
   3.6171744572796593`*^9, {3.617193389361415*^9, 3.6171934129954567`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", "t"}], "}"}]}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"DD1", "[", 
     RowBox[{"rsf", ",", "\[Gamma]", ",", 
      SuperscriptBox["\[Gamma]", "\[Prime]",
       MultilineFunction->None]}], "]"}], "[", "t", "]"}], "\[Equal]", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"k", "[", "t", "]"}], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Alpha]", "[", "t", "]"}], "]"}]}], ",", "0"}], 
    "}"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5980164417854304`*^9, 3.5980164693506784`*^9}, {
  3.598016626224554*^9, 3.598016666847026*^9}, {3.6171932823608274`*^9, 
  3.617193289053239*^9}}],

Cell[TextData[{
 "It follows: ",
 StyleBox["Any curve is a geodesic on the normal surface generated by its \
binormals. ",
  FontColor->RGBColor[0, 0, 1]],
 "\[FilledRectangle]"
}], "Text",
 CellChangeTimes->{{3.598016655053405*^9, 3.598016715659511*^9}, 
   3.5980167597451887`*^9, {3.5980169228434753`*^9, 3.5980169797367754`*^9}, {
   3.5980170368952756`*^9, 3.5980170459588914`*^9}, {3.5980183077359076`*^9, 
   3.598018313476718*^9}, {3.598074739939757*^9, 3.598074742295361*^9}, 
   3.613285387981558*^9, 3.617193376413392*^9}],

Cell["\<\
Now we consider the special ruled surface generated by normals of the x-axis:\
\>", "Text",
 CellChangeTimes->{{3.6171938010149384`*^9, 3.617193859561841*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rsf", "[", "w_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", 
  RowBox[{"{", 
   RowBox[{"u", ",", " ", 
    RowBox[{"v", "*", 
     RowBox[{"Cos", "[", 
      RowBox[{"w", "[", "u", "]"}], "]"}]}], ",", 
    RowBox[{"v", "*", 
     RowBox[{"Sin", "[", 
      RowBox[{"w", "[", "u", "]"}], "]"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.598018362570004*^9, 3.5980185772263813`*^9}, 
   3.598074791778648*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "3", "]"}], "[", 
    RowBox[{"rsf", "[", "w", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.59801860508803*^9, 3.5980186424188957`*^9}, {
   3.598074818563895*^9, 3.5980748315275173`*^9}, 3.6148618628107452`*^9, 
   3.614917794104565*^9, {3.6171935611489167`*^9, 3.6171935620381184`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"v", " ", 
      RowBox[{
       SuperscriptBox["w", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], 
     SqrtBox[
      RowBox[{"1", "+", 
       RowBox[{
        SuperscriptBox["v", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["w", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}]}]]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"Sin", "[", 
      RowBox[{"w", "[", "u", "]"}], "]"}], 
     SqrtBox[
      RowBox[{"1", "+", 
       RowBox[{
        SuperscriptBox["v", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["w", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}]}]]]}], ",", 
   FractionBox[
    RowBox[{"Cos", "[", 
     RowBox[{"w", "[", "u", "]"}], "]"}], 
    SqrtBox[
     RowBox[{"1", "+", 
      RowBox[{
       SuperscriptBox["v", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["w", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"]}]}]]]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.5980186442440987`*^9, 3.5980748351467237`*^9, 3.5980751350728507`*^9, 
   3.598075230747819*^9, 3.6132855607954426`*^9, 3.6132856546158085`*^9, {
   3.61719354575169*^9, 3.617193564424923*^9}, 3.61719364841547*^9, 
   3.618829068606403*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Norm", "[", "%", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5980186576289225`*^9, 3.5980186982669935`*^9}}],

Cell[BoxData[
 FractionBox[
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"Abs", "[", 
      RowBox[{"Cos", "[", 
       RowBox[{"w", "[", "u", "]"}], "]"}], "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"Abs", "[", 
      RowBox[{"Sin", "[", 
       RowBox[{"w", "[", "u", "]"}], "]"}], "]"}], "2"], "+", 
    RowBox[{"v", " ", 
     SuperscriptBox[
      RowBox[{"Abs", "[", 
       RowBox[{
        SuperscriptBox["w", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "]"}], "2"], " ", 
     RowBox[{"Conjugate", "[", "v", "]"}]}]}]], 
  SqrtBox[
   RowBox[{"Abs", "[", 
    RowBox[{"1", "+", 
     RowBox[{
      SuperscriptBox["v", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["w", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "2"]}]}], 
    "]"}]]]], "Output",
 CellChangeTimes->{3.6171936046417933`*^9, 3.6171936560750837`*^9, 
  3.6188290779889393`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"w", "[", "u", "]"}], "\[Element]", " ", "Reals"}], ",", 
     RowBox[{"v", " ", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["w", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], "\[Element]", " ", 
      "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5980187581554985`*^9, 3.5980188628628826`*^9}, {
   3.598074896969633*^9, 3.598074903755645*^9}, 3.5980751467728715`*^9, {
   3.598075207238578*^9, 3.598075224086607*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.5980188679796915`*^9, 3.598074914160863*^9, 
  3.598075148660475*^9, 3.5980752389378333`*^9, 3.6132855725491147`*^9, 
  3.613285665754446*^9, 3.6171936793347244`*^9, 3.6188290833932486`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", 
     RowBox[{"rsf", "[", "w", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"w", "[", "u", "]"}], "\[Element]", " ", "Reals"}], ",", 
     RowBox[{"v", " ", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["w", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], "\[Element]", " ", 
      "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5980189149669743`*^9, 3.598018950675437*^9}, 
   3.598018999519123*^9, 3.5980749646425514`*^9, {3.5980752585314674`*^9, 
   3.598075273632294*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["w", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}], "2"], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{
       SuperscriptBox["v", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["w", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"]}]}], ")"}], 
    "2"]]}]], "Output",
 CellChangeTimes->{3.5980190081147375`*^9, 3.5980749760617714`*^9, 
  3.5980752770487003`*^9, 3.613285582764699*^9, 3.613285671518776*^9, 
  3.6171936985539584`*^9, 3.618829089901621*^9}]
}, Closed]],

Cell[TextData[{
 "It follows: ",
 StyleBox["The surface is developable, namely a part of a plane, iff w(u) == \
const.",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.59807502072465*^9, 3.598075092843577*^9}}],

Cell["\<\
Of course, the x-axis and the generating lines are geodesics:\
\>", "Text",
 CellChangeTimes->{{3.5980755458014727`*^9, 3.5980755807694726`*^9}, 
   3.613286069453536*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0"}], "}"}]}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"DD1", "[", 
     RowBox[{
      RowBox[{"rsf", "[", "w", "]"}], ",", "\[Gamma]", ",", 
      SuperscriptBox["\[Gamma]", "\[Prime]",
       MultilineFunction->None]}], "]"}], "[", "t", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.598019304281258*^9, 3.5980193805497923`*^9}, {
  3.5980194122022476`*^9, 3.598019418036658*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.598019426148672*^9, 3.6132860791780925`*^9, 
  3.6171939012919145`*^9, 3.6188291848510513`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{"uo", ",", "t"}], "}"}]}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"DD1", "[", 
     RowBox[{
      RowBox[{"rsf", "[", "w", "]"}], ",", "\[Gamma]", ",", 
      SuperscriptBox["\[Gamma]", "\[Prime]",
       MultilineFunction->None]}], "]"}], "[", "t", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.598019304281258*^9, 3.5980193805497923`*^9}, {
  3.5980194122022476`*^9, 3.598019418036658*^9}, {3.598019521090439*^9, 
  3.5980195443968797`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.5980195502624903`*^9, 3.6132860860524855`*^9, 
  3.6171939038971186`*^9, 3.618829189788334*^9}]
}, Closed]],

Cell["Let", "Text",
 CellChangeTimes->{{3.5980758476497374`*^9, 3.598075856841263*^9}, {
  3.6132867770860105`*^9, 3.613286807238735*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"w", "[", "u_", "]"}], " ", ":=", " ", "u"}]], "Input",
 CellChangeTimes->{{3.613286962941641*^9, 3.613286976054391*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"rsf", "[", "w", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.613287147781213*^9, 3.6132872376243515`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsf1", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6132872841090107`*^9, 3.6132872905983815`*^9}}],

Cell["We consider the curve", "Text",
 CellChangeTimes->{{3.5980758476497374`*^9, 3.598075856841263*^9}, {
  3.6132867770860105`*^9, 3.613286807238735*^9}, {3.617193967841631*^9, 
  3.617193970571636*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"rsf", "[", "w", "]"}], "[", 
  RowBox[{"t", ",", "1"}], "]"}]], "Input",
 CellChangeTimes->{3.613286393944096*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"t", ",", 
   RowBox[{"Cos", "[", "t", "]"}], ",", 
   RowBox[{"Sin", "[", "t", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6132862569942627`*^9, 3.6132864181714816`*^9, 
  3.613286988091079*^9, 3.617193975969246*^9, 3.618829232666786*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"rsf", "[", "w", "]"}], "[", 
    RowBox[{"t", ",", "1"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", " ", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6132869979946456`*^9, 3.6132870553199244`*^9}}],

Cell["It isn\[CloseCurlyQuote]t a geodesic:", "Text",
 CellChangeTimes->{{3.5980761396094365`*^9, 3.598076149833021*^9}, {
   3.613286460212886*^9, 3.6132864682773476`*^9}, 3.6132870776131997`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{"t", ",", "1"}], "}"}]}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"DD1", "[", 
     RowBox[{
      RowBox[{"rsf", "[", "w", "]"}], ",", "\[Gamma]", ",", 
      SuperscriptBox["\[Gamma]", "\[Prime]",
       MultilineFunction->None]}], "]"}], "[", "t", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.598019304281258*^9, 3.5980193805497923`*^9}, {
  3.5980194122022476`*^9, 3.598019418036658*^9}, {3.598019521090439*^9, 
  3.5980195443968797`*^9}, {3.598019590884961*^9, 3.5980196226154175`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"-", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{3.59801962982263*^9, 3.598075742196706*^9, 
  3.598075895462472*^9, 3.6132863601521635`*^9, 3.613287068079654*^9, 
  3.6171940005392885`*^9, 3.6171942151332655`*^9, 3.6188292437934227`*^9}]
}, Closed]],

Cell["We try to find some geodesics.", "Text",
 CellChangeTimes->{{3.5980768531292477`*^9, 3.598076874889492*^9}}],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.617194795048684*^9, 3.617194806343104*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"dabs", "[", "t_", "]"}], " ", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"DD1", "[", 
      RowBox[{
       RowBox[{"rsf", "[", "w", "]"}], ",", "\[Gamma]", ",", 
       SuperscriptBox["\[Gamma]", "\[Prime]",
        MultilineFunction->None]}], "]"}], "[", "t", "]"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5980199572984047`*^9, 3.598020047950164*^9}, {
   3.5980782588376493`*^9, 3.598078279077807*^9}, {3.6171941205814996`*^9, 
   3.617194139551133*^9}, 3.6171942578929405`*^9, {3.617194540331437*^9, 
   3.617194543716643*^9}, {3.617194818901126*^9, 3.6171948227699327`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"v", "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox["v", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], 
     RowBox[{"1", "+", 
      SuperscriptBox[
       RowBox[{"v", "[", "t", "]"}], "2"]}]], "+", 
    RowBox[{
     SuperscriptBox["u", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"v", "[", "t", "]"}]}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{
     SuperscriptBox["v", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.598020064439393*^9, 3.598021003639043*^9, 
  3.5980761693311367`*^9, 3.5980780587762065`*^9, 3.598078284237102*^9, 
  3.6132864856613417`*^9, 3.6132870840555677`*^9, 3.6171940184793205`*^9, 
  3.617194266613356*^9, 3.6171945459630466`*^9, 3.617194828292342*^9, 
  3.6188292857738237`*^9}]
}, Closed]],

Cell["Again a symbolic solution isn\[CloseCurlyQuote]t  available:", "Text",
 CellChangeTimes->{{3.598078644105685*^9, 3.5980786681610613`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"u", "[", "0", "]"}], "\[Equal]", " ", "1"}], ",", 
     RowBox[{
      RowBox[{"v", "[", "0", "]"}], "\[Equal]", " ", ".2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.5980200989310536`*^9, 3.598020171689582*^9}, {
   3.5980202241992736`*^9, 3.59802039280437*^9}, {3.598020424176025*^9, 
   3.5980205019109616`*^9}, {3.5980205409734297`*^9, 
   3.5980205616278667`*^9}, {3.5980209521589527`*^9, 3.598020953484955*^9}, {
   3.5980210114702563`*^9, 3.598021015027063*^9}, 3.5980781057668943`*^9, {
   3.598078143270039*^9, 3.598078158902933*^9}, 3.614861862841945*^9, 
   3.6148646600360584`*^9, {3.6171945812503085`*^9, 3.6171945997987413`*^9}, {
   3.6171948391343613`*^9, 3.617194848946779*^9}}],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"v", "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["v", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"v", "[", "t", "]"}], "2"]}]], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"v", "[", "t", "]"}]}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"u", "[", "0", "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{"v", "[", "0", "]"}], "\[Equal]", "0.2`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Output",
 CellChangeTimes->{3.6171946075831547`*^9, 3.617194852581585*^9, 
  3.6188292970104666`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"v", "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["v", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"v", "[", "t", "]"}], "2"]}]], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"v", "[", "t", "]"}]}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"u", "[", "0", "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{"v", "[", "0", "]"}], "\[Equal]", "0.2`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.614861862841945*^9, 3.6148618628575454`*^9}, 
   3.6148646600516586`*^9}],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"v", "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["v", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"v", "[", "t", "]"}], "2"]}]], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"v", "[", "t", "]"}]}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"u", "[", "0", "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{"v", "[", "0", "]"}], "\[Equal]", "0.2`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Output",
 CellChangeTimes->{3.617194721088954*^9, 3.6188293017277365`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"dabs", "[", "t", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"dabs", "[", "t", "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"u", "[", "0", "]"}], "\[Equal]", " ", "1"}], ",", 
     RowBox[{
      RowBox[{"v", "[", "0", "]"}], "\[Equal]", " ", ".2"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", " ", "1"}], 
     ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["v", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", " ", "1"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.5980200989310536`*^9, 3.598020171689582*^9}, {
   3.5980202241992736`*^9, 3.59802039280437*^9}, {3.598020424176025*^9, 
   3.5980205019109616`*^9}, {3.5980205409734297`*^9, 
   3.5980205616278667`*^9}, {3.5980209521589527`*^9, 3.598020953484955*^9}, {
   3.5980210114702563`*^9, 3.598021015027063*^9}, 3.5980781057668943`*^9, {
   3.598078143270039*^9, 3.598078158902933*^9}, {3.598079224186864*^9, 
   3.5980792763758492`*^9}, 3.614861862873145*^9, 3.6148646600672584`*^9}],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"v", "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["v", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"v", "[", "t", "]"}], "2"]}]], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"v", "[", "t", "]"}]}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"u", "[", "0", "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{"v", "[", "0", "]"}], "\[Equal]", "0.2`"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["v", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "1"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Output",
 CellChangeTimes->{3.61719475289741*^9, 3.617194896230462*^9, 
  3.6188293069130335`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"v", "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["v", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"v", "[", "t", "]"}], "2"]}]], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"v", "[", "t", "]"}]}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"u", "[", "0", "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{"v", "[", "0", "]"}], "\[Equal]", "0.2`"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["v", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "1"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.614861862873145*^9, 3.6148618628887453`*^9}, 
   3.614864660082858*^9}],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"v", "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["v", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"v", "[", "t", "]"}], "2"]}]], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"v", "[", "t", "]"}]}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"u", "[", "0", "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{"v", "[", "0", "]"}], "\[Equal]", "0.2`"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["v", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "1"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Output",
 CellChangeTimes->{3.6171949050600777`*^9, 3.618829311440292*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"dabs", "[", "t", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"dabs", "[", "t", "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "v"}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.5980200989310536`*^9, 3.598020171689582*^9}, {
   3.5980202241992736`*^9, 3.59802039280437*^9}, {3.598020424176025*^9, 
   3.5980205019109616`*^9}, {3.5980205409734297`*^9, 
   3.5980205616278667`*^9}, {3.5980209521589527`*^9, 3.598020953484955*^9}, {
   3.5980210114702563`*^9, 3.598021015027063*^9}, 3.5980781057668943`*^9, {
   3.598078143270039*^9, 3.598078158902933*^9}, {3.598079224186864*^9, 
   3.598079328933855*^9}, 3.6148618628887453`*^9, 3.6148646600984583`*^9}],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"v", "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["v", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"v", "[", "t", "]"}], "2"]}]], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"v", "[", "t", "]"}]}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "v"}], "}"}], ",", "t"}], "]"}]], "Output",
 CellChangeTimes->{3.6171949115808887`*^9, 3.6188293162945695`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"v", "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["v", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"v", "[", "t", "]"}], "2"]}]], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"v", "[", "t", "]"}]}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "v"}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.6148618628887453`*^9, 3.6148618629043455`*^9}, 
   3.6148646600984583`*^9}],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"v", "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["v", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"v", "[", "t", "]"}], "2"]}]], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"v", "[", "t", "]"}]}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "v"}], "}"}], ",", "t"}], "]"}]], "Output",
 CellChangeTimes->{3.618829320622817*^9}]
}, Closed]],

Cell["We find a numeric solution:", "Text",
 CellChangeTimes->{{3.598078687809185*^9, 3.5980787026570344`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NDSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"dabs", "[", "t", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"dabs", "[", "t", "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"u", "[", "0", "]"}], "\[Equal]", " ", "1."}], ",", 
     RowBox[{
      RowBox[{"v", "[", "0", "]"}], "\[Equal]", " ", ".2"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", " ", "1."}], 
     ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["v", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", " ", "1."}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5980200989310536`*^9, 3.598020171689582*^9}, {
   3.5980202241992736`*^9, 3.59802039280437*^9}, {3.598020424176025*^9, 
   3.5980205019109616`*^9}, {3.5980205409734297`*^9, 
   3.5980205616278667`*^9}, {3.5980209521589527`*^9, 3.598020953484955*^9}, {
   3.5980210114702563`*^9, 3.598021015027063*^9}, {3.5980783063833685`*^9, 
   3.5980783360160637`*^9}, {3.613286573172347*^9, 3.6132866043161287`*^9}, 
   3.6148618629043455`*^9, 3.6148646601140585`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       TemplateBox[{RowBox[{
           StyleBox[
            TagBox["InterpolatingFunction", "SummaryHead"], 
            "NonInterpretableSummary"], 
           StyleBox["[", "NonInterpretableSummary"], 
           DynamicModuleBox[{Typeset`open$$ = False}, 
            PanelBox[
             PaneSelectorBox[{False -> GridBox[{{
                   PaneBox[
                    ButtonBox[
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                    ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                    None, Evaluator -> Automatic, Method -> "Preemptive"], 
                    Alignment -> {Center, Center}, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                   GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAbA3N7f//779YQ8H2b+G4P0nT52zp
9O6/7JQTI/kHvj/78OagW9PtvxPqYXwz68E/WALLBf7E7L8af4/yY7zEP8Qo
6Rzuu+u/37vLJkuZxz8Fp+voZpzqvwi4F5aD0co/8RjT5Q+Q6b9TgeZqPe7N
P7LinpdBbei/rK8lHM210D+BwaT7wE/nvyrJdxxce9I//JOPkHBF5r9gPVzU
qC/UP0u+XtqoJOW/5nRT3+AW1j9G3BJVERfkv6HaK8eY6tc/Tw8BgscO47+x
gNTyvMDZPy2a02MG8OG/MOYs3ETL2z+2GIt2deTgvyNQsoTavd0/KN5NfNqE
37/5D2affuXfPwG1+W9lS92/xMRjo7kG4T8wc2/FUDjbvwuwMDZMDOI/CeGt
hE342L/p1z3cCyzjPzk2tqWq3ta/3ouxW+c75D8SO4cwGZjUvylLkE5xZeU/
CGrMHyNc0r+pGyVm6ovmP1WA23CNRtC/Dai+fyOg5z+XjGZXEgjMv+WXBJib
zOg/MuepkMrPx78cDxTMdOXpPweW1ZK5rMO/TnD3F4H46j9eSCXRll++v9QE
BtrtIew/CQLHAzz/tb9IbJH3/DXtP7f0FrtN1qm/V5RUKeZe7j+IbIIk/QWQ
vw6m86Vvf+8/9JqKEJs6kT8IZtPsr0TwP+pThlQOpao/1UUXTt3S8D/SDzwJ
5ry1P6gmIuVwVfE/PE1kVtf8vT9RcM8WOdPxPwDmNH5BeMM/Umc+RABZ8j+0
1qONVqXHP2R1uIUX0/I/FWiByUgszD80YVoSSlTzP2SV5SA9M9A/HaKyINLJ
8z+hTJZ4ukXSPwauUs4EOvQ/NFR+ZiaF1D9NWVrbObD0P3B0nPIxntY/7iN/
RzIb9T8D5fEULOTYP9E1kIRni/U/eSvT0oof2z9tx4tHx/X1P5iK6i6JNN0/
qa7Yc51V9j8NOjkhdnbfP72F0obXufY/FgHfWAHJ4D8P0yki+hP3PxZQ5+55
0eE/Vj5d4Shp9z9BRwvQafDiPyI4dnATwvc/wUpKgCn84z8n4MtE0xH4P2z2
pHtgHuU/vEmeGddk+D8JjcXESTvmPx6Xu5X3svg/+i8B3QJF5z/pt+jr6fj4
Pxd7WEAzZeg/SFss4LFB+T+I0spyM3LpPzzDtq3Wgvk/JNJY8KqV6j/tywvI
fsb5P7K8rLvUs+s/KygYQRMG+j+VsxtWzr7sP8kDvy30Pvo/o1KmOz/g7T/j
+w5+Enr6PwX+S/B/7u4/F9v9Vfuu+j9sDc3t///vPwMT6/9f4vo/oaD+xg==

                    "]]}}}, {
                    DisplayFunction -> Identity, AspectRatio -> 1, 
                    Axes -> {False, False}, AxesLabel -> {None, None}, 
                    AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                    Frame -> {{True, True}, {True, True}}, 
                    FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                    Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                    FrameTicks -> {{None, None}, {None, None}}, 
                    GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                    Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{-1., 1.}, {0., 
                    1.6802673336798655`}}, PlotRangeClipping -> True, 
                    PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                   GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], ",", "1.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                    AutoDelete -> False, 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> {
                    ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
                 GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False,
                  GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaselinePosition -> {1, 1}], True -> GridBox[{{
                   PaneBox[
                    ButtonBox[
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                    ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                    None, Evaluator -> Automatic, Method -> "Preemptive"], 
                    Alignment -> {Center, Center}, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                   GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAbA3N7f//779YQ8H2b+G4P0nT52zp
9O6/7JQTI/kHvj/78OagW9PtvxPqYXwz68E/WALLBf7E7L8af4/yY7zEP8Qo
6Rzuu+u/37vLJkuZxz8Fp+voZpzqvwi4F5aD0co/8RjT5Q+Q6b9TgeZqPe7N
P7LinpdBbei/rK8lHM210D+BwaT7wE/nvyrJdxxce9I//JOPkHBF5r9gPVzU
qC/UP0u+XtqoJOW/5nRT3+AW1j9G3BJVERfkv6HaK8eY6tc/Tw8BgscO47+x
gNTyvMDZPy2a02MG8OG/MOYs3ETL2z+2GIt2deTgvyNQsoTavd0/KN5NfNqE
37/5D2affuXfPwG1+W9lS92/xMRjo7kG4T8wc2/FUDjbvwuwMDZMDOI/CeGt
hE342L/p1z3cCyzjPzk2tqWq3ta/3ouxW+c75D8SO4cwGZjUvylLkE5xZeU/
CGrMHyNc0r+pGyVm6ovmP1WA23CNRtC/Dai+fyOg5z+XjGZXEgjMv+WXBJib
zOg/MuepkMrPx78cDxTMdOXpPweW1ZK5rMO/TnD3F4H46j9eSCXRll++v9QE
BtrtIew/CQLHAzz/tb9IbJH3/DXtP7f0FrtN1qm/V5RUKeZe7j+IbIIk/QWQ
vw6m86Vvf+8/9JqKEJs6kT8IZtPsr0TwP+pThlQOpao/1UUXTt3S8D/SDzwJ
5ry1P6gmIuVwVfE/PE1kVtf8vT9RcM8WOdPxPwDmNH5BeMM/Umc+RABZ8j+0
1qONVqXHP2R1uIUX0/I/FWiByUgszD80YVoSSlTzP2SV5SA9M9A/HaKyINLJ
8z+hTJZ4ukXSPwauUs4EOvQ/NFR+ZiaF1D9NWVrbObD0P3B0nPIxntY/7iN/
RzIb9T8D5fEULOTYP9E1kIRni/U/eSvT0oof2z9tx4tHx/X1P5iK6i6JNN0/
qa7Yc51V9j8NOjkhdnbfP72F0obXufY/FgHfWAHJ4D8P0yki+hP3PxZQ5+55
0eE/Vj5d4Shp9z9BRwvQafDiPyI4dnATwvc/wUpKgCn84z8n4MtE0xH4P2z2
pHtgHuU/vEmeGddk+D8JjcXESTvmPx6Xu5X3svg/+i8B3QJF5z/pt+jr6fj4
Pxd7WEAzZeg/SFss4LFB+T+I0spyM3LpPzzDtq3Wgvk/JNJY8KqV6j/tywvI
fsb5P7K8rLvUs+s/KygYQRMG+j+VsxtWzr7sP8kDvy30Pvo/o1KmOz/g7T/j
+w5+Enr6PwX+S/B/7u4/F9v9Vfuu+j9sDc3t///vPwMT6/9f4vo/oaD+xg==

                    "]]}}}, {
                    DisplayFunction -> Identity, AspectRatio -> 1, 
                    Axes -> {False, False}, AxesLabel -> {None, None}, 
                    AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                    Frame -> {{True, True}, {True, True}}, 
                    FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                    Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                    FrameTicks -> {{None, None}, {None, None}}, 
                    GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                    Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{-1., 1.}, {0., 
                    1.6802673336798655`}}, PlotRangeClipping -> True, 
                    PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                   GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], ",", "1.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                    AutoDelete -> False, 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> {
                    ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
                 GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False,
                  GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaselinePosition -> {1, 1}]}, 
              Dynamic[Typeset`open$$], ImageSize -> Automatic], 
             BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
           StyleBox["]", "NonInterpretableSummary"]}]},
        "CopyTag",
        DisplayFunction->(#& ),
        InterpretationFunction->("InterpolatingFunction[{{-1., 1.}}, <>]"& )],
       False,
       Editable->False,
       SelectWithContents->True,
       Selectable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"v", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       TemplateBox[{RowBox[{
           StyleBox[
            TagBox["InterpolatingFunction", "SummaryHead"], 
            "NonInterpretableSummary"], 
           StyleBox["[", "NonInterpretableSummary"], 
           DynamicModuleBox[{Typeset`open$$ = False}, 
            PanelBox[
             PaneSelectorBox[{False -> GridBox[{{
                   PaneBox[
                    ButtonBox[
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                    ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                    None, Evaluator -> Automatic, Method -> "Preemptive"], 
                    Alignment -> {Center, Center}, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                   GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAbA3N7f//778VQeB4QRzrv0nT52zp
9O6/fAjXJm/g6b/78OagW9Ptv/ct7NIxjei/WALLBf7E7L8OvQ6reFPnv8Qo
6Rzuu+u/VwNYKtAi5r8Fp+voZpzqvyYoRvum2+S/8RjT5Q+Q6b8AYNHZe63j
v7LinpdBbei/Y8D+0H1p4r+BwaT7wE/nvwHjL/LuLuG//JOPkHBF5r+3nnNR
pwzgv0u+XtqoJOW/7C+Yw4qq3b9G3BJVERfkv9XmQfFla9u/Tw8BgscO47+/
h6yNQz3Zvy2a02MG8OG/AqBr1NXl1r+2GIt2deTgv7ou8bkGvNS/KN5NfNqE
37/I2WovXmnSvwG1+W9lS92/7uupH+Im0L8wc2/FUDjbv9GlVeZiH8y/CeGt
hE342L8t3ULO057Hvzk2tqWq3ta/TN/OkeVxw78SO4cwGZjUv4/bTpqw472/
CGrMHyNc0r8FGyqvcxe1v1WA23CNRtC/x22X2mzRqb+XjGZXEgjMv150A9kM
N5C/MuepkMrPx790SqHB8NWQPweW1ZK5rMO/id786M+gqD9eSCXRll++v28P
kL93H7U/CQLHAzz/tb9wjumDN169P7f0FrtN1qm/QwqtF8Irwz+IbIIk/QWQ
v981IcKimcc/9JqKEJs6kT8bOBgN4MHLP+pThlQOpao/KKy6Py8m0D/SDzwJ
5ry1P6UZgdwtSdI/PE1kVtf8vT9on6xC72XUPwDmNH5BeMM/goWMti621j+0
1qONVqXHPytB6Kw35Ng/FWiByUgszD8XwhoTakfbP2SV5SA9M9A/m36G2juI
3T+hTJZ4ukXSP8rgl2qgw98/NFR+ZiaF1D8GxUQcEBvhP3B0nPIxntY/cJaZ
X5tC4j8D5fEULOTYP/AZx7VdhuM/eSvT0oof2z8OW2oav8fkP5iK6i6JNN0/
4av/Zqn25T8NOjkhdnbfP1Pqqo54Quc/FgHfWAHJ4D/gU1z6V3voPxZQ5+55
0eE/d8Xlnuew6T9BRwvQafDiPz2FbA/cA+s/wUpKgCn84z/pweWK+ELsP2z2
pHtgHuU/wSsomNWf7T8JjcXESTvmP4V0rBI6+e4/+i8B3QJF5z9PPxgS7R7w
Pxd7WEAzZeg/EYwze0TQ8D+I0spyM3LpP5Jdq/r5dvE/JNJY8KqV6j+vskwe
1SzyP7K8rLvUs+s/8wfGt4/g8j+VsxtWzr7sP0az8MQ+ifM/o1KmOz/g7T8B
+TwtK0H0PwX+S/B/7u4/kFSBW9Xt9D9sDc3t///vP6j7V0pynfU/xnAK5A==

                    "]]}}}, {
                    DisplayFunction -> Identity, AspectRatio -> 1, 
                    Axes -> {False, False}, AxesLabel -> {None, None}, 
                    AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                    Frame -> {{True, True}, {True, True}}, 
                    FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                    Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                    FrameTicks -> {{None, None}, {None, None}}, 
                    GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                    Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{-1., 1.}, {-0.8471991883143654, 
                    1.350939073948874}}, PlotRangeClipping -> True, 
                    PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                   GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], ",", "1.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                    AutoDelete -> False, 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> {
                    ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
                 GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False,
                  GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaselinePosition -> {1, 1}], True -> GridBox[{{
                   PaneBox[
                    ButtonBox[
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                    ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                    None, Evaluator -> Automatic, Method -> "Preemptive"], 
                    Alignment -> {Center, Center}, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                   GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAbA3N7f//778VQeB4QRzrv0nT52zp
9O6/fAjXJm/g6b/78OagW9Ptv/ct7NIxjei/WALLBf7E7L8OvQ6reFPnv8Qo
6Rzuu+u/VwNYKtAi5r8Fp+voZpzqvyYoRvum2+S/8RjT5Q+Q6b8AYNHZe63j
v7LinpdBbei/Y8D+0H1p4r+BwaT7wE/nvwHjL/LuLuG//JOPkHBF5r+3nnNR
pwzgv0u+XtqoJOW/7C+Yw4qq3b9G3BJVERfkv9XmQfFla9u/Tw8BgscO47+/
h6yNQz3Zvy2a02MG8OG/AqBr1NXl1r+2GIt2deTgv7ou8bkGvNS/KN5NfNqE
37/I2WovXmnSvwG1+W9lS92/7uupH+Im0L8wc2/FUDjbv9GlVeZiH8y/CeGt
hE342L8t3ULO057Hvzk2tqWq3ta/TN/OkeVxw78SO4cwGZjUv4/bTpqw472/
CGrMHyNc0r8FGyqvcxe1v1WA23CNRtC/x22X2mzRqb+XjGZXEgjMv150A9kM
N5C/MuepkMrPx790SqHB8NWQPweW1ZK5rMO/id786M+gqD9eSCXRll++v28P
kL93H7U/CQLHAzz/tb9wjumDN169P7f0FrtN1qm/QwqtF8Irwz+IbIIk/QWQ
v981IcKimcc/9JqKEJs6kT8bOBgN4MHLP+pThlQOpao/KKy6Py8m0D/SDzwJ
5ry1P6UZgdwtSdI/PE1kVtf8vT9on6xC72XUPwDmNH5BeMM/goWMti621j+0
1qONVqXHPytB6Kw35Ng/FWiByUgszD8XwhoTakfbP2SV5SA9M9A/m36G2juI
3T+hTJZ4ukXSP8rgl2qgw98/NFR+ZiaF1D8GxUQcEBvhP3B0nPIxntY/cJaZ
X5tC4j8D5fEULOTYP/AZx7VdhuM/eSvT0oof2z8OW2oav8fkP5iK6i6JNN0/
4av/Zqn25T8NOjkhdnbfP1Pqqo54Quc/FgHfWAHJ4D/gU1z6V3voPxZQ5+55
0eE/d8Xlnuew6T9BRwvQafDiPz2FbA/cA+s/wUpKgCn84z/pweWK+ELsP2z2
pHtgHuU/wSsomNWf7T8JjcXESTvmP4V0rBI6+e4/+i8B3QJF5z9PPxgS7R7w
Pxd7WEAzZeg/EYwze0TQ8D+I0spyM3LpP5Jdq/r5dvE/JNJY8KqV6j+vskwe
1SzyP7K8rLvUs+s/8wfGt4/g8j+VsxtWzr7sP0az8MQ+ifM/o1KmOz/g7T8B
+TwtK0H0PwX+S/B/7u4/kFSBW9Xt9D9sDc3t///vP6j7V0pynfU/xnAK5A==

                    "]]}}}, {
                    DisplayFunction -> Identity, AspectRatio -> 1, 
                    Axes -> {False, False}, AxesLabel -> {None, None}, 
                    AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                    Frame -> {{True, True}, {True, True}}, 
                    FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                    Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                    FrameTicks -> {{None, None}, {None, None}}, 
                    GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                    Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{-1., 1.}, {-0.8471991883143654, 
                    1.350939073948874}}, PlotRangeClipping -> True, 
                    PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                   GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], ",", "1.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                    AutoDelete -> False, 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> {
                    ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
                 GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False,
                  GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaselinePosition -> {1, 1}]}, 
              Dynamic[Typeset`open$$], ImageSize -> Automatic], 
             BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
           StyleBox["]", "NonInterpretableSummary"]}]},
        "CopyTag",
        DisplayFunction->(#& ),
        InterpretationFunction->("InterpolatingFunction[{{-1., 1.}}, <>]"& )],
       False,
       Editable->False,
       SelectWithContents->True,
       Selectable->False], "[", "t", "]"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.598020151534346*^9, 3.5980205171989884`*^9, 3.598020564420271*^9, 
   3.5980209735153894`*^9, 3.598021020424672*^9, 3.5980783491018124`*^9, 
   3.613286521910415*^9, {3.6132865836699476`*^9, 3.6132866087383814`*^9}, 
   3.613287105264781*^9, 3.6171949216741066`*^9, 3.618829326627161*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fu", "[", "t_", "]"}], " ", "=", 
  RowBox[{
   RowBox[{"u", "[", "t", "]"}], "/.", 
   RowBox[{
    RowBox[{"Flatten", "[", "%", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5980105673455124`*^9, 3.598010700881747*^9}, {
  3.5980110599163775`*^9, 3.59801106141398*^9}}],

Cell[BoxData[
 RowBox[{
  TagBox[
   TemplateBox[{RowBox[{
       StyleBox[
        TagBox["InterpolatingFunction", "SummaryHead"], 
        "NonInterpretableSummary"], 
       StyleBox["[", "NonInterpretableSummary"], 
       DynamicModuleBox[{Typeset`open$$ = False}, 
        PanelBox[
         PaneSelectorBox[{False -> GridBox[{{
               PaneBox[
                ButtonBox[
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "FEBitmaps", "SquarePlusIconMedium"]], 
                 ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                 None, Evaluator -> Automatic, Method -> "Preemptive"], 
                Alignment -> {Center, Center}, ImageSize -> 
                Dynamic[{
                  Automatic, 
                   3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
               GraphicsBox[{{{}, {}, {
                   Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                   LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAbA3N7f//779YQ8H2b+G4P0nT52zp
9O6/7JQTI/kHvj/78OagW9PtvxPqYXwz68E/WALLBf7E7L8af4/yY7zEP8Qo
6Rzuu+u/37vLJkuZxz8Fp+voZpzqvwi4F5aD0co/8RjT5Q+Q6b9TgeZqPe7N
P7LinpdBbei/rK8lHM210D+BwaT7wE/nvyrJdxxce9I//JOPkHBF5r9gPVzU
qC/UP0u+XtqoJOW/5nRT3+AW1j9G3BJVERfkv6HaK8eY6tc/Tw8BgscO47+x
gNTyvMDZPy2a02MG8OG/MOYs3ETL2z+2GIt2deTgvyNQsoTavd0/KN5NfNqE
37/5D2affuXfPwG1+W9lS92/xMRjo7kG4T8wc2/FUDjbvwuwMDZMDOI/CeGt
hE342L/p1z3cCyzjPzk2tqWq3ta/3ouxW+c75D8SO4cwGZjUvylLkE5xZeU/
CGrMHyNc0r+pGyVm6ovmP1WA23CNRtC/Dai+fyOg5z+XjGZXEgjMv+WXBJib
zOg/MuepkMrPx78cDxTMdOXpPweW1ZK5rMO/TnD3F4H46j9eSCXRll++v9QE
BtrtIew/CQLHAzz/tb9IbJH3/DXtP7f0FrtN1qm/V5RUKeZe7j+IbIIk/QWQ
vw6m86Vvf+8/9JqKEJs6kT8IZtPsr0TwP+pThlQOpao/1UUXTt3S8D/SDzwJ
5ry1P6gmIuVwVfE/PE1kVtf8vT9RcM8WOdPxPwDmNH5BeMM/Umc+RABZ8j+0
1qONVqXHP2R1uIUX0/I/FWiByUgszD80YVoSSlTzP2SV5SA9M9A/HaKyINLJ
8z+hTJZ4ukXSPwauUs4EOvQ/NFR+ZiaF1D9NWVrbObD0P3B0nPIxntY/7iN/
RzIb9T8D5fEULOTYP9E1kIRni/U/eSvT0oof2z9tx4tHx/X1P5iK6i6JNN0/
qa7Yc51V9j8NOjkhdnbfP72F0obXufY/FgHfWAHJ4D8P0yki+hP3PxZQ5+55
0eE/Vj5d4Shp9z9BRwvQafDiPyI4dnATwvc/wUpKgCn84z8n4MtE0xH4P2z2
pHtgHuU/vEmeGddk+D8JjcXESTvmPx6Xu5X3svg/+i8B3QJF5z/pt+jr6fj4
Pxd7WEAzZeg/SFss4LFB+T+I0spyM3LpPzzDtq3Wgvk/JNJY8KqV6j/tywvI
fsb5P7K8rLvUs+s/KygYQRMG+j+VsxtWzr7sP8kDvy30Pvo/o1KmOz/g7T/j
+w5+Enr6PwX+S/B/7u4/F9v9Vfuu+j9sDc3t///vPwMT6/9f4vo/oaD+xg==

                    "]]}}}, {
                DisplayFunction -> Identity, AspectRatio -> 1, 
                 Axes -> {False, False}, AxesLabel -> {None, None}, 
                 AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                 Frame -> {{True, True}, {True, True}}, 
                 FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                 Directive[
                   Opacity[0.5], 
                   Thickness[Tiny], 
                   RGBColor[0.368417, 0.506779, 0.709798]], 
                 FrameTicks -> {{None, None}, {None, None}}, 
                 GridLines -> {None, None}, GridLinesStyle -> Directive[
                   GrayLevel[0.5, 0.4]], ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                 Method -> {
                  "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                   None}, PlotRange -> {{-1., 1.}, {0., 1.6802673336798655`}},
                  PlotRangeClipping -> True, PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
               GridBox[{{
                  RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], ",", "1.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {
                 "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                BaseStyle -> {
                 ShowStringCharacters -> False, NumberMarks -> False, 
                  PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
             GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             BaselinePosition -> {1, 1}], True -> GridBox[{{
               PaneBox[
                ButtonBox[
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "FEBitmaps", "SquareMinusIconMedium"]], 
                 ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                 None, Evaluator -> Automatic, Method -> "Preemptive"], 
                Alignment -> {Center, Center}, ImageSize -> 
                Dynamic[{
                  Automatic, 
                   3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
               GraphicsBox[{{{}, {}, {
                   Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                   LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAbA3N7f//779YQ8H2b+G4P0nT52zp
9O6/7JQTI/kHvj/78OagW9PtvxPqYXwz68E/WALLBf7E7L8af4/yY7zEP8Qo
6Rzuu+u/37vLJkuZxz8Fp+voZpzqvwi4F5aD0co/8RjT5Q+Q6b9TgeZqPe7N
P7LinpdBbei/rK8lHM210D+BwaT7wE/nvyrJdxxce9I//JOPkHBF5r9gPVzU
qC/UP0u+XtqoJOW/5nRT3+AW1j9G3BJVERfkv6HaK8eY6tc/Tw8BgscO47+x
gNTyvMDZPy2a02MG8OG/MOYs3ETL2z+2GIt2deTgvyNQsoTavd0/KN5NfNqE
37/5D2affuXfPwG1+W9lS92/xMRjo7kG4T8wc2/FUDjbvwuwMDZMDOI/CeGt
hE342L/p1z3cCyzjPzk2tqWq3ta/3ouxW+c75D8SO4cwGZjUvylLkE5xZeU/
CGrMHyNc0r+pGyVm6ovmP1WA23CNRtC/Dai+fyOg5z+XjGZXEgjMv+WXBJib
zOg/MuepkMrPx78cDxTMdOXpPweW1ZK5rMO/TnD3F4H46j9eSCXRll++v9QE
BtrtIew/CQLHAzz/tb9IbJH3/DXtP7f0FrtN1qm/V5RUKeZe7j+IbIIk/QWQ
vw6m86Vvf+8/9JqKEJs6kT8IZtPsr0TwP+pThlQOpao/1UUXTt3S8D/SDzwJ
5ry1P6gmIuVwVfE/PE1kVtf8vT9RcM8WOdPxPwDmNH5BeMM/Umc+RABZ8j+0
1qONVqXHP2R1uIUX0/I/FWiByUgszD80YVoSSlTzP2SV5SA9M9A/HaKyINLJ
8z+hTJZ4ukXSPwauUs4EOvQ/NFR+ZiaF1D9NWVrbObD0P3B0nPIxntY/7iN/
RzIb9T8D5fEULOTYP9E1kIRni/U/eSvT0oof2z9tx4tHx/X1P5iK6i6JNN0/
qa7Yc51V9j8NOjkhdnbfP72F0obXufY/FgHfWAHJ4D8P0yki+hP3PxZQ5+55
0eE/Vj5d4Shp9z9BRwvQafDiPyI4dnATwvc/wUpKgCn84z8n4MtE0xH4P2z2
pHtgHuU/vEmeGddk+D8JjcXESTvmPx6Xu5X3svg/+i8B3QJF5z/pt+jr6fj4
Pxd7WEAzZeg/SFss4LFB+T+I0spyM3LpPzzDtq3Wgvk/JNJY8KqV6j/tywvI
fsb5P7K8rLvUs+s/KygYQRMG+j+VsxtWzr7sP8kDvy30Pvo/o1KmOz/g7T/j
+w5+Enr6PwX+S/B/7u4/F9v9Vfuu+j9sDc3t///vPwMT6/9f4vo/oaD+xg==

                    "]]}}}, {
                DisplayFunction -> Identity, AspectRatio -> 1, 
                 Axes -> {False, False}, AxesLabel -> {None, None}, 
                 AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                 Frame -> {{True, True}, {True, True}}, 
                 FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                 Directive[
                   Opacity[0.5], 
                   Thickness[Tiny], 
                   RGBColor[0.368417, 0.506779, 0.709798]], 
                 FrameTicks -> {{None, None}, {None, None}}, 
                 GridLines -> {None, None}, GridLinesStyle -> Directive[
                   GrayLevel[0.5, 0.4]], ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                 Method -> {
                  "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                   None}, PlotRange -> {{-1., 1.}, {0., 1.6802673336798655`}},
                  PlotRangeClipping -> True, PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
               GridBox[{{
                  RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], ",", "1.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {
                 "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                BaseStyle -> {
                 ShowStringCharacters -> False, NumberMarks -> False, 
                  PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
             GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             BaselinePosition -> {1, 1}]}, 
          Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
         Baseline], DynamicModuleValues :> {}], 
       StyleBox["]", "NonInterpretableSummary"]}]},
    "CopyTag",
    DisplayFunction->(#& ),
    InterpretationFunction->("InterpolatingFunction[{{-1., 1.}}, <>]"& )],
   False,
   Editable->False,
   SelectWithContents->True,
   Selectable->False], "[", "t", "]"}]], "Output",
 CellChangeTimes->{3.598020658254436*^9, 3.598021025541481*^9, 
  3.5980783691259575`*^9, 3.613287112734208*^9, 3.6171949280545177`*^9, 
  3.618829339503897*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"gu", "[", "t_", "]"}], " ", "=", 
  RowBox[{
   RowBox[{"v", "[", "t", "]"}], "/.", 
   RowBox[{
    RowBox[{"Flatten", "[", "%%", "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5980105673455124`*^9, 3.5980107410050173`*^9}, {
  3.598011081772016*^9, 3.598011083410019*^9}}],

Cell[BoxData[
 RowBox[{
  TagBox[
   TemplateBox[{RowBox[{
       StyleBox[
        TagBox["InterpolatingFunction", "SummaryHead"], 
        "NonInterpretableSummary"], 
       StyleBox["[", "NonInterpretableSummary"], 
       DynamicModuleBox[{Typeset`open$$ = False}, 
        PanelBox[
         PaneSelectorBox[{False -> GridBox[{{
               PaneBox[
                ButtonBox[
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "FEBitmaps", "SquarePlusIconMedium"]], 
                 ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                 None, Evaluator -> Automatic, Method -> "Preemptive"], 
                Alignment -> {Center, Center}, ImageSize -> 
                Dynamic[{
                  Automatic, 
                   3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
               GraphicsBox[{{{}, {}, {
                   Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                   LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAbA3N7f//778VQeB4QRzrv0nT52zp
9O6/fAjXJm/g6b/78OagW9Ptv/ct7NIxjei/WALLBf7E7L8OvQ6reFPnv8Qo
6Rzuu+u/VwNYKtAi5r8Fp+voZpzqvyYoRvum2+S/8RjT5Q+Q6b8AYNHZe63j
v7LinpdBbei/Y8D+0H1p4r+BwaT7wE/nvwHjL/LuLuG//JOPkHBF5r+3nnNR
pwzgv0u+XtqoJOW/7C+Yw4qq3b9G3BJVERfkv9XmQfFla9u/Tw8BgscO47+/
h6yNQz3Zvy2a02MG8OG/AqBr1NXl1r+2GIt2deTgv7ou8bkGvNS/KN5NfNqE
37/I2WovXmnSvwG1+W9lS92/7uupH+Im0L8wc2/FUDjbv9GlVeZiH8y/CeGt
hE342L8t3ULO057Hvzk2tqWq3ta/TN/OkeVxw78SO4cwGZjUv4/bTpqw472/
CGrMHyNc0r8FGyqvcxe1v1WA23CNRtC/x22X2mzRqb+XjGZXEgjMv150A9kM
N5C/MuepkMrPx790SqHB8NWQPweW1ZK5rMO/id786M+gqD9eSCXRll++v28P
kL93H7U/CQLHAzz/tb9wjumDN169P7f0FrtN1qm/QwqtF8Irwz+IbIIk/QWQ
v981IcKimcc/9JqKEJs6kT8bOBgN4MHLP+pThlQOpao/KKy6Py8m0D/SDzwJ
5ry1P6UZgdwtSdI/PE1kVtf8vT9on6xC72XUPwDmNH5BeMM/goWMti621j+0
1qONVqXHPytB6Kw35Ng/FWiByUgszD8XwhoTakfbP2SV5SA9M9A/m36G2juI
3T+hTJZ4ukXSP8rgl2qgw98/NFR+ZiaF1D8GxUQcEBvhP3B0nPIxntY/cJaZ
X5tC4j8D5fEULOTYP/AZx7VdhuM/eSvT0oof2z8OW2oav8fkP5iK6i6JNN0/
4av/Zqn25T8NOjkhdnbfP1Pqqo54Quc/FgHfWAHJ4D/gU1z6V3voPxZQ5+55
0eE/d8Xlnuew6T9BRwvQafDiPz2FbA/cA+s/wUpKgCn84z/pweWK+ELsP2z2
pHtgHuU/wSsomNWf7T8JjcXESTvmP4V0rBI6+e4/+i8B3QJF5z9PPxgS7R7w
Pxd7WEAzZeg/EYwze0TQ8D+I0spyM3LpP5Jdq/r5dvE/JNJY8KqV6j+vskwe
1SzyP7K8rLvUs+s/8wfGt4/g8j+VsxtWzr7sP0az8MQ+ifM/o1KmOz/g7T8B
+TwtK0H0PwX+S/B/7u4/kFSBW9Xt9D9sDc3t///vP6j7V0pynfU/xnAK5A==

                    "]]}}}, {
                DisplayFunction -> Identity, AspectRatio -> 1, 
                 Axes -> {False, False}, AxesLabel -> {None, None}, 
                 AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                 Frame -> {{True, True}, {True, True}}, 
                 FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                 Directive[
                   Opacity[0.5], 
                   Thickness[Tiny], 
                   RGBColor[0.368417, 0.506779, 0.709798]], 
                 FrameTicks -> {{None, None}, {None, None}}, 
                 GridLines -> {None, None}, GridLinesStyle -> Directive[
                   GrayLevel[0.5, 0.4]], ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                 Method -> {
                  "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                   None}, PlotRange -> {{-1., 1.}, {-0.8471991883143654, 
                  1.350939073948874}}, PlotRangeClipping -> True, 
                 PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
               GridBox[{{
                  RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], ",", "1.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {
                 "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                BaseStyle -> {
                 ShowStringCharacters -> False, NumberMarks -> False, 
                  PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
             GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             BaselinePosition -> {1, 1}], True -> GridBox[{{
               PaneBox[
                ButtonBox[
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "FEBitmaps", "SquareMinusIconMedium"]], 
                 ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                 None, Evaluator -> Automatic, Method -> "Preemptive"], 
                Alignment -> {Center, Center}, ImageSize -> 
                Dynamic[{
                  Automatic, 
                   3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
               GraphicsBox[{{{}, {}, {
                   Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                   LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAbA3N7f//778VQeB4QRzrv0nT52zp
9O6/fAjXJm/g6b/78OagW9Ptv/ct7NIxjei/WALLBf7E7L8OvQ6reFPnv8Qo
6Rzuu+u/VwNYKtAi5r8Fp+voZpzqvyYoRvum2+S/8RjT5Q+Q6b8AYNHZe63j
v7LinpdBbei/Y8D+0H1p4r+BwaT7wE/nvwHjL/LuLuG//JOPkHBF5r+3nnNR
pwzgv0u+XtqoJOW/7C+Yw4qq3b9G3BJVERfkv9XmQfFla9u/Tw8BgscO47+/
h6yNQz3Zvy2a02MG8OG/AqBr1NXl1r+2GIt2deTgv7ou8bkGvNS/KN5NfNqE
37/I2WovXmnSvwG1+W9lS92/7uupH+Im0L8wc2/FUDjbv9GlVeZiH8y/CeGt
hE342L8t3ULO057Hvzk2tqWq3ta/TN/OkeVxw78SO4cwGZjUv4/bTpqw472/
CGrMHyNc0r8FGyqvcxe1v1WA23CNRtC/x22X2mzRqb+XjGZXEgjMv150A9kM
N5C/MuepkMrPx790SqHB8NWQPweW1ZK5rMO/id786M+gqD9eSCXRll++v28P
kL93H7U/CQLHAzz/tb9wjumDN169P7f0FrtN1qm/QwqtF8Irwz+IbIIk/QWQ
v981IcKimcc/9JqKEJs6kT8bOBgN4MHLP+pThlQOpao/KKy6Py8m0D/SDzwJ
5ry1P6UZgdwtSdI/PE1kVtf8vT9on6xC72XUPwDmNH5BeMM/goWMti621j+0
1qONVqXHPytB6Kw35Ng/FWiByUgszD8XwhoTakfbP2SV5SA9M9A/m36G2juI
3T+hTJZ4ukXSP8rgl2qgw98/NFR+ZiaF1D8GxUQcEBvhP3B0nPIxntY/cJaZ
X5tC4j8D5fEULOTYP/AZx7VdhuM/eSvT0oof2z8OW2oav8fkP5iK6i6JNN0/
4av/Zqn25T8NOjkhdnbfP1Pqqo54Quc/FgHfWAHJ4D/gU1z6V3voPxZQ5+55
0eE/d8Xlnuew6T9BRwvQafDiPz2FbA/cA+s/wUpKgCn84z/pweWK+ELsP2z2
pHtgHuU/wSsomNWf7T8JjcXESTvmP4V0rBI6+e4/+i8B3QJF5z9PPxgS7R7w
Pxd7WEAzZeg/EYwze0TQ8D+I0spyM3LpP5Jdq/r5dvE/JNJY8KqV6j+vskwe
1SzyP7K8rLvUs+s/8wfGt4/g8j+VsxtWzr7sP0az8MQ+ifM/o1KmOz/g7T8B
+TwtK0H0PwX+S/B/7u4/kFSBW9Xt9D9sDc3t///vP6j7V0pynfU/xnAK5A==

                    "]]}}}, {
                DisplayFunction -> Identity, AspectRatio -> 1, 
                 Axes -> {False, False}, AxesLabel -> {None, None}, 
                 AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                 Frame -> {{True, True}, {True, True}}, 
                 FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                 Directive[
                   Opacity[0.5], 
                   Thickness[Tiny], 
                   RGBColor[0.368417, 0.506779, 0.709798]], 
                 FrameTicks -> {{None, None}, {None, None}}, 
                 GridLines -> {None, None}, GridLinesStyle -> Directive[
                   GrayLevel[0.5, 0.4]], ImageSize -> 
                 Dynamic[{
                   Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                 Method -> {
                  "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                   None}, PlotRange -> {{-1., 1.}, {-0.8471991883143654, 
                  1.350939073948874}}, PlotRangeClipping -> True, 
                 PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
               GridBox[{{
                  RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], ",", "1.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {
                 "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                BaseStyle -> {
                 ShowStringCharacters -> False, NumberMarks -> False, 
                  PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
             GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             BaselinePosition -> {1, 1}]}, 
          Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
         Baseline], DynamicModuleValues :> {}], 
       StyleBox["]", "NonInterpretableSummary"]}]},
    "CopyTag",
    DisplayFunction->(#& ),
    InterpretationFunction->("InterpolatingFunction[{{-1., 1.}}, <>]"& )],
   False,
   Editable->False,
   SelectWithContents->True,
   Selectable->False], "[", "t", "]"}]], "Output",
 CellChangeTimes->{3.5980206617644424`*^9, 3.5980210285054865`*^9, 
  3.598078369186961*^9, 3.613287117817499*^9, 3.617194931080923*^9, 
  3.6188293443031716`*^9}]
}, Closed]],

Cell["Here is the geodesic:", "Text",
 CellChangeTimes->{{3.5980787235852313`*^9, 3.5980787307136393`*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"rsf", "[", "w", "]"}], "[", 
    RowBox[{
     RowBox[{"fu", "[", "t", "]"}], ",", 
     RowBox[{"gu", "[", "t", "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"PlotStyle", " ", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Thick", ",", "Red"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.59793530857513*^9, 3.597935328999298*^9}, {
   3.597935372503786*^9, 3.597935416552306*^9}, 3.5979361503762784`*^9, {
   3.5980107984599185`*^9, 3.5980108206743574`*^9}, {3.5980108954452887`*^9, 
   3.5980109588282003`*^9}, {3.5980111031908536`*^9, 
   3.5980111599125533`*^9}, {3.598020677192869*^9, 3.598020773601039*^9}, {
   3.6132873225702105`*^9, 3.613287327424488*^9}, {3.617195528998773*^9, 
   3.617195531619578*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"geod1", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.598020793662674*^9, 3.5980208002614856`*^9}}],

Cell["Its position on the surface is shown here:", "Text",
 CellChangeTimes->{{3.5980788702026176`*^9, 3.5980788941529875`*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{"rsf1", ",", "geod1"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.5980208669204025`*^9, 3.5980208873408384`*^9}}],

Cell["\<\
We control the deviation of the absolute differential from the null vector:\
\>", "Text",
 CellChangeTimes->{{3.6171956229421387`*^9, 3.6171956730962267`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fu", "[", "t", "]"}], ",", 
     RowBox[{"gu", "[", "t", "]"}]}], "}"}]}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"DD1", "[", 
     RowBox[{
      RowBox[{"rsf", "[", "w", "]"}], ",", "\[Gamma]", ",", 
      SuperscriptBox["\[Gamma]", "\[Prime]",
       MultilineFunction->None]}], "]"}], "[", "t", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.617195036006707*^9, 3.617195039142313*^9}, 
   3.6171950857239947`*^9, {3.61719513417768*^9, 3.617195172038946*^9}}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"%", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "^", "2"}], " ", "+", " ", 
    RowBox[{
     RowBox[{"%", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "^", "2"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.617195254859492*^9, 3.617195319771206*^9}, {
  3.6171953742309017`*^9, 3.6171953918901324`*^9}, {3.6171954242757893`*^9, 
  3.617195429735799*^9}}],

Cell["\<\
The deviation is comparatively small.
Find more geodesics with other initial conditions.\
\>", "Text",
 CellChangeTimes->{{3.5980789447378807`*^9, 3.598078967265169*^9}, {
  3.6171956903654566`*^9, 3.6171957148886995`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2.6. Geodesic Curvature", "Subsubsection",
 CellChangeTimes->{{3.595076945363204*^9, 3.5950769905720835`*^9}, 
   3.5953174793534184`*^9, {3.5953175263051033`*^9, 3.595317587064579*^9}, 
   3.5956008724322104`*^9, {3.5965213907316623`*^9, 3.5965214041788855`*^9}, {
   3.5972984401750546`*^9, 3.59729846072029*^9}, {3.5972984954771514`*^9, 
   3.5972985062723703`*^9}, {3.5973320886172123`*^9, 3.5973320905123205`*^9}, 
   3.5973952636966553`*^9, {3.597729800827932*^9, 3.59772986233884*^9}, {
   3.597910399537461*^9, 3.597910436118553*^9}, {3.5979116271266747`*^9, 
   3.5979116482228813`*^9}, {3.5988859626392813`*^9, 3.5988859896078234`*^9}, 
   3.613287406886033*^9, 3.6145881974242153`*^9, 3.6171958241200914`*^9, 
   3.617440712305024*^9}],

Cell[TextData[{
 "Already in Section 3.4 we introduced the ",
 ButtonBox["geodesic curvature",
  BaseStyle->"Hyperlink",
  ButtonData->"geodc"],
 " of a curve on the surface sf[u;v]:"
}], "Text",
 CellChangeTimes->{{3.598943532606222*^9, 3.598943598786008*^9}, {
  3.5989437640264587`*^9, 3.59894377804226*^9}, {3.598943994802658*^9, 
  3.5989440320987916`*^9}, {3.614313265943533*^9, 3.6143132659465327`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"cx", "[", "s_", "]"}], " ", ":=", " ", 
  RowBox[{"sf", "[", 
   RowBox[{
    RowBox[{"hu", "[", "s", "]"}], ",", 
    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5911639056057415`*^9, 3.5911639586847773`*^9}, 
   3.5911644865179677`*^9, 3.618135579701305*^9, {3.6188395679109087`*^9, 
   3.618839573838919*^9}, 3.6188396059437757`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Gamma]", "[", "s_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"hu", "[", "s", "]"}], ",", 
    RowBox[{"hv", "[", "s", "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5911640806537533`*^9, 3.5911641202370176`*^9}}],

Cell[TextData[{
 "We calculate the curvature vector of the curve cx[s] \[Element] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "3"], TraditionalForm]]],
 "s the arc length, under this assumption:"
}], "Text",
 CellChangeTimes->{{3.5990257160305843`*^9, 3.5990257932975206`*^9}, 
   3.5990258639656444`*^9, 3.618135581074107*^9, {3.6181360567969427`*^9, 
   3.6181360986986165`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"cx", "[", "s", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", "2"}], "}"}]}], "]"}], ",", 
   RowBox[{"scond2", "[", "sf", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5989446013283496`*^9, 3.5989446663580694`*^9}, 
   3.6136210267017107`*^9, {3.6172830626050825`*^9, 3.6172830651634874`*^9}, 
   3.618135583492111*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["hv", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["hv", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["hu", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["hu", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox["hv", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["hu", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["hv", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["hv", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["hu", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["hu", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox["hv", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["hu", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["hv", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["hv", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["hu", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["hu", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox["hv", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["hu", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5989447548671317`*^9}]
}, Closed]],

Cell["\<\
Warning. The last cell needs a long evaluation time and possibly can\
\[CloseCurlyQuote]t be evaluated on too week computers. 
Using this simplification we define a formula to calculate the curvature \
vector as the second derivative of the curve cx[s], s its arc length:\
\>", "Text",
 CellChangeTimes->{{3.59894497180654*^9, 3.598945037306286*^9}, {
   3.598945077202568*^9, 3.598945138706086*^9}, 3.6172010145564814`*^9, {
   3.617336690851932*^9, 3.6173367837032948`*^9}, {3.6173369022519894`*^9, 
   3.6173370104041758`*^9}, 3.617441792188218*^9, 3.6181355864405165`*^9, 
   3.618136128666269*^9, {3.6181361761059523`*^9, 3.618136187587572*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"d2cx", "[", "s_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["hv", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["hv", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["hu", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["hu", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox["hv", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["hu", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["hv", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["hv", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["hu", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["hu", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox["hv", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["hu", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["hv", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["hv", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["hu", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["hu", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox["hv", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["hu", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5989449039436584`*^9, 3.5989449378745995`*^9}, 
   3.6181355885621204`*^9}],

Cell[TextData[{
 "It coincides with the vector ",
 ButtonBox["ccc[s] calculated in Section 3.4",
  BaseStyle->"Hyperlink",
  ButtonData->"ccc"],
 ", as expected:"
}], "Text",
 CellChangeTimes->{{3.598945287538599*^9, 3.5989453046125755`*^9}, {
   3.5989454775794687`*^9, 3.5989455059860935`*^9}, {3.5989456271360226`*^9, 
   3.5989456271400228`*^9}, 3.59902396562951*^9, {3.599026031135538*^9, 
   3.599026045846364*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d2cx", "[", "s", "]"}], " ", "-", 
    RowBox[{"ccc", "[", "s", "]"}]}], ",", " ", 
   RowBox[{"scond2", "[", "sf", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.598945219080683*^9, 3.5989452639312487`*^9}, 
   3.613621040694935*^9, 3.6181355911985245`*^9}],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.598945273157776*^9, 3.6173419382460318`*^9, 
  3.6173563237647977`*^9, 3.618139794781908*^9, 3.618148892174287*^9, 
  3.6188313121867285`*^9, 3.6188392612763696`*^9}]
}, Closed]],

Cell["Its tangential projection is", "Text",
 CellChangeTimes->{{3.5989458073863325`*^9, 3.5989458423543324`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"pT", "[", "sf", "]"}], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
     RowBox[{"d2cx", "[", "s", "]"}], "]"}], ",", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"scond2", "[", "sf", "]"}], ",", 
      RowBox[{"s", ">", "0"}]}], "}"}], ",", " ", 
    RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.598945882152609*^9, 3.598945992372913*^9}, {
   3.5989466625182433`*^9, 3.5989466663334613`*^9}, {3.5989467172543736`*^9, 
   3.598946767455245*^9}, {3.598951350742051*^9, 3.5989513740263824`*^9}, 
   3.598957784087018*^9, 3.59895786157845*^9, 3.59895790475692*^9, 
   3.5990231499040775`*^9, {3.613443680308923*^9, 3.613443723037398*^9}, 
   3.613621042754139*^9, 3.618135592368527*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{
                RowBox[{"hu", "[", "s", "]"}], ",", 
                RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{
                RowBox[{"hu", "[", "s", "]"}], ",", 
                RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "s", "]"}], ",", 
            RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "s", "]"}], ",", 
            RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "s", "]"}], ",", 
            RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "s", "]"}], ",", 
            RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "s", "]"}], ",", 
            RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "s", "]"}], ",", 
            RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
     ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{
                RowBox[{"hu", "[", "s", "]"}], ",", 
                RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{
                RowBox[{"hu", "[", "s", "]"}], ",", 
                RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "s", "]"}], ",", 
            RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "s", "]"}], ",", 
            RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "s", "]"}], ",", 
            RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "s", "]"}], ",", 
            RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "s", "]"}], ",", 
            RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "s", "]"}], ",", 
            RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
     ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{
                RowBox[{"hu", "[", "s", "]"}], ",", 
                RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{
                RowBox[{"hu", "[", "s", "]"}], ",", 
                RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{
             RowBox[{"hu", "[", "s", "]"}], ",", 
             RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "s", "]"}], ",", 
            RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "s", "]"}], ",", 
            RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "s", "]"}], ",", 
            RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "s", "]"}], ",", 
            RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "s", "]"}], ",", 
            RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"hu", "[", "s", "]"}], ",", 
            RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
     ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6181489738872304`*^9}]
}, Closed]],

Cell["Using this result we define ", "Text",
 CellChangeTimes->{{3.599023115459217*^9, 3.599023135427252*^9}, 
   3.5990262044050426`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pTd2cx", "[", "s_", "]"}], " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
       ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
       ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
       ")"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{3.599023047177897*^9, 3.5990230977843857`*^9, 
  3.61813559378813*^9}],

Cell[TextData[{
 "This is a tangent vector of the surface in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "3"], TraditionalForm]]],
 ", the tangential projection of the curvature vector of the curve ",
 "cx[",
 "s]. By definition its norm is the ",
 StyleBox["geodesic curvature",
  FontColor->RGBColor[0, 0, 1]],
 " of the curve: the ",
 StyleBox["outer definition of the geodesic curvature",
  FontSlant->"Italic"],
 ". Now we show that it coincides with the ",
 StyleBox["inner definition of the geodesic curvature",
  FontSlant->"Italic"],
 ", contained in the\n",
 StyleBox["Proposition",
  FontColor->RGBColor[0, 0, 1]],
 ". ",
 StyleBox["The geodesic curvature is the norm of the absolute derivative of \
the tangent unit vector of the curve DD1[sf,\[Gamma],\[Gamma]\
\[CloseCurlyQuote]][s] with respect to the arc length s",
  FontSlant->"Italic"],
 ".  Thus a curve is a geodesic iff its geodesic curvature is zero.\n",
 StyleBox["Proof",
  FontColor->RGBColor[0, 0, 1]],
 "."
}], "Text",
 CellChangeTimes->{{3.59902627165676*^9, 3.599026696726307*^9}, {
   3.5990267275831614`*^9, 3.599026737676379*^9}, 3.5990267771600485`*^9, 
   3.6130242329889708`*^9, {3.6142281112104774`*^9, 3.6142281129576807`*^9}, {
   3.6173570308642416`*^9, 3.617357042295895*^9}, 3.6181355968925347`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"pTd2cx", "[", "s", "]"}], ".", 
     RowBox[{"pTd2cx", "[", "s", "]"}]}], "-", 
    RowBox[{
     RowBox[{
      RowBox[{"fund1", "[", "sf", "]"}], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
     RowBox[{
      RowBox[{
       RowBox[{"DD1", "[", 
        RowBox[{"sf", ",", "\[Gamma]", ",", 
         RowBox[{"\[Gamma]", "'"}]}], "]"}], "[", "s", "]"}], ",", 
      RowBox[{
       RowBox[{"DD1", "[", 
        RowBox[{"sf", ",", "\[Gamma]", ",", 
         RowBox[{"\[Gamma]", "'"}]}], "]"}], "[", "s", "]"}]}], "]"}]}], ",", 
   RowBox[{"scond2", "[", "sf", "]"}], ",", " ", 
   RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.598957931526451*^9, 3.5989579547757807`*^9}, {
   3.5990234271945643`*^9, 3.599023494118682*^9}, {3.5990235576575937`*^9, 
   3.5990236292773194`*^9}, {3.599023667949787*^9, 3.5990237026754484`*^9}, 
   3.613445355876666*^9, {3.613445387497921*^9, 3.6134454029107485`*^9}, {
   3.6134463165107527`*^9, 3.6134463361355877`*^9}, 3.6136210445325418`*^9, {
   3.6181355982965374`*^9, 3.618135599372939*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.613448897862887*^9, 3.6173596910303946`*^9}]
}, Closed]],

Cell["\[FilledRectangle]", "Text",
 CellChangeTimes->{{3.5990269204618998`*^9, 3.5990269204618998`*^9}}],

Cell["\<\
Thus we define the geodesic curvature (up to sign) of the curve\
\>", "Text",
 CellChangeTimes->{{3.614146476570078*^9, 3.614146480048884*^9}, {
   3.614146537956186*^9, 3.614146561574627*^9}, 3.6141465923690815`*^9, {
   3.6142297053268776`*^9, 3.6142297166836977`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Gamma]", "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.6141466259559402`*^9, 3.6141466278123436`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"hu", "[", "s", "]"}], ",", 
   RowBox[{"hv", "[", "s", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6141466461267757`*^9, 3.61736089592031*^9, 
  3.6188393811469803`*^9}]
}, Closed]],

Cell["\<\
on the surface ff[u,v], s an arbitrary parameter, by the formula\
\>", "Text",
 CellChangeTimes->{{3.614146913948046*^9, 3.614146920047657*^9}, 
   3.6141480432028294`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"geodcurvature", "[", 
    RowBox[{"ff_", ",", "hu_", ",", "hv_"}], "]"}], "[", "s_", "]"}], ":=", 
  " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "cuv", ",", "t", ",", "aa", ",", "bb", ",", "abc", ",", "vbc", ",", 
      "tt"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"cuv", "[", "t_", "]"}], "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"hu", "[", "t", "]"}], ",", 
        RowBox[{"hv", "[", "t", "]"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"abc", "[", "t_", "]"}], " ", "=", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"cuv", "[", "tt", "]"}], ",", "tt"}], "]"}], "/.", 
       RowBox[{"tt", "\[Rule]", "t"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"bb", "[", "t_", "]"}], " ", "=", " ", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"fund1", "[", "ff", "]"}], "[", 
          RowBox[{
           RowBox[{"hu", "[", "t", "]"}], ",", 
           RowBox[{"hv", "[", "t", "]"}]}], "]"}], "[", 
         RowBox[{
          RowBox[{"abc", "[", "t", "]"}], ",", 
          RowBox[{"abc", "[", "t", "]"}]}], "]"}], ",", 
        RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"vbc", "[", "t_", "]"}], " ", "=", 
      RowBox[{
       RowBox[{"abc", "[", "t", "]"}], "/", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"bb", "[", "t", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"aa", "[", "t_", "]"}], " ", "=", " ", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"fund1", "[", "ff", "]"}], "[", 
          RowBox[{
           RowBox[{"hu", "[", "t", "]"}], ",", 
           RowBox[{"hv", "[", "t", "]"}]}], "]"}], "[", 
         RowBox[{
          RowBox[{
           RowBox[{"DD1", "[", 
            RowBox[{"ff", ",", "cuv", ",", "vbc"}], "]"}], "[", "t", "]"}], 
          ",", 
          RowBox[{
           RowBox[{"DD1", "[", 
            RowBox[{"ff", ",", "cuv", ",", "vbc"}], "]"}], "[", "t", "]"}]}], 
         "]"}], ",", 
        RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"aa", "[", "s", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"bb", "[", "s", "]"}], ")"}]}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6141469785009594`*^9, 3.6141471594612775`*^9}, {
   3.614147207197361*^9, 3.614147215184575*^9}, 3.6141472683494687`*^9, {
   3.6141473036055307`*^9, 3.6141473691880455`*^9}, {3.6141474491693864`*^9, 
   3.6141474805566416`*^9}, {3.6141475110702953`*^9, 3.614147680611393*^9}, {
   3.61414772454107*^9, 3.614147742309501*^9}, {3.6141477802799683`*^9, 
   3.6141477893903837`*^9}, {3.614147823055243*^9, 3.61414788398895*^9}, {
   3.6141479364050417`*^9, 3.6141479817075214`*^9}, {3.614151658259579*^9, 
   3.614151816007056*^9}, {3.614235429132931*^9, 3.614235440661351*^9}, {
   3.6142355823876004`*^9, 3.6142355873484087`*^9}, {3.614236105440919*^9, 
   3.61423614015098*^9}, {3.6142572420372305`*^9, 3.614257250040045*^9}, {
   3.614397469072534*^9, 3.614397515295415*^9}, {3.614397546121069*^9, 
   3.6143976442608414`*^9}, {3.6143978611324224`*^9, 3.6143978685112357`*^9}, 
   3.6143981191256757`*^9, {3.6144010659989595`*^9, 3.614401078382668*^9}, 
   3.614401116990876*^9, {3.614401159157288*^9, 3.614401252086603*^9}, {
   3.614401300351364*^9, 3.614401303728557*^9}, {3.614401342224759*^9, 
   3.6144014189041443`*^9}, {3.6144014551352167`*^9, 
   3.6144015880558195`*^9}, {3.614401629657199*^9, 3.614401720151375*^9}, 
   3.614401760607689*^9, {3.614401801610034*^9, 3.614401837968114*^9}, 
   3.6144019127433906`*^9, 3.6144914658978214`*^9, {3.614861863091546*^9, 
   3.614861863107146*^9}, 3.6148631367089825`*^9, 3.6149177943229656`*^9}],

Cell["\<\
If t is the arc length of the curve,  then bb[t] == 1, and the definition \
corresponds to the result of the proposition.  For arbitrary parameters the \
norming defines the tangent unit vector vbc[t], and ensures that the \
expression is invariant under a parameter transformations. Obviously, by this \
definition the geodesic curvature is always non-negative. 

For the next calculation we need as in Section 3.4 the condition\
\>", "Text",
 CellChangeTimes->{{3.59902816170928*^9, 3.599028196403741*^9}, {
   3.6141482435071816`*^9, 3.614148310478099*^9}, {3.614430191294223*^9, 
   3.61443019195026*^9}, {3.614430470191175*^9, 3.614430667510461*^9}, {
   3.6144307257667933`*^9, 3.6144308274956117`*^9}, {3.6174418306204166`*^9, 
   3.6174418465883303`*^9}, 3.6188394259034586`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "assu"}]], "Input",
 CellChangeTimes->{{3.5990277485269547`*^9, 3.5990277502897577`*^9}}],

Cell[BoxData[
 StyleBox["\<\"assu[c][s] is a set of assumptions in the first four \
derivatives of the \\nparameter representation c[s] of a smooth curve in the \
n-dimensional Euclidean space \\ngiving True if s is the Euclidean arc length \
of the curve.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.617360936345622*^9},
 CellTags->"Info3617368136-1949107"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "assus", "]"}], ";", 
  RowBox[{
   RowBox[{"assus", "[", "y_", "]"}], ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"assu", "[", "y", "]"}], "[", "s", "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"assu", "[", "y", "]"}], "[", "s", "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.5990276111843133`*^9, 3.59902766625241*^9}, {
  3.5990276972184644`*^9, 3.5990277244093122`*^9}, {3.599027790943429*^9, 
  3.5990278517523355`*^9}, {3.613621164886753*^9, 3.6136211958216076`*^9}, {
  3.6188395094104056`*^9, 3.6188395202680244`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"assus", "[", "y", "]"}]], "Input",
 CellChangeTimes->{{3.6136213818675346`*^9, 3.6136213877487445`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["y", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], ".", 
     RowBox[{
      SuperscriptBox["y", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}]}], "\[Equal]", "1"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["y", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], ".", 
     RowBox[{
      SuperscriptBox["y", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "s", "]"}]}], "\[Equal]", "0"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.613621389698748*^9, 3.6139765085086293`*^9, 
  3.6139944584342003`*^9, 3.6142572629100676`*^9, 3.6173609465452056`*^9, 
  3.6188395281772385`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"assus", "[", "cx", "]"}]], "Input",
 CellChangeTimes->{{3.6136212080520287`*^9, 3.613621218176447*^9}, {
  3.618839635100227*^9, 3.618839637253031*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], "2"]}], 
    "\[Equal]", "1"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hu", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["hv", "\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{
             SuperscriptBox["hu", "\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["hv", "\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{
             SuperscriptBox["hu", "\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"2", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], ")"}]}], 
     "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hu", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["hv", "\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{
             SuperscriptBox["hu", "\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["hv", "\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{
             SuperscriptBox["hu", "\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"2", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], ")"}]}], 
     "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hu", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hv", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["hv", "\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{
             SuperscriptBox["hu", "\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["hu", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["hv", "\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
           RowBox[{
            RowBox[{
             SuperscriptBox["hu", "\[Prime]",
              MultilineFunction->None], "[", "s", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"2", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
       ")"}]}]}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6134496580678225`*^9, 3.6134731398926735`*^9, 
  3.6135413258714023`*^9, 3.61362122004845*^9, 3.6139765124398365`*^9, 
  3.61399446408141*^9, 3.6142300735343246`*^9, 3.6142572668568745`*^9, 
  3.617360967015376*^9, 3.618839535228451*^9, 3.6188396390782337`*^9}]
}, Closed]],

Cell[TextData[{
 "We show\n",
 StyleBox["Lemma",
  FontColor->RGBColor[0, 0, 1]],
 ". ",
 StyleBox["The absolute derivative \
DD1[sf,\[Gamma],\[Gamma]\[CloseCurlyQuote]][s], s the arc length of the \
curve,  is orthogonal to the tangent vector \[Gamma]\[CloseCurlyQuote][s], s \
the arc length",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.599028227837796*^9, 3.599028350376012*^9}, {
   3.6144300781997547`*^9, 3.6144300966158075`*^9}, 3.617360986151471*^9, 
   3.617361063695906*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", "sf", "]"}], "[", 
     RowBox[{
      RowBox[{"hu", "[", "s", "]"}], ",", 
      RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"DD1", "[", 
       RowBox[{"sf", ",", "\[Gamma]", ",", 
        RowBox[{"\[Gamma]", "'"}]}], "]"}], "[", "s", "]"}], ",", 
     RowBox[{
      RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], ",", 
   RowBox[{"assus", "[", "cx", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5990270185548725`*^9, 3.5990270848237886`*^9}, {
   3.59902713120267*^9, 3.599027132887473*^9}, {3.5990278914232054`*^9, 
   3.599027893310809*^9}, 3.613449468246689*^9, 3.6134495002267447`*^9, 
   3.6134495381348114`*^9, 3.6134495822360888`*^9, 3.613449621048957*^9, 
   3.613621310653409*^9, 3.6188396723842926`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.613474447736571*^9, 3.6173610274508333`*^9, 
  3.618839715437168*^9}]
}, Closed]],

Cell["\<\
\[FilledRectangle]
Analogously with the similar condition scond2[sf]:\
\>", "Text",
 CellChangeTimes->{{3.5990284562845974`*^9, 3.599028539573144*^9}, {
  3.6134750413644133`*^9, 3.613475070349264*^9}, {3.613621057028164*^9, 
  3.6136210638609757`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", "sf", "]"}], "[", 
     RowBox[{
      RowBox[{"hu", "[", "s", "]"}], ",", 
      RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"DD1", "[", 
       RowBox[{"sf", ",", "\[Gamma]", ",", 
        RowBox[{"\[Gamma]", "'"}]}], "]"}], "[", "s", "]"}], ",", 
     RowBox[{
      RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], ",", 
   RowBox[{"scond2", "[", "sf", "]"}], ",", " ", 
   RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5990270185548725`*^9, 3.5990270848237886`*^9}, {
   3.59902713120267*^9, 3.599027132887473*^9}, {3.6134749581538677`*^9, 
   3.613474977232701*^9}, 3.613621082643409*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.599027090564599*^9, 3.5990271381134825`*^9, 
  3.613475020709977*^9, 3.617361114093789*^9, 3.6188408801040134`*^9}]
}, Closed]],

Cell[TextData[{
 "Now, as in case of the plane, we can provide the non zero geodesic \
curvature with a sign: If the orientation of the tangent planes defined by \
the pair {\[Gamma]\[CloseCurlyQuote][s], DD1[sf,\[Gamma],\[Gamma]\
\[CloseCurlyQuote]][s]}  coincides with the orientation defined by the \
parameters {tv[1][sf],tv[2][sf]} we take the curvature as positive, and as \
negative if this is not the case. In this sense the",
 StyleBox[" oriented geodesic curvature",
  FontColor->RGBColor[0, 0, 1]],
 " is defined."
}], "Text",
 CellChangeTimes->{{3.599028678070187*^9, 3.5990289698842993`*^9}, {
   3.5990290095707693`*^9, 3.599029014515978*^9}, {3.599029058773256*^9, 
   3.599029104512536*^9}, 3.617600026709092*^9, 3.617600085848796*^9, {
   3.6188408953452406`*^9, 3.618840921288086*^9}}],

Cell["\<\
On my computer evaluating the next cells waiting a long time didn\
\[CloseCurlyQuote]t give results; I aborted the evaluations.\
\>", "Text",
 CellChangeTimes->{{3.6136215027053466`*^9, 3.613621632201174*^9}, {
   3.61414866399032*^9, 3.614148664349121*^9}, 3.614313586866888*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fund2a", "[", "sf", "]"}], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], "^", "2"}], " ", 
    "+", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"fund1", "[", "sf", "]"}], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
     RowBox[{
      RowBox[{
       RowBox[{"DD1", "[", 
        RowBox[{"sf", ",", "\[Gamma]", ",", 
         RowBox[{"\[Gamma]", "'"}]}], "]"}], "[", "s", "]"}], ",", 
      RowBox[{
       RowBox[{"DD1", "[", 
        RowBox[{"sf", ",", "\[Gamma]", ",", 
         RowBox[{"\[Gamma]", "'"}]}], "]"}], "[", "s", "]"}]}], "]"}], "-", 
    RowBox[{
     RowBox[{
      RowBox[{"curvature", "[", "xx", "]"}], "[", "s", "]"}], "^", "2"}]}], 
   ",", 
   RowBox[{"assus", "[", "xx", "]"}], ",", " ", 
   RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.599029134745389*^9, 3.599029405593065*^9}, 
   3.613476504428583*^9, 3.6136213128686132`*^9, {3.6136297165565734`*^9, 
   3.6136297593162484`*^9}, 3.6148618631227455`*^9, 3.6148631367089825`*^9}],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.599040142967642*^9, 3.6134764830097456`*^9, 
  3.613483610147464*^9, 3.613631445039609*^9, 3.6173702781482124`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"curvature", "[", "xx", "]"}], "[", "s", "]"}], "^", "2"}], " ", 
  "]"}]], "Input",
 CellChangeTimes->{{3.599029134745389*^9, 3.599029405593065*^9}, 
   3.613476504428583*^9, 3.6135413441546345`*^9, 3.613541451716823*^9, 
   3.6135623764432173`*^9, {3.6135662001971335`*^9, 3.6135662139719577`*^9}, {
   3.613566603535842*^9, 3.6135666134574594`*^9}, 3.6148618631383457`*^9, 
   3.6148631367089825`*^9}],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.6135445389934454`*^9, 3.6135661697146797`*^9, 
  3.613566564301773*^9, 3.613567310513484*^9, 3.617372992091441*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"curvatures", "[", "xx", "]"}], "[", "s", "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "^", "2"}], ",", 
   RowBox[{"assus", "[", "xx", "]"}], ",", " ", 
   RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.599029134745389*^9, 3.599029405593065*^9}, 
   3.613476504428583*^9, 3.6135413441546345`*^9, 3.613541451716823*^9, {
   3.613560142534894*^9, 3.6135601564969187`*^9}, 3.6136213141478157`*^9}],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.613562346709565*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fund2a", "[", "sf", "]"}], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], "^", "2"}], "+", 
    " ", 
    RowBox[{
     RowBox[{
      RowBox[{"fund1", "[", "sf", "]"}], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
     RowBox[{
      RowBox[{
       RowBox[{"DD1", "[", 
        RowBox[{"sf", ",", "\[Gamma]", ",", 
         RowBox[{"\[Gamma]", "'"}]}], "]"}], "[", "s", "]"}], ",", 
      RowBox[{
       RowBox[{"DD1", "[", 
        RowBox[{"sf", ",", "\[Gamma]", ",", 
         RowBox[{"\[Gamma]", "'"}]}], "]"}], "[", "s", "]"}]}], "]"}], "-", 
    RowBox[{
     RowBox[{
      RowBox[{"curvature", "[", "xx", "]"}], "[", "s", "]"}], "^", "2"}]}], 
   ",", 
   RowBox[{"scond2", "[", "sf", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.599029134745389*^9, 3.599029405593065*^9}, 
   3.599040146992449*^9, {3.5990401854777164`*^9, 3.5990401961013346`*^9}, 
   3.613621085654214*^9, 3.613621484016514*^9, {3.6136232678952465`*^9, 
   3.6136232769900627`*^9}, {3.6136268909080105`*^9, 3.61362689666442*^9}, 
   3.614861863153946*^9, 3.6148631367089825`*^9}],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.599054387772852*^9, 3.613626863717163*^9, 
  3.6136296706768928`*^9}]
}, Closed]],

Cell["\<\
We try to control the relation specifying the surface and considering an \
arbitrary curve \[Gamma][s] on the surface.\
\>", "Text",
 CellChangeTimes->{{3.6136216629488277`*^9, 3.6136217472669764`*^9}, {
   3.6136219986458178`*^9, 3.6136220101274376`*^9}, {3.6136316409915533`*^9, 
   3.6136316447511597`*^9}, {3.613631706792469*^9, 3.6136317217996955`*^9}, 
   3.613631784777006*^9}],

Cell[TextData[{
 StyleBox["Example",
  FontColor->RGBColor[0, 0, 1]],
 ". The unit sphere"
}], "Text",
 CellChangeTimes->{{3.6136216629488277`*^9, 3.6136217472669764`*^9}, {
  3.6136219986458178`*^9, 3.6136220101274376`*^9}, {3.6136316409915533`*^9, 
  3.6136316447511597`*^9}, {3.613631706792469*^9, 3.6136317217996955`*^9}, {
  3.613631784777006*^9, 3.6136317936534214`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sphero", "[", "1", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6144904863257933`*^9, 3.6144904977664475`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", "u", "]"}], " ", 
    RowBox[{"Cos", "[", "v", "]"}]}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", "v", "]"}], " ", 
    RowBox[{"Sin", "[", "u", "]"}]}], ",", 
   RowBox[{"Sin", "[", "v", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6144905613000813`*^9, 3.6174268389313335`*^9, 
  3.6188410053254337`*^9, 3.618911303075421*^9}]
}, Closed]],

Cell[" We consider the circles", "Text",
 CellChangeTimes->{{3.6141488938255234`*^9, 3.6141489033727407`*^9}, {
   3.6143272794730387`*^9, 3.6143272834572663`*^9}, 3.6144904761582117`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"h1", "[", "t_", "]"}], " ", ":=", " ", "t"}], ";", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"h2", "[", "ca_", "]"}], "[", "t_", "]"}], " ", ":=", " ", "ca"}],
   ";"}]], "Input",
 CellChangeTimes->{{3.6141489619820433`*^9, 3.614149121149123*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Sin", "[", 
  RowBox[{
   RowBox[{"h2", "[", 
    FractionBox["\[Pi]", "4"], "]"}], "[", "t", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6174276073262825`*^9, 3.6174276174663005`*^9}, {
  3.617427656341569*^9, 3.617427687822424*^9}}],

Cell[BoxData[
 FractionBox["1", 
  SqrtBox["2"]]], "Output",
 CellChangeTimes->{
  3.6174276185583024`*^9, {3.6174276680415897`*^9, 3.617427689304427*^9}, 
   3.6188410530459175`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sphero", "[", "1", "]"}], "[", 
    RowBox[{
     RowBox[{"h1", "[", "t", "]"}], ",", 
     RowBox[{
      RowBox[{"h2", "[", 
       RowBox[{"Pi", "/", "4"}], "]"}], "[", "t", "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"Thick", ",", " ", "Red"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6141489619820433`*^9, 3.614149089215867*^9}, {
  3.6141491303999395`*^9, 3.614149285058611*^9}}],

Cell[BoxData[
 Graphics3DBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[Large], Line3DBox[CompressedData["
1:eJxF1Xk41VkYB3ATYZQYaSRqUJYnbkxP5lH3TifboGHsZO9hXFSMlNKMFuFm
yeBmS1xlHyVbtxljOdfYyn5tWXK524+4d6IGT0Yaf4xz/nif85zPH+c57/t8
n3M0/X9yCtwmISFhuVmSm5VDvkllPCSANKk9luMWdbLn/z3TtHvoQebm2r1g
VmRfCrbctTJnjHGZAE/M1TI7LJ4jHy65t59kQoAb3oZGauotyBuWNTiOPCGg
g/wc022dyKM1E0o9PwlAh0ubRvDUAPKyiD7lrH4+sLI5dLd8agR5j/RV6Qgj
Hig+mRtzcGEC+Ya1USfhPwMk30UcsDOexuc0sm8/sX0NRmz6y23Luchbk2k5
QSGvwHp3H5/iw0ce5rjqJhE9CM6ydTwDygTIE+Y/RqiVvwTx1lp0yToh8myu
sSHZuA0QdW5egbsI5EWVfreKvJuAyr3R0Tln7LRqRp/uuVqQZPAiOv029rXI
lLRbOfmgV17ucOcD7A41a+5yrnRob7Gys5WBXeSlbRWTXA3b2/fe8EvArp06
Netb3ABDjRX0q7yxe7ZL1R9wbIVx+f9wdNWw0/d6zzONXkJaQb80qwH3Zegx
Tg183wfXggyWgsyx0xcbdzXPD0NAEcw0KeL5/LB4qWT343FoUSFfwizkISev
U2VO+HOgKOkDTdw2g/xt/M2AOh0u3PPbkl5b3BTyhQS1nt8/8ODlwtgd70rH
cN6Uvg6ZCxNAI5ntqX+FDyFXkaJOyl0TQiWmb+zbpB7knyL3PK0hhPCOX4Gj
NexAzrexNvUgE3BZT/i4YpyFXHVo9u/oSwTcd4T3y48pOM/BV6zGbTIJKLFU
ZCBdiPM/MaklyHtIwNn1iusedxyQf6nef8Y2i4BdGe9lFXJL4JbvLojWrIog
4IfMOJI/6zly5p8L1D5jAmocebSoaNeCfN5gfjF88/5V2++bkVo7kPuo5gXl
xQih7/kLumtaPcjtrb44bu8ngOaWCfvYNUPIj7rYHFef5UGybvU0Z3oMeY0w
iUOjcGHiDbfhJscp5JlJduw1Sw6s1VsgP2XPII+95OSuxBmHRnOWcTvTechj
gkUXN/RGIDu5kgiUECDfaNRU/pzaD7tZBZoCEyHy0CaWTPa+Lngo6TT5WgX2
78NleM+YbbDiMx2fJWkCueQ7R5mTd5vgI7F7gdgJu72UrgkluQZaeqXEe8Rj
p2qrshzk78N82bZ0nXzsOYOqp5z1M8CzKMpHXwb2QpM3Oy+qVQOuvs63xYnY
ZenRzGz1BnDslbbYyg87X/Qiy/ZqKzDJi1xQUMUuBhQLp9MvAXdKJC+ox331
ftX7YoeIDcTnSfslO/F8ogKj3LqcXwH/tAlySwAf+TZl/oX646+BFaP26EwV
F7nFN4pmzqQZoHVOqce1eBp5szi02eUgD1B+Hhu5uGsSeZpz0UppJR8UDrj0
vnEbRe7KWpWLEghA1qDG9PJZNvIgUSm8MikEvSqHTzFCOpEP/Bphf4ZEAKlj
q5aXV3E+tXNfpyaGbJ4noH0XPvsH8qWwt/8O0wkA4ImMspVyPP+td7Tsetzm
/9K85f8B7oN8yA==
     "]]}},
  Axes->True,
  DisplayFunction->Identity,
  FaceGridsStyle->Automatic,
  Method->{},
  PlotRange->{{-0.7071060615334048, 0.7071067811865417}, {-0.7068324037570819,
    0.7068801167644184}, {0., 1.414213562373095}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6188410645431376`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"circ", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6141493241678796`*^9, 3.6141493321082935`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sphero", "[", "1", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
   RowBox[{"Mesh", "\[Rule]", "None"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"Opacity", "[", "0.7", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6141493439487143`*^9, 3.6141494448340917`*^9}, {
  3.614149700861741*^9, 3.6141497219685783`*^9}, {3.6142600151061015`*^9, 
  3.6142600366653395`*^9}}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1m3lcz9n3x0N+Zsg6Y5kxDYVkkCWylE4MQtayi6HQNikMRihkq+zMhIhk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   "], {
    {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[2], Opacity[
     0.7], EdgeForm[None], Specularity[
      GrayLevel[1], 3], 
     StyleBox[GraphicsGroup3DBox[Polygon3DBox[CompressedData["
1:eJxNm3f819Mexz/fYxMapCTtQUpLE/0KmaWhIdGyqTSISoNkZ5P2kNIgWRk3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        "]]],
      Lighting->{{"Ambient", 
         RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
        "Directional", 
         RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
         ImageScaled[{0, 2, 2}]}, {"Directional", 
         RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
         ImageScaled[{2, 2, 2}]}, {"Directional", 
         RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
         ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}},
   VertexNormals->CompressedData["
1:eJx1W2lYT93bbUJ5VGgwRCFkDEkifseQJBRlDJVSoVGpkBQhDSJEac5QSEil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    "]],
  Axes->True,
  DisplayFunction->Identity,
  FaceGridsStyle->Automatic,
  Method->{},
  PlotRange->{{-1., 0.9999999999998993}, {-0.9999999999999748, 
   0.9999999999999748}, {-0.9999999999999748, 0.9999999999999748}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6188410747611556`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sph1", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6141497356654024`*^9, 3.61414974589902*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"circ", ",", "sph1"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.614149757833041*^9, 3.614149804227523*^9}}],

Cell[BoxData[
 Graphics3DBox[{{{}, {}, 
    {RGBColor[1, 0, 0], Thickness[Large], Line3DBox[CompressedData["
1:eJxF1Xk41VkYB3ATYZQYaSRqUJYnbkxP5lH3TifboGHsZO9hXFSMlNKMFuFm
yeBmS1xlHyVbtxljOdfYyn5tWXK524+4d6IGT0Yaf4xz/nif85zPH+c57/t8
n3M0/X9yCtwmISFhuVmSm5VDvkllPCSANKk9luMWdbLn/z3TtHvoQebm2r1g
VmRfCrbctTJnjHGZAE/M1TI7LJ4jHy65t59kQoAb3oZGauotyBuWNTiOPCGg
g/wc022dyKM1E0o9PwlAh0ubRvDUAPKyiD7lrH4+sLI5dLd8agR5j/RV6Qgj
Hig+mRtzcGEC+Ya1USfhPwMk30UcsDOexuc0sm8/sX0NRmz6y23Luchbk2k5
QSGvwHp3H5/iw0ce5rjqJhE9CM6ydTwDygTIE+Y/RqiVvwTx1lp0yToh8myu
sSHZuA0QdW5egbsI5EWVfreKvJuAyr3R0Tln7LRqRp/uuVqQZPAiOv029rXI
lLRbOfmgV17ucOcD7A41a+5yrnRob7Gys5WBXeSlbRWTXA3b2/fe8EvArp06
Netb3ABDjRX0q7yxe7ZL1R9wbIVx+f9wdNWw0/d6zzONXkJaQb80qwH3Zegx
Tg183wfXggyWgsyx0xcbdzXPD0NAEcw0KeL5/LB4qWT343FoUSFfwizkISev
U2VO+HOgKOkDTdw2g/xt/M2AOh0u3PPbkl5b3BTyhQS1nt8/8ODlwtgd70rH
cN6Uvg6ZCxNAI5ntqX+FDyFXkaJOyl0TQiWmb+zbpB7knyL3PK0hhPCOX4Gj
NexAzrexNvUgE3BZT/i4YpyFXHVo9u/oSwTcd4T3y48pOM/BV6zGbTIJKLFU
ZCBdiPM/MaklyHtIwNn1iusedxyQf6nef8Y2i4BdGe9lFXJL4JbvLojWrIog
4IfMOJI/6zly5p8L1D5jAmocebSoaNeCfN5gfjF88/5V2++bkVo7kPuo5gXl
xQih7/kLumtaPcjtrb44bu8ngOaWCfvYNUPIj7rYHFef5UGybvU0Z3oMeY0w
iUOjcGHiDbfhJscp5JlJduw1Sw6s1VsgP2XPII+95OSuxBmHRnOWcTvTechj
gkUXN/RGIDu5kgiUECDfaNRU/pzaD7tZBZoCEyHy0CaWTPa+Lngo6TT5WgX2
78NleM+YbbDiMx2fJWkCueQ7R5mTd5vgI7F7gdgJu72UrgkluQZaeqXEe8Rj
p2qrshzk78N82bZ0nXzsOYOqp5z1M8CzKMpHXwb2QpM3Oy+qVQOuvs63xYnY
ZenRzGz1BnDslbbYyg87X/Qiy/ZqKzDJi1xQUMUuBhQLp9MvAXdKJC+ox331
ftX7YoeIDcTnSfslO/F8ogKj3LqcXwH/tAlySwAf+TZl/oX646+BFaP26EwV
F7nFN4pmzqQZoHVOqce1eBp5szi02eUgD1B+Hhu5uGsSeZpz0UppJR8UDrj0
vnEbRe7KWpWLEghA1qDG9PJZNvIgUSm8MikEvSqHTzFCOpEP/Bphf4ZEAKlj
q5aXV3E+tXNfpyaGbJ4noH0XPvsH8qWwt/8O0wkA4ImMspVyPP+td7Tsetzm
/9K85f8B7oN8yA==
      "]]}}, GraphicsComplex3DBox[CompressedData["
1:eJx1m3lcz9n3x0N+Zsg6Y5kxDYVkkCWylE4MQtayi6HQNikMRihkq+zMhIhk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    "], {
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[2], Opacity[
      0.7], EdgeForm[None], Specularity[
       GrayLevel[1], 3], 
      StyleBox[GraphicsGroup3DBox[Polygon3DBox[CompressedData["
1:eJxNm3f819Mexz/fYxMapCTtQUpLE/0KmaWhIdGyqTSISoNkZ5P2kNIgWRk3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         "]]],
       Lighting->{{"Ambient", 
          RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
         "Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{0, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{2, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}},
    VertexNormals->CompressedData["
1:eJx1W2lYT93bbUJ5VGgwRCFkDEkifseQJBRlDJVSoVGpkBQhDSJEac5QSEil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     "]]},
  Axes->True,
  DisplayFunction->Identity,
  FaceGridsStyle->Automatic,
  Method->{},
  PlotRange->All,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.618841082373969*^9}]
}, Closed]],

Cell["The geodesic curvature of this circle is", "Text",
 CellChangeTimes->{{3.6142629124679904`*^9, 3.6142629310944233`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kg", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"geodcurvature", "[", 
     RowBox[{
      RowBox[{"sphero", "[", "1", "]"}], ",", "h1", ",", 
      RowBox[{"h2", "[", "x", "]"}]}], "]"}], "[", "s", "]"}], "/.", 
   RowBox[{"x", "\[Rule]", 
    RowBox[{"Pi", "/", "4"}]}]}]}]], "Input",
 CellChangeTimes->{{3.614149876050049*^9, 3.614149963925003*^9}, {
   3.6141500332983255`*^9, 3.6141501013612447`*^9}, {3.6141501802973833`*^9, 
   3.6141502134162416`*^9}, 3.6141519955165715`*^9, {3.614236185172659*^9, 
   3.6142361856406603`*^9}, {3.6144907894011283`*^9, 3.6144908578020406`*^9}, 
   3.614861863216346*^9, 3.6148631367089825`*^9, 3.6188411396416693`*^9, 
   3.618841188157755*^9, {3.6188417041442614`*^9, 3.6188417117726746`*^9}, {
   3.618841825949275*^9, 3.618841866805747*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.618841869005351*^9, 3.618911347083098*^9}]
}, Closed]],

Cell["Only the great circles are geodesics.", "Text",
 CellChangeTimes->{{3.6142629436212454`*^9, 3.6142629704532924`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"geodcurvature", "[", 
    RowBox[{
     RowBox[{"sphero", "[", "1", "]"}], ",", "h1", ",", 
     RowBox[{"h2", "[", "x", "]"}]}], "]"}], "[", "s", "]"}], "/.", 
  RowBox[{"x", "\[Rule]", " ", "0"}]}]], "Input",
 CellChangeTimes->{{3.6141651610029974`*^9, 3.6141651785998282`*^9}, {
   3.6141652204391017`*^9, 3.6141652288007164`*^9}, {3.614492159057468*^9, 
   3.6144921791046147`*^9}, 3.614861863231946*^9, 3.6148631367089825`*^9, {
   3.618841892062191*^9, 3.618841904932214*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.6141652316087213`*^9, 3.614260200996028*^9, 3.614490666131078*^9, 
   3.6144908809313636`*^9, 3.61449158860184*^9, 3.6144921913393145`*^9, 
   3.617427484273267*^9, {3.6188418861497808`*^9, 3.618841909128621*^9}, 
   3.618911356833115*^9}]
}, Closed]],

Cell["We consider more generally ", "Text",
 CellChangeTimes->{{3.6144922075662427`*^9, 3.6144922210630145`*^9}, 
   3.6174418763880343`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kg", " ", "=", 
  RowBox[{
   RowBox[{"geodcurvature", "[", 
    RowBox[{
     RowBox[{"sphero", "[", "r", "]"}], ",", "h1", ",", 
     RowBox[{"h2", "[", "a", "]"}]}], "]"}], "[", "t", "]"}]}]], "Input",
 CellChangeTimes->{{3.614491947920392*^9, 3.614491994032029*^9}, 
   3.614861863247546*^9, 3.6148631367245827`*^9}],

Cell[BoxData[
 SqrtBox[
  FractionBox[
   SuperscriptBox[
    RowBox[{"Tan", "[", "a", "]"}], "2"], 
   SuperscriptBox["r", "2"]]]], "Output",
 CellChangeTimes->{{3.6144919794051924`*^9, 3.614491996691181*^9}, 
   3.6174274973616896`*^9, 3.6188419253214493`*^9, 3.618911370483139*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kn", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"normalcurvature", "[", 
     RowBox[{
      RowBox[{"sphero", "[", "r", "]"}], ",", "h1", ",", 
      RowBox[{"h2", "[", "a", "]"}]}], "]"}], "[", "t", "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6143273297369137`*^9, 3.614327353778289*^9}, {
   3.614327390450386*^9, 3.614327420572109*^9}, {3.6144908890498276`*^9, 
   3.6144909391846952`*^9}, 3.6144917093297453`*^9, 3.6144918945373383`*^9, 
   3.614861863263146*^9, 3.6148631367245827`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "a", "]"}]}], 
   SqrtBox[
    RowBox[{
     SuperscriptBox["r", "4"], " ", 
     SuperscriptBox[
      RowBox[{"Cos", "[", "a", "]"}], "2"]}]]]}]], "Output",
 CellChangeTimes->{3.614327442304352*^9, 3.614490690043445*^9, 
  3.6144909403897643`*^9, 3.614491898100542*^9, 3.617427919763632*^9, 
  3.618841930734659*^9, 3.6189113831659613`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sx", "[", "t_", "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"sphero", "[", "r", "]"}], "[", 
    RowBox[{
     RowBox[{"h1", "[", "t", "]"}], ",", 
     RowBox[{
      RowBox[{"h2", "[", "a", "]"}], "[", "t", "]"}]}], "]"}]}], ";", 
  RowBox[{"kk", " ", "=", " ", 
   RowBox[{
    RowBox[{"curvature", "[", "sx", "]"}], "[", "t", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.61449096601723*^9, 3.614491046232818*^9}, {
   3.6144910803047667`*^9, 3.614491184156707*^9}, {3.614491760169653*^9, 
   3.614491772410353*^9}, 3.6148618632787457`*^9, 3.6148631367245827`*^9}],

Cell[BoxData[
 FractionBox[
  SqrtBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "a", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "a", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "t", "]"}], "2"]}]}], ")"}], "2"]], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "a", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "t", "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "a", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "t", "]"}], "2"]}]}], ")"}], 
   RowBox[{"3", "/", "2"}]]]], "Output",
 CellChangeTimes->{3.6144910538222523`*^9, 3.6144911995405865`*^9, 
  3.6144917836189947`*^9, 3.6144918209621305`*^9, 3.614491853338982*^9, 
  3.61742793018445*^9, 3.6188419358670683`*^9, 3.618911393134379*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kk", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"t", ">", "0"}], ",", 
      RowBox[{"r", ">", "0"}], ",", 
      RowBox[{"a", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6144912102411985`*^9, 3.6144912524796147`*^9}, {
  3.6144918028020916`*^9, 3.614491847393642*^9}}],

Cell[BoxData[
 FractionBox[
  SuperscriptBox[
   RowBox[{"Cos", "[", "a", "]"}], "2"], 
  RowBox[{"r", " ", 
   SuperscriptBox[
    RowBox[{"Abs", "[", 
     RowBox[{"Cos", "[", "a", "]"}], "]"}], "3"]}]]], "Output",
 CellChangeTimes->{3.6144912549047537`*^9, 3.6144917891213093`*^9, 
  3.6144918252353745`*^9, 3.614491857411215*^9, 3.6174279356444597`*^9, 
  3.6188419434642816`*^9, 3.6189114005911922`*^9}]
}, Closed]],

Cell["Test of the curvature relation:", "Text",
 CellChangeTimes->{{3.6144922778622637`*^9, 3.614492295334263*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"kk", "^", "2"}], "-", 
  RowBox[{"kn", "^", "2"}], "-", 
  RowBox[{"kg", "^", "2"}]}]], "Input",
 CellChangeTimes->{{3.6144912677174864`*^9, 3.6144912827293453`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", 
    SuperscriptBox["r", "2"]]}], "+", 
  FractionBox[
   SuperscriptBox[
    RowBox[{"Cos", "[", "a", "]"}], "4"], 
   RowBox[{
    SuperscriptBox["r", "2"], " ", 
    SuperscriptBox[
     RowBox[{"Abs", "[", 
      RowBox[{"Cos", "[", "a", "]"}], "]"}], "6"]}]], "-", 
  FractionBox[
   SuperscriptBox[
    RowBox[{"Tan", "[", "a", "]"}], "2"], 
   SuperscriptBox["r", "2"]]}]], "Output",
 CellChangeTimes->{3.6144912904597874`*^9, 3.6144915009338255`*^9, 
  3.6144920073667917`*^9, 3.6174279465176783`*^9, 3.6188419479570894`*^9, 
  3.6189114077828045`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Together", "[", "%", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"t", ">", "0"}], ",", 
     RowBox[{"r", ">", "0"}], ",", 
     RowBox[{"a", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.614492018684439*^9, 3.614492069089322*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6144920711064377`*^9, 3.6174279509480867`*^9, 
  3.618841953136298*^9, 3.6189114157076187`*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example",
  FontColor->RGBColor[0, 0, 1]],
 ". Graphs of Functions"
}], "Text",
 CellChangeTimes->{{3.6136216629488277`*^9, 3.6136217472669764`*^9}, {
   3.6136219986458178`*^9, 3.6136220101274376`*^9}, {3.6136316409915533`*^9, 
   3.6136316447511597`*^9}, {3.613631706792469*^9, 3.6136317217996955`*^9}, {
   3.613631784777006*^9, 3.6136317936534214`*^9}, 3.6136319442872863`*^9, {
   3.6142629800161095`*^9, 3.6142629821221128`*^9}, 3.6143299951743555`*^9}],

Cell["\<\
We consider the graph of an unspecified function f[u,v]. In this case we \
obtain general formulas for all kind of curvatures of a general curve on the \
surface.\
\>", "Text",
 CellChangeTimes->{{3.613632210517354*^9, 3.6136322491742215`*^9}, {
  3.614329894398178*^9, 3.614329951790679*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"a", ",", "hu", ",", "hv", ",", "sx"}], "]"}], ";", 
  RowBox[{
   RowBox[{"hu", "[", "s_", "]"}], " ", "=", " ", "s"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"hv", "[", "a_", "]"}], "[", "s_", "]"}], ":=", " ", "a"}], ";", 
  RowBox[{
   RowBox[{"sx", "[", "s_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"graph", "[", "f", "]"}], "[", 
    RowBox[{
     RowBox[{"hu", "[", "s", "]"}], ",", 
     RowBox[{
      RowBox[{"hv", "[", "a", "]"}], "[", "s", "]"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.6143294721366367`*^9, 3.614329624065303*^9}, {
   3.614494308370402*^9, 3.6144943725460725`*^9}, {3.614505389490672*^9, 
   3.614505523245307*^9}, {3.6145055567073655`*^9, 3.614505570107789*^9}, 
   3.6148618633255463`*^9, 3.6148631367245827`*^9, 3.6189119646725826`*^9, {
   3.6189120064650564`*^9, 3.6189120185394773`*^9}, {3.618912065011959*^9, 
   3.6189120878035994`*^9}, {3.618912435263009*^9, 3.6189124443734255`*^9}, {
   3.6189124810178895`*^9, 3.6189125661316395`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kk", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"curvature", "[", "sx", "]"}], "[", "s", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6189121673325386`*^9, 3.618912199640196*^9}, 
   3.618912235660659*^9, 3.6189122782331333`*^9, {3.61891238421972*^9, 
   3.618912384906121*^9}, {3.618912595880892*^9, 3.6189125967232933`*^9}}],

Cell[BoxData[
 FractionBox[
  SqrtBox[
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"s", ",", "a"}], "]"}], "2"]], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"s", ",", "a"}], "]"}], "2"]}], ")"}], 
   RowBox[{"3", "/", "2"}]]]], "Output",
 CellChangeTimes->{3.618912604538907*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kg", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"geodcurvature", "[", 
     RowBox[{
      RowBox[{"graph", "[", "f", "]"}], ",", "hu", ",", 
      RowBox[{"hv", "[", "a", "]"}]}], "]"}], "[", "s", "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6143294721366367`*^9, 3.614329624065303*^9}, {
   3.614494308370402*^9, 3.6144943725460725`*^9}, {3.614505389490672*^9, 
   3.614505523245307*^9}, {3.6145055567073655`*^9, 3.614505570107789*^9}, 
   3.6148618633255463`*^9, 3.6148631367245827`*^9, 3.6189119646725826`*^9, {
   3.618912026261491*^9, 3.618912029865097*^9}}],

Cell[BoxData[
 SqrtBox[
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"s", ",", "a"}], "]"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"s", ",", "a"}], "]"}], "2"]}], 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"s", ",", "a"}], "]"}], "2"]}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"s", ",", "a"}], "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"s", ",", "a"}], "]"}], "2"]}], ")"}]}]]]], "Output",
 CellChangeTimes->{{3.6145055582673683`*^9, 3.6145055737425957`*^9}, 
   3.6174292368739448`*^9, 3.6174293863690076`*^9, 3.618911984016617*^9, 
   3.618912036495109*^9, 3.618912099035619*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kn", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"normalcurvature", "[", 
     RowBox[{
      RowBox[{"graph", "[", "f", "]"}], ",", "hu", ",", 
      RowBox[{"hv", "[", "a", "]"}]}], "]"}], "[", "s", "]"}], " ", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, 3.61432944564779*^9, {
   3.614329681629404*^9, 3.6143297762279706`*^9}, {3.6145055851462154`*^9, 
   3.6145056105742607`*^9}, 3.6148618633255463`*^9, 3.6148631367245827`*^9, {
   3.6189121285040703`*^9, 3.618912134603681*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["f", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"2", ",", "0"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"s", ",", "a"}], "]"}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"s", ",", "a"}], "]"}], "2"]}], ")"}], " ", 
   SqrtBox[
    RowBox[{"1", "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"s", ",", "a"}], "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"s", ",", "a"}], "]"}], "2"]}]]}]]], "Output",
 CellChangeTimes->{3.6143297807051783`*^9, 3.614505612196663*^9, 
  3.617429243675557*^9, 3.617429379333395*^9, 3.618912137396086*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Together", "[", 
   RowBox[{
    RowBox[{"kk", "^", "2"}], "-", 
    RowBox[{"kn", "^", "2"}], "-", 
    RowBox[{"kg", "^", "2"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6145056477179255`*^9, 3.6145057008360186`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.614505702630022*^9, 3.6174292503991685`*^9, 
  3.6174293109896755`*^9, 3.6174293938726206`*^9, 3.6189126141017237`*^9}]
}, Closed]],

Cell["The same for the specified function f3:", "Text",
 CellChangeTimes->{{3.6189278059856067`*^9, 3.6189278320064526`*^9}, 
   3.6189955701473665`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f3", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"u", "^", "3"}], "+", 
   RowBox[{"v", "^", "3"}]}]}]], "Input",
 CellChangeTimes->{{3.618918953500458*^9, 3.6189189761204977`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"a", ",", "hu", ",", "hv", ",", "sx"}], "]"}], ";", 
  RowBox[{
   RowBox[{"hu", "[", "s_", "]"}], " ", "=", " ", "s"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"hv", "[", "a_", "]"}], "[", "s_", "]"}], ":=", " ", "a"}], ";", 
  RowBox[{
   RowBox[{"sx", "[", "s_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"graph", "[", "f3", "]"}], "[", 
    RowBox[{
     RowBox[{"hu", "[", "s", "]"}], ",", 
     RowBox[{
      RowBox[{"hv", "[", "a", "]"}], "[", "s", "]"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.6143294721366367`*^9, 3.614329624065303*^9}, {
   3.614494308370402*^9, 3.6144943725460725`*^9}, {3.614505389490672*^9, 
   3.614505523245307*^9}, {3.6145055567073655`*^9, 3.614505570107789*^9}, 
   3.6148618633255463`*^9, 3.6148631367245827`*^9, 3.6189119646725826`*^9, {
   3.6189120064650564`*^9, 3.6189120185394773`*^9}, {3.618912065011959*^9, 
   3.6189120878035994`*^9}, {3.618912435263009*^9, 3.6189124443734255`*^9}, {
   3.6189124810178895`*^9, 3.6189125661316395`*^9}, {3.6189131345654373`*^9, 
   3.6189131457974577`*^9}, 3.6189190083501544`*^9, {3.6189274238941355`*^9, 
   3.618927442770169*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"graph", "[", "f3", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6189190252917843`*^9, 3.618919153118409*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"scond2", "[", 
  RowBox[{"graph", "[", "f3", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6189191898252735`*^9, 3.618919299243865*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"1", "+", 
     RowBox[{"9", " ", 
      SuperscriptBox["s", "4"]}]}], "\[Equal]", "1"}], ",", 
   RowBox[{
    RowBox[{"36", " ", 
     SuperscriptBox["s", "3"]}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6189192294493427`*^9, {3.618919271054616*^9, 3.6189193021454706`*^9}, 
   3.6189274649846077`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kk", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"curvature", "[", "sx", "]"}], "[", "s", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.618927532517126*^9, 3.6189275639511814`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"6", " ", 
   SqrtBox[
    SuperscriptBox["s", "2"]]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"9", " ", 
      SuperscriptBox["s", "4"]}]}], ")"}], 
   RowBox[{"3", "/", "2"}]]]], "Output",
 CellChangeTimes->{3.6189275691459904`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kg", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"geodcurvature", "[", 
     RowBox[{
      RowBox[{"graph", "[", "f3", "]"}], ",", "hu", ",", 
      RowBox[{"hv", "[", "a", "]"}]}], "]"}], "[", "s", "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6143294721366367`*^9, 3.614329624065303*^9}, {
   3.614494308370402*^9, 3.6144943725460725`*^9}, {3.614505389490672*^9, 
   3.614505523245307*^9}, {3.6145055567073655`*^9, 3.614505570107789*^9}, 
   3.6148618633255463`*^9, 3.6148631367245827`*^9, 3.6189119646725826`*^9, {
   3.618912026261491*^9, 3.618912029865097*^9}, 3.618913684263603*^9, {
   3.618916542438223*^9, 3.6189165488186345`*^9}, {3.6189198543552403`*^9, 
   3.618919862155254*^9}, 3.6189275059502797`*^9, {3.6189276139960694`*^9, 
   3.6189276170536747`*^9}}],

Cell[BoxData[
 RowBox[{"18", " ", 
  SqrtBox[
   FractionBox[
    RowBox[{
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["s", "2"]}], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"9", " ", 
         SuperscriptBox["s", "4"]}]}], ")"}], "3"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"9", " ", 
        SuperscriptBox["a", "4"]}], "+", 
       RowBox[{"9", " ", 
        SuperscriptBox["s", "4"]}]}], ")"}]}]]]}]], "Output",
 CellChangeTimes->{{3.6145055582673683`*^9, 3.6145055737425957`*^9}, 
   3.6174292368739448`*^9, 3.6174293863690076`*^9, 3.618911984016617*^9, 
   3.618912036495109*^9, 3.618912099035619*^9, 3.6189164132543964`*^9, 
   3.6189188876215425`*^9, 3.618927297190713*^9, 3.61892762563369*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kn", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"normalcurvature", "[", 
     RowBox[{
      RowBox[{"graph", "[", "f3", "]"}], ",", "hu", ",", 
      RowBox[{"hv", "[", "a", "]"}]}], "]"}], "[", "s", "]"}], " ", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, 3.61432944564779*^9, {
   3.614329681629404*^9, 3.6143297762279706`*^9}, {3.6145055851462154`*^9, 
   3.6145056105742607`*^9}, 3.6148618633255463`*^9, 3.6148631367245827`*^9, {
   3.6189121285040703`*^9, 3.618912134603681*^9}, 3.6189276436205215`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"6", " ", "s"}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"9", " ", 
      SuperscriptBox["s", "4"]}]}], ")"}], " ", 
   SqrtBox[
    RowBox[{"1", "+", 
     RowBox[{"9", " ", 
      SuperscriptBox["a", "4"]}], "+", 
     RowBox[{"9", " ", 
      SuperscriptBox["s", "4"]}]}]]}]]], "Output",
 CellChangeTimes->{3.6143297807051783`*^9, 3.614505612196663*^9, 
  3.617429243675557*^9, 3.617429379333395*^9, 3.618912137396086*^9, 
  3.618927649189731*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Together", "[", 
   RowBox[{
    RowBox[{"kk", "^", "2"}], "-", 
    RowBox[{"kn", "^", "2"}], "-", 
    RowBox[{"kg", "^", "2"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6145056477179255`*^9, 3.6145057008360186`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.614505702630022*^9, 3.6174292503991685`*^9, 
  3.6174293109896755`*^9, 3.6174293938726206`*^9, 3.6189126141017237`*^9, 
  3.618927655008541*^9}]
}, Closed]],

Cell["OK.", "Text",
 CellChangeTimes->{{3.6145057514113073`*^9, 3.6145057689301386`*^9}}],

Cell[TextData[{
 StyleBox["Example",
  FontColor->RGBColor[0, 0, 1]],
 ". Helix Normal Surface"
}], "Text",
 CellChangeTimes->{{3.6136216629488277`*^9, 3.6136217472669764`*^9}, {
   3.6136219986458178`*^9, 3.6136220101274376`*^9}, {3.6136316409915533`*^9, 
   3.6136316447511597`*^9}, {3.613631706792469*^9, 3.6136317217996955`*^9}, {
   3.613631784777006*^9, 3.6136317936534214`*^9}, 3.6136319442872863`*^9, {
   3.613977412358617*^9, 3.6139774462886763`*^9}}],

Cell[TextData[{
 "We consider a normal surface of the helix, see Subsection ",
 ButtonBox["3.7.2",
  BaseStyle->"Hyperlink",
  ButtonData->"helix"],
 "."
}], "Text",
 CellChangeTimes->{{3.614330152547432*^9, 3.614330182062683*^9}, {
  3.6143302386127825`*^9, 3.614330280420856*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hel", "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.6147509470177927`*^9, 3.614750947048992*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"Cos", "[", "t", "]"}], 
    SqrtBox["2"]], ",", 
   FractionBox[
    RowBox[{"Sin", "[", "t", "]"}], 
    SqrtBox["2"]], ",", 
   FractionBox["t", 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{3.6147516629966497`*^9, 3.6174295101396246`*^9}]
}, Closed]],

Cell["The surface generated by the binormals:", "Text",
 CellChangeTimes->{{3.618981650960631*^9, 3.6189816787130795`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"cb", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"Pi", "/", "2"}]}]], "Input",
 CellChangeTimes->{{3.613977464712309*^9, 3.6139774850859447`*^9}, {
  3.613994501006675*^9, 3.613994505015882*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hnsf", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"helixnormalsf", "[", "cb", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
    RowBox[{"v", "\[Element]", "Reals"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6139774919343567`*^9, 3.613977501715574*^9}, {
  3.61397753935844*^9, 3.613977571853297*^9}, {3.6139776021953506`*^9, 
  3.6139776329898043`*^9}, {3.61433035108898*^9, 3.614330391461851*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"Cos", "[", "v", "]"}], "+", 
     RowBox[{"u", " ", 
      RowBox[{"Sin", "[", "v", "]"}]}]}], 
    SqrtBox["2"]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "u"}], " ", 
      RowBox[{"Cos", "[", "v", "]"}]}], "+", 
     RowBox[{"Sin", "[", "v", "]"}]}], 
    SqrtBox["2"]], ",", 
   FractionBox[
    RowBox[{"u", "+", "v"}], 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{3.613977572992099*^9, 3.6139776348930078`*^9, 
  3.613994513455497*^9, 3.613994587212426*^9, 3.614053574080867*^9, 
  3.614330317408521*^9, 3.6143303925382533`*^9, 3.6145059938045335`*^9, 
  3.6147516893918962`*^9, 3.6174295361604705`*^9, 3.6189815742552958`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"hnsf", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.613977668760667*^9, 3.613977729663174*^9}, {
  3.614330411133486*^9, 3.6143304144874916`*^9}, {3.6143304498527536`*^9, 
  3.61433045337836*^9}, {3.6143307201856284`*^9, 3.614330757391694*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"hel1", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6143305134852657`*^9, 3.614330520380478*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"hel", "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotStyle", " ", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Thick", ",", " ", "Red"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6143305234224825`*^9, 3.6143305311132965`*^9}, {
   3.6143306628399277`*^9, 3.614330695381585*^9}, {3.6143307681869125`*^9, 
   3.6143307872501464`*^9}, {3.6143308932991323`*^9, 3.6143309148271704`*^9}, 
   3.6147509693882313`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"hel2", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.61433080043217*^9, 3.614330813395792*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"hel1", ",", "hel2"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6143308164845977`*^9, 3.614330844439847*^9}}],

Cell["\<\
We consider  hnsf. The helix itself is a curve on the surface\
\>", "Text",
 CellChangeTimes->{{3.613632210517354*^9, 3.6136322491742215`*^9}, {
  3.613977780737664*^9, 3.613977788802878*^9}, {3.6143310270537677`*^9, 
  3.6143310468814025`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "sx", "]"}], ";", 
  RowBox[{
   RowBox[{"sx", "[", "s_", "]"}], " ", ":=", " ", 
   RowBox[{"hnsf", "[", 
    RowBox[{"0", ",", "s"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, {3.6139778317185535`*^9, 
   3.6139778583322*^9}, {3.6140535554544344`*^9, 3.614053565142051*^9}, 
   3.614057854151184*^9, {3.6140579446937437`*^9, 3.614057962664975*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sx", "[", "t", "]"}]], "Input",
 CellChangeTimes->{
  3.6140536423777866`*^9, 3.6140578620915985`*^9, {3.6140579046484733`*^9, 
   3.614057915490492*^9}, {3.614057981244608*^9, 3.6140579829762106`*^9}, 
   3.61450612840157*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"Cos", "[", "t", "]"}], 
    SqrtBox["2"]], ",", 
   FractionBox[
    RowBox[{"Sin", "[", "t", "]"}], 
    SqrtBox["2"]], ",", 
   FractionBox["t", 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.613994668162896*^9, 3.61405358743449*^9, {3.614053643703789*^9, 
   3.6140536637654247`*^9}, 3.6140578631524005`*^9, {3.6140579079244785`*^9, 
   3.6140579166292944`*^9}, 3.6140579844894133`*^9, 3.614506129774372*^9, 
   3.617429694625549*^9, 3.618981724889161*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"curvature", "[", "sx", "]"}], "[", "t", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, {3.6139778317185535`*^9, 
   3.6139778583322*^9}, {3.613977953227167*^9, 3.613977974224804*^9}, 
   3.61399468710133*^9, {3.6140012428100443`*^9, 3.614001260500475*^9}, 
   3.614003200051882*^9, {3.614053692017074*^9, 3.6140537100195055`*^9}, 
   3.6143312564053707`*^9, 3.614506139196789*^9, 3.614861863387946*^9, 
   3.614863136740183*^9}],

Cell[BoxData[
 FractionBox["1", 
  SqrtBox["2"]]], "Output",
 CellChangeTimes->{
  3.6136224568186226`*^9, 3.6136225274711466`*^9, 3.613632030165437*^9, 
   3.6139779460979548`*^9, 3.6139810211053524`*^9, 3.614001232233226*^9, 
   3.61400320456029*^9, 3.614003942613186*^9, 3.6140537126871104`*^9, 
   3.6140579982486377`*^9, {3.6143312575129724`*^9, 3.614331266888589*^9}, 
   3.6145061466536016`*^9, 3.6174297036579647`*^9, 3.618981729085568*^9}]
}, Closed]],

Cell["It is a geodesic on the surface:", "Text",
 CellChangeTimes->{{3.614331293034235*^9, 3.614331320037882*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"hu", ",", "hv"}], "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"hu", "[", "a_", "]"}], "[", "s_", "]"}], ":=", " ", "a"}], ";", 
  RowBox[{
   RowBox[{"hv", "[", "s_", "]"}], ":=", " ", "s"}], ";"}]], "Input",
 CellChangeTimes->{{3.599029134745389*^9, 3.599029405593065*^9}, 
   3.613476504428583*^9, 3.6136213128686132`*^9, {3.6136220816691637`*^9, 
   3.6136221609485025`*^9}, 3.6136226985098467`*^9, {3.6136230453764563`*^9, 
   3.613623055532074*^9}, {3.613632058448287*^9, 3.613632088088339*^9}, {
   3.613981056689015*^9, 3.6139810903850737`*^9}, {3.6140538078940773`*^9, 
   3.6140538380645304`*^9}, {3.614053909044655*^9, 3.6140539372963047`*^9}, {
   3.614057401001589*^9, 3.6140574170228167`*^9}, {3.6140574584564896`*^9, 
   3.614057531854618*^9}, {3.6140577454501934`*^9, 3.6140577665102305`*^9}, {
   3.614058011789461*^9, 3.6140580637219524`*^9}, {3.614331077410656*^9, 
   3.614331090155878*^9}, {3.6143311369871607`*^9, 3.6143311824612403`*^9}, 
   3.614861863387946*^9, 3.614863136740183*^9, {3.6189817649032307`*^9, 
   3.618981788786873*^9}, {3.6189818891262493`*^9, 3.618981900436269*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"geodcurvature", "[", 
     RowBox[{"hnsf", ",", 
      RowBox[{"hu", "[", "a", "]"}], ",", "hv"}], "]"}], "[", "t", "]"}], 
   "]"}], "/.", 
  RowBox[{"a", "\[Rule]", " ", "0"}]}]], "Input",
 CellChangeTimes->{{3.599029134745389*^9, 3.599029405593065*^9}, 
   3.613476504428583*^9, 3.6136213128686132`*^9, {3.6136220816691637`*^9, 
   3.6136221609485025`*^9}, 3.6136226985098467`*^9, {3.6136230453764563`*^9, 
   3.613623055532074*^9}, {3.613632058448287*^9, 3.613632088088339*^9}, {
   3.613981056689015*^9, 3.6139810903850737`*^9}, {3.6140538078940773`*^9, 
   3.6140538380645304`*^9}, {3.614053909044655*^9, 3.6140539372963047`*^9}, {
   3.614057401001589*^9, 3.6140574170228167`*^9}, {3.6140574584564896`*^9, 
   3.614057531854618*^9}, {3.6140577454501934`*^9, 3.6140577665102305`*^9}, {
   3.614058011789461*^9, 3.6140580637219524`*^9}, {3.614331077410656*^9, 
   3.614331090155878*^9}, {3.6143311369871607`*^9, 3.6143311824612403`*^9}, 
   3.614861863387946*^9, 3.614863136740183*^9, {3.6189817649032307`*^9, 
   3.618981846787775*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.6140538430721397`*^9, 3.614053939074708*^9, 3.6140573465886927`*^9, 
   3.614057535068224*^9, 3.6140577849026628`*^9, 3.614058075531173*^9, 
   3.6143311973124666`*^9, 3.6145061634704313`*^9, {3.6174297162315865`*^9, 
   3.6174297200847936`*^9}, 3.6189817453251963`*^9, {3.6189818209385295`*^9, 
   3.6189818501885805`*^9}, 3.618981908860284*^9}]
}, Closed]],

Cell["Its normal curvature coincides with its curvature:", "Text",
 CellChangeTimes->{{3.614331335575509*^9, 3.61433136426396*^9}, 
   3.6174418910598736`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"normalcurvature", "[", 
     RowBox[{"hnsf", ",", 
      RowBox[{"hu", "[", "a", "]"}], ",", "hv"}], "]"}], "[", "t", "]"}], 
   "]"}], "/.", " ", 
  RowBox[{"a", "\[Rule]", " ", "0"}]}]], "Input",
 CellChangeTimes->{{3.599029134745389*^9, 3.599029405593065*^9}, 
   3.613476504428583*^9, 3.6136213128686132`*^9, {3.6136220816691637`*^9, 
   3.6136221609485025`*^9}, 3.6136226985098467`*^9, {3.6136230453764563`*^9, 
   3.613623055532074*^9}, {3.613632058448287*^9, 3.613632088088339*^9}, {
   3.613981056689015*^9, 3.6139810903850737`*^9}, {3.6140538078940773`*^9, 
   3.6140538380645304`*^9}, {3.614053909044655*^9, 3.6140539372963047`*^9}, {
   3.614057401001589*^9, 3.6140574170228167`*^9}, {3.6140574584564896`*^9, 
   3.614057531854618*^9}, {3.6140577454501934`*^9, 3.6140577665102305`*^9}, {
   3.614058011789461*^9, 3.6140580637219524`*^9}, {3.614331077410656*^9, 
   3.614331090155878*^9}, {3.6143311369871607`*^9, 3.614331232490528*^9}, 
   3.6148618634035463`*^9, 3.614863136740183*^9, {3.6189819294679203`*^9, 
   3.618981931745524*^9}, {3.618982920522061*^9, 3.618982951940516*^9}}],

Cell[BoxData[
 FractionBox["1", 
  SqrtBox["2"]]], "Output",
 CellChangeTimes->{3.6143312352985334`*^9, 3.614506175591653*^9, 
  3.617429728430808*^9, 3.6189819337267275`*^9, 3.6189829446865034`*^9}]
}, Closed]],

Cell["Clearly, the generating lines are geodesics too:", "Text",
 CellChangeTimes->{{3.614331549857486*^9, 3.6143315806051397`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hnsf", "[", 
  RowBox[{"s", ",", "ca"}], "]"}]], "Input",
 CellChangeTimes->{{3.6143314959437914`*^9, 3.6143315099214153`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"Cos", "[", "ca", "]"}], "+", 
     RowBox[{"s", " ", 
      RowBox[{"Sin", "[", "ca", "]"}]}]}], 
    SqrtBox["2"]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "s"}], " ", 
      RowBox[{"Cos", "[", "ca", "]"}]}], "+", 
     RowBox[{"Sin", "[", "ca", "]"}]}], 
    SqrtBox["2"]], ",", 
   FractionBox[
    RowBox[{"ca", "+", "s"}], 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{3.61433151243302*^9, 3.6145061898188777`*^9, 
  3.6174297363088217`*^9, 3.6189829978825965`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hu", "[", "s_", "]"}], ":=", " ", "s"}], ";", 
  RowBox[{
   RowBox[{"hv", "[", "s_", "]"}], ":=", " ", "ca"}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"geodcurvature", "[", 
     RowBox[{"hnsf", ",", "hu", ",", "hv"}], "]"}], "[", "t", "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.599029134745389*^9, 3.599029405593065*^9}, 
   3.613476504428583*^9, 3.6136213128686132`*^9, {3.6136220816691637`*^9, 
   3.6136221609485025`*^9}, 3.6136226985098467`*^9, {3.6136230453764563`*^9, 
   3.613623055532074*^9}, {3.613632058448287*^9, 3.613632088088339*^9}, {
   3.613981056689015*^9, 3.6139810903850737`*^9}, {3.6140538078940773`*^9, 
   3.6140538380645304`*^9}, {3.614053909044655*^9, 3.6140539372963047`*^9}, {
   3.614057401001589*^9, 3.6140574170228167`*^9}, {3.6140574584564896`*^9, 
   3.614057531854618*^9}, {3.6140577454501934`*^9, 3.6140577665102305`*^9}, {
   3.614058011789461*^9, 3.6140580637219524`*^9}, {3.614331077410656*^9, 
   3.614331090155878*^9}, {3.6143311369871607`*^9, 3.6143311824612403`*^9}, {
   3.6143314227796626`*^9, 3.614331442981698*^9}, 3.6148618634191465`*^9, 
   3.614863136740183*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6143314558049207`*^9, 3.614506205980506*^9, 
  3.617429742704833*^9, 3.6189830096294174`*^9}]
}, Closed]],

Cell["For the parameter curves u = u0 we calculate", "Text",
 CellChangeTimes->{{3.618983158547279*^9, 3.618983177438912*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sx", "[", "s_", "]"}], ":=", 
  RowBox[{"hnsf", "[", 
   RowBox[{"uo", ",", "s"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.614331807290964*^9, 3.614331815195416*^9}, {
   3.6145062733882246`*^9, 3.614506286851048*^9}, {3.6145063753032036`*^9, 
   3.614506378017608*^9}, 3.614506412150468*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sc", "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.6189830814987435`*^9, 3.618983098299973*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["s", "2"], ",", 
   SuperscriptBox["s", "3"]}], "}"}]], "Output",
 CellChangeTimes->{3.618983100827177*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kk", " ", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"curvature", "[", "sx", "]"}], "[", "s", "]"}], ",", 
    RowBox[{"s", "\[Element]", "Reals"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6145063038550777`*^9, 3.614506385412021*^9}, 
   3.614506423351288*^9, 3.6148618634347467`*^9, 3.614863136740183*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SqrtBox["2"], " ", 
   SqrtBox[
    RowBox[{"2", "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["uo", "2"]}], "+", 
     SuperscriptBox["uo", "4"]}]]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"2", "+", 
     SuperscriptBox["uo", "2"]}], ")"}], 
   RowBox[{"3", "/", "2"}]]]], "Output",
 CellChangeTimes->{3.6145063229963117`*^9, 3.6145064286708975`*^9, 
  3.617429752969651*^9, 3.6189830268206472`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "torsion"}]], "Input",
 CellChangeTimes->{{3.6143322148102727`*^9, 3.614332225668894*^9}}],

Cell[BoxData[
 StyleBox["\<\"torsion[curve][t] yields the torsion of the curve[t] in \\nthe \
Euclidean 3-space; it is defined only at points with non vanishing curvature.\
\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6143322271609793`*^9},
 CellTags->"Info3614339427-8121375"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"torsion", "[", "sx", "]"}], "[", "s", "]"}], ",", 
   RowBox[{"s", "\[Element]", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6145063038550777`*^9, 3.614506385412021*^9}, 
   3.614506423351288*^9, {3.614506500259423*^9, 3.614506531506278*^9}}],

Cell[BoxData[
 FractionBox[
  SqrtBox["2"], 
  RowBox[{"2", "+", 
   SuperscriptBox["uo", "2"]}]]], "Output",
 CellChangeTimes->{3.614506539555892*^9, 3.6174297856985087`*^9, 
  3.618983192648939*^9}]
}, Closed]],

Cell["\<\
It follows: The parameter curves u= const. are helices again, its curvature \
and torsion depend on uo.\
\>", "Text",
 CellChangeTimes->{{3.6143322874654284`*^9, 3.614332359217532*^9}, {
  3.614506634216858*^9, 3.6145066625777082`*^9}, {3.618983208092966*^9, 
  3.6189832084049664`*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"hnsf", "[", 
    RowBox[{"1", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"Thick", ",", " ", "Green"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6143317451024065`*^9, 3.614331772987002*^9}, {
  3.6143318641392155`*^9, 3.614331897460121*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"hel3", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6143319076417036`*^9, 3.614331921147476*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"hel1", ",", "hel2", ",", "hel3"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6143308164845977`*^9, 3.614330844439847*^9}, {
  3.614331956171479*^9, 3.6143319583726053`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hu", "[", "s_", "]"}], ":=", " ", "uo"}], ";", 
  RowBox[{
   RowBox[{"hv", "[", "s_", "]"}], ":=", " ", "s"}], ";", 
  RowBox[{"kg", " ", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"geodcurvature", "[", 
       RowBox[{"hnsf", ",", "hu", ",", "hv"}], "]"}], "[", "s", "]"}], ",", 
     RowBox[{"s", "\[Element]", "Reals"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.599029134745389*^9, 3.599029405593065*^9}, 
   3.613476504428583*^9, 3.6136213128686132`*^9, {3.6136220816691637`*^9, 
   3.6136221609485025`*^9}, 3.6136226985098467`*^9, {3.6136230453764563`*^9, 
   3.613623055532074*^9}, {3.613632058448287*^9, 3.613632088088339*^9}, {
   3.613981056689015*^9, 3.6139810903850737`*^9}, {3.6140538078940773`*^9, 
   3.6140538380645304`*^9}, {3.614053909044655*^9, 3.6140539372963047`*^9}, {
   3.614057401001589*^9, 3.6140574170228167`*^9}, {3.6140574584564896`*^9, 
   3.614057531854618*^9}, {3.6140577454501934`*^9, 3.6140577665102305`*^9}, {
   3.614058011789461*^9, 3.6140580637219524`*^9}, {3.614331077410656*^9, 
   3.614331090155878*^9}, {3.6143311369871607`*^9, 3.6143311824612403`*^9}, {
   3.6143314227796626`*^9, 3.614331442981698*^9}, {3.6143316492429237`*^9, 
   3.6143316728042717`*^9}, 3.6143317151976967`*^9, 3.614506458201749*^9, 
   3.6145064916482077`*^9, {3.614506787409127*^9, 3.6145067899987316`*^9}, 
   3.6148618634815464`*^9, 3.614863136740183*^9}],

Cell[BoxData[
 SqrtBox[
  FractionBox[
   SuperscriptBox["uo", "2"], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"2", "+", 
      SuperscriptBox["uo", "2"]}], ")"}], "2"]]]], "Output",
 CellChangeTimes->{
  3.614331677758555*^9, 3.6143317189249096`*^9, 3.6145068011215515`*^9, {
   3.617429834854195*^9, 3.6174298390038023`*^9}, {3.618983254643448*^9, 
   3.618983259526256*^9}}]
}, Closed]],

Cell["\<\
The only geodesic parameter curve u == uo is the generating hel obtained for \
uo = 0.\
\>", "Text",
 CellChangeTimes->{{3.6143326361293707`*^9, 3.6143326704333324`*^9}, 
   3.6145069125525475`*^9, 3.614751027217533*^9, {3.617429872653062*^9, 
   3.6174299091727257`*^9}, {3.618983277747088*^9, 3.6189833075431404`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kn", " ", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"normalcurvature", "[", 
      RowBox[{"hnsf", ",", "hu", ",", "hv"}], "]"}], "[", "t", "]"}], ",", 
    RowBox[{"t", "\[Element]", "Reals"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.614332709739581*^9, 3.6143327141728344`*^9}, {
   3.614506937574991*^9, 3.614506939836995*^9}, 3.6148618634971466`*^9, 
   3.614863136740183*^9}],

Cell[BoxData[
 FractionBox["1", 
  SqrtBox[
   RowBox[{"2", "+", 
    SuperscriptBox["uo", "2"]}]]]], "Output",
 CellChangeTimes->{3.614332718673092*^9, 3.6143329155993557`*^9, 
  3.6145069450474043`*^9, 3.6189833240791693`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Together", "[", 
    RowBox[{
     RowBox[{"kk", "^", "2"}], " ", "-", " ", 
     RowBox[{"kg", "^", "2"}], "-", 
     RowBox[{"kn", "^", "2"}]}], "]"}], ",", 
   RowBox[{"uo", "\[Element]", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6143327450406*^9, 3.614332813123494*^9}, {
  3.614332923036781*^9, 3.6143329233798003`*^9}, {3.6145069563262243`*^9, 
  3.614507048615986*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.614332815720643*^9, 3.614332924913888*^9, 
  3.61450705059719*^9, 3.6189833292583785`*^9}]
}, Closed]],

Cell["OK.", "Text",
 CellChangeTimes->{{3.6145070851824503`*^9, 3.614507087226054*^9}}],

Cell[TextData[{
 StyleBox["Example",
  FontColor->RGBColor[0, 0, 1]],
 ". Catenoids"
}], "Text",
 CellChangeTimes->{{3.6136216629488277`*^9, 3.6136217472669764`*^9}, {
   3.6136219986458178`*^9, 3.6136220101274376`*^9}, {3.6136316409915533`*^9, 
   3.6136316447511597`*^9}, {3.613631706792469*^9, 3.6136317217996955`*^9}, {
   3.613631784777006*^9, 3.6136317936534214`*^9}, 3.6136319442872863`*^9, {
   3.6136323634132223`*^9, 3.613632369544033*^9}, {3.6143337794257636`*^9, 
   3.6143337836740065`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"catenoid", "[", "a", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.61433378758123*^9, 3.6143337980828304`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", " ", 
    RowBox[{"Cos", "[", "u", "]"}], " ", 
    RowBox[{"Cosh", "[", 
     FractionBox["v", "a"], "]"}]}], ",", 
   RowBox[{"a", " ", 
    RowBox[{"Cosh", "[", 
     FractionBox["v", "a"], "]"}], " ", 
    RowBox[{"Sin", "[", "u", "]"}]}], ",", "v"}], "}"}]], "Output",
 CellChangeTimes->{3.614333799050886*^9, 3.6145071415765495`*^9, 
  3.617430012585307*^9, 3.618983345888008*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"catenoid", "[", "1", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.614333822495227*^9, 3.614333879636495*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", 
     RowBox[{"catenoid", "[", "ao", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", "Reals"}], ",", 
     RowBox[{"v", "\[Element]", "Reals"}], ",", 
     RowBox[{"ao", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.614334848950937*^9, 3.6143348515860877`*^9}, {
  3.614334951923826*^9, 3.6143349775872946`*^9}, {3.6143361902226534`*^9, 
  3.6143362040454435`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   SuperscriptBox[
    RowBox[{"Sech", "[", 
     FractionBox["v", "ao"], "]"}], "4"], 
   SuperscriptBox["ao", "2"]]}]], "Output",
 CellChangeTimes->{3.6143349811644993`*^9, 3.6143362062895722`*^9, 
  3.614507171637802*^9, 3.6174300339729447`*^9, 3.6189833705360513`*^9}]
}, Closed]],

Cell["\<\
Remember that this is the only minimal surface of revolution:\
\>", "Text",
 CellChangeTimes->{{3.617430756535014*^9, 3.61743078288346*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"meancurvature", "[", 
     RowBox[{"catenoid", "[", "ao", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", "Reals"}], ",", 
     RowBox[{"v", "\[Element]", "Reals"}], ",", 
     RowBox[{"ao", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.614334848950937*^9, 3.6143348515860877`*^9}, {
   3.614334951923826*^9, 3.6143349775872946`*^9}, {3.6143361902226534`*^9, 
   3.6143362040454435`*^9}, 3.617430053285779*^9, {3.6174307303581676`*^9, 
   3.6174307367073793`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.617430738844583*^9, 3.6189833916584883`*^9}]
}, Closed]],

Cell["The geodesic curvature of a meridian is", "Text",
 CellChangeTimes->{{3.61433633999422*^9, 3.61433636132944*^9}, 
   3.6143959895035353`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"h1", "[", "t_", "]"}], " ", ":=", "uo"}], ";", 
  RowBox[{
   RowBox[{"h2", "[", "t_", "]"}], ":=", " ", "t"}], ";", " ", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"geodcurvature", "[", 
      RowBox[{
       RowBox[{"catenoid", "[", "ao", "]"}], ",", "h1", ",", "h2"}], "]"}], 
     "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"uo", "\[Element]", "Reals"}], ",", 
      RowBox[{"t", "\[Element]", "Reals"}], ",", 
      RowBox[{"ao", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.614335163132907*^9, 3.6143352204111834`*^9}, {
   3.614335253212059*^9, 3.614335367557599*^9}, 3.614335503949401*^9, 
   3.6145073265928745`*^9, 3.6148618635127463`*^9, 3.614863136755783*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.614397745239819*^9, 3.6143979095393076`*^9, 
  3.6144021870190783`*^9, 3.6145072102634697`*^9, 3.617430805862301*^9, 
  3.618983404887312*^9}]
}, Closed]],

Cell[" The meridians are geodesics.", "Text",
 CellChangeTimes->{{3.6145072358007145`*^9, 3.6145072494975386`*^9}}],

Cell["Its normal curvature :", "Text",
 CellChangeTimes->{{3.6143363759432755`*^9, 3.6143363979705353`*^9}, {
  3.614507283645999*^9, 3.614507284753601*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kn", " ", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"normalcurvature", "[", 
      RowBox[{
       RowBox[{"catenoid", "[", "ao", "]"}], ",", "h1", ",", "h2"}], "]"}], 
     "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"uo", "\[Element]", "Reals"}], ",", 
      RowBox[{"t", "\[Element]", "Reals"}], ",", 
      RowBox[{"ao", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.614335163132907*^9, 3.6143352204111834`*^9}, {
   3.614335253212059*^9, 3.614335367557599*^9}, 3.614335503949401*^9, {
   3.6143360854696617`*^9, 3.6143361025496387`*^9}, {3.614507348666913*^9, 
   3.614507356794527*^9}, 3.614861863528346*^9, 3.614863136755783*^9}],

Cell[BoxData[
 FractionBox[
  SuperscriptBox[
   RowBox[{"Sech", "[", 
    FractionBox["t", "ao"], "]"}], "2"], "ao"]], "Output",
 CellChangeTimes->{3.6143361056118135`*^9, 3.6145073593217316`*^9, 
  3.6174308143175154`*^9, 3.6189834159165306`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sx", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"catenoid", "[", "ao", "]"}], "[", 
   RowBox[{"uo", ",", "t"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6143966521458993`*^9, 3.6143966702887306`*^9}, {
  3.6143967042499905`*^9, 3.6143967161684113`*^9}, {3.6143967976629543`*^9, 
  3.6143968015005617`*^9}, {3.6145073821445723`*^9, 3.6145073949989944`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sx", "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.614396727759232*^9, 3.6143967316436386`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ao", " ", 
    RowBox[{"Cos", "[", "uo", "]"}], " ", 
    RowBox[{"Cosh", "[", 
     FractionBox["t", "ao"], "]"}]}], ",", 
   RowBox[{"ao", " ", 
    RowBox[{"Cosh", "[", 
     FractionBox["t", "ao"], "]"}], " ", 
    RowBox[{"Sin", "[", "uo", "]"}]}], ",", "t"}], "}"}]], "Output",
 CellChangeTimes->{3.61439673270444*^9, 3.614396806820171*^9, 
  3.6174308257523355`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kk", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"curvature", "[", "sx", "]"}], "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"uo", "\[Element]", "Reals"}], ",", 
      RowBox[{"t", "\[Element]", "Reals"}], ",", 
      RowBox[{"ao", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.614396815415786*^9, 3.6143968606402655`*^9}, {
   3.614507412595825*^9, 3.6145074240930457`*^9}, 3.6148618635439463`*^9, 
   3.614863136755783*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   SqrtBox["2"], " ", 
   RowBox[{"Cosh", "[", 
    FractionBox["t", "ao"], "]"}]}], 
  RowBox[{"ao", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"Cosh", "[", 
       FractionBox[
        RowBox[{"2", " ", "t"}], "ao"], "]"}]}], ")"}], 
    RowBox[{"3", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{3.6143968624654684`*^9, 3.6143972842590094`*^9, 
  3.614507427088251*^9, 3.6174308303387437`*^9, 3.6189834246837463`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"kk", "^", "2"}], "-", 
   RowBox[{"kn", "^", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.614396897955531*^9, 3.614396932634392*^9}, 
   3.614397004098117*^9, 3.6143972530589542`*^9, {3.61450748368515*^9, 
   3.614507504776387*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.614397024378153*^9, 3.614397254650157*^9, 
  3.614397288190216*^9, 3.6145075072723913`*^9, 3.6174308378111567`*^9, 
  3.6189834287865534`*^9}]
}, Closed]],

Cell["The geodesic curvature of the generating circles  v = vo is", "Text",
 CellChangeTimes->{{3.6143366537701664`*^9, 3.6143366972176514`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"h1", "[", "t_", "]"}], " ", ":=", "t"}], ";", 
  RowBox[{
   RowBox[{"h2", "[", "t_", "]"}], ":=", " ", "vo"}], ";", " ", 
  RowBox[{"kg1", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"geodcurvature", "[", 
       RowBox[{
        RowBox[{"catenoid", "[", "ao", "]"}], ",", "h1", ",", "h2"}], "]"}], 
      "[", "t", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"t", "\[Element]", "Reals"}], ",", 
       RowBox[{"vo", "\[Element]", "Reals"}], ",", 
       RowBox[{"ao", ">", "0"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.614335163132907*^9, 3.6143352204111834`*^9}, {
   3.614335253212059*^9, 3.614335367557599*^9}, 3.614335503949401*^9, {
   3.6143365726285257`*^9, 3.6143365995500655`*^9}, {3.614507543948056*^9, 
   3.614507584570527*^9}, 3.6148618635595465`*^9, 3.614863136755783*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"Abs", "[", 
    RowBox[{"Tanh", "[", 
     FractionBox["vo", "ao"], "]"}], "]"}], " ", 
   RowBox[{"Sech", "[", 
    FractionBox["vo", "ao"], "]"}]}], "ao"]], "Output",
 CellChangeTimes->{
  3.614336609526636*^9, 3.6144019450682397`*^9, 3.614507586489331*^9, {
   3.6174308456267705`*^9, 3.6174308487935762`*^9}, 3.6189834384741707`*^9}]
}, Closed]],

Cell["It is a geodesic for vo = 0 only.", "Text",
 CellChangeTimes->{{3.6143367097293673`*^9, 3.614336749553645*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"h1", "[", "t_", "]"}], " ", ":=", "t"}], ";", 
  RowBox[{
   RowBox[{"h2", "[", "t_", "]"}], ":=", " ", "vo"}], ";", " ", 
  RowBox[{"kn1", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"normalcurvature", "[", 
       RowBox[{
        RowBox[{"catenoid", "[", "ao", "]"}], ",", "h1", ",", "h2"}], "]"}], 
      "[", "t", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"t", "\[Element]", "Reals"}], ",", 
       RowBox[{"vo", "\[Element]", "Reals"}], ",", 
       RowBox[{"ao", ">", "0"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.614335163132907*^9, 3.6143352204111834`*^9}, {
   3.614335253212059*^9, 3.614335367557599*^9}, 3.614335503949401*^9, {
   3.6143365726285257`*^9, 3.6143365995500655`*^9}, {3.614507543948056*^9, 
   3.614507584570527*^9}, {3.6145076250993986`*^9, 3.6145076497474422`*^9}, 
   3.6148618635751467`*^9, 3.614863136755783*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   SuperscriptBox[
    RowBox[{"Sech", "[", 
     FractionBox["vo", "ao"], "]"}], "2"], "ao"]}]], "Output",
 CellChangeTimes->{
  3.6145076590918584`*^9, {3.61743088512604*^9, 3.6174308922864523`*^9}, 
   3.6189834837922497`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sx", "[", "t_", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"catenoid", "[", "ao", "]"}], "[", 
   RowBox[{"t", ",", "vo"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6145076705110784`*^9, 3.614507738542798*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ao", " ", 
    RowBox[{"Cos", "[", "t", "]"}], " ", 
    RowBox[{"Cosh", "[", 
     FractionBox["vo", "ao"], "]"}]}], ",", 
   RowBox[{"ao", " ", 
    RowBox[{"Cosh", "[", 
     FractionBox["vo", "ao"], "]"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", "vo"}], "}"}]], "Output",
 CellChangeTimes->{3.614507740134001*^9, 3.617430898120863*^9, 
  3.6189834927310658`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kk1", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"curvature", "[", "sx", "]"}], "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"t", "\[Element]", "Reals"}], ",", 
      RowBox[{"vo", "\[Element]", "Reals"}], ",", 
      RowBox[{"ao", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.614507752239622*^9, 3.614507799242504*^9}, 
   3.614861863590747*^9, 3.614863136755783*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"Sech", "[", 
   FractionBox["vo", "ao"], "]"}], "ao"]], "Output",
 CellChangeTimes->{3.614507818414938*^9, 3.6174309032220716`*^9, 
  3.618983498534276*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Together", "[", 
    RowBox[{
     RowBox[{"kk1", "^", "2"}], "-", 
     RowBox[{"kn1", "^", "2"}], "-", 
     RowBox[{"kg1", "^", "2"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"vo", "\[Element]", "Reals"}], ",", 
     RowBox[{"ao", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6145078278997545`*^9, 3.61450790487029*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6145079110167007`*^9, 3.617430909165682*^9, 
  3.6189835198595133`*^9}]
}, Closed]],

Cell["OK.", "Text",
 CellChangeTimes->{{3.6145079169291115`*^9, 3.614507921234719*^9}}],

Cell[TextData[{
 StyleBox["Example",
  FontColor->RGBColor[0, 0, 1]],
 ". Surfaces of revolution"
}], "Text",
 CellChangeTimes->{{3.6136216629488277`*^9, 3.6136217472669764`*^9}, {
   3.6136219986458178`*^9, 3.6136220101274376`*^9}, {3.6136316409915533`*^9, 
   3.6136316447511597`*^9}, {3.613631706792469*^9, 3.6136317217996955`*^9}, {
   3.613631784777006*^9, 3.6136317936534214`*^9}, 3.6136319442872863`*^9, {
   3.6136323634132223`*^9, 3.613632369544033*^9}, {3.614337018522029*^9, 
   3.614337032273816*^9}}],

Cell[TextData[{
 "We consider the special surfaces of revolution with  an unspecified \
function f[z], see Subsection ",
 ButtonBox["3.8.2",
  BaseStyle->"Hyperlink",
  ButtonData->"sfrev"],
 "."
}], "Text",
 CellChangeTimes->{{3.613632210517354*^9, 3.6136322491742215`*^9}, {
  3.614337045025545*^9, 3.614337100169699*^9}, {3.614337139193931*^9, 
  3.6143371486734734`*^9}, {3.6143371788692007`*^9, 3.614337178873201*^9}, {
  3.614337255633591*^9, 3.614337261929951*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sfr", "[", "f", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{3.6143369034754486`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Cos", "[", "v", "]"}], " ", 
    RowBox[{"f", "[", "u", "]"}]}], ",", 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", "u"}], "}"}]], "Output",
 CellChangeTimes->{3.614337242810858*^9, 3.614507976708416*^9, 
  3.6174309157332935`*^9, 3.6189835906368375`*^9}]
}, Closed]],

Cell["The meridians of a surface of revolution are geodesics:", "Text",
 CellChangeTimes->{{3.6145105285608983`*^9, 3.6145105522417397`*^9}, 
   3.617441960564849*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"sx", ",", "hu", ",", "hv"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, 3.6136324917858477`*^9, {
   3.6139708453034763`*^9, 3.6139709222428117`*^9}, 3.6139709681380925`*^9, 
   3.613972610035379*^9, 3.6139765411438866`*^9, {3.6143373012522*^9, 
   3.6143373205003014`*^9}, 3.614337396340639*^9, {3.6143374303895864`*^9, 
   3.614337446300497*^9}, {3.61451029605809*^9, 3.6145103278509455`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hu", "[", "s_", "]"}], ":=", " ", "s"}], ";", 
  RowBox[{
   RowBox[{"hv", "[", "s_", "]"}], " ", ":=", " ", "vo"}], ";", 
  RowBox[{"kg", " ", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"geodcurvature", "[", 
      RowBox[{
       RowBox[{"sfr", "[", "f", "]"}], ",", "hu", ",", "hv"}], "]"}], "[", 
     "s", "]"}], " ", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, 3.6136324917858477`*^9, {
   3.6139708453034763`*^9, 3.6139709222428117`*^9}, 3.6139709681380925`*^9, 
   3.613972610035379*^9, 3.6139765411438866`*^9, {3.614337351228059*^9, 
   3.6143373738843546`*^9}, {3.614339108452566*^9, 3.6143391480198298`*^9}, {
   3.61433920555312*^9, 3.6143392193249083`*^9}, {3.6145080441629343`*^9, 
   3.614508046003738*^9}, {3.6145097196370773`*^9, 3.6145097964828124`*^9}, 
   3.614861863606347*^9, 3.614863136755783*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.614339612479395*^9, 3.61450964144974*^9, 
  3.6145098116772394`*^9, 3.617430925935712*^9, 3.617431654958902*^9, 
  3.6189836046456623`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kn", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"normalcurvature", "[", 
     RowBox[{
      RowBox[{"sfr", "[", "f", "]"}], ",", "hu", ",", "hv"}], "]"}], "[", "s",
     "]"}], " ", "]"}]}]], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, 3.6136324917858477`*^9, {
   3.6139708453034763`*^9, 3.6139709222428117`*^9}, 3.6139709681380925`*^9, 
   3.613972610035379*^9, 3.6139765411438866`*^9, {3.614337351228059*^9, 
   3.6143373738843546`*^9}, {3.614339108452566*^9, 3.6143391480198298`*^9}, {
   3.6145080216832952`*^9, 3.6145080231028976`*^9}, 3.614861863621947*^9, 
   3.614863136771383*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "s", "]"}], "3"], " ", 
    RowBox[{
     SuperscriptBox["f", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "s", "]"}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "s", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}], "2"]}], ")"}]}], ")"}], 
    RowBox[{"3", "/", "2"}]]]}]], "Output",
 CellChangeTimes->{
  3.6136224568186226`*^9, 3.6136225274711466`*^9, 3.613632030165437*^9, 
   3.613635245284284*^9, 3.613972601455364*^9, 3.6139743831720943`*^9, {
   3.61433737590847*^9, 3.6143374025709953`*^9}, 3.614339101383162*^9, 
   3.6143391615506034`*^9, 3.614508029108908*^9, 3.6145100884217253`*^9, 
   3.6145104199067073`*^9, 3.617430939351735*^9, 3.618983632850512*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sx", "[", "s_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"sfr", "[", "f", "]"}], "[", 
    RowBox[{"s", ",", "vo"}], "]"}]}], ";", 
  RowBox[{"kk", " ", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"curvature", "[", "sx", "]"}], "[", "s", "]"}], ",", 
     RowBox[{"s", "\[Element]", "Reals"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6143402822007008`*^9, 3.6143403642143917`*^9}, {
   3.614340406997839*^9, 3.6143404223017144`*^9}, {3.6145101194969797`*^9, 
   3.614510178839484*^9}, 3.6145103356353593`*^9, 3.6148618636375465`*^9, 
   3.614863136771383*^9}],

Cell[BoxData[
 FractionBox[
  SqrtBox[
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["f", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "s", "]"}], "2"]], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"]}], ")"}], 
   RowBox[{"3", "/", "2"}]]]], "Output",
 CellChangeTimes->{3.6143403734449196`*^9, 3.614345431863245*^9, 
  3.614510181132688*^9, 3.614510345026576*^9, 3.614510424914316*^9, 
  3.617430945622946*^9, 3.618983640790926*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"%", "^", "2"}], "-", 
   RowBox[{"%%", "^", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.614510431934328*^9, 3.61451046704999*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.614510468188792*^9, 3.6174309518941574`*^9, 
  3.618983650166542*^9}]
}, Closed]],

Cell["For the generating circles we obtain the following results:", "Text",
 CellChangeTimes->{{3.6145106139710484`*^9, 3.6145106484627085`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"sx", ",", "hu", ",", "hv"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, 3.6136324917858477`*^9, {
   3.6139708453034763`*^9, 3.6139709222428117`*^9}, 3.6139709681380925`*^9, 
   3.613972610035379*^9, 3.6139765411438866`*^9, {3.6143373012522*^9, 
   3.6143373205003014`*^9}, 3.614337396340639*^9, {3.6143374303895864`*^9, 
   3.614337446300497*^9}, {3.61451029605809*^9, 3.6145103278509455`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hu", "[", "s_", "]"}], ":=", " ", "uo"}], ";", 
  RowBox[{
   RowBox[{"hv", "[", "s_", "]"}], " ", ":=", " ", "s"}], ";", 
  RowBox[{"kg1", " ", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"geodcurvature", "[", 
       RowBox[{
        RowBox[{"sfr", "[", "f", "]"}], ",", "hu", ",", "hv"}], "]"}], "[", 
      "s", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s", "\[Element]", "Reals"}], ",", 
       RowBox[{
        RowBox[{"f", "[", "uo", "]"}], ">", "0"}]}], "}"}]}], " ", 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, 3.6136324917858477`*^9, {
   3.6139708453034763`*^9, 3.6139709222428117`*^9}, 3.6139709681380925`*^9, 
   3.613972610035379*^9, 3.6139765411438866`*^9, {3.614337351228059*^9, 
   3.6143373738843546`*^9}, {3.614339108452566*^9, 3.6143391480198298`*^9}, {
   3.61433920555312*^9, 3.6143392193249083`*^9}, {3.6145080441629343`*^9, 
   3.614508046003738*^9}, {3.6145097196370773`*^9, 3.6145097964828124`*^9}, {
   3.614510676839159*^9, 3.614510701627602*^9}, 3.614511028260976*^9, 
   3.6148618636531467`*^9, 3.614863136771383*^9}],

Cell[BoxData[
 FractionBox[
  SqrtBox[
   RowBox[{"1", "-", 
    FractionBox["1", 
     RowBox[{"1", "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "uo", "]"}], "2"]}]]}]], 
  RowBox[{"f", "[", "uo", "]"}]]], "Output",
 CellChangeTimes->{3.614339612479395*^9, 3.61450964144974*^9, 
  3.6145098116772394`*^9, 3.614510705605609*^9, 3.6145110327069836`*^9, 
  3.6174309599749713`*^9, 3.6189836632549653`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kn1", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"normalcurvature", "[", 
     RowBox[{
      RowBox[{"sfr", "[", "f", "]"}], ",", "hu", ",", "hv"}], "]"}], "[", "s",
     "]"}], " ", "]"}]}]], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, 3.6136324917858477`*^9, {
   3.6139708453034763`*^9, 3.6139709222428117`*^9}, 3.6139709681380925`*^9, 
   3.613972610035379*^9, 3.6139765411438866`*^9, {3.614337351228059*^9, 
   3.6143373738843546`*^9}, {3.614339108452566*^9, 3.6143391480198298`*^9}, {
   3.6145080216832952`*^9, 3.6145080231028976`*^9}, 3.6145107301132526`*^9, 
   3.614861863668747*^9, 3.614863136771383*^9}],

Cell[BoxData[
 FractionBox["1", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"f", "[", "uo", "]"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "uo", "]"}], "2"]}], 
     ")"}]}]]]], "Output",
 CellChangeTimes->{
  3.6136224568186226`*^9, 3.6136225274711466`*^9, 3.613632030165437*^9, 
   3.613635245284284*^9, 3.613972601455364*^9, 3.6139743831720943`*^9, {
   3.61433737590847*^9, 3.6143374025709953`*^9}, 3.614339101383162*^9, 
   3.6143391615506034`*^9, 3.614508029108908*^9, 3.6145100884217253`*^9, 
   3.6145104199067073`*^9, 3.614510734918061*^9, 3.6174309674317846`*^9, 
   3.618983673223383*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sx", "[", "s_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"sfr", "[", "f", "]"}], "[", 
    RowBox[{"uo", ",", "s"}], "]"}]}], ";", 
  RowBox[{"kk1", " ", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"curvature", "[", "sx", "]"}], "[", "s", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s", "\[Element]", "Reals"}], ",", 
       RowBox[{
        RowBox[{"f", "[", "uo", "]"}], ">", "0"}]}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6143402822007008`*^9, 3.6143403642143917`*^9}, {
   3.614340406997839*^9, 3.6143404223017144`*^9}, {3.6145101194969797`*^9, 
   3.614510178839484*^9}, 3.6145103356353593`*^9, {3.6145107478816833`*^9, 
   3.614510761375707*^9}, {3.614510957171651*^9, 3.614510976578085*^9}, 
   3.614861863684347*^9, 3.614863136771383*^9}],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{"f", "[", "uo", "]"}]]], "Output",
 CellChangeTimes->{
  3.6143403734449196`*^9, 3.614345431863245*^9, 3.614510181132688*^9, 
   3.614510345026576*^9, 3.614510424914316*^9, 3.614510769191321*^9, 
   3.614510980758892*^9, {3.617430986853819*^9, 3.617430993015829*^9}, 
   3.6189836855786047`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Together", "[", 
   RowBox[{
    RowBox[{"kk1", "^", "2"}], "-", 
    RowBox[{"kg1", "^", "2"}], " ", "-", 
    RowBox[{"kn1", "^", "2"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.614510431934328*^9, 3.61451046704999*^9}, {
  3.614510786335751*^9, 3.6145108526046677`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6145108539930696`*^9, 3.6174309997706413`*^9, 
  3.6189836900558124`*^9}]
}, Closed]],

Cell["OK.", "Text",
 CellChangeTimes->{{3.6145113332883115`*^9, 3.614511335768716*^9}}],

Cell[TextData[{
 StyleBox["Example",
  FontColor->RGBColor[0, 0, 1]],
 ". Pseudosphere"
}], "Text",
 CellChangeTimes->{{3.6136216629488277`*^9, 3.6136217472669764`*^9}, {
   3.6136219986458178`*^9, 3.6136220101274376`*^9}, {3.6136316409915533`*^9, 
   3.6136316447511597`*^9}, {3.613631706792469*^9, 3.6136317217996955`*^9}, {
   3.613631784777006*^9, 3.6136317936534214`*^9}, 3.6136319442872863`*^9, {
   3.6136323634132223`*^9, 3.613632369544033*^9}, {3.614337018522029*^9, 
   3.614337032273816*^9}, {3.614520626709233*^9, 3.614520632524565*^9}}],

Cell["We consider the  surface of revolution named", "Text",
 CellChangeTimes->{{3.613632210517354*^9, 3.6136322491742215`*^9}, {
  3.614337045025545*^9, 3.614337100169699*^9}, {3.614337139193931*^9, 
  3.6143371486734734`*^9}, {3.6143371788692007`*^9, 3.614337178873201*^9}, {
  3.614337255633591*^9, 3.614337261929951*^9}, {3.614520784941283*^9, 
  3.614520803445341*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "pseudosphere"}]], "Input",
 CellChangeTimes->{{3.6145206567479506`*^9, 3.614520666822527*^9}}],

Cell[BoxData[
 StyleBox["\<\"{u,v}->pseudosphere[a][u,v] is the standard parametrization of \
a pseudosphere of constant negative curvature -1/a^2.  To plot try \
pseudosphere[1][0,3Pi/2,0.001,Pi-0.001].\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.617431005932652*^9},
 CellTags->"Info3617438205-2838022"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"pseudosphere", "[", "a", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{
  3.6143369034754486`*^9, {3.6145206979213057`*^9, 3.6145207228067293`*^9}, 
   3.614861863699947*^9, 3.614862881648535*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", " ", 
    RowBox[{"Cos", "[", "u", "]"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"a", " ", 
    RowBox[{"Sin", "[", "u", "]"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", "v", "]"}], "+", 
      RowBox[{"Log", "[", 
       RowBox[{"Tan", "[", 
        FractionBox["v", "2"], "]"}], "]"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.614337242810858*^9, 3.614507976708416*^9, 
  3.6145207297581267`*^9, 3.617431010082259*^9, 3.618983698479827*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"pseudosphere", "[", "1", "]"}], 
  StyleBox["[",
   FontWeight->"Plain"], 
  StyleBox[
   RowBox[{"0", ",", " ", 
    RowBox[{"3", "*", 
     RowBox[{"Pi", "/", "2"}]}], ",", "0.001", ",", " ", 
    RowBox[{"Pi", "-", "0.001"}]}], "MSG",
   FontWeight->"Plain"], 
  StyleBox["]", "MSG",
   FontWeight->"Plain"]}]], "Input",
 CellChangeTimes->{{3.6145211179693313`*^9, 3.614521219566142*^9}, 
   3.6148618637155466`*^9, 3.614862882927737*^9}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"pseudosphere", "[", "5", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   StyleBox[
    RowBox[{"{", 
     RowBox[{"u", ",", 
      StyleBox["0", "MSG"], 
      StyleBox[",", "MSG"], 
      StyleBox[" ", "MSG"], 
      StyleBox[
       RowBox[{
        StyleBox[
         StyleBox["2", "MSG",
          FontWeight->"Plain"],
         FontWeight->"Plain"], 
        StyleBox[
         StyleBox["*", "MSG",
          FontWeight->"Plain"],
         FontWeight->"Plain"], "Pi"}], "MSG"]}], 
     StyleBox["}", "MSG"]}],
    FontWeight->"Plain"], 
   StyleBox[
    StyleBox[",", "MSG"],
    FontWeight->"Plain"], 
   RowBox[{
    StyleBox["{",
     FontWeight->"Plain"], 
    StyleBox[
     RowBox[{"v", ",", ".05", 
      StyleBox[",", "MSG"], 
      StyleBox[" ", "MSG"], "3.07"}],
     FontWeight->"Plain"], 
    StyleBox["}", "MSG"]}], 
   StyleBox[",", "MSG"], 
   RowBox[{
    StyleBox["PlotRange", "MSG"], 
    StyleBox[" ", "MSG"], 
    StyleBox["\[Rule]", "MSG"], " ", "All"}]}], 
  StyleBox[
   StyleBox["]", "MSG"],
   FontWeight->"Plain"]}]], "Input",
 CellChangeTimes->{{3.6145211179693313`*^9, 3.614521219566142*^9}, {
   3.61458697032903*^9, 3.61458724307563*^9}, {3.614587291074375*^9, 
   3.6145873808355093`*^9}, 3.6145874129723473`*^9, {3.6145875356043615`*^9, 
   3.6145876236113954`*^9}, {3.6145876565172777`*^9, 3.614587683412816*^9}, {
   3.6145877298114696`*^9, 3.6145877299794793`*^9}, {3.614587809876049*^9, 
   3.614587847756216*^9}, {3.6145878805000887`*^9, 3.614587970652245*^9}, {
   3.614588043044386*^9, 3.6145881118043184`*^9}, 3.614861863746747*^9, 
   3.6148628843317394`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"pseudosphere", "[", "a", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{3.6189942016752872`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", " ", 
    RowBox[{"Cos", "[", "u", "]"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"a", " ", 
    RowBox[{"Sin", "[", "u", "]"}], " ", 
    RowBox[{"Sin", "[", "v", "]"}]}], ",", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", "v", "]"}], "+", 
      RowBox[{"Log", "[", 
       RowBox[{"Tan", "[", 
        FractionBox["v", "2"], "]"}], "]"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.6189942030948896`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", 
     RowBox[{"pseudosphere", "[", "a", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"v", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.614520815235016*^9, 3.6145208500470066`*^9}, 
   3.614521396431258*^9, {3.614521453503523*^9, 3.614521505631504*^9}, 
   3.614861863777947*^9, 3.614862885376941*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["1", 
   SuperscriptBox["a", "2"]]}]], "Output",
 CellChangeTimes->{3.6189942361513476`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"prcurvatures", "[", 
     RowBox[{"pseudosphere", "[", "a", "]"}], "]"}], "[", " ", 
    RowBox[{"u", ",", " ", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"v", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592315825904586*^9, 3.592315836169404*^9}, 
   3.592315870785865*^9, 3.592741650505703*^9, 3.5988843282017965`*^9, {
   3.612074334747755*^9, 3.612074353998189*^9}, {3.614573304329767*^9, 
   3.614573332097816*^9}, {3.614573363750272*^9, 3.614573366168276*^9}, 
   3.6148618637935467`*^9, 3.6148628872021446`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"Abs", "[", 
      RowBox[{"Cos", "[", "v", "]"}], "]"}], " ", 
     RowBox[{"Csc", "[", "v", "]"}]}], "a"], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"Abs", "[", 
       RowBox[{"Cos", "[", "v", "]"}], "]"}], " ", 
      RowBox[{"Sec", "[", "v", "]"}], " ", 
      RowBox[{"Tan", "[", "v", "]"}]}], "a"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5988843309699545`*^9, 3.6120742855608683`*^9, 
  3.6120743557921915`*^9, 3.614582126738063*^9, 3.6174310382247086`*^9, 
  3.617431214926219*^9, 3.6189942707366085`*^9}]
}, Closed]],

Cell["\<\
We obtain the Gaussian curvature as the product of the principal curvatures:\
\>", "Text",
 CellChangeTimes->{{3.6145828150596323`*^9, 3.614582894979203*^9}, {
  3.6145868363523664`*^9, 3.614586850311165*^9}, {3.6174318859931164`*^9, 
  3.617431890201357*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"%", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "*", 
    RowBox[{"%", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], ",", 
   RowBox[{"v", "\[Element]", " ", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.617431089080798*^9, 3.61743118701777*^9}, 
   3.617431225752638*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["1", 
   SuperscriptBox["a", "2"]]}]], "Output",
 CellChangeTimes->{3.6145212990906906`*^9, 3.614521445866086*^9, 
  3.6145216069222975`*^9, 3.614522691258318*^9, 3.6145270936252375`*^9, 
  3.617431026914689*^9, 3.618994293231848*^9}]
}, Closed]],

Cell[TextData[{
 "It is constant negative, as we know already, see ",
 ButtonBox["Case1",
  BaseStyle->"Hyperlink",
  ButtonData->"pseusph"],
 " in Subsection 3.8.5."
}], "Text",
 CellChangeTimes->{{3.614582936275565*^9, 3.614582960251937*^9}, {
   3.614583309187895*^9, 3.614583327723955*^9}, {3.6145833661561527`*^9, 
   3.6145833803799667`*^9}, {3.6145834365011764`*^9, 3.6145834365021763`*^9}, 
   3.6145881791771717`*^9}],

Cell["OK.", "Text",
 CellChangeTimes->{{3.6145113332883115`*^9, 3.614511335768716*^9}}],

Cell["\<\
As for all surfaces of revolution the meridians are geodesics. For the other \
parameter curves, the circles, we obtain\
\>", "Text",
 CellChangeTimes->{{3.6174320470253267`*^9, 3.6174320687845716`*^9}, {
  3.618994352449552*^9, 3.6189944130712585`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"hu", "[", "s_", "]"}], ":=", "s"}], ";", 
  RowBox[{
   RowBox[{"hv", "[", "s_", "]"}], " ", ":=", " ", "uo"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"kg1", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"geodcurvature", "[", 
      RowBox[{
       RowBox[{"pseudosphere", "[", "a", "]"}], ",", "hu", ",", "hv"}], "]"}],
      "[", "s", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", ">", "0"}], ",", 
      RowBox[{"s", ">", "0"}]}], "}"}]}], " ", "]"}]}]}], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, 3.6136324917858477`*^9, {
   3.6139708453034763`*^9, 3.6139709222428117`*^9}, 3.6139709681380925`*^9, 
   3.613972610035379*^9, 3.6139765411438866`*^9, {3.614337351228059*^9, 
   3.6143373738843546`*^9}, {3.614339108452566*^9, 3.6143391480198298`*^9}, {
   3.6145080216832952`*^9, 3.6145080231028976`*^9}, 3.614521785152492*^9, {
   3.6145218322641864`*^9, 3.6145218887524176`*^9}, {3.614522956094466*^9, 
   3.614523048511752*^9}, {3.6145835550879593`*^9, 3.614583556488039*^9}, 
   3.6145835939061794`*^9, {3.6148618638559475`*^9, 3.6148618638559475`*^9}, 
   3.6148628927713547`*^9, 3.6148631367869825`*^9}],

Cell[BoxData[
 FractionBox["1", "a"]], "Output",
 CellChangeTimes->{{3.6145835685097265`*^9, 3.61458359724337*^9}, 
   3.617432079172166*^9, 3.618994424662079*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kn1", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"normalcurvature", "[", 
      RowBox[{
       RowBox[{"pseudosphere", "[", "a", "]"}], ",", "hu", ",", "hv"}], "]"}],
      "[", "s", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", ">", "0"}], ",", 
      RowBox[{"s", ">", "0"}]}], "}"}]}], " ", "]"}]}]], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, 3.6136324917858477`*^9, {
   3.6139708453034763`*^9, 3.6139709222428117`*^9}, 3.6139709681380925`*^9, 
   3.613972610035379*^9, 3.6139765411438866`*^9, {3.614337351228059*^9, 
   3.6143373738843546`*^9}, {3.614339108452566*^9, 3.6143391480198298`*^9}, {
   3.6145080216832952`*^9, 3.6145080231028976`*^9}, 3.614521785152492*^9, {
   3.6145218322641864`*^9, 3.6145218887524176`*^9}, {3.614522956094466*^9, 
   3.614523048511752*^9}, {3.6145835550879593`*^9, 3.614583556488039*^9}, 
   3.6145835939061794`*^9, {3.6148618638559475`*^9, 3.6148618638559475`*^9}, 
   3.6148628927713547`*^9, 3.6148631367869825`*^9, 3.617432148730144*^9, {
   3.6174321926216545`*^9, 3.617432218900158*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SqrtBox[
     SuperscriptBox[
      RowBox[{"Cos", "[", "uo", "]"}], "2"]], " ", 
    RowBox[{"Csc", "[", "uo", "]"}]}], "a"]}]], "Output",
 CellChangeTimes->{3.61743222051725*^9, 3.6189944332888937`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sx", "[", "s_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"pseudosphere", "[", "a", "]"}], "[", 
    RowBox[{"s", ",", "uo"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"kk1", " ", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"curvature", "[", "sx", "]"}], "[", "s", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", ">", "0"}], ",", 
      RowBox[{"s", ">", "0"}]}], "}"}]}], " ", "]"}]}]}], "Input",
 CellChangeTimes->{{3.6145864758237457`*^9, 3.614586558650483*^9}, {
   3.6145866388910723`*^9, 3.6145866895779715`*^9}, {3.614861863871547*^9, 
   3.614861863887147*^9}, 3.614862893816556*^9, 3.6148631367869825`*^9}],

Cell[BoxData[
 FractionBox[
  SqrtBox[
   SuperscriptBox[
    RowBox[{"Sin", "[", "uo", "]"}], "4"]], 
  RowBox[{"a", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "uo", "]"}], "2"], ")"}], 
    RowBox[{"3", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{3.6145866996405473`*^9, 3.61743209918931*^9, 
  3.6189944406677065`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"kn1", "^", "2"}], "+", 
    RowBox[{"kg1", "^", "2"}], "-", 
    RowBox[{"kk1", "^", "2"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", 
     RowBox[{"uo", ">", "0"}]}], "}"}]}], " ", "]"}]], "Input",
 CellChangeTimes->{{3.6145863523506837`*^9, 3.614586387312683*^9}, {
  3.6145867153694468`*^9, 3.6145867620811186`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6145863879677205`*^9, 3.6145867659083376`*^9, 
  3.617432229485763*^9, 3.618994446205716*^9}]
}, Closed]],

Cell["OK.", "Text",
 CellChangeTimes->{{3.614586770251586*^9, 3.614586793679926*^9}}],

Cell[TextData[{
 "Using the local isometry of the pseudosphere with H. Poincar\[EAcute]\
\[CloseCurlyQuote]s model of the hyperbolic plane (see e.g. [",
 ButtonBox["OS3",
  BaseStyle->"Hyperlink",
  ButtonData->"OS3"],
 "],p. 255) one easily finds all geodesics of the pseudosphere. A good \
visualization  of the geodesics is the CDF-program ",
 ButtonBox["Pseudosphere Geodesics",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/PseudosphereGeodesics/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/PseudosphereGeodesics/"],
 " in Wolfram ",
 ButtonBox["Demonstrations Project.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/index.html"], None},
  ButtonNote->"http://demonstrations.wolfram.com/index.html"]
}], "Text",
 CellChangeTimes->{{3.620533656797402*^9, 3.620533693067466*^9}, {
   3.620533723331519*^9, 3.6205338124076757`*^9}, {3.6205338774597893`*^9, 
   3.6205340125560265`*^9}, {3.6205345720787644`*^9, 3.620534626349869*^9}, {
   3.620534741843527*^9, 3.620534741843527*^9}, {3.620535057918519*^9, 
   3.620535074262454*^9}, {3.620535119074215*^9, 3.6205351472078247`*^9}, 
   3.620535178017508*^9, {3.6205352215883846`*^9, 3.6205352215883846`*^9}}],

Cell[TextData[{
 StyleBox["Exercise",
  FontColor->RGBColor[0, 0, 1]],
 ". Study this CDF program and calculate the geodesic curvature of the curves \
on the pseudosphere; it must be zero."
}], "Text",
 CellChangeTimes->{{3.620535308386937*^9, 3.6205354134687214`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6178041659455204`*^9, 3.6178041730591326`*^9}}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["References", "Subtitle",
 CellChangeTimes->{{3.5881675431561174`*^9, 3.588167577236067*^9}, 
   3.5883163578378267`*^9, {3.591690059078165*^9, 3.591690069748584*^9}, {
   3.592463089910284*^9, 3.5924631116099224`*^9}, {3.5949735445390763`*^9, 
   3.594973561296035*^9}, {3.5980125441965847`*^9, 3.5980125441965847`*^9}, 
   3.598016745174763*^9, {3.614340028650199*^9, 3.61434006957854*^9}}],

Cell["\<\
[B-R]  W. Blaschke, H. Reichardt. Einf\[UDoubleDot]hrung in die \
Differentialgeometrie.2. Aufl. Springer-Verlag. \
Berlin.G\[ODoubleDot]ttingen.Heidelberg. 1960.\
\>", "Text",
 CellChangeTimes->{{3.5866621958935566`*^9, 3.5866623742377577`*^9}, 
   3.5875491110897255`*^9, {3.588167593643005*^9, 3.5881676056026893`*^9}},
 CellTags->"B-R"],

Cell[TextData[{
 "[G06] Alfred Gray, Simon Salamon, Elsa Abbena. Modern Differential Geometry \
of Curves and Surfaces with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ".\nThird ed. CRC Press. 2006. "
}], "Text",
 CellChangeTimes->{{3.4481738125625*^9, 3.448173840671875*^9}, {
   3.44817393246875*^9, 3.44817394509375*^9}, {3.448173979828125*^9, 
   3.448173980734375*^9}, {3.4481759745*^9, 3.448176007265625*^9}, 
   3.450237117953125*^9, {3.450237154*^9, 3.450237191546875*^9}, {
   3.450238953984375*^9, 3.450238956734375*^9}, 3.541836408394127*^9, 
   3.5418367181953497`*^9},
 CellTags->"Gray"],

Cell[TextData[{
 "[G06nb] Alfred Gray, Simon Salamon, Elsa Abbena. A series of 27 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " notebooks corresponding to the chapters of [G06], available from the \
website ",
 "\n",
 ButtonBox["http://alpha01.dm.unito.it/personalpages/abbena/gray/",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://alpha01.dm.unito.it/personalpages/abbena/gray/"], None},
  ButtonNote->"http://alpha01.dm.unito.it/personalpages/abbena/gray/"]
}], "Text",
 CellChangeTimes->{{3.599201219155733*^9, 3.599201261780171*^9}, {
  3.5992013329092393`*^9, 3.599201340627681*^9}, {3.5992013935957108`*^9, 
  3.5992014308198395`*^9}, {3.599201571187868*^9, 3.599201593564148*^9}, {
  3.599201693291852*^9, 3.5992016987161627`*^9}, {3.599201729499923*^9, 
  3.599201765534984*^9}},
 CellTags->"Gray2"],

Cell["\<\
[G94] Alfred Gray. Differentialgeometrie. Klassische Theorie in moderner \
Darstellung. (\[CapitalUDoubleDot]bersetzung aus dem Amerikanischen H. Gollek).
Spektrum Akademischer Verlag, Heidelberg.Berlin.Oxford. 1994.\
\>", "Text",
 CellChangeTimes->{{3.450237198875*^9, 3.45023720096875*^9}, {
   3.450237249703125*^9, 3.450237440828125*^9}, {3.450238940359375*^9, 
   3.45023894278125*^9}, {3.454066758375*^9, 3.4540668540625*^9}, 
   3.45407173278125*^9, 3.541836408394155*^9, 3.5418367181953783`*^9},
 CellTags->"Gray3"],

Cell["\<\
[Kr] Erwin Kreyszig. Differentialgeometrie. Akademische Verlagsgesellschaft \
Geest & Portig K. G. Leipzig 1957.\
\>", "Text",
 CellChangeTimes->{{3.5906430418435745`*^9, 3.5906431143993025`*^9}, {
  3.5906432147074785`*^9, 3.590643286436404*^9}},
 CellTags->"Kr"],

Cell["\<\
{K-N1] S. Kobayashi, K. Nomizu. Foundations of Differential Geometry, Vol.  \
I. Interscience Publishers. New York - London. 1963.\
\>", "Text",
 CellChangeTimes->{{3.597388908321149*^9, 3.5973889165686207`*^9}, {
  3.5973889798572407`*^9, 3.597389168017003*^9}},
 CellTags->"K-N1"],

Cell["\<\
[OS3] A. L. Onishchik, R. Sulanke. Projective and Cayley-Klein Geometries. \
Springer-Verlag. Berlin,Heidelberg. 2006.\
\>", "Text",
 CellChangeTimes->{{3.450266884375*^9, 3.45026689246875*^9}, {
   3.4502669551875*^9, 3.45026703496875*^9}, {3.450267067078125*^9, 
   3.450267115015625*^9}, 3.541836408394287*^9, 3.541836718195511*^9, {
   3.6205335043695345`*^9, 3.6205335122631483`*^9}},
 CellTags->"OS3"],

Cell[CellGroupData[{

Cell["Homepage", "Subsubtitle",
 CellChangeTimes->{
  3.445933589770261*^9, {3.4459337168429823`*^9, 3.445933720398094*^9}, 
   3.541836408394314*^9, 3.541836718195538*^9}],

Cell[TextData[ButtonBox["http://www-irm.mathematik.hu-berlin.de/~sulanke",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["http://www-irm.mathematik.hu-berlin.de/~sulanke"], None}]], "Text",
 CellChangeTimes->{{3.4459337369318686`*^9, 3.4459338102072334`*^9}, {
   3.4465638794375*^9, 3.4465638794375*^9}, 3.54183640839435*^9, 
   3.541836718195591*^9},
 CellTags->"Home"],

Cell["e-mail: sulanke@mathematik.hu-berlin.de", "Text",
 CellChangeTimes->{{3.618995363041403*^9, 3.618995394834259*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{1452, 879},
WindowMargins->{{94, Automatic}, {26, Automatic}},
ShowSelection->True,
Magnification:>2. Inherited,
FrontEndVersion->"10.0 for Microsoft Windows (64-bit) (July 1, 2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3611564042-9853252"->{
  Cell[49795, 1073, 665, 14, 936, "Print",
   CellTags->"Info3611564042-9853252"]},
 "Info3614759581-1510807"->{
  Cell[58799, 1342, 344, 6, 2147483647, "Print",
   CellTags->"Info3614759581-1510807"]},
 "Info3614759634-1510807"->{
  Cell[60253, 1390, 1285, 24, 2147483647, "Print",
   CellTags->"Info3614759634-1510807"]},
 "Info3617553236-6950008"->{
  Cell[70363, 1662, 573, 9, 2147483647, "Print",
   CellTags->"Info3617553236-6950008"]},
 "Info3617535750-7168362"->{
  Cell[76681, 1845, 1734, 29, 2147483647, "Print",
   CellTags->"Info3617535750-7168362"]},
 "Info3614782809-5384848"->{
  Cell[124301, 3280, 293, 5, 2147483647, "Print",
   CellTags->"Info3614782809-5384848"]},
 "Info3617624477-4857690"->{
  Cell[217311, 5860, 295, 5, 2147483647, "Print",
   CellTags->"Info3617624477-4857690"]},
 "g(i"->{
  Cell[258926, 7109, 2126, 45, 2147483647, "Text",
   CellTags->"g(i"]},
 "ptr"->{
  Cell[296786, 8227, 388, 12, 2147483647, "Input",
   CellTags->"ptr"]},
 "Info3617713755-3903716"->{
  Cell[1747976, 49455, 521, 8, 2147483647, "Print",
   CellTags->"Info3617713755-3903716"]},
 "Info3617715037-3903716"->{
  Cell[1788676, 50788, 781, 16, 2147483647, "Print",
   CellTags->"Info3617715037-3903716"]},
 "Info3617715109-3903716"->{
  Cell[1803094, 51143, 517, 12, 2147483647, "Print",
   CellTags->"Info3617715109-3903716"]},
 "Info3617715161-3903716"->{
  Cell[1806269, 51245, 319, 6, 2147483647, "Print",
   CellTags->"Info3617715161-3903716"]},
 "Info3617715512-6521894"->{
  Cell[1827616, 51947, 338, 6, 2147483647, "Print",
   CellTags->"Info3617715512-6521894"]},
 "bastr"->{
  Cell[1928530, 55094, 386, 9, 257949696, "Text",
   CellTags->"bastr"]},
 "intcond"->{
  Cell[1973595, 56453, 129, 2, 76, "Subsubsection",
   CellTags->"intcond"]},
 "Info3615122570-1826612"->{
  Cell[1975324, 56488, 288, 5, 2147483647, "Print",
   CellTags->"Info3615122570-1826612"]},
 "lem2.1.1"->{
  Cell[2031330, 58199, 576, 11, 2147483647, "Text",
   CellTags->"lem2.1.1"]},
 "Info3617872349-5808961"->{
  Cell[2042280, 58495, 431, 7, 2147483647, "Print",
   CellTags->"Info3617872349-5808961"]},
 "Info3617897129-8063059"->{
  Cell[2316717, 65968, 293, 5, 2147483647, "Print",
   CellTags->"Info3617897129-8063059"]},
 "polco"->{
  Cell[2333569, 66442, 244, 7, 2147483647, "Text",
   CellTags->"polco"]},
 "Info3617897576-4001495"->{
  Cell[2338261, 66578, 2633, 42, 2147483647, "Print",
   CellTags->"Info3617897576-4001495"]},
 "Info3617955319-5478789"->{
  Cell[2347368, 66814, 278, 5, 2147483647, "Print",
   CellTags->"Info3617955319-5478789"]},
 "Info3617952361-9601952"->{
  Cell[2367143, 67393, 285, 5, 2147483647, "Print",
   CellTags->"Info3617952361-9601952"]},
 "Info3615193095-5730655"->{
  Cell[2369857, 67468, 2628, 42, 2147483647, "Print",
   CellTags->"Info3615193095-5730655"]},
 "Info3617953349-6268934"->{
  Cell[2396623, 68231, 377, 6, 2147483647, "Print",
   CellTags->"Info3617953349-6268934"]},
 "Info3617953932-5478789"->{
  Cell[2409629, 68609, 203, 4, 2147483647, "Print",
   CellTags->"Info3617953932-5478789"]},
 "Info3617958083-5478789"->{
  Cell[2439049, 69405, 407, 6, 2147483647, "Print",
   CellTags->"Info3617958083-5478789"]},
 "Info3617958574-5478789"->{
  Cell[2475715, 70370, 280, 5, 2147483647, "Print",
   CellTags->"Info3617958574-5478789"]},
 "Info3609831043-6425210"->{
  Cell[2480111, 70495, 2880, 45, 2147483647, "Print",
   CellTags->"Info3609831043-6425210"]},
 "gaussK"->{
  Cell[2576186, 72314, 1214, 36, 2147483647, "Input",
   InitializationCell->True,
   CellTags->"gaussK"]},
 "Info3615219021-6377691"->{
  Cell[2758075, 77702, 224, 4, 2147483647, "Print",
   CellTags->"Info3615219021-6377691"]},
 "cij"->{
  Cell[2789263, 78561, 198, 7, 1966080, "Text",
   CellTags->"cij"]},
 "Info3618045930-7228279"->{
  Cell[2946423, 83153, 373, 6, 614400, "Print",
   CellTags->"Info3618045930-7228279"]},
 "ccc"->{
  Cell[2980309, 84129, 223109, 5766, 11162624, "Input",
   CellTags->"ccc"]},
 "geodc"->{
  Cell[3224866, 90516, 1179, 27, 573440, "Text",
   CellTags->"geodc"]},
 "Info3598454626-3632977"->{
  Cell[3255683, 91367, 1043, 19, 2147483647, "Print",
   CellTags->"Info3598454626-3632977"]},
 "Info3618475557-7588711"->{
  Cell[3269310, 91747, 290, 5, 60817408, "Print",
   CellTags->"Info3618475557-7588711"]},
 "Info3611648456-7479549"->{
  Cell[3292165, 92511, 1983, 33, 2147483647, "Print",
   CellTags->"Info3611648456-7479549"]},
 "helix"->{
  Cell[3574292, 100407, 422, 6, 60, "Subsubsection",
   CellTags->"helix"]},
 "Info3592989565-2940166"->{
  Cell[3577467, 100496, 375, 6, 2147483647, "Print",
   CellTags->"Info3592989565-2940166"]},
 "Info3616241832-1704369"->{
  Cell[3666493, 103082, 827, 12, 8257536, "Print",
   CellTags->"Info3616241832-1704369"]},
 "Info3616243093-1704369"->{
  Cell[3706517, 104279, 382, 6, 4915200, "Print",
   CellTags->"Info3616243093-1704369"]},
 "sfrev"->{
  Cell[3717511, 104603, 580, 11, 3211264, "Text",
   CellTags->"sfrev"]},
 "Info3614344124-9136096"->{
  Cell[3718255, 104624, 121, 2, 2654208, "Print",
   CellTags->"Info3614344124-9136096"],
  Cell[3718379, 104628, 781, 22, 1409024, "Print",
   CellTags->"Info3614344124-9136096"]},
 "Info3616244308-7460579"->{
  Cell[3735318, 105154, 288, 5, 3801088, "Print",
   CellTags->"Info3616244308-7460579"]},
 "Info3616509861-3077392"->{
  Cell[3906307, 110132, 320, 5, 464, "Print",
   CellTags->"Info3616509861-3077392"]},
 "fund1"->{
  Cell[4132596, 116934, 286, 7, 352, "Text",
   CellTags->"fund1"]},
 "Info3618648866-2375024"->{
  Cell[4133076, 116950, 492, 8, 1228800, "Print",
   CellTags->"Info3618648866-2375024"]},
 "Info3618649093-2375024"->{
  Cell[4138550, 117132, 122, 2, 663552, "Print",
   CellTags->"Info3618649093-2375024"],
  Cell[4138675, 117136, 2230, 59, 1048576, "Print",
   CellTags->"Info3618649093-2375024"]},
 "Info3617083932-1439888"->{
  Cell[4167614, 117981, 527, 8, 1785856, "Print",
   CellTags->"Info3617083932-1439888"]},
 "Info3620543793-1087837"->{
  Cell[4177737, 118276, 120, 2, 81, "Print",
   CellTags->"Info3620543793-1087837"],
  Cell[4177860, 118280, 1040, 29, 43, "Print",
   CellTags->"Info3620543793-1087837"]},
 "dtt(1)"->{
  Cell[4261972, 120952, 230, 6, 491520, "Text",
   CellTags->"dtt(1)"]},
 "Info3613289226-3398588"->{
  Cell[5284272, 149490, 638, 10, 753664, "Print",
   CellTags->"Info3613289226-3398588"]},
 "Info3617368136-1949107"->{
  Cell[6006939, 167853, 373, 6, 614400, "Print",
   CellTags->"Info3617368136-1949107"]},
 "Info3614339427-8121375"->{
  Cell[6155377, 171250, 292, 5, 14848, "Print",
   CellTags->"Info3614339427-8121375"]},
 "Info3617438205-2838022"->{
  Cell[6188899, 172209, 320, 5, 464, "Print",
   CellTags->"Info3617438205-2838022"]},
 "B-R"->{
  Cell[6204033, 172652, 350, 7, 98, "Text",
   CellTags->"B-R"]},
 "Gray"->{
  Cell[6204386, 172661, 609, 13, 136, "Text",
   CellTags->"Gray"]},
 "Gray2"->{
  Cell[6204998, 172676, 827, 18, 136, "Text",
   CellTags->"Gray2"]},
 "Gray3"->{
  Cell[6205828, 172696, 533, 9, 136, "Text",
   CellTags->"Gray3"]},
 "Kr"->{
  Cell[6206364, 172707, 274, 6, 98, "Text",
   CellTags->"Kr"]},
 "K-N1"->{
  Cell[6206641, 172715, 292, 6, 98, "Text",
   CellTags->"K-N1"]},
 "OS3"->{
  Cell[6206936, 172723, 417, 8, 98, "Text",
   CellTags->"OS3"]},
 "Home"->{
  Cell[6207553, 172740, 372, 7, 60, "Text",
   CellTags->"Home"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3611564042-9853252", 6208472, 172768},
 {"Info3614759581-1510807", 6208585, 172771},
 {"Info3614759634-1510807", 6208704, 172774},
 {"Info3617553236-6950008", 6208825, 172777},
 {"Info3617535750-7168362", 6208944, 172780},
 {"Info3614782809-5384848", 6209065, 172783},
 {"Info3617624477-4857690", 6209185, 172786},
 {"g(i", 6209286, 172789},
 {"ptr", 6209369, 172792},
 {"Info3617713755-3903716", 6209471, 172795},
 {"Info3617715037-3903716", 6209593, 172798},
 {"Info3617715109-3903716", 6209716, 172801},
 {"Info3617715161-3903716", 6209839, 172804},
 {"Info3617715512-6521894", 6209961, 172807},
 {"bastr", 6210066, 172810},
 {"intcond", 6210154, 172813},
 {"Info3615122570-1826612", 6210261, 172816},
 {"lem2.1.1", 6210369, 172819},
 {"Info3617872349-5808961", 6210477, 172822},
 {"Info3617897129-8063059", 6210599, 172825},
 {"polco", 6210704, 172828},
 {"Info3617897576-4001495", 6210808, 172831},
 {"Info3617955319-5478789", 6210932, 172834},
 {"Info3617952361-9601952", 6211054, 172837},
 {"Info3615193095-5730655", 6211176, 172840},
 {"Info3617953349-6268934", 6211300, 172843},
 {"Info3617953932-5478789", 6211422, 172846},
 {"Info3617958083-5478789", 6211544, 172849},
 {"Info3617958574-5478789", 6211666, 172852},
 {"Info3609831043-6425210", 6211788, 172855},
 {"gaussK", 6211896, 172858},
 {"Info3615219021-6377691", 6212033, 172862},
 {"cij", 6212136, 172865},
 {"Info3618045930-7228279", 6212235, 172868},
 {"ccc", 6212334, 172871},
 {"geodc", 6212424, 172874},
 {"Info3598454626-3632977", 6212526, 172877},
 {"Info3618475557-7588711", 6212650, 172880},
 {"Info3611648456-7479549", 6212770, 172883},
 {"helix", 6212877, 172886},
 {"Info3592989565-2940166", 6212983, 172889},
 {"Info3616241832-1704369", 6213106, 172892},
 {"Info3616243093-1704369", 6213227, 172895},
 {"sfrev", 6213330, 172898},
 {"Info3614344124-9136096", 6213433, 172901},
 {"Info3616244308-7460579", 6213644, 172906},
 {"Info3616509861-3077392", 6213764, 172909},
 {"fund1", 6213863, 172912},
 {"Info3618648866-2375024", 6213961, 172915},
 {"Info3618649093-2375024", 6214081, 172918},
 {"Info3617083932-1439888", 6214292, 172923},
 {"Info3620543793-1087837", 6214412, 172926},
 {"dtt(1)", 6214598, 172931},
 {"Info3613289226-3398588", 6214700, 172934},
 {"Info3617368136-1949107", 6214820, 172937},
 {"Info3614339427-8121375", 6214939, 172940},
 {"Info3617438205-2838022", 6215057, 172943},
 {"B-R", 6215154, 172946},
 {"Gray", 6215231, 172949},
 {"Gray2", 6215312, 172952},
 {"Gray3", 6215394, 172955},
 {"Kr", 6215472, 172958},
 {"K-N1", 6215548, 172961},
 {"OS3", 6215625, 172964},
 {"Home", 6215702, 172967}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 116, 2, 201, "Title"],
Cell[699, 26, 200, 3, 111, "Subtitle"],
Cell[902, 31, 395, 9, 98, "Text"],
Cell[CellGroupData[{
Cell[1322, 44, 200, 3, 95, "Subsection"],
Cell[1525, 49, 10180, 178, 2034, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11742, 232, 145, 2, 95, "Subsection"],
Cell[11890, 236, 2526, 36, 440, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14453, 277, 195, 3, 95, "Subsection"],
Cell[14651, 282, 719, 11, 32000, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[15407, 298, 170, 2, 108, "Section"],
Cell[15580, 302, 264, 5, 480, "Text"],
Cell[CellGroupData[{
Cell[15869, 311, 359, 6, 480, "Input",
 InitializationCell->True],
Cell[16231, 319, 7957, 109, 140, "Output"]
}, Open  ]],
Cell[24203, 431, 238, 4, 480, "Text"],
Cell[24444, 437, 31, 0, 480, "Input"],
Cell[24478, 439, 865, 15, 1392, "Text"],
Cell[25346, 456, 282, 5, 784, "Text"],
Cell[25631, 463, 153, 2, 480, "Text"],
Cell[CellGroupData[{
Cell[25809, 469, 161, 2, 760, "Subsection"],
Cell[25973, 473, 252, 6, 784, "Text"],
Cell[26228, 481, 453, 8, 480, "Input",
 InitializationCell->True],
Cell[26684, 491, 198, 4, 480, "Text"],
Cell[26885, 497, 166, 3, 480, "Input",
 InitializationCell->True],
Cell[27054, 502, 333, 6, 480, "Text"],
Cell[27390, 510, 216, 4, 480, "Input",
 InitializationCell->True],
Cell[27609, 516, 270, 5, 784, "Text"],
Cell[27882, 523, 324, 6, 480, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[28231, 533, 132, 2, 480, "Input"],
Cell[28366, 537, 86, 1, 73924608, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[28501, 544, 203, 3, 760, "Subsection"],
Cell[CellGroupData[{
Cell[28729, 551, 271, 5, 480, "Input",
 InitializationCell->True],
Cell[29003, 558, 13771, 330, 140, "Print"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[42823, 894, 125, 2, 760, "Subsection"],
Cell[CellGroupData[{
Cell[42973, 900, 147, 3, 480, "Input",
 InitializationCell->True],
Cell[43123, 905, 6434, 157, 140, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49594, 1067, 198, 4, 10624, "Input"],
Cell[49795, 1073, 665, 14, 936, "Print",
 CellTags->"Info3611564042-9853252"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[50509, 1093, 101, 1, 760, "Subsection"],
Cell[CellGroupData[{
Cell[50635, 1098, 149, 3, 480, "Input",
 InitializationCell->True],
Cell[50787, 1103, 3130, 76, 140, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[53954, 1184, 127, 2, 480, "Input"],
Cell[54084, 1188, 666, 20, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[54787, 1213, 181, 4, 352, "Input"],
Cell[54971, 1219, 405, 11, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[55413, 1235, 215, 5, 352, "Input"],
Cell[55631, 1242, 1321, 39, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[56989, 1286, 433, 11, 352, "Input"],
Cell[57425, 1299, 220, 3, 2147483647, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[57694, 1308, 150, 2, 760, "Subsection"],
Cell[57847, 1312, 118, 2, 480, "Input"],
Cell[57968, 1316, 245, 8, 480, "Input"],
Cell[58216, 1326, 441, 8, 784, "Text"],
Cell[CellGroupData[{
Cell[58682, 1338, 114, 2, 480, "Input"],
Cell[58799, 1342, 344, 6, 2147483647, "Print",
 CellTags->"Info3614759581-1510807"]
}, Closed]],
Cell[CellGroupData[{
Cell[59180, 1353, 131, 2, 352, "Input"],
Cell[59314, 1357, 85, 1, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[59436, 1363, 388, 11, 352, "Input"],
Cell[59827, 1376, 73, 1, 2147483647, "Output"]
}, Closed]],
Cell[59915, 1380, 193, 2, 400, "Text"],
Cell[CellGroupData[{
Cell[60133, 1386, 117, 2, 480, "Input"],
Cell[60253, 1390, 1285, 24, 2147483647, "Print",
 CellTags->"Info3614759634-1510807"]
}, Closed]],
Cell[61553, 1417, 356, 11, 352, "Input"],
Cell[CellGroupData[{
Cell[61934, 1432, 402, 11, 480, "Input"],
Cell[62339, 1445, 348, 10, 2147483647, "Output"]
}, Closed]],
Cell[62702, 1458, 192, 4, 352, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[62931, 1467, 202, 3, 760, "Subsection"],
Cell[63136, 1472, 116, 2, 480, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[63289, 1479, 248, 3, 760, "Subsection"],
Cell[63540, 1484, 165, 3, 960, "Text"],
Cell[63708, 1489, 121, 2, 1360, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[63878, 1497, 458, 6, 108, "Section"],
Cell[CellGroupData[{
Cell[64361, 1507, 218, 3, 95, "Subsection"],
Cell[64582, 1512, 408, 12, 248, "Text"],
Cell[64993, 1526, 461, 13, 240, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[65479, 1543, 250, 6, 240, "Input"],
Cell[65732, 1551, 401, 12, 2147483647, "Output"]
}, Closed]],
Cell[66148, 1566, 1623, 32, 960, "Text"],
Cell[67774, 1600, 2450, 54, 1004, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[70249, 1658, 111, 2, 240, "Input"],
Cell[70363, 1662, 573, 9, 2147483647, "Print",
 CellTags->"Info3617553236-6950008"]
}, Closed]],
Cell[70951, 1674, 321, 4, 200, "Text"],
Cell[CellGroupData[{
Cell[71297, 1682, 154, 3, 240, "Input"],
Cell[71454, 1687, 351, 7, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[71842, 1699, 176, 4, 1441792, "Input"],
Cell[72021, 1705, 121, 2, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[72179, 1712, 224, 5, 1441792, "Input"],
Cell[72406, 1719, 280, 5, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[72723, 1729, 249, 5, 1441792, "Input"],
Cell[72975, 1736, 143, 3, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[73155, 1744, 175, 4, 1441792, "Input"],
Cell[73333, 1750, 241, 5, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[73611, 1760, 199, 5, 1441792, "Input"],
Cell[73813, 1767, 215, 4, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[74065, 1776, 143, 3, 1441792, "Input"],
Cell[74211, 1781, 309, 4, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[74557, 1790, 283, 5, 1441792, "Input"],
Cell[74843, 1797, 508, 8, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[75388, 1810, 406, 7, 1441792, "Input"],
Cell[75797, 1819, 407, 7, 2147483647, "Output"]
}, Closed]],
Cell[76219, 1829, 321, 8, 1638400, "Text"],
Cell[CellGroupData[{
Cell[76565, 1841, 113, 2, 1966080, "Input"],
Cell[76681, 1845, 1734, 29, 2147483647, "Print",
 CellTags->"Info3617535750-7168362"]
}, Closed]],
Cell[CellGroupData[{
Cell[78452, 1879, 253, 7, 1441792, "Input"],
Cell[78708, 1888, 705, 22, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[79450, 1915, 175, 4, 1441792, "Input"],
Cell[79628, 1921, 974, 26, 2147483647, "Output"]
}, Closed]],
Cell[80617, 1950, 353, 6, 2883584, "Text"],
Cell[CellGroupData[{
Cell[80995, 1960, 377, 9, 1966080, "Input"],
Cell[81375, 1971, 608, 21, 2147483647, "Output"]
}, Closed]],
Cell[81998, 1995, 138, 1, 1638400, "Text"],
Cell[CellGroupData[{
Cell[82161, 2000, 283, 7, 1966080, "Input"],
Cell[82447, 2009, 2068, 68, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[84552, 2082, 294, 8, 1441792, "Input"],
Cell[84849, 2092, 99, 1, 2147483647, "Output"]
}, Closed]],
Cell[84963, 2096, 140, 1, 1638400, "Text"],
Cell[85106, 2099, 428, 11, 1966080, "Input",
 Evaluatable->False],
Cell[85537, 2112, 271, 5, 1966080, "Text"],
Cell[85811, 2119, 365, 10, 1966080, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[86201, 2133, 513, 12, 1966080, "Input"],
Cell[86717, 2147, 879, 29, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[87633, 2181, 277, 8, 1441792, "Input"],
Cell[87913, 2191, 2307, 77, 2147483647, "Output"]
}, Closed]],
Cell[90235, 2271, 119, 1, 1638400, "Text"],
Cell[CellGroupData[{
Cell[90379, 2276, 105, 3, 1966080, "Input"],
Cell[90487, 2281, 584, 20, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[91108, 2306, 838, 24, 1441792, "Input"],
Cell[91949, 2332, 245, 3, 2147483647, "Output"]
}, Closed]],
Cell[92209, 2338, 155, 2, 1638400, "Text"],
Cell[CellGroupData[{
Cell[92389, 2344, 1001, 28, 1966080, "Input"],
Cell[93393, 2374, 984, 16, 2147483647, "Message"],
Cell[94380, 2392, 984, 16, 2147483647, "Message"],
Cell[95367, 2410, 3758, 130, 2147483647, "Output"]
}, Closed]],
Cell[99140, 2543, 125, 1, 1638400, "Text"],
Cell[CellGroupData[{
Cell[99290, 2548, 902, 25, 1966080, "Input"],
Cell[100195, 2575, 197, 3, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[100429, 2583, 262, 6, 1441792, "Input"],
Cell[100694, 2591, 2267, 74, 2147483647, "Output"]
}, Closed]],
Cell[102976, 2668, 602, 11, 1638400, "Text"],
Cell[CellGroupData[{
Cell[103603, 2683, 507, 12, 1966080, "Input"],
Cell[104113, 2697, 119, 2, 2147483647, "Output"]
}, Closed]],
Cell[104247, 2702, 1816, 43, 7864320, "Text"],
Cell[106066, 2747, 753, 14, 1966080, "Text"],
Cell[CellGroupData[{
Cell[106844, 2765, 180, 4, 1966080, "Input"],
Cell[107027, 2771, 431, 11, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[107495, 2787, 139, 4, 1441792, "Input"],
Cell[107637, 2793, 821, 26, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[108495, 2824, 230, 7, 1441792, "Input"],
Cell[108728, 2833, 481, 14, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[109246, 2852, 493, 11, 1441792, "Input"],
Cell[109742, 2865, 193, 3, 2147483647, "Output"]
}, Closed]],
Cell[109950, 2871, 218, 4, 1638400, "Text"],
Cell[110171, 2877, 542, 15, 1966080, "Input"],
Cell[110716, 2894, 599, 15, 1966080, "Input"],
Cell[111318, 2911, 277, 6, 1966080, "Input"],
Cell[111598, 2919, 302, 8, 1966080, "Text"],
Cell[111903, 2929, 617, 11, 7798784, "Input",
 InitializationCell->True],
Cell[112523, 2942, 1759, 46, 5308416, "Input",
 InitializationCell->True],
Cell[114285, 2990, 104, 1, 1966080, "Text"],
Cell[CellGroupData[{
Cell[114414, 2995, 715, 13, 2785280, "Input",
 InitializationCell->True],
Cell[115132, 3010, 761, 19, 140, "Output"]
}, Open  ]],
Cell[115908, 3032, 106, 1, 1966080, "Text"],
Cell[CellGroupData[{
Cell[116039, 3037, 302, 7, 1966080, "Input"],
Cell[116344, 3046, 833, 30, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[117214, 3081, 639, 12, 2260992, "Input",
 InitializationCell->True],
Cell[117856, 3095, 2092, 48, 140, "Output"]
}, Open  ]],
Cell[119963, 3146, 416, 7, 1966080, "Text"],
Cell[CellGroupData[{
Cell[120404, 3157, 431, 13, 1966080, "Input"],
Cell[120838, 3172, 445, 14, 2147483647, "Output"]
}, Closed]],
Cell[121298, 3189, 192, 2, 1638400, "Text"],
Cell[CellGroupData[{
Cell[121515, 3195, 184, 4, 1966080, "Input"],
Cell[121702, 3201, 248, 5, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[121987, 3211, 327, 9, 1441792, "Input"],
Cell[122317, 3222, 226, 4, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[122580, 3231, 359, 10, 1441792, "Input"],
Cell[122942, 3243, 352, 9, 2147483647, "Output"]
}, Closed]],
Cell[123309, 3255, 572, 10, 4128768, "Text"],
Cell[123884, 3267, 266, 5, 1966080, "Text"],
Cell[CellGroupData[{
Cell[124175, 3276, 123, 2, 1966080, "Input"],
Cell[124301, 3280, 293, 5, 2147483647, "Print",
 CellTags->"Info3614782809-5384848"]
}, Closed]],
Cell[124609, 3288, 421, 9, 1441792, "Input"],
Cell[125033, 3299, 147, 3, 1966080, "Input"],
Cell[CellGroupData[{
Cell[125205, 3306, 184, 5, 1966080, "Input"],
Cell[125392, 3313, 330, 9, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[125759, 3327, 747, 19, 2719744, "Input"],
Cell[126509, 3348, 496, 12, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[127042, 3365, 200, 4, 1441792, "Input"],
Cell[127245, 3371, 224, 4, 2147483647, "Output"]
}, Closed]],
Cell[127484, 3378, 762, 17, 1441792, "Input"],
Cell[128249, 3397, 175, 4, 1966080, "Input"],
Cell[128427, 3403, 817, 15, 5701632, "Text"],
Cell[129247, 3420, 609, 17, 2785280, "Input",
 InitializationCell->True],
Cell[129859, 3439, 355, 8, 5308416, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[130239, 3451, 439, 10, 1966080, "Input"],
Cell[130681, 3463, 8730, 161, 2147483647, "Output"]
}, Closed]],
Cell[139426, 3627, 371, 8, 5373952, "Text"],
Cell[CellGroupData[{
Cell[139822, 3639, 171, 4, 1966080, "Input"],
Cell[139996, 3645, 548, 10, 2147483647, "Message"],
Cell[140547, 3657, 372, 10, 2147483647, "Output"]
}, Closed]],
Cell[140934, 3670, 97, 1, 200, "Text"],
Cell[CellGroupData[{
Cell[141056, 3675, 236, 6, 240, "Input"],
Cell[141295, 3683, 678, 21, 2147483647, "Output"]
}, Closed]],
Cell[141988, 3707, 386, 9, 352, "Text"],
Cell[142377, 3718, 934, 25, 396, "Input",
 InitializationCell->True],
Cell[143314, 3745, 391, 9, 700, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[143730, 3758, 322, 9, 240, "Input"],
Cell[144055, 3769, 478, 15, 2147483647, "Output"]
}, Closed]],
Cell[144548, 3787, 1266, 30, 332, "Input"],
Cell[145817, 3819, 676, 16, 240, "Input"],
Cell[146496, 3837, 554, 11, 240, "Input"],
Cell[CellGroupData[{
Cell[147075, 3852, 539, 11, 240, "Input",
 InitializationCell->True],
Cell[147617, 3865, 9809, 181, 140, "Output"]
}, Open  ]],
Cell[157441, 4049, 566, 11, 392, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[158044, 4065, 515, 6, 75, "Subsection"],
Cell[CellGroupData[{
Cell[158584, 4075, 266, 3, 76, "Subsubsection"],
Cell[158853, 4080, 146, 3, 2147483647, "Input"],
Cell[CellGroupData[{
Cell[159024, 4087, 144, 3, 2147483647, "Input"],
Cell[159171, 4092, 401, 12, 2147483647, "Output"]
}, Closed]],
Cell[159587, 4107, 1372, 37, 2147483647, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[160984, 4148, 333, 7, 2147483647, "Input"],
Cell[161320, 4157, 3918, 132, 2147483647, "Output"]
}, Closed]],
Cell[165253, 4292, 317, 8, 2147483647, "Text"],
Cell[165573, 4302, 1253, 35, 2147483647, "Input",
 InitializationCell->True],
Cell[166829, 4339, 1295, 36, 2147483647, "Input",
 InitializationCell->True],
Cell[168127, 4377, 566, 11, 2147483647, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[168718, 4392, 469, 9, 2147483647, "Input"],
Cell[169190, 4403, 16793, 514, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[186020, 4922, 495, 10, 2147483647, "Input"],
Cell[186518, 4934, 24714, 752, 2147483647, "Output"]
}, Closed]],
Cell[211247, 5689, 151, 2, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[211423, 5695, 952, 22, 2147483647, "Input"],
Cell[212378, 5719, 523, 12, 2147483647, "Output"]
}, Closed]],
Cell[212916, 5734, 122, 1, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[213063, 5739, 522, 13, 2147483647, "Input"],
Cell[213588, 5754, 267, 4, 2147483647, "Output"]
}, Closed]],
Cell[213870, 5761, 411, 10, 2147483647, "Text"],
Cell[214284, 5773, 291, 7, 2147483647, "Text"],
Cell[214578, 5782, 1722, 47, 2147483647, "Input",
 InitializationCell->True],
Cell[216303, 5831, 587, 11, 2147483647, "Input",
 InitializationCell->True],
Cell[216893, 5844, 212, 7, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[217130, 5855, 178, 3, 2147483647, "Input"],
Cell[217311, 5860, 295, 5, 2147483647, "Print",
 CellTags->"Info3617624477-4857690"]
}, Closed]],
Cell[CellGroupData[{
Cell[217643, 5870, 210, 5, 2147483647, "Input"],
Cell[217856, 5877, 354, 9, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[218247, 5891, 598, 13, 2147483647, "Input"],
Cell[218848, 5906, 928, 27, 2147483647, "Output"]
}, Closed]],
Cell[219791, 5936, 388, 7, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[220204, 5947, 1175, 27, 2147483647, "Input"],
Cell[221382, 5976, 507, 10, 2147483647, "Message"]
}, Closed]],
Cell[221904, 5989, 561, 7, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[222490, 6000, 463, 13, 2147483647, "Input"],
Cell[222956, 6015, 242, 8, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[223235, 6028, 1139, 24, 2147483647, "Input"],
Cell[224377, 6054, 429, 8, 2147483647, "Message"],
Cell[224809, 6064, 147, 4, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[224993, 6073, 140, 4, 2147483647, "Input"],
Cell[225136, 6079, 173, 4, 2147483647, "Output"]
}, Closed]],
Cell[225324, 6086, 899, 20, 2147483647, "Input"],
Cell[226226, 6108, 137, 3, 2147483647, "Input"],
Cell[226366, 6113, 454, 12, 2147483647, "Input"],
Cell[226823, 6127, 145, 3, 2147483647, "Input"],
Cell[226971, 6132, 522, 13, 2147483647, "Input"],
Cell[227496, 6147, 142, 3, 2147483647, "Input"],
Cell[227641, 6152, 561, 15, 2147483647, "Input"],
Cell[228205, 6169, 148, 3, 2147483647, "Input"],
Cell[228356, 6174, 330, 7, 2147483647, "Input"],
Cell[228689, 6183, 301, 5, 2147483647, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[229027, 6193, 238, 3, 60, "Subsubsection"],
Cell[229268, 6198, 387, 10, 2147483647, "Input"],
Cell[229658, 6210, 237, 4, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[229920, 6218, 333, 8, 2147483647, "Input"],
Cell[230256, 6228, 272, 8, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[230565, 6241, 277, 6, 2147483647, "Input"],
Cell[230845, 6249, 322, 11, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[231204, 6265, 299, 7, 2147483647, "Input"],
Cell[231506, 6274, 346, 12, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[231889, 6291, 1096, 25, 2147483647, "Input"],
Cell[232988, 6318, 351, 10, 2147483647, "Output"]
}, Closed]],
Cell[233354, 6331, 192, 2, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[233571, 6337, 503, 13, 2147483647, "Input"],
Cell[234077, 6352, 351, 10, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[234465, 6367, 513, 13, 2147483647, "Input"],
Cell[234981, 6382, 355, 10, 2147483647, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[235385, 6398, 367, 4, 60, "Subsubsection"],
Cell[235755, 6404, 137, 1, 2147483647, "Text"],
Cell[235895, 6407, 507, 11, 2147483647, "Input",
 InitializationCell->True],
Cell[236405, 6420, 175, 2, 2147483647, "Text"],
Cell[236583, 6424, 597, 13, 2147483647, "Input",
 InitializationCell->True],
Cell[237183, 6439, 110, 1, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[237318, 6444, 323, 9, 2147483647, "Input"],
Cell[237644, 6455, 3384, 101, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[241065, 6561, 1248, 28, 2147483647, "Input"],
Cell[242316, 6591, 365, 6, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[242718, 6602, 666, 16, 2147483647, "Input"],
Cell[243387, 6620, 269, 4, 2147483647, "Output"]
}, Closed]],
Cell[243671, 6627, 528, 9, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[244224, 6640, 801, 20, 2147483647, "Input"],
Cell[245028, 6662, 3948, 138, 2147483647, "Output"]
}, Closed]],
Cell[248991, 6803, 432, 7, 2147483647, "Text"],
Cell[249426, 6812, 2114, 57, 2147483647, "Input",
 InitializationCell->True],
Cell[251543, 6871, 689, 12, 2147483647, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[252257, 6887, 228, 7, 2147483647, "Input"],
Cell[252488, 6896, 931, 33, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[253456, 6934, 277, 8, 2147483647, "Input"],
Cell[253736, 6944, 1612, 60, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[255385, 7009, 533, 12, 2147483647, "Input",
 InitializationCell->True],
Cell[255921, 7023, 766, 17, 140, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[256724, 7045, 564, 15, 2147483647, "Input"],
Cell[257291, 7062, 296, 5, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[257624, 7072, 1063, 29, 2147483647, "Input"],
Cell[258690, 7103, 221, 3, 2147483647, "Output"]
}, Closed]],
Cell[258926, 7109, 2126, 45, 2147483647, "Text",
 CellTags->"g(i"],
Cell[261055, 7156, 2237, 55, 2147483647, "Input",
 InitializationCell->True],
Cell[263295, 7213, 454, 8, 2147483647, "Input"],
Cell[263752, 7223, 209, 3, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[263986, 7230, 709, 18, 2147483647, "Input"],
Cell[264698, 7250, 566, 14, 2147483647, "Output"]
}, Closed]],
Cell[265279, 7267, 151, 2, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[265455, 7273, 1030, 29, 2147483647, "Input"],
Cell[266488, 7304, 193, 3, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[266718, 7312, 533, 16, 2147483647, "Input"],
Cell[267254, 7330, 826, 24, 2147483647, "Output"]
}, Closed]],
Cell[268095, 7357, 225, 5, 2147483647, "Text"],
Cell[268323, 7364, 534, 17, 2147483647, "Input",
 InitializationCell->True],
Cell[268860, 7383, 339, 8, 2147483647, "Input",
 InitializationCell->True],
Cell[269202, 7393, 346, 6, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[269573, 7403, 672, 20, 2147483647, "Input"],
Cell[270248, 7425, 97, 1, 2147483647, "Output"]
}, Closed]],
Cell[270360, 7429, 341, 6, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[270726, 7439, 527, 15, 2147483647, "Input"],
Cell[271256, 7456, 6087, 206, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[277380, 7667, 1175, 30, 2147483647, "Input"],
Cell[278558, 7699, 191, 3, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[278786, 7707, 1301, 31, 2147483647, "Input"],
Cell[280090, 7740, 122, 2, 2147483647, "Output"]
}, Closed]],
Cell[280227, 7745, 393, 12, 2147483647, "Text"],
Cell[280623, 7759, 1202, 28, 2147483647, "Input",
 InitializationCell->True],
Cell[281828, 7789, 373, 8, 2147483647, "Input",
 InitializationCell->True],
Cell[282204, 7799, 401, 7, 2147483647, "Text"],
Cell[282608, 7808, 168, 5, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[282801, 7817, 386, 9, 2147483647, "Input"],
Cell[283190, 7828, 434, 11, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[283661, 7844, 434, 9, 2147483647, "Input"],
Cell[284098, 7855, 190, 6, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[284325, 7866, 800, 19, 2147483647, "Input"],
Cell[285128, 7887, 344, 7, 2147483647, "Output"]
}, Closed]],
Cell[285487, 7897, 101, 1, 2147483647, "Text"],
Cell[285591, 7900, 802, 14, 2147483647, "Text"],
Cell[286396, 7916, 164, 5, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[286585, 7925, 306, 8, 2147483647, "Input"],
Cell[286894, 7935, 258, 7, 2147483647, "Output"]
}, Closed]],
Cell[287167, 7945, 199, 2, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[287391, 7951, 359, 10, 2147483647, "Input"],
Cell[287753, 7963, 185, 4, 2147483647, "Output"]
}, Closed]],
Cell[287953, 7970, 190, 4, 2147483647, "Text"],
Cell[288146, 7976, 651, 17, 2147483647, "Input"],
Cell[288800, 7995, 632, 15, 2147483647, "Input"],
Cell[289435, 8012, 101, 1, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[289561, 8017, 306, 8, 2147483647, "Input"],
Cell[289870, 8027, 353, 10, 2147483647, "Output"]
}, Closed]],
Cell[290238, 8040, 140, 2, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[290403, 8046, 689, 15, 2147483647, "Input"],
Cell[291095, 8063, 358, 7, 2147483647, "Output"]
}, Closed]],
Cell[291468, 8073, 261, 3, 2147483647, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[291766, 8081, 597, 8, 60, "Subsubsection"],
Cell[292366, 8091, 181, 2, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[292572, 8097, 129, 2, 2147483647, "Input"],
Cell[292704, 8101, 98, 1, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[292839, 8107, 148, 3, 2147483647, "Input"],
Cell[292990, 8112, 428, 13, 2147483647, "Output"]
}, Closed]],
Cell[293433, 8128, 481, 13, 2147483647, "Input"],
Cell[CellGroupData[{
Cell[293939, 8145, 148, 3, 2147483647, "Input"],
Cell[294090, 8150, 584, 15, 2147483647, "Output"]
}, Closed]],
Cell[294689, 8168, 226, 5, 2147483647, "Text"],
Cell[294918, 8175, 736, 20, 2147483647, "Input",
 Evaluatable->False],
Cell[295657, 8197, 516, 14, 2147483647, "Input"],
Cell[296176, 8213, 607, 12, 2147483647, "Text"],
Cell[296786, 8227, 388, 12, 2147483647, "Input",
 CellTags->"ptr"],
Cell[297177, 8241, 296, 7, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[297498, 8252, 283, 5, 2147483647, "Input"],
Cell[297784, 8259, 872, 21, 2147483647, "Output"]
}, Closed]],
Cell[298671, 8283, 264, 3, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[298960, 8290, 586, 15, 2147483647, "Input"],
Cell[299549, 8307, 1552, 40, 2147483647, "Output"]
}, Closed]],
Cell[301116, 8350, 264, 5, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[301405, 8359, 261, 5, 2147483647, "Input"],
Cell[301669, 8366, 10471, 309, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[312177, 8680, 1483, 36, 2147483647, "Input"],
Cell[313663, 8718, 490, 9, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[314190, 8732, 883, 25, 2147483647, "Input"],
Cell[315076, 8759, 125, 3, 2147483647, "Output"]
}, Closed]],
Cell[315216, 8765, 462, 8, 2147483647, "Text"],
Cell[315681, 8775, 231, 5, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[315937, 8784, 210, 5, 2147483647, "Input"],
Cell[316150, 8791, 1632, 52, 2147483647, "Output"]
}, Closed]],
Cell[317797, 8846, 185, 4, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[318007, 8854, 278, 8, 2147483647, "Input"],
Cell[318288, 8864, 1094, 38, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[319419, 8907, 448, 11, 2147483647, "Input"],
Cell[319870, 8920, 2104, 64, 2147483647, "Output"]
}, Closed]],
Cell[321989, 8987, 337, 6, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[322351, 8997, 154, 3, 2147483647, "Input"],
Cell[322508, 9002, 376, 10, 2147483647, "Output"]
}, Closed]],
Cell[322899, 9015, 465, 8, 2147483647, "Text"],
Cell[323367, 9025, 885, 21, 2147483647, "Input"],
Cell[324255, 9048, 159, 3, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[324439, 9055, 350, 10, 2147483647, "Input"],
Cell[324792, 9067, 6972, 241, 2147483647, "Output"]
}, Closed]],
Cell[331779, 9311, 146, 2, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[331950, 9317, 247, 5, 2147483647, "Input"],
Cell[332200, 9324, 6689, 219, 2147483647, "Output"]
}, Closed]],
Cell[338904, 9546, 580, 9, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[339509, 9559, 1919, 47, 2147483647, "Input"],
Cell[341431, 9608, 216, 3, 2147483647, "Output"]
}, Closed]],
Cell[341662, 9614, 162, 2, 2147483647, "Text"],
Cell[341827, 9618, 1756, 44, 2147483647, "Input"],
Cell[343586, 9664, 93, 1, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[343704, 9669, 914, 25, 2147483647, "Input"],
Cell[344621, 9696, 163, 2, 2147483647, "Output"]
}, Closed]],
Cell[344799, 9701, 309, 5, 2147483647, "Text"],
Cell[345111, 9708, 2207, 53, 2147483647, "Input"],
Cell[347321, 9763, 91, 1, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[347437, 9768, 805, 22, 2147483647, "Input"],
Cell[348245, 9792, 335, 9, 2147483647, "Output"]
}, Closed]],
Cell[348595, 9804, 591, 11, 2147483647, "Text"],
Cell[349189, 9817, 581, 15, 2147483647, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[349795, 9836, 789, 24, 2147483647, "Input"],
Cell[350587, 9862, 175, 2, 2147483647, "Output"]
}, Closed]],
Cell[350777, 9867, 1157, 25, 2147483647, "Text"],
Cell[351937, 9894, 540, 16, 2147483647, "Input",
 Evaluatable->False],
Cell[352480, 9912, 1193, 19, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[353698, 9935, 291, 7, 2147483647, "Input"],
Cell[353992, 9944, 10521, 310, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[364550, 10259, 1535, 38, 2147483647, "Input"],
Cell[366088, 10299, 246, 4, 2147483647, "Output"]
}, Closed]],
Cell[366349, 10306, 897, 17, 2147483647, "Text"],
Cell[367249, 10325, 326, 4, 2147483647, "Text"],
Cell[367578, 10331, 217, 4, 2147483647, "Text"],
Cell[367798, 10337, 567, 16, 2147483647, "Input",
 Evaluatable->False],
Cell[368368, 10355, 500, 9, 2147483647, "Text"],
Cell[368871, 10366, 452, 10, 2147483647, "Text"],
Cell[369326, 10378, 372, 11, 2147483647, "Input"],
Cell[369701, 10391, 306, 6, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[370032, 10401, 526, 14, 2147483647, "Input"],
Cell[370561, 10417, 812, 26, 2147483647, "Output"]
}, Closed]],
Cell[371388, 10446, 216, 5, 2147483647, "Text"],
Cell[371607, 10453, 280, 5, 2147483647, "Text"],
Cell[371890, 10460, 735, 19, 2147483647, "Input"],
Cell[CellGroupData[{
Cell[372650, 10483, 239, 6, 2147483647, "Input"],
Cell[372892, 10491, 726, 19, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[373655, 10515, 930, 24, 2147483647, "Input"],
Cell[374588, 10541, 264, 8, 2147483647, "Output"]
}, Closed]],
Cell[374867, 10552, 437, 10, 2147483647, "Text"],
Cell[375307, 10564, 555, 16, 2147483647, "Input",
 Evaluatable->False],
Cell[375865, 10582, 644, 10, 2147483647, "Text"],
Cell[376512, 10594, 209, 5, 2147483647, "Input"],
Cell[376724, 10601, 1796, 32, 2147483647, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[378557, 10638, 516, 7, 60, "Subsubsection"],
Cell[379076, 10647, 297, 7, 2147483647, "Text"],
Cell[379376, 10656, 427, 12, 2147483647, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[379828, 10672, 206, 5, 2147483647, "Input"],
Cell[380037, 10679, 389, 12, 2147483647, "Output"]
}, Closed]],
Cell[380441, 10694, 681, 20, 2147483647, "Input",
 InitializationCell->True],
Cell[381125, 10716, 593, 12, 2147483647, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[381743, 10732, 255, 6, 2147483647, "Input"],
Cell[382001, 10740, 3743, 130, 2147483647, "Output"]
}, Closed]],
Cell[385759, 10873, 894, 20, 2147483647, "Input",
 InitializationCell->True],
Cell[386656, 10895, 511, 9, 2147483647, "Input"],
Cell[CellGroupData[{
Cell[387192, 10908, 315, 7, 2147483647, "Input"],
Cell[387510, 10917, 1324403, 37436, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1711950, 48358, 159, 3, 2147483647, "Input"],
Cell[1712112, 48363, 94, 1, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1712243, 48369, 485, 10, 2147483647, "Input"],
Cell[1712731, 48381, 1528, 54, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1714296, 48440, 151, 3, 2147483647, "Input"],
Cell[1714450, 48445, 1859, 63, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1716346, 48513, 205, 5, 2147483647, "Input"],
Cell[1716554, 48520, 92, 1, 2147483647, "Output"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1716707, 48528, 309, 4, 95, "Subsection"],
Cell[1717019, 48534, 793, 15, 136, "Text"],
Cell[CellGroupData[{
Cell[1717837, 48553, 393, 5, 76, "Subsubsection"],
Cell[1718233, 48560, 572, 9, 1088, "Text"],
Cell[CellGroupData[{
Cell[1718830, 48573, 243, 7, 480, "Input"],
Cell[1719076, 48582, 542, 19, 2147483647, "Output"]
}, Closed]],
Cell[1719633, 48604, 257, 5, 400, "Text"],
Cell[1719893, 48611, 4408, 82, 2312, "Input",
 InitializationCell->True],
Cell[1724304, 48695, 1052, 17, 2616, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1725381, 48716, 181, 4, 2147483647, "Input"],
Cell[1725565, 48722, 1162, 32, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1726764, 48759, 253, 6, 2147483647, "Input"],
Cell[1727020, 48767, 344, 10, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1727401, 48782, 224, 5, 2147483647, "Input"],
Cell[1727628, 48789, 1940, 66, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1729605, 48860, 171, 4, 2147483647, "Input"],
Cell[1729779, 48866, 262, 5, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1730078, 48876, 307, 7, 352, "Input"],
Cell[1730388, 48885, 94, 1, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1730519, 48891, 440, 10, 352, "Input"],
Cell[1730962, 48903, 1297, 37, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1732296, 48945, 476, 9, 352, "Input"],
Cell[1732775, 48956, 1035, 34, 2147483647, "Output"]
}, Closed]],
Cell[1733825, 48993, 263, 6, 704, "Text"],
Cell[CellGroupData[{
Cell[1734113, 49003, 148, 3, 480, "Input"],
Cell[1734264, 49008, 426, 13, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1734727, 49026, 172, 4, 352, "Input"],
Cell[1734902, 49032, 1924, 65, 2147483647, "Output"]
}, Closed]],
Cell[1736841, 49100, 247, 3, 400, "Text"],
Cell[CellGroupData[{
Cell[1737113, 49107, 630, 16, 480, "Input"],
Cell[1737746, 49125, 191, 3, 2147483647, "Output"]
}, Closed]],
Cell[1737952, 49131, 255, 5, 400, "Text"],
Cell[CellGroupData[{
Cell[1738232, 49140, 230, 6, 480, "Input"],
Cell[1738465, 49148, 2095, 70, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1740597, 49223, 804, 24, 352, "Input"],
Cell[1741404, 49249, 243, 3, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1741684, 49257, 1125, 32, 664, "Input"],
Cell[1742812, 49291, 223, 3, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1743072, 49299, 630, 16, 352, "Input"],
Cell[1743705, 49317, 221, 3, 2147483647, "Output"]
}, Closed]],
Cell[1743941, 49323, 168, 2, 400, "Text"],
Cell[CellGroupData[{
Cell[1744134, 49329, 745, 20, 480, "Input"],
Cell[1744882, 49351, 1841, 64, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1746760, 49420, 206, 5, 352, "Input"],
Cell[1746969, 49427, 148, 2, 2147483647, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1747166, 49435, 273, 3, 60, "Subsubsection"],
Cell[1747442, 49440, 364, 6, 480, "Text"],
Cell[CellGroupData[{
Cell[1747831, 49450, 142, 3, 480, "Input"],
Cell[1747976, 49455, 521, 8, 2147483647, "Print",
 CellTags->"Info3617713755-3903716"]
}, Closed]],
Cell[CellGroupData[{
Cell[1748534, 49468, 131, 2, 352, "Input"],
Cell[1748668, 49472, 134, 2, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1748839, 49479, 202, 5, 352, "Input"],
Cell[1749044, 49486, 320, 8, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1749401, 49499, 275, 7, 352, "Input"],
Cell[1749679, 49508, 168, 2, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1749884, 49515, 127, 2, 352, "Input"],
Cell[1750014, 49519, 145, 2, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1750196, 49526, 148, 3, 352, "Input"],
Cell[1750347, 49531, 123, 2, 2147483647, "Output"]
}, Closed]],
Cell[1750485, 49536, 219, 2, 400, "Text"],
Cell[CellGroupData[{
Cell[1750729, 49542, 166, 5, 480, "Input"],
Cell[1750898, 49549, 291, 7, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1751226, 49561, 225, 6, 352, "Input"],
Cell[1751454, 49569, 242, 6, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1751733, 49580, 624, 16, 352, "Input"],
Cell[1752360, 49598, 200, 3, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1752597, 49606, 916, 23, 352, "Input"],
Cell[1753516, 49631, 191, 3, 2147483647, "Output"]
}, Closed]],
Cell[1753722, 49637, 256, 5, 704, "Text"],
Cell[CellGroupData[{
Cell[1754003, 49646, 194, 5, 480, "Input"],
Cell[1754200, 49653, 169, 4, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1754406, 49662, 222, 6, 352, "Input"],
Cell[1754631, 49670, 116, 2, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1754784, 49677, 540, 12, 352, "Input"],
Cell[1755327, 49691, 244, 4, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1755608, 49700, 487, 10, 352, "Input"],
Cell[1756098, 49712, 200, 4, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1756335, 49721, 895, 24, 2147483647, "Input"],
Cell[1757233, 49747, 2212, 80, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1759482, 49832, 128, 2, 2147483647, "Input"],
Cell[1759613, 49836, 143, 2, 2147483647, "Output"]
}, Closed]],
Cell[1759771, 49841, 309, 6, 2147483647, "Text"],
Cell[1760083, 49849, 833, 18, 2147483647, "Input",
 Evaluatable->False],
Cell[1760919, 49869, 736, 16, 2147483647, "Input",
 Evaluatable->False],
Cell[1761658, 49887, 288, 5, 2147483647, "Text"],
Cell[1761949, 49894, 495, 12, 2147483647, "Input"],
Cell[CellGroupData[{
Cell[1762469, 49910, 202, 5, 2147483647, "Input"],
Cell[1762674, 49917, 1400, 50, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1764111, 49972, 817, 19, 2147483647, "Input"],
Cell[1764931, 49993, 168, 4, 2147483647, "Output"]
}, Closed]],
Cell[1765114, 50000, 120, 1, 400, "Text"],
Cell[CellGroupData[{
Cell[1765259, 50005, 255, 7, 480, "Input"],
Cell[1765517, 50014, 655, 22, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1766209, 50041, 266, 7, 352, "Input"],
Cell[1766478, 50050, 188, 4, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1766703, 50059, 331, 8, 352, "Input"],
Cell[1767037, 50069, 682, 22, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1767756, 50096, 317, 8, 352, "Input"],
Cell[1768076, 50106, 144, 2, 2147483647, "Output"]
}, Closed]],
Cell[1768235, 50111, 138, 4, 704, "Text"],
Cell[1768376, 50117, 366, 10, 480, "Input"],
Cell[CellGroupData[{
Cell[1768767, 50131, 175, 4, 480, "Input"],
Cell[1768945, 50137, 1632, 58, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1770614, 50200, 131, 2, 352, "Input"],
Cell[1770748, 50204, 1656, 58, 2147483647, "Output"]
}, Closed]],
Cell[1772419, 50265, 262, 7, 352, "Input"],
Cell[CellGroupData[{
Cell[1772706, 50276, 172, 4, 480, "Input"],
Cell[1772881, 50282, 852, 30, 2147483647, "Output"]
}, Closed]],
Cell[1773748, 50315, 668, 14, 352, "Input"],
Cell[CellGroupData[{
Cell[1774441, 50333, 253, 5, 480, "Input"],
Cell[1774697, 50340, 677, 22, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1775411, 50367, 349, 7, 352, "Input"],
Cell[1775763, 50376, 4684, 159, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1780484, 50540, 483, 10, 352, "Input"],
Cell[1780970, 50552, 5110, 169, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1786117, 50726, 1395, 29, 352, "Input"],
Cell[1787515, 50757, 200, 4, 2147483647, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1787764, 50767, 419, 5, 60, "Subsubsection"],
Cell[1788186, 50774, 238, 4, 480, "Text"],
Cell[CellGroupData[{
Cell[1788449, 50782, 224, 4, 480, "Input"],
Cell[1788676, 50788, 781, 16, 2147483647, "Print",
 CellTags->"Info3617715037-3903716"]
}, Closed]],
Cell[CellGroupData[{
Cell[1789494, 50809, 214, 3, 352, "Input"],
Cell[1789711, 50814, 206, 3, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1789954, 50822, 704, 15, 352, "Input"],
Cell[1790661, 50839, 9752, 205, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1800450, 51049, 127, 2, 352, "Input"],
Cell[1800580, 51053, 2357, 81, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1802974, 51139, 117, 2, 352, "Input"],
Cell[1803094, 51143, 517, 12, 2147483647, "Print",
 CellTags->"Info3617715109-3903716"]
}, Closed]],
Cell[1803626, 51158, 237, 5, 400, "Text"],
Cell[CellGroupData[{
Cell[1803888, 51167, 550, 14, 480, "Input"],
Cell[1804441, 51183, 1050, 38, 2147483647, "Output"]
}, Closed]],
Cell[1805506, 51224, 160, 2, 400, "Text"],
Cell[1805669, 51228, 454, 9, 480, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1806148, 51241, 118, 2, 480, "Input"],
Cell[1806269, 51245, 319, 6, 2147483647, "Print",
 CellTags->"Info3617715161-3903716"]
}, Closed]],
Cell[CellGroupData[{
Cell[1806625, 51256, 97, 2, 352, "Input"],
Cell[1806725, 51260, 145, 2, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1806907, 51267, 132, 2, 352, "Input"],
Cell[1807042, 51271, 111, 1, 2147483647, "Output"]
}, Closed]],
Cell[1807168, 51275, 239, 5, 400, "Text"],
Cell[CellGroupData[{
Cell[1807432, 51284, 180, 4, 480, "Input"],
Cell[1807615, 51290, 182, 4, 2147483647, "Output"]
}, Closed]],
Cell[1807812, 51297, 124, 1, 400, "Text"],
Cell[CellGroupData[{
Cell[1807961, 51302, 209, 5, 480, "Input"],
Cell[1808173, 51309, 195, 4, 2147483647, "Output"]
}, Closed]],
Cell[1808383, 51316, 89, 1, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[1808497, 51321, 389, 10, 2147483647, "Input"],
Cell[1808889, 51333, 782, 24, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1809708, 51362, 465, 11, 2147483647, "Input"],
Cell[1810176, 51375, 813, 27, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1811026, 51407, 237, 6, 2147483647, "Input"],
Cell[1811266, 51415, 2655, 89, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1813958, 51509, 549, 15, 2147483647, "Input"],
Cell[1814510, 51526, 172, 2, 2147483647, "Output"]
}, Closed]],
Cell[1814697, 51531, 259, 5, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[1814981, 51540, 475, 14, 2147483647, "Input"],
Cell[1815459, 51556, 494, 16, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1815990, 51577, 464, 13, 2147483647, "Input"],
Cell[1816457, 51592, 496, 16, 2147483647, "Output"]
}, Closed]],
Cell[1816968, 51611, 121, 1, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[1817114, 51616, 537, 12, 2147483647, "Input"],
Cell[1817654, 51630, 6974, 225, 2147483647, "Output"]
}, Closed]],
Cell[1824643, 51858, 144, 2, 2147483647, "Text"],
Cell[1824790, 51862, 731, 19, 2147483647, "Input"],
Cell[1825524, 51883, 667, 16, 2147483647, "Input"],
Cell[CellGroupData[{
Cell[1826216, 51903, 176, 3, 2147483647, "Input"],
Cell[1826395, 51908, 201, 3, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1826633, 51916, 480, 13, 2147483647, "Input"],
Cell[1827116, 51931, 244, 4, 2147483647, "Output"]
}, Closed]],
Cell[1827375, 51938, 96, 1, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[1827496, 51943, 117, 2, 2147483647, "Input"],
Cell[1827616, 51947, 338, 6, 2147483647, "Print",
 CellTags->"Info3617715512-6521894"]
}, Closed]],
Cell[1827969, 51956, 135, 1, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[1828129, 51961, 321, 9, 2147483647, "Input"],
Cell[1828453, 51972, 699, 16, 2147483647, "Output"]
}, Closed]],
Cell[1829167, 51991, 114, 1, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[1829306, 51996, 205, 3, 2147483647, "Input"],
Cell[1829514, 52001, 2381, 81, 2147483647, "Output"]
}, Closed]],
Cell[1831910, 52085, 116, 1, 400, "Text"],
Cell[CellGroupData[{
Cell[1832051, 52090, 347, 10, 480, "Input"],
Cell[1832401, 52102, 2387, 81, 2147483647, "Output"]
}, Closed]],
Cell[1834803, 52186, 169, 2, 400, "Text"],
Cell[CellGroupData[{
Cell[1834997, 52192, 205, 4, 480, "Input"],
Cell[1835205, 52198, 177, 2, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1835419, 52205, 293, 9, 352, "Input"],
Cell[1835715, 52216, 2185, 78, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1837937, 52299, 457, 12, 352, "Input"],
Cell[1838397, 52313, 168, 4, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1838602, 52322, 437, 11, 352, "Input"],
Cell[1839042, 52335, 162, 4, 2147483647, "Output"]
}, Closed]],
Cell[1839219, 52342, 645, 15, 352, "Input"],
Cell[CellGroupData[{
Cell[1839889, 52361, 148, 3, 480, "Input"],
Cell[1840040, 52366, 285, 9, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1840362, 52380, 251, 8, 352, "Input"],
Cell[1840616, 52390, 2261, 79, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1842914, 52474, 1069, 27, 664, "Input"],
Cell[1843986, 52503, 2539, 83, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1846562, 52591, 1409, 37, 664, "Input"],
Cell[1847974, 52630, 99, 1, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1848110, 52636, 1050, 28, 664, "Input"],
Cell[1849163, 52666, 312, 8, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1849512, 52679, 493, 12, 352, "Input"],
Cell[1850008, 52693, 460, 11, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1850505, 52709, 729, 18, 352, "Input"],
Cell[1851237, 52729, 307, 9, 2147483647, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1851593, 52744, 381, 5, 60, "Subsubsection"],
Cell[1851977, 52751, 855, 17, 1392, "Text"],
Cell[1852835, 52770, 4834, 119, 3224, "Input",
 InitializationCell->True],
Cell[1857672, 52891, 482, 10, 1400, "Input",
 InitializationCell->True],
Cell[1858157, 52903, 233, 4, 784, "Text"],
Cell[CellGroupData[{
Cell[1858415, 52911, 414, 11, 2147483647, "Input"],
Cell[1858832, 52924, 750, 14, 2147483647, "Output"]
}, Closed]],
Cell[1859597, 52941, 418, 11, 2147483647, "Input"],
Cell[CellGroupData[{
Cell[1860040, 52956, 253, 6, 2147483647, "Input"],
Cell[1860296, 52964, 648, 17, 2147483647, "Output"]
}, Closed]],
Cell[1860959, 52984, 315, 9, 2147483647, "Input"],
Cell[CellGroupData[{
Cell[1861299, 52997, 174, 4, 2147483647, "Input"],
Cell[1861476, 53003, 432, 14, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1861945, 53022, 197, 5, 2147483647, "Input"],
Cell[1862145, 53029, 315, 5, 2147483647, "Print"]
}, Closed]],
Cell[CellGroupData[{
Cell[1862497, 53039, 135, 4, 2147483647, "Input"],
Cell[1862635, 53045, 99, 1, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1862771, 53051, 354, 8, 2147483647, "Input"],
Cell[1863128, 53061, 219, 4, 2147483647, "Output"]
}, Closed]],
Cell[1863362, 53068, 237, 4, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[1863624, 53076, 288, 8, 2147483647, "Input"],
Cell[1863915, 53086, 424, 11, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1864376, 53102, 199, 5, 2147483647, "Input"],
Cell[1864578, 53109, 420, 12, 2147483647, "Output"]
}, Closed]],
Cell[1865013, 53124, 493, 9, 704, "Text"],
Cell[1865509, 53135, 213, 4, 480, "Text"],
Cell[CellGroupData[{
Cell[1865747, 53143, 457, 9, 480, "Input"],
Cell[1866207, 53154, 191, 3, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1866435, 53162, 274, 7, 352, "Input"],
Cell[1866712, 53171, 1844, 64, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1868593, 53240, 204, 5, 352, "Input"],
Cell[1868800, 53247, 198, 4, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1869035, 53256, 226, 5, 352, "Input"],
Cell[1869264, 53263, 260, 3, 2147483647, "Print"]
}, Closed]],
Cell[CellGroupData[{
Cell[1869561, 53271, 256, 6, 352, "Input"],
Cell[1869820, 53279, 235, 3, 2147483647, "Print"]
}, Closed]],
Cell[CellGroupData[{
Cell[1870092, 53287, 209, 5, 352, "Input"],
Cell[1870304, 53294, 364, 8, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1870705, 53307, 177, 4, 352, "Input"],
Cell[1870885, 53313, 260, 3, 2147483647, "Print"]
}, Closed]],
Cell[CellGroupData[{
Cell[1871182, 53321, 314, 8, 352, "Input"],
Cell[1871499, 53331, 548, 14, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1872084, 53350, 227, 5, 352, "Input"],
Cell[1872314, 53357, 1955, 66, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1874306, 53428, 279, 6, 352, "Input"],
Cell[1874588, 53436, 94, 1, 2147483647, "Print"]
}, Closed]],
Cell[CellGroupData[{
Cell[1874719, 53442, 307, 7, 352, "Input"],
Cell[1875029, 53451, 3843, 132, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1878909, 53588, 204, 5, 352, "Input"],
Cell[1879116, 53595, 291, 5, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1879444, 53605, 604, 16, 352, "Input"],
Cell[1880051, 53623, 2318, 81, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1882406, 53709, 175, 4, 352, "Input"],
Cell[1882584, 53715, 3275, 116, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1885896, 53836, 1009, 25, 352, "Input"],
Cell[1886908, 53863, 302, 6, 2147483647, "Output"]
}, Closed]],
Cell[1887225, 53872, 341, 6, 704, "Text"],
Cell[1887569, 53880, 521, 14, 480, "Input",
 Evaluatable->False]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1888139, 53900, 321, 4, 95, "Subsection"],
Cell[CellGroupData[{
Cell[1888485, 53908, 328, 5, 76, "Subsubsection"],
Cell[1888816, 53915, 446, 7, 205520896, "Text"],
Cell[1889265, 53924, 2525, 50, 367001600, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1891815, 53978, 213, 4, 125829120, "Input",
 InitializationCell->True],
Cell[1892031, 53984, 983, 18, 140, "Output"]
}, Open  ]],
Cell[1893029, 54005, 472, 9, 367001600, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1893526, 54018, 147, 2, 125829120, "Input"],
Cell[1893676, 54022, 94, 1, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1893807, 54028, 400, 8, 92274688, "Input"],
Cell[1894210, 54038, 3837, 129, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1898084, 54172, 496, 10, 92274688, "Input"],
Cell[1898583, 54184, 5488, 166, 2147483647, "Output"]
}, Closed]],
Cell[1904086, 54353, 105, 1, 104857600, "Text"],
Cell[CellGroupData[{
Cell[1904216, 54358, 514, 13, 125829120, "Input"],
Cell[1904733, 54373, 190, 4, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1904960, 54382, 376, 8, 92274688, "Input"],
Cell[1905339, 54392, 165, 4, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1905541, 54401, 428, 9, 92274688, "Input"],
Cell[1905972, 54412, 95, 1, 2147483647, "Print"]
}, Closed]],
Cell[CellGroupData[{
Cell[1906104, 54418, 461, 10, 92274688, "Input"],
Cell[1906568, 54430, 144, 2, 2147483647, "Print"]
}, Closed]],
Cell[CellGroupData[{
Cell[1906749, 54437, 296, 7, 92274688, "Input"],
Cell[1907048, 54446, 1535, 48, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1908620, 54499, 337, 9, 92274688, "Input"],
Cell[1908960, 54510, 275, 7, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1909272, 54522, 543, 15, 92274688, "Input"],
Cell[1909818, 54539, 208, 4, 2147483647, "Output"]
}, Closed]],
Cell[1910041, 54546, 263, 7, 184549376, "Text"],
Cell[1910307, 54555, 1046, 29, 125829120, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1911378, 54588, 1534, 41, 287309824, "Input"],
Cell[1912915, 54631, 255, 5, 2147483647, "Output"]
}, Closed]],
Cell[1913185, 54639, 638, 18, 92274688, "Input",
 Evaluatable->False],
Cell[1913826, 54659, 138, 1, 125829120, "Text"],
Cell[1913967, 54662, 269, 8, 125829120, "Input"],
Cell[CellGroupData[{
Cell[1914261, 54674, 1337, 37, 207618048, "Input"],
Cell[1915601, 54713, 190, 3, 2147483647, "Output"]
}, Closed]],
Cell[1915806, 54719, 718, 20, 92274688, "Input"],
Cell[CellGroupData[{
Cell[1916549, 54743, 783, 20, 125829120, "Input"],
Cell[1917335, 54765, 146, 2, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1917518, 54772, 543, 14, 92274688, "Input"],
Cell[1918064, 54788, 9049, 264, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1927150, 55057, 648, 18, 92274688, "Input"],
Cell[1927801, 55077, 195, 3, 2147483647, "Output"]
}, Closed]],
Cell[1928011, 55083, 516, 9, 264241152, "Text"],
Cell[1928530, 55094, 386, 9, 257949696, "Text",
 CellTags->"bastr"],
Cell[1928919, 55105, 645, 19, 239075328, "Input",
 Evaluatable->False],
Cell[1929567, 55126, 688, 19, 262144000, "Input",
 Evaluatable->False],
Cell[1930258, 55147, 154, 5, 125829120, "Text"],
Cell[CellGroupData[{
Cell[1930437, 55156, 2025, 51, 287309824, "Input"],
Cell[1932465, 55209, 296, 4, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1932798, 55218, 1688, 39, 253755392, "Input"],
Cell[1934489, 55259, 195, 3, 2147483647, "Output"]
}, Closed]],
Cell[1934699, 55265, 95, 1, 104857600, "Text"],
Cell[CellGroupData[{
Cell[1934819, 55270, 825, 22, 207618048, "Input"],
Cell[1935647, 55294, 167, 2, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1935851, 55301, 679, 19, 92274688, "Input"],
Cell[1936533, 55322, 150, 2, 2147483647, "Output"]
}, Closed]],
Cell[1936698, 55327, 282, 5, 184549376, "Text"],
Cell[CellGroupData[{
Cell[1937005, 55336, 230, 6, 125829120, "Input"],
Cell[1937238, 55344, 862, 31, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1938137, 55380, 230, 6, 92274688, "Input"],
Cell[1938370, 55388, 862, 31, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1939269, 55424, 789, 21, 92274688, "Input"],
Cell[1940061, 55447, 148, 2, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1940246, 55454, 1818, 49, 413138944, "Input"],
Cell[1942067, 55505, 121, 2, 2147483647, "Output"]
}, Closed]],
Cell[1942203, 55510, 177, 4, 104857600, "Text"],
Cell[CellGroupData[{
Cell[1942405, 55518, 695, 19, 125829120, "Input"],
Cell[1943103, 55539, 148, 2, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1943288, 55546, 1418, 37, 174063616, "Input"],
Cell[1944709, 55585, 147, 2, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1944893, 55592, 1328, 36, 174063616, "Input"],
Cell[1946224, 55630, 119, 2, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1946380, 55637, 596, 18, 92274688, "Input"],
Cell[1946979, 55657, 121, 2, 2147483647, "Output"]
}, Closed]],
Cell[1947115, 55662, 217, 5, 104857600, "Text"],
Cell[1947335, 55669, 772, 19, 125829120, "Input",
 Evaluatable->False],
Cell[1948110, 55690, 735, 19, 125829120, "Input",
 Evaluatable->False]
}, Closed]],
Cell[CellGroupData[{
Cell[1948882, 55714, 279, 3, 60, "Subsubsection"],
Cell[1949164, 55719, 245, 5, 2147483647, "Text"],
Cell[1949412, 55726, 983, 24, 2147483647, "Input",
 Evaluatable->False],
Cell[1950398, 55752, 398, 7, 2147483647, "Text"],
Cell[1950799, 55761, 581, 13, 2147483647, "Input",
 Evaluatable->False],
Cell[1951383, 55776, 249, 7, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[1951657, 55787, 137, 2, 2147483647, "Input"],
Cell[1951797, 55791, 107, 2, 2147483647, "Output"]
}, Closed]],
Cell[1951919, 55796, 2622, 59, 2147483647, "Input",
 InitializationCell->True],
Cell[1954544, 55857, 137, 3, 2147483647, "Input"],
Cell[CellGroupData[{
Cell[1954706, 55864, 339, 8, 2147483647, "Input"],
Cell[1955048, 55874, 294, 6, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1955379, 55885, 385, 8, 2147483647, "Input"],
Cell[1955767, 55895, 94, 1, 2147483647, "Print"]
}, Closed]],
Cell[1955876, 55899, 476, 10, 2147483647, "Input"],
Cell[CellGroupData[{
Cell[1956377, 55913, 649, 16, 2147483647, "Input"],
Cell[1957029, 55931, 184, 4, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1957250, 55940, 405, 10, 2147483647, "Input"],
Cell[1957658, 55952, 162, 4, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1957857, 55961, 280, 7, 2147483647, "Input"],
Cell[1958140, 55970, 166, 4, 2147483647, "Output"]
}, Closed]],
Cell[1958321, 55977, 286, 7, 2147483647, "Input"],
Cell[CellGroupData[{
Cell[1958632, 55988, 601, 15, 2147483647, "Input"],
Cell[1959236, 56005, 166, 4, 2147483647, "Output"]
}, Closed]],
Cell[1959417, 56012, 286, 7, 2147483647, "Input"],
Cell[CellGroupData[{
Cell[1959728, 56023, 508, 14, 2147483647, "Input"],
Cell[1960239, 56039, 161, 4, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1960437, 56048, 284, 7, 2147483647, "Input"],
Cell[1960724, 56057, 164, 4, 2147483647, "Output"]
}, Closed]],
Cell[1960903, 56064, 169, 2, 2147483647, "Text"],
Cell[1961075, 56068, 1428, 43, 2147483647, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1962528, 56115, 160, 3, 2147483647, "Input",
 InitializationCell->True],
Cell[1962691, 56120, 995, 18, 140, "Output"]
}, Open  ]],
Cell[1963701, 56141, 627, 12, 2147483647, "Input",
 InitializationCell->True],
Cell[1964331, 56155, 342, 7, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[1964698, 56166, 559, 17, 2147483647, "Input"],
Cell[1965260, 56185, 170, 4, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1965467, 56194, 580, 16, 2147483647, "Input"],
Cell[1966050, 56212, 183, 5, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1966270, 56222, 634, 17, 2147483647, "Input"],
Cell[1966907, 56241, 195, 5, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1967139, 56251, 634, 17, 2147483647, "Input"],
Cell[1967776, 56270, 197, 5, 2147483647, "Output"]
}, Closed]],
Cell[1967988, 56278, 150, 3, 2147483647, "Input"],
Cell[1968141, 56283, 297, 7, 2147483647, "Text"],
Cell[1968441, 56292, 613, 14, 2147483647, "Input",
 Evaluatable->False],
Cell[1969057, 56308, 589, 14, 2147483647, "Input",
 Evaluatable->False],
Cell[1969649, 56324, 610, 15, 2147483647, "Input",
 Evaluatable->False],
Cell[1970262, 56341, 617, 15, 2147483647, "Input",
 Evaluatable->False],
Cell[1970882, 56358, 187, 6, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[1971094, 56368, 1992, 66, 2147483647, "Input"],
Cell[1973089, 56436, 148, 3, 2147483647, "Output"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1973298, 56446, 272, 3, 95, "Subsection"],
Cell[CellGroupData[{
Cell[1973595, 56453, 129, 2, 76, "Subsubsection",
 CellTags->"intcond"],
Cell[1973727, 56457, 1459, 23, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[1975211, 56484, 110, 2, 2147483647, "Input"],
Cell[1975324, 56488, 288, 5, 2147483647, "Print",
 CellTags->"Info3615122570-1826612"]
}, Closed]],
Cell[1975627, 56496, 368, 10, 2147483647, "Input",
 Evaluatable->False],
Cell[1975998, 56508, 349, 9, 2147483647, "Input",
 Evaluatable->False],
Cell[1976350, 56519, 418, 11, 2147483647, "Input",
 Evaluatable->False],
Cell[1976771, 56532, 372, 10, 2147483647, "Input",
 Evaluatable->False],
Cell[1977146, 56544, 370, 10, 2147483647, "Input",
 Evaluatable->False],
Cell[1977519, 56556, 395, 10, 2147483647, "Input",
 Evaluatable->False],
Cell[1977917, 56568, 334, 6, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[1978276, 56578, 146, 3, 2147483647, "Input"],
Cell[1978425, 56583, 379, 12, 2147483647, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1978853, 56601, 253, 4, 60, "Subsubsection"],
Cell[1979109, 56607, 139, 3, 2147483647, "Input"],
Cell[CellGroupData[{
Cell[1979273, 56614, 173, 5, 2147483647, "Input"],
Cell[1979449, 56621, 29038, 987, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2008524, 57613, 799, 22, 2147483647, "Input"],
Cell[2009326, 57637, 165, 2, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2009528, 57644, 851, 23, 2147483647, "Input"],
Cell[2010382, 57669, 147, 2, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2010566, 57676, 1039, 30, 2147483647, "Input"],
Cell[2011608, 57708, 143, 2, 2147483647, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[2011800, 57716, 258, 4, 60, "Subsubsection"],
Cell[CellGroupData[{
Cell[2012083, 57724, 847, 23, 2147483647, "Input"],
Cell[2012933, 57749, 117, 2, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2013087, 57756, 901, 24, 2147483647, "Input"],
Cell[2013991, 57782, 117, 2, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2014145, 57789, 897, 24, 2147483647, "Input"],
Cell[2015045, 57815, 121, 2, 2147483647, "Output"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2015227, 57824, 268, 3, 95, "Subsection"],
Cell[2015498, 57829, 220, 4, 392, "Text"],
Cell[2015721, 57835, 1601, 27, 1008, "Text"],
Cell[2017325, 57864, 2240, 32, 1456, "Text"],
Cell[2019568, 57898, 873, 21, 240, "Input",
 Evaluatable->False],
Cell[2020444, 57921, 753, 20, 240, "Input",
 Evaluatable->False],
Cell[2021200, 57943, 773, 21, 240, "Input",
 Evaluatable->False],
Cell[2021976, 57966, 826, 21, 240, "Input",
 Evaluatable->False],
Cell[2022805, 57989, 866, 14, 696, "Text"],
Cell[2023674, 58005, 176, 5, 240, "Text"],
Cell[CellGroupData[{
Cell[2023875, 58014, 568, 11, 240, "Input"],
Cell[2024446, 58027, 237, 6, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2024720, 58038, 131, 2, 176, "Input"],
Cell[2024854, 58042, 215, 6, 2147483647, "Output"]
}, Closed]],
Cell[2025084, 58051, 205, 3, 200, "Text"],
Cell[CellGroupData[{
Cell[2025314, 58058, 631, 12, 240, "Input"],
Cell[2025948, 58072, 94, 1, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2026079, 58078, 633, 14, 176, "Input"],
Cell[2026715, 58094, 92, 1, 2147483647, "Output"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2026868, 58102, 272, 3, 140, "Section"],
Cell[CellGroupData[{
Cell[2027165, 58109, 160, 2, 95, "Subsection"],
Cell[CellGroupData[{
Cell[2027350, 58115, 326, 4, 76, "Subsubsection"],
Cell[2027679, 58121, 1963, 34, 2147483647, "Text"],
Cell[2029645, 58157, 778, 21, 2147483647, "Input",
 Evaluatable->False],
Cell[2030426, 58180, 901, 17, 2147483647, "Text"],
Cell[2031330, 58199, 576, 11, 2147483647, "Text",
 CellTags->"lem2.1.1"],
Cell[2031909, 58212, 222, 5, 2147483647, "Text"],
Cell[2032134, 58219, 277, 3, 2147483647, "Text"],
Cell[2032414, 58224, 453, 7, 2147483647, "Text"],
Cell[2032870, 58233, 663, 16, 2147483647, "Input",
 Evaluatable->False],
Cell[2033536, 58251, 716, 11, 2147483647, "Text"],
Cell[2034255, 58264, 445, 10, 2147483647, "Input",
 Evaluatable->False],
Cell[2034703, 58276, 92, 1, 2147483647, "Text"],
Cell[2034798, 58279, 1845, 48, 2147483647, "Input",
 Evaluatable->False],
Cell[2036646, 58329, 425, 7, 2147483647, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[2037108, 58341, 290, 4, 60, "Subsubsection"],
Cell[2037401, 58347, 432, 10, 2147483647, "Text"],
Cell[2037836, 58359, 457, 13, 2147483647, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2038318, 58376, 201, 5, 2147483647, "Input"],
Cell[2038522, 58383, 717, 22, 2147483647, "Output"]
}, Closed]],
Cell[2039254, 58408, 646, 16, 2147483647, "Text"],
Cell[2039903, 58426, 289, 7, 2147483647, "Text"],
Cell[2040195, 58435, 669, 15, 2147483647, "Text"],
Cell[2040867, 58452, 673, 17, 2147483647, "Input"],
Cell[2041543, 58471, 432, 12, 2147483647, "Input"],
Cell[2041978, 58485, 157, 2, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2042160, 58491, 117, 2, 2147483647, "Input"],
Cell[2042280, 58495, 431, 7, 2147483647, "Print",
 CellTags->"Info3617872349-5808961"]
}, Closed]],
Cell[CellGroupData[{
Cell[2042748, 58507, 151, 3, 2147483647, "Input"],
Cell[2042902, 58512, 284, 8, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2043223, 58525, 228, 5, 2147483647, "Input"],
Cell[2043454, 58532, 244, 7, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2043735, 58544, 313, 7, 2147483647, "Input"],
Cell[2044051, 58553, 437, 14, 2147483647, "Output"]
}, Closed]],
Cell[2044503, 58570, 356, 10, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2044884, 58584, 731, 19, 2147483647, "Input"],
Cell[2045618, 58605, 367, 12, 2147483647, "Output"]
}, Closed]],
Cell[2046000, 58620, 729, 22, 2147483647, "Input"],
Cell[2046732, 58644, 113, 1, 2147483647, "Text"],
Cell[2046848, 58647, 724, 20, 2147483647, "Input"],
Cell[2047575, 58669, 188, 4, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2047788, 58677, 417, 9, 2147483647, "Input"],
Cell[2048208, 58688, 680, 21, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2048925, 58714, 196, 4, 2147483647, "Input"],
Cell[2049124, 58720, 295, 9, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2049456, 58734, 159, 3, 2147483647, "Input"],
Cell[2049618, 58739, 337, 10, 2147483647, "Output"]
}, Closed]],
Cell[2049970, 58752, 101, 1, 2147483647, "Text"],
Cell[2050074, 58755, 236, 3, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2050335, 58762, 409, 11, 2147483647, "Input"],
Cell[2050747, 58775, 121, 2, 2147483647, "Output"]
}, Closed]],
Cell[2050883, 58780, 164, 2, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2051072, 58786, 801, 22, 2147483647, "Input"],
Cell[2051876, 58810, 172, 2, 2147483647, "Output"]
}, Closed]],
Cell[2052063, 58815, 96, 1, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2052184, 58820, 651, 18, 2147483647, "Input"],
Cell[2052838, 58840, 18160, 523, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2071035, 59368, 260, 7, 2147483647, "Input"],
Cell[2071298, 59377, 174812, 4494, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2246147, 63876, 705, 19, 2147483647, "Input"],
Cell[2246855, 63897, 15054, 433, 2147483647, "Output"]
}, Closed]],
Cell[2261924, 64333, 1161, 17, 2147483647, "Text"],
Cell[2263088, 64352, 1506, 43, 2147483647, "Input",
 InitializationCell->True],
Cell[2264597, 64397, 236, 5, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2264858, 64406, 559, 12, 2147483647, "Input"],
Cell[2265420, 64420, 371, 10, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2265828, 64435, 563, 12, 2147483647, "Input"],
Cell[2266394, 64449, 7234, 220, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2273665, 64674, 592, 13, 2147483647, "Input"],
Cell[2274260, 64689, 9321, 282, 2147483647, "Output"]
}, Closed]],
Cell[2283596, 64974, 217, 4, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2283838, 64982, 291, 6, 2147483647, "Input"],
Cell[2284132, 64990, 19640, 577, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2303809, 65572, 243, 5, 2147483647, "Input"],
Cell[2304055, 65579, 11339, 348, 2147483647, "Output"]
}, Closed]],
Cell[2315409, 65930, 442, 9, 2147483647, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[2315888, 65944, 392, 5, 60, "Subsubsection"],
Cell[2316283, 65951, 281, 9, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2316589, 65964, 125, 2, 2147483647, "Input"],
Cell[2316717, 65968, 293, 5, 2147483647, "Print",
 CellTags->"Info3617897129-8063059"]
}, Closed]],
Cell[CellGroupData[{
Cell[2317047, 65978, 312, 7, 2147483647, "Input"],
Cell[2317362, 65987, 379, 10, 2147483647, "Output"]
}, Closed]],
Cell[2317756, 66000, 420, 9, 2147483647, "Input"],
Cell[2318179, 66011, 296, 7, 2147483647, "Text"],
Cell[2318478, 66020, 2214, 48, 2147483647, "Input",
 InitializationCell->True],
Cell[2320695, 66070, 111, 1, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2320831, 66075, 557, 15, 2147483647, "Input"],
Cell[2321391, 66092, 197, 3, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2321625, 66100, 531, 11, 2147483647, "Input"],
Cell[2322159, 66113, 126, 2, 2147483647, "Output"]
}, Closed]],
Cell[2322300, 66118, 222, 4, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2322547, 66126, 1287, 34, 2147483647, "Input"],
Cell[2323837, 66162, 150, 3, 2147483647, "Output"]
}, Closed]],
Cell[2324002, 66168, 122, 1, 2147483647, "Text"],
Cell[2324127, 66171, 1536, 29, 2147483647, "Input"],
Cell[CellGroupData[{
Cell[2325688, 66204, 1408, 25, 2147483647, "Input"],
Cell[2327099, 66231, 176, 4, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2327312, 66240, 501, 12, 2147483647, "Input"],
Cell[2327816, 66254, 815, 28, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2328668, 66287, 149, 3, 2147483647, "Input"],
Cell[2328820, 66292, 96, 1, 2147483647, "Output"]
}, Closed]],
Cell[2328931, 66296, 685, 11, 2147483647, "Text"],
Cell[2329619, 66309, 167, 3, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2329811, 66316, 549, 15, 2147483647, "Input"],
Cell[2330363, 66333, 1270, 40, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2331670, 66378, 131, 2, 2147483647, "Input"],
Cell[2331804, 66382, 445, 13, 2147483647, "Output"]
}, Closed]],
Cell[2332264, 66398, 89, 1, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2332378, 66403, 365, 11, 2147483647, "Input"],
Cell[2332746, 66416, 172, 2, 2147483647, "Output"]
}, Closed]],
Cell[2332933, 66421, 187, 4, 2147483647, "Text"],
Cell[2333123, 66427, 443, 13, 2147483647, "Input",
 Evaluatable->False],
Cell[2333569, 66442, 244, 7, 2147483647, "Text",
 CellTags->"polco"],
Cell[2333816, 66451, 403, 11, 2147483647, "Input"],
Cell[2334222, 66464, 157, 3, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2334404, 66471, 489, 14, 2147483647, "Input"],
Cell[2334896, 66487, 319, 8, 2147483647, "Output"]
}, Closed]],
Cell[2335230, 66498, 106, 1, 2147483647, "Text"],
Cell[2335339, 66501, 319, 9, 2147483647, "Input"],
Cell[2335661, 66512, 127, 2, 2147483647, "Text"],
Cell[2335791, 66516, 368, 10, 2147483647, "Input"],
Cell[2336162, 66528, 443, 7, 2147483647, "Text"],
Cell[2336608, 66537, 562, 14, 2147483647, "Input"],
Cell[2337173, 66553, 683, 10, 2147483647, "Text"],
Cell[2337859, 66565, 257, 5, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2338141, 66574, 117, 2, 2147483647, "Input"],
Cell[2338261, 66578, 2633, 42, 2147483647, "Print",
 CellTags->"Info3617897576-4001495"]
}, Closed]],
Cell[CellGroupData[{
Cell[2340931, 66625, 402, 12, 2147483647, "Input"],
Cell[2341336, 66639, 373, 11, 2147483647, "Output"]
}, Closed]],
Cell[2341724, 66653, 244, 5, 2147483647, "Input"],
Cell[2341971, 66660, 184, 2, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2342180, 66666, 224, 5, 2147483647, "Input"],
Cell[2342407, 66673, 451, 14, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2342895, 66692, 201, 5, 2147483647, "Input"],
Cell[2343099, 66699, 87, 1, 2147483647, "Output"]
}, Closed]],
Cell[2343201, 66703, 1082, 22, 2147483647, "Input"],
Cell[2344286, 66727, 178, 4, 2147483647, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[2344501, 66736, 460, 6, 60, "Subsubsection"],
Cell[2344964, 66744, 788, 15, 2147483647, "Text"],
Cell[2345755, 66761, 326, 9, 2147483647, "Input",
 InitializationCell->True],
Cell[2346084, 66772, 521, 11, 2147483647, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2346630, 66787, 176, 4, 2147483647, "Input"],
Cell[2346809, 66793, 402, 12, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2347248, 66810, 117, 2, 2147483647, "Input"],
Cell[2347368, 66814, 278, 5, 2147483647, "Print",
 CellTags->"Info3617955319-5478789"]
}, Closed]],
Cell[CellGroupData[{
Cell[2347683, 66824, 154, 4, 2147483647, "Input"],
Cell[2347840, 66830, 404, 12, 2147483647, "Output"]
}, Closed]],
Cell[2348259, 66845, 403, 7, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2348687, 66856, 104, 1, 2147483647, "Input"],
Cell[2348794, 66859, 2610, 84, 2147483647, "Output"]
}, Closed]],
Cell[2351419, 66946, 133, 1, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2351577, 66951, 860, 18, 2147483647, "Input"],
Cell[2352440, 66971, 1745, 54, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2354222, 67030, 322, 8, 2147483647, "Input"],
Cell[2354547, 67040, 119, 2, 2147483647, "Output"]
}, Closed]],
Cell[2354681, 67045, 386, 7, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2355092, 67056, 400, 8, 2147483647, "Input"],
Cell[2355495, 67066, 174, 4, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2355706, 67075, 685, 15, 2147483647, "Input"],
Cell[2356394, 67092, 172, 4, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2356603, 67101, 823, 18, 2147483647, "Input"],
Cell[2357429, 67121, 551, 17, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2358017, 67143, 301, 7, 2147483647, "Input"],
Cell[2358321, 67152, 120, 2, 2147483647, "Output"]
}, Closed]],
Cell[2358456, 67157, 188, 2, 2147483647, "Text"],
Cell[2358647, 67161, 1398, 40, 2147483647, "Input"],
Cell[2360048, 67203, 219, 4, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2360292, 67211, 858, 23, 2147483647, "Input"],
Cell[2361153, 67236, 122, 2, 2147483647, "Output"]
}, Closed]],
Cell[2361290, 67241, 223, 2, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2361538, 67247, 807, 22, 2147483647, "Input"],
Cell[2362348, 67271, 264, 7, 2147483647, "Output"]
}, Closed]],
Cell[2362627, 67281, 197, 2, 2147483647, "Text"],
Cell[2362827, 67285, 314, 10, 2147483647, "Input",
 Evaluatable->False],
Cell[2363144, 67297, 761, 15, 2147483647, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[2363942, 67317, 463, 6, 60, "Subsubsection"],
Cell[2364408, 67325, 176, 5, 2147483647, "Text"],
Cell[2364587, 67332, 1357, 24, 2147483647, "Text"],
Cell[2365947, 67358, 575, 14, 2147483647, "Input",
 InitializationCell->True],
Cell[2366525, 67374, 359, 8, 2147483647, "Input"],
Cell[2366887, 67384, 101, 1, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2367013, 67389, 127, 2, 2147483647, "Input"],
Cell[2367143, 67393, 285, 5, 2147483647, "Print",
 CellTags->"Info3617952361-9601952"]
}, Closed]],
Cell[CellGroupData[{
Cell[2367465, 67403, 208, 5, 2147483647, "Input"],
Cell[2367676, 67410, 340, 9, 2147483647, "Output"]
}, Closed]],
Cell[2368031, 67422, 779, 15, 2147483647, "Input",
 InitializationCell->True],
Cell[2368813, 67439, 762, 18, 2147483647, "Input"],
Cell[2369578, 67459, 132, 1, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2369735, 67464, 119, 2, 2147483647, "Input"],
Cell[2369857, 67468, 2628, 42, 2147483647, "Print",
 CellTags->"Info3615193095-5730655"]
}, Closed]],
Cell[2372500, 67513, 582, 16, 2147483647, "Input"],
Cell[2373085, 67531, 293, 7, 2147483647, "Input"],
Cell[CellGroupData[{
Cell[2373403, 67542, 631, 14, 2147483647, "Input"],
Cell[2374037, 67558, 278, 8, 2147483647, "Output"]
}, Closed]],
Cell[2374330, 67569, 448, 7, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2374803, 67580, 375, 9, 2147483647, "Input"],
Cell[2375181, 67591, 1052, 34, 2147483647, "Output"]
}, Closed]],
Cell[2376248, 67628, 206, 4, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2376479, 67636, 1010, 30, 2147483647, "Input"],
Cell[2377492, 67668, 217, 5, 2147483647, "Output"]
}, Closed]],
Cell[2377724, 67676, 527, 8, 2147483647, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[2378288, 67689, 513, 7, 60, "Subsubsection"],
Cell[2378804, 67698, 563, 14, 2147483647, "Text"],
Cell[2379370, 67714, 543, 15, 2147483647, "Input",
 InitializationCell->True],
Cell[2379916, 67731, 471, 10, 2147483647, "Input",
 InitializationCell->True],
Cell[2380390, 67743, 223, 5, 2147483647, "Text"],
Cell[2380616, 67750, 341, 8, 2147483647, "Input",
 InitializationCell->True],
Cell[2380960, 67760, 219, 6, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2381204, 67770, 657, 16, 2147483647, "Input"],
Cell[2381864, 67788, 2361, 72, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2384262, 67865, 205, 4, 2147483647, "Input"],
Cell[2384470, 67871, 176, 4, 2147483647, "Output"]
}, Closed]],
Cell[2384661, 67878, 172, 2, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2384858, 67884, 1385, 34, 2147483647, "Input",
 InitializationCell->True],
Cell[2386246, 67920, 2564, 69, 140, "Output"]
}, Open  ]],
Cell[2388825, 67992, 176, 4, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2389026, 68000, 390, 9, 2147483647, "Input"],
Cell[2389419, 68011, 4653, 144, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2394109, 68160, 709, 17, 2147483647, "Input"],
Cell[2394821, 68179, 176, 4, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2395034, 68188, 726, 17, 2147483647, "Input"],
Cell[2395763, 68207, 176, 4, 2147483647, "Output"]
}, Closed]],
Cell[2395954, 68214, 522, 9, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2396501, 68227, 119, 2, 2147483647, "Input"],
Cell[2396623, 68231, 377, 6, 2147483647, "Print",
 CellTags->"Info3617953349-6268934"]
}, Closed]],
Cell[2397015, 68240, 361, 9, 2147483647, "Input"],
Cell[CellGroupData[{
Cell[2397401, 68253, 216, 6, 2147483647, "Input"],
Cell[2397620, 68261, 550, 17, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2398207, 68283, 215, 6, 2147483647, "Input"],
Cell[2398425, 68291, 2446, 79, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2400908, 68375, 693, 16, 2147483647, "Input"],
Cell[2401604, 68393, 224, 5, 2147483647, "Output"]
}, Closed]],
Cell[2401843, 68401, 485, 10, 2147483647, "Text"],
Cell[2402331, 68413, 263, 5, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2402619, 68422, 741, 21, 2147483647, "Input"],
Cell[2403363, 68445, 1040, 31, 2147483647, "Output"]
}, Closed]],
Cell[2404418, 68479, 403, 10, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2404846, 68493, 1102, 24, 2147483647, "Input"],
Cell[2405951, 68519, 223, 3, 2147483647, "Output"]
}, Closed]],
Cell[2406189, 68525, 254, 5, 2147483647, "Text"],
Cell[2406446, 68532, 656, 18, 2147483647, "Input"],
Cell[2407105, 68552, 481, 10, 2147483647, "Text"],
Cell[2407589, 68564, 1315, 23, 2147483647, "Text"],
Cell[2408907, 68589, 576, 12, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2409508, 68605, 118, 2, 2147483647, "Input"],
Cell[2409629, 68609, 203, 4, 2147483647, "Print",
 CellTags->"Info3617953932-5478789"]
}, Closed]],
Cell[CellGroupData[{
Cell[2409869, 68618, 211, 5, 2147483647, "Input"],
Cell[2410083, 68625, 300, 7, 2147483647, "Output"]
}, Closed]],
Cell[2410398, 68635, 559, 14, 2147483647, "Input"],
Cell[2410960, 68651, 141, 3, 2147483647, "Input"],
Cell[CellGroupData[{
Cell[2411126, 68658, 213, 6, 2147483647, "Input"],
Cell[2411342, 68666, 397, 12, 2147483647, "Output"]
}, Closed]],
Cell[2411754, 68681, 860, 20, 2147483647, "Input"],
Cell[2412617, 68703, 258, 6, 2147483647, "Input"],
Cell[2412878, 68711, 378, 8, 2147483647, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[2413293, 68724, 616, 8, 60, "Subsubsection"],
Cell[2413912, 68734, 1190, 26, 2147483647, "Text"],
Cell[2415105, 68762, 372, 8, 2147483647, "Text"],
Cell[2415480, 68772, 280, 6, 2147483647, "Text"],
Cell[2415763, 68780, 640, 16, 2147483647, "Input",
 Evaluatable->False],
Cell[2416406, 68798, 583, 14, 2147483647, "Input",
 Evaluatable->False],
Cell[2416992, 68814, 508, 8, 2147483647, "Text"],
Cell[2417503, 68824, 516, 13, 2147483647, "Input"],
Cell[2418022, 68839, 213, 4, 2147483647, "Text"],
Cell[2418238, 68845, 616, 16, 2147483647, "Input"],
Cell[2418857, 68863, 237, 5, 2147483647, "Text"],
Cell[2419097, 68870, 516, 14, 2147483647, "Input"],
Cell[2419616, 68886, 1029, 17, 2147483647, "Text"],
Cell[2420648, 68905, 263, 7, 2147483647, "Input"],
Cell[2420914, 68914, 462, 9, 2147483647, "Text"],
Cell[2421379, 68925, 362, 10, 2147483647, "Input"],
Cell[2421744, 68937, 101, 1, 2147483647, "Text"],
Cell[2421848, 68940, 324, 10, 2147483647, "Input"],
Cell[2422175, 68952, 396, 12, 2147483647, "Input"],
Cell[2422574, 68966, 498, 8, 2147483647, "Text"],
Cell[2423075, 68976, 206, 5, 2147483647, "Input"],
Cell[2423284, 68983, 93, 1, 2147483647, "Text"],
Cell[2423380, 68986, 390, 12, 2147483647, "Input"],
Cell[2423773, 69000, 440, 14, 2147483647, "Input"],
Cell[2424216, 69016, 91, 1, 2147483647, "Text"],
Cell[2424310, 69019, 411, 12, 2147483647, "Input",
 InitializationCell->True],
Cell[2424724, 69033, 227, 5, 2147483647, "Text"],
Cell[2424954, 69040, 412, 11, 2147483647, "Input",
 InitializationCell->True],
Cell[2425369, 69053, 202, 4, 2147483647, "Input"],
Cell[2425574, 69059, 326, 6, 2147483647, "Text"],
Cell[2425903, 69067, 809, 12, 2147483647, "Text"],
Cell[2426715, 69081, 528, 13, 2147483647, "Input"],
Cell[2427246, 69096, 698, 11, 2147483647, "Text"],
Cell[2427947, 69109, 609, 18, 2147483647, "Input"],
Cell[2428559, 69129, 300, 9, 2147483647, "Input"],
Cell[2428862, 69140, 138, 1, 2147483647, "Text"],
Cell[2429003, 69143, 662, 20, 2147483647, "Input"],
Cell[2429668, 69165, 347, 11, 2147483647, "Input"],
Cell[2430018, 69178, 245, 5, 2147483647, "Text"],
Cell[2430266, 69185, 289, 8, 2147483647, "Input"],
Cell[2430558, 69195, 1419, 20, 2147483647, "Text"],
Cell[2431980, 69217, 624, 19, 2147483647, "Input",
 Evaluatable->False],
Cell[2432607, 69238, 281, 5, 2147483647, "Text"],
Cell[2432891, 69245, 616, 19, 2147483647, "Input"],
Cell[2433510, 69266, 216, 4, 2147483647, "Text"],
Cell[2433729, 69272, 419, 12, 2147483647, "Input",
 Evaluatable->False],
Cell[2434151, 69286, 486, 8, 2147483647, "Text"],
Cell[2434640, 69296, 831, 24, 2147483647, "Input"],
Cell[2435474, 69322, 315, 6, 2147483647, "Text"],
Cell[2435792, 69330, 605, 10, 2147483647, "Text"],
Cell[2436400, 69342, 285, 8, 2147483647, "Input",
 Evaluatable->False],
Cell[2436688, 69352, 511, 8, 2147483647, "Text"],
Cell[2437202, 69362, 229, 5, 2147483647, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[2437468, 69372, 622, 8, 60, "Subsubsection"],
Cell[2438093, 69382, 804, 15, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2438922, 69401, 124, 2, 2147483647, "Input"],
Cell[2439049, 69405, 407, 6, 2147483647, "Print",
 CellTags->"Info3617958083-5478789"]
}, Closed]],
Cell[CellGroupData[{
Cell[2439493, 69416, 246, 6, 2147483647, "Input"],
Cell[2439742, 69424, 429, 12, 2147483647, "Output"]
}, Closed]],
Cell[2440186, 69439, 233, 7, 2147483647, "Input"],
Cell[2440422, 69448, 280, 7, 2147483647, "Input"],
Cell[2440705, 69457, 97, 1, 2147483647, "Text"],
Cell[2440805, 69460, 430, 11, 2147483647, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2441260, 69475, 198, 4, 2147483647, "Input"],
Cell[2441461, 69481, 384, 11, 2147483647, "Output"]
}, Closed]],
Cell[2441860, 69495, 814, 19, 2147483647, "Input",
 InitializationCell->True],
Cell[2442677, 69516, 125, 1, 2147483647, "Text"],
Cell[2442805, 69519, 307, 7, 2147483647, "Input"],
Cell[2443115, 69528, 110, 1, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2443250, 69533, 744, 19, 2147483647, "Input",
 InitializationCell->True],
Cell[2443997, 69554, 8586, 132, 140, "Output"]
}, Open  ]],
Cell[2452598, 69689, 227, 4, 2147483647, "Text"],
Cell[2452828, 69695, 592, 16, 2147483647, "Input"],
Cell[2453423, 69713, 286, 6, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2453734, 69723, 787, 20, 2147483647, "Input"],
Cell[2454524, 69745, 573, 18, 2147483647, "Output"]
}, Closed]],
Cell[2455112, 69766, 220, 2, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2455357, 69772, 174, 4, 2147483647, "Input"],
Cell[2455534, 69778, 147, 3, 2147483647, "Output"]
}, Closed]],
Cell[2455696, 69784, 819, 24, 2147483647, "Input"],
Cell[2456518, 69810, 860, 22, 2147483647, "Input"],
Cell[2457381, 69834, 608, 14, 2147483647, "Input"],
Cell[2457992, 69850, 245, 5, 2147483647, "Text"],
Cell[2458240, 69857, 531, 10, 2147483647, "Input"],
Cell[2458774, 69869, 217, 4, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2459016, 69877, 1098, 24, 2147483647, "Input"],
Cell[2460117, 69903, 522, 9, 2147483647, "Message"],
Cell[2460642, 69914, 4931, 133, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2465610, 70052, 259, 7, 2147483647, "Input"],
Cell[2465872, 70061, 2568, 76, 2147483647, "Output"]
}, Closed]],
Cell[2468455, 70140, 737, 16, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2469217, 70160, 178, 4, 2147483647, "Input"],
Cell[2469398, 70166, 2389, 77, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2471824, 70248, 298, 8, 2147483647, "Input"],
Cell[2472125, 70258, 525, 14, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2472687, 70277, 133, 2, 2147483647, "Input"],
Cell[2472823, 70281, 141, 2, 2147483647, "Output"]
}, Closed]],
Cell[2472979, 70286, 341, 6, 2147483647, "Text"],
Cell[2473323, 70294, 449, 12, 2147483647, "Input"],
Cell[CellGroupData[{
Cell[2473797, 70310, 403, 10, 2147483647, "Input"],
Cell[2474203, 70322, 249, 5, 2147483647, "Output"]
}, Closed]],
Cell[2474467, 70330, 555, 16, 2147483647, "Text"],
Cell[2475025, 70348, 555, 14, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2475605, 70366, 107, 2, 2147483647, "Input"],
Cell[2475715, 70370, 280, 5, 2147483647, "Print",
 CellTags->"Info3617958574-5478789"]
}, Closed]],
Cell[CellGroupData[{
Cell[2476032, 70380, 164, 3, 2147483647, "Input"],
Cell[2476199, 70385, 245, 5, 2147483647, "Output"]
}, Closed]],
Cell[2476459, 70393, 154, 4, 2147483647, "Input"],
Cell[2476616, 70399, 226, 4, 2147483647, "Text"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2476891, 70409, 321, 4, 95, "Subsection"],
Cell[CellGroupData[{
Cell[2477237, 70417, 264, 5, 76, "Subsubsection"],
Cell[2477504, 70424, 108, 1, 2147483647, "Text"],
Cell[2477615, 70427, 772, 21, 2147483647, "Input",
 InitializationCell->True],
Cell[2478390, 70450, 141, 1, 2147483647, "Text"],
Cell[2478534, 70453, 543, 13, 2147483647, "Input"],
Cell[2479080, 70468, 317, 7, 2147483647, "Input"],
Cell[2479400, 70477, 561, 10, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2479986, 70491, 122, 2, 2147483647, "Input"],
Cell[2480111, 70495, 2880, 45, 2147483647, "Print",
 CellTags->"Info3609831043-6425210"]
}, Closed]],
Cell[2483006, 70543, 287, 6, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2483318, 70553, 596, 15, 2147483647, "Input"],
Cell[2483917, 70570, 264, 6, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2484218, 70581, 122, 2, 2147483647, "Input"],
Cell[2484343, 70585, 184, 2, 2147483647, "Output"]
}, Closed]],
Cell[2484542, 70590, 143, 1, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2484710, 70595, 671, 17, 2147483647, "Input"],
Cell[2485384, 70614, 213, 4, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2485634, 70623, 122, 2, 2147483647, "Input"],
Cell[2485759, 70627, 184, 2, 2147483647, "Output"]
}, Closed]],
Cell[2485958, 70632, 307, 6, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2486290, 70642, 278, 7, 2147483647, "Input"],
Cell[2486571, 70651, 440, 14, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2487048, 70670, 346, 8, 2147483647, "Input"],
Cell[2487397, 70680, 390, 12, 2147483647, "Output"]
}, Closed]],
Cell[2487802, 70695, 2024, 30, 2147483647, "Text"],
Cell[2489829, 70727, 334, 6, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2490188, 70737, 453, 14, 2147483647, "Input"],
Cell[2490644, 70753, 411, 13, 2147483647, "Output"]
}, Closed]],
Cell[2491070, 70769, 252, 5, 2147483647, "Text"],
Cell[2491325, 70776, 498, 13, 2147483647, "Input"],
Cell[2491826, 70791, 493, 13, 2147483647, "Input"],
Cell[2492322, 70806, 513, 14, 2147483647, "Input"],
Cell[2492838, 70822, 514, 14, 2147483647, "Input"],
Cell[CellGroupData[{
Cell[2493377, 70840, 324, 8, 2147483647, "Input"],
Cell[2493704, 70850, 36962, 620, 2147483647, "Output"]
}, Closed]],
Cell[2530681, 71473, 137, 1, 2147483647, "Text"],
Cell[2530821, 71476, 770, 18, 2147483647, "Input"],
Cell[2531594, 71496, 772, 18, 2147483647, "Input"],
Cell[2532369, 71516, 853, 20, 2147483647, "Input"],
Cell[2533225, 71538, 852, 20, 2147483647, "Input"],
Cell[CellGroupData[{
Cell[2534102, 71562, 460, 10, 2147483647, "Input"],
Cell[2534565, 71574, 37156, 623, 2147483647, "Output"]
}, Closed]],
Cell[2571736, 72200, 1100, 17, 2147483647, "Text"],
Cell[2572839, 72219, 422, 12, 2147483647, "Input",
 Evaluatable->False],
Cell[2573264, 72233, 361, 7, 2147483647, "Text"],
Cell[2573628, 72242, 743, 20, 2147483647, "Input"],
Cell[2574374, 72264, 236, 4, 2147483647, "Text"],
Cell[2574613, 72270, 984, 28, 2147483647, "Input",
 Evaluatable->False],
Cell[2575600, 72300, 583, 12, 2147483647, "Text"],
Cell[2576186, 72314, 1214, 36, 2147483647, "Input",
 InitializationCell->True,
 CellTags->"gaussK"],
Cell[2577403, 72352, 354, 8, 2147483647, "Input",
 InitializationCell->True],
Cell[2577760, 72362, 610, 11, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2578395, 72377, 222, 5, 2147483647, "Input"],
Cell[2578620, 72384, 318, 7, 2147483647, "Output"]
}, Closed]],
Cell[2578953, 72394, 316, 6, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2579294, 72404, 363, 10, 2147483647, "Input"],
Cell[2579660, 72416, 4117, 78, 2147483647, "Output"]
}, Closed]],
Cell[2583792, 72497, 165, 3, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2583982, 72504, 227, 5, 2147483647, "Input"],
Cell[2584212, 72511, 117554, 3531, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2701803, 76047, 295, 6, 2147483647, "Input"],
Cell[2702101, 76055, 54823, 1611, 2147483647, "Output"]
}, Closed]],
Cell[2756939, 77669, 224, 5, 2147483647, "Text"],
Cell[2757166, 77676, 525, 11, 2147483647, "Text"],
Cell[2757694, 77689, 188, 4, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2757907, 77697, 165, 3, 2147483647, "Input"],
Cell[2758075, 77702, 224, 4, 2147483647, "Print",
 CellTags->"Info3615219021-6377691"]
}, Closed]],
Cell[CellGroupData[{
Cell[2758336, 77711, 486, 11, 2147483647, "Input"],
Cell[2758825, 77724, 280, 6, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2759142, 77735, 176, 4, 2147483647, "Input"],
Cell[2759321, 77741, 170, 3, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2759528, 77749, 308, 7, 2147483647, "Input"],
Cell[2759839, 77758, 163, 2, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2760039, 77765, 379, 8, 2147483647, "Input"],
Cell[2760421, 77775, 165, 2, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2760623, 77782, 463, 10, 2147483647, "Input"],
Cell[2761089, 77794, 165, 2, 2147483647, "Output"]
}, Closed]],
Cell[2761269, 77799, 331, 9, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2761625, 77812, 483, 9, 2147483647, "Input"],
Cell[2762111, 77823, 211, 4, 2147483647, "Output"]
}, Closed]],
Cell[2762337, 77830, 225, 4, 2147483647, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[2762599, 77839, 317, 4, 60, "Subsubsection"],
Cell[2762919, 77845, 609, 10, 2147483647, "Text"],
Cell[2763531, 77857, 319, 7, 2147483647, "Text"],
Cell[2763853, 77866, 465, 12, 2147483647, "Input",
 Evaluatable->False],
Cell[2764321, 77880, 930, 18, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2765276, 77902, 1397, 35, 2147483647, "Input"],
Cell[2766676, 77939, 261, 4, 2147483647, "Output"]
}, Closed]],
Cell[2766952, 77946, 378, 6, 2147483647, "Text"],
Cell[2767333, 77954, 464, 12, 2147483647, "Input",
 Evaluatable->False],
Cell[2767800, 77968, 341, 9, 2147483647, "Text"],
Cell[2768144, 77979, 1097, 29, 2147483647, "Input",
 InitializationCell->True],
Cell[2769244, 78010, 1064, 29, 2147483647, "Input",
 InitializationCell->True],
Cell[2770311, 78041, 482, 9, 2147483647, "Input"],
Cell[2770796, 78052, 98, 1, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2770919, 78057, 1265, 33, 2147483647, "Input"],
Cell[2772187, 78092, 381, 7, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2772605, 78104, 1153, 34, 2147483647, "Input"],
Cell[2773761, 78140, 141, 2, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2773939, 78147, 1282, 34, 2147483647, "Input"],
Cell[2775224, 78183, 75, 1, 2147483647, "Output"]
}, Closed]],
Cell[2775314, 78187, 386, 8, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2775725, 78199, 1850, 50, 2147483647, "Input"],
Cell[2777578, 78251, 623, 18, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2778238, 78274, 885, 15, 2147483647, "Input"],
Cell[2779126, 78291, 619, 18, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2779782, 78314, 554, 17, 2147483647, "Input"],
Cell[2780339, 78333, 529, 17, 2147483647, "Output"]
}, Closed]],
Cell[2780883, 78353, 182, 4, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2781090, 78361, 463, 13, 2147483647, "Input"],
Cell[2781556, 78376, 365, 10, 2147483647, "Output"]
}, Closed]],
Cell[2781936, 78389, 105, 1, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2782066, 78394, 180, 4, 2147483647, "Input"],
Cell[2782249, 78400, 474, 15, 2147483647, "Output"]
}, Closed]],
Cell[2782738, 78418, 107, 1, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2782870, 78423, 450, 12, 2147483647, "Input"],
Cell[2783323, 78437, 144, 2, 2147483647, "Output"]
}, Closed]],
Cell[2783482, 78442, 16, 0, 2147483647, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[2783535, 78447, 370, 5, 60, "Subsubsection"],
Cell[2783908, 78454, 568, 9, 4456448, "Text"],
Cell[2784479, 78465, 888, 16, 5701632, "Text"],
Cell[2785370, 78483, 3008, 48, 15663104, "Text"],
Cell[2788381, 78533, 879, 26, 3244032, "Input",
 Evaluatable->False],
Cell[2789263, 78561, 198, 7, 1966080, "Text",
 CellTags->"cij"],
Cell[2789464, 78570, 1418, 40, 5308416, "Input",
 InitializationCell->True],
Cell[2790885, 78612, 3827, 113, 11534336, "Input",
 InitializationCell->True],
Cell[2794715, 78727, 114, 1, 1966080, "Text"],
Cell[CellGroupData[{
Cell[2794854, 78732, 549, 15, 1966080, "Input"],
Cell[2795406, 78749, 216, 3, 2147483647, "Output"]
}, Closed]],
Cell[2795637, 78755, 555, 9, 2883584, "Text"],
Cell[2796195, 78766, 1177, 31, 3244032, "Input",
 Evaluatable->False],
Cell[2797375, 78799, 395, 7, 3211264, "Text"],
Cell[2797773, 78808, 716, 20, 1966080, "Input",
 Evaluatable->False],
Cell[2798492, 78830, 257, 3, 1966080, "Text"],
Cell[2798752, 78835, 796, 22, 1966080, "Input",
 Evaluatable->False],
Cell[2799551, 78859, 244, 6, 1966080, "Text"],
Cell[2799798, 78867, 792, 22, 1966080, "Input",
 Evaluatable->False],
Cell[2800593, 78891, 134, 1, 1966080, "Text"],
Cell[2800730, 78894, 824, 21, 1966080, "Input",
 Evaluatable->False],
Cell[2801557, 78917, 299, 6, 1966080, "Text"],
Cell[2801859, 78925, 424, 11, 1966080, "Input",
 Evaluatable->False],
Cell[2802286, 78938, 494, 8, 3211264, "Text"],
Cell[2802783, 78948, 901, 17, 8192000, "Text"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2803745, 78972, 374, 5, 140, "Section"],
Cell[CellGroupData[{
Cell[2804144, 78981, 316, 4, 95, "Subsection"],
Cell[2804463, 78987, 149, 3, 240, "Input"],
Cell[2804615, 78992, 392, 12, 240, "Text"],
Cell[2805010, 79006, 1177, 29, 396, "Input",
 InitializationCell->True],
Cell[2806190, 79037, 427, 8, 548, "Input"],
Cell[2806620, 79047, 1100, 19, 1000, "Text"],
Cell[CellGroupData[{
Cell[2807745, 79070, 2229, 54, 700, "Input"],
Cell[2809977, 79126, 240, 3, 2147483647, "Output"]
}, Closed]],
Cell[2810232, 79132, 410, 9, 636, "Input",
 InitializationCell->True],
Cell[2810645, 79143, 240, 7, 240, "Text"],
Cell[CellGroupData[{
Cell[2810910, 79154, 732, 20, 396, "Input"],
Cell[2811645, 79176, 231, 3, 2147483647, "Output"]
}, Closed]],
Cell[2811891, 79182, 578, 15, 352, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[2812506, 79202, 321, 4, 75, "Subsection"],
Cell[2812830, 79208, 212, 4, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2813067, 79216, 1069, 28, 2147483647, "Input"],
Cell[2814139, 79246, 160, 2, 2147483647, "Output"]
}, Closed]],
Cell[2814314, 79251, 695, 14, 2147483647, "Text"],
Cell[2815012, 79267, 347, 10, 2147483647, "Text"],
Cell[2815362, 79279, 2087, 68, 2147483647, "Input",
 InitializationCell->True],
Cell[2817452, 79349, 439, 9, 2147483647, "Input",
 InitializationCell->True],
Cell[2817894, 79360, 257, 4, 2147483647, "Text"],
Cell[2818154, 79366, 625, 18, 2147483647, "Input",
 Evaluatable->False],
Cell[2818782, 79386, 154, 5, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2818961, 79395, 1613, 44, 2147483647, "Input"],
Cell[2820577, 79441, 217, 3, 2147483647, "Output"]
}, Closed]],
Cell[2820809, 79447, 266, 3, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2821100, 79454, 1247, 34, 2147483647, "Input"],
Cell[2822350, 79490, 195, 3, 2147483647, "Output"]
}, Closed]],
Cell[2822560, 79496, 230, 8, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2822815, 79508, 1892, 49, 2147483647, "Input"],
Cell[2824710, 79559, 192, 3, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2824939, 79567, 859, 23, 2147483647, "Input"],
Cell[2825801, 79592, 385, 11, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2826223, 79608, 792, 19, 2147483647, "Input"],
Cell[2827018, 79629, 515, 14, 2147483647, "Output"]
}, Closed]],
Cell[2827548, 79646, 90, 1, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2827663, 79651, 1211, 30, 2147483647, "Input"],
Cell[2828877, 79683, 219, 3, 2147483647, "Output"]
}, Closed]],
Cell[2829111, 79689, 412, 12, 2147483647, "Text"],
Cell[CellGroupData[{
Cell[2829548, 79705, 881, 23, 2147483647, "Input"],
Cell[2830432, 79730, 340, 7, 2147483647, "Output"]
}, Closed]],
Cell[2830787, 79740, 106, 1, 2147483647, "Text"],
Cell[2830896, 79743, 472, 11, 2147483647, "Input"],
Cell[CellGroupData[{
Cell[2831393, 79758, 363, 11, 2147483647, "Input"],
Cell[2831759, 79771, 165, 2, 2147483647, "Output"]
}, Closed]],
Cell[2831939, 79776, 408, 7, 2147483647, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[2832384, 79788, 325, 6, 75, "Subsection"],
Cell[2832712, 79796, 322, 6, 240, "Text"],
Cell[CellGroupData[{
Cell[2833059, 79806, 1318, 41, 700, "Input"],
Cell[2834380, 79849, 73, 1, 2147483647, "Output"]
}, Closed]],
Cell[2834468, 79853, 159, 3, 200, "Text"],
Cell[CellGroupData[{
Cell[2834652, 79860, 1154, 29, 396, "Input"],
Cell[2835809, 79891, 200, 3, 2147483647, "Output"]
}, Closed]],
Cell[2836024, 79897, 132, 1, 200, "Text"],
Cell[CellGroupData[{
Cell[2836181, 79902, 783, 22, 240, "Input"],
Cell[2836967, 79926, 197, 3, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2837201, 79934, 792, 21, 176, "Input"],
Cell[2837996, 79957, 170, 2, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2838203, 79964, 790, 21, 176, "Input"],
Cell[2838996, 79987, 170, 2, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2839203, 79994, 835, 23, 176, "Input"],
Cell[2840041, 80019, 171, 2, 2147483647, "Output"]
}, Closed]],
Cell[2840227, 80024, 119, 1, 200, "Text"],
Cell[CellGroupData[{
Cell[2840371, 80029, 3027, 81, 1004, "Input"],
Cell[2843401, 80112, 315, 5, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2843753, 80122, 1061, 28, 332, "Input"],
Cell[2844817, 80152, 241, 4, 2147483647, "Output"]
}, Closed]],
Cell[2845073, 80159, 126, 1, 200, "Text"],
Cell[2845202, 80162, 1251, 34, 396, "Input",
 InitializationCell->True],
Cell[2846456, 80198, 137, 1, 240, "Text"],
Cell[CellGroupData[{
Cell[2846618, 80203, 722, 17, 240, "Input"],
Cell[2847343, 80222, 169, 2, 2147483647, "Output"]
}, Closed]],
Cell[2847527, 80227, 70, 1, 176, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[2847634, 80233, 268, 3, 75, "Subsection"],
Cell[2847905, 80238, 308, 6, 480, "Text"],
Cell[2848216, 80246, 302, 8, 480, "Input",
 InitializationCell->True],
Cell[2848521, 80256, 133, 1, 480, "Text"],
Cell[2848657, 80259, 352, 10, 480, "Input",
 InitializationCell->True],
Cell[2849012, 80271, 126, 1, 480, "Text"],
Cell[2849141, 80274, 373, 8, 480, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2849539, 80286, 125, 2, 480, "Input"],
Cell[2849667, 80290, 588, 18, 241664, "Output"]
}, Closed]],
Cell[2850270, 80311, 328, 6, 400, "Text"],
Cell[CellGroupData[{
Cell[2850623, 80321, 850, 22, 480, "Input"],
Cell[2851476, 80345, 8542, 274, 1470464, "Output"]
}, Closed]],
Cell[2860033, 80622, 136, 2, 400, "Text"],
Cell[2860172, 80626, 906, 23, 480, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2861103, 80653, 346, 6, 480, "Input"],
Cell[2861452, 80661, 611, 18, 241664, "Output"]
}, Closed]],
Cell[2862078, 80682, 270, 7, 704, "Text"],
Cell[CellGroupData[{
Cell[2862373, 80693, 903, 23, 792, "Input"],
Cell[2863279, 80718, 1205, 34, 241664, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2864521, 80757, 917, 23, 45056, "Input"],
Cell[2865441, 80782, 22823, 701, 4317184, "Output"]
}, Closed]],
Cell[2888279, 81486, 173, 2, 51200, "Text"],
Cell[2888455, 81490, 2022, 44, 179200, "Input",
 InitializationCell->True],
Cell[2890480, 81536, 247, 3, 61440, "Text"],
Cell[CellGroupData[{
Cell[2890752, 81543, 858, 22, 61440, "Input"],
Cell[2891613, 81567, 553, 8, 241664, "Output"]
}, Closed]],
Cell[2892181, 81578, 319, 7, 51200, "Text"],
Cell[CellGroupData[{
Cell[2892525, 81589, 489, 14, 61440, "Input"],
Cell[2893017, 81605, 468, 14, 241664, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2893522, 81624, 143, 3, 45056, "Input"],
Cell[2893668, 81629, 1067, 32, 241664, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2894772, 81666, 932, 24, 84992, "Input"],
Cell[2895707, 81692, 1036, 31, 241664, "Output"]
}, Closed]],
Cell[2896758, 81726, 317, 6, 90112, "Text"],
Cell[CellGroupData[{
Cell[2897100, 81736, 285, 6, 61440, "Input"],
Cell[2897388, 81744, 1627, 49, 397312, "Output"]
}, Closed]],
Cell[2899030, 81796, 115, 1, 51200, "Text"],
Cell[CellGroupData[{
Cell[2899170, 81801, 1034, 24, 61440, "Input"],
Cell[2900207, 81827, 96, 1, 241664, "Output"]
}, Closed]],
Cell[2900318, 81831, 95, 1, 51200, "Text"],
Cell[2900416, 81834, 171, 5, 245760, "Text"],
Cell[2900590, 81841, 159, 3, 245760, "Text"],
Cell[CellGroupData[{
Cell[2900774, 81848, 147, 3, 245760, "Input"],
Cell[2900924, 81853, 361, 10, 241664, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2901322, 81868, 508, 16, 245760, "Input"],
Cell[2901833, 81886, 1370, 41, 397312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2903240, 81932, 1165, 27, 405504, "Input"],
Cell[2904408, 81961, 143, 2, 241664, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2904588, 81968, 942, 29, 405504, "Input"],
Cell[2905533, 81999, 583, 18, 241664, "Output"]
}, Closed]],
Cell[2906131, 82020, 217, 4, 245760, "Text"],
Cell[CellGroupData[{
Cell[2906373, 82028, 1154, 33, 561152, "Input"],
Cell[2907530, 82063, 121, 2, 241664, "Output"]
}, Closed]],
Cell[2907666, 82068, 152, 5, 557056, "Text"],
Cell[CellGroupData[{
Cell[2907843, 82077, 956, 30, 405504, "Input"],
Cell[2908802, 82109, 408, 6, 241664, "Output"]
}, Closed]],
Cell[2909225, 82118, 473, 10, 401408, "Text"],
Cell[2909701, 82130, 942, 27, 561152, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2910668, 82161, 369, 11, 245760, "Input"],
Cell[2911040, 82174, 3501, 102, 974848, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2914578, 82281, 133, 2, 245760, "Input"],
Cell[2914714, 82285, 910, 29, 430080, "Output"]
}, Closed]],
Cell[2915639, 82317, 755, 12, 401408, "Text",
 InitializationCell->True],
Cell[2916397, 82331, 1941, 45, 716800, "Input",
 InitializationCell->True],
Cell[2918341, 82378, 100, 1, 245760, "Text"],
Cell[CellGroupData[{
Cell[2918466, 82383, 688, 11, 245760, "Input"],
Cell[2919157, 82396, 1532, 43, 512000, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2920726, 82444, 450, 9, 245760, "Input"],
Cell[2921179, 82455, 10478, 280, 4153344, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2931694, 82740, 705, 17, 405504, "Input"],
Cell[2932402, 82759, 8787, 257, 4370432, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2941226, 83021, 1105, 25, 245760, "Input"],
Cell[2942334, 83048, 434, 9, 307200, "Message"],
Cell[2942771, 83059, 432, 9, 307200, "Message"],
Cell[2943206, 83070, 126, 2, 241664, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2943369, 83077, 1568, 33, 561152, "Input"],
Cell[2944940, 83112, 478, 15, 241664, "Output"]
}, Closed]],
Cell[2945433, 83130, 402, 5, 245760, "Text"],
Cell[2945838, 83137, 444, 8, 401408, "Text"],
Cell[CellGroupData[{
Cell[2946307, 83149, 113, 2, 245760, "Input"],
Cell[2946423, 83153, 373, 6, 614400, "Print",
 CellTags->"Info3618045930-7228279"]
}, Closed]],
Cell[CellGroupData[{
Cell[2946833, 83164, 357, 8, 245760, "Input"],
Cell[2947193, 83174, 245, 3, 241664, "Output"]
}, Closed]],
Cell[2947453, 83180, 308, 6, 401408, "Text"],
Cell[CellGroupData[{
Cell[2947786, 83190, 614, 15, 245760, "Input"],
Cell[2948403, 83207, 72, 1, 241664, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2948512, 83213, 1366, 27, 45056, "Input",
 InitializationCell->True],
Cell[2949881, 83242, 15831, 464, 140, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2965749, 83711, 452, 11, 61440, "Input"],
Cell[2966204, 83724, 7543, 248, 1306624, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2973784, 83977, 1613, 31, 84992, "Input"],
Cell[2975400, 84010, 103, 1, 241664, "Output"]
}, Closed]],
Cell[2975518, 84014, 222, 3, 51200, "Text"],
Cell[CellGroupData[{
Cell[2975765, 84021, 832, 19, 101376, "Input"],
Cell[2976600, 84042, 607, 10, 458752, "Message"],
Cell[2977210, 84054, 605, 10, 458752, "Message"],
Cell[2977818, 84066, 605, 10, 458752, "Message"],
Cell[2978426, 84078, 544, 10, 176128, "Message"],
Cell[2978973, 84090, 219, 3, 241664, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2979229, 84098, 777, 19, 84992, "Input"],
Cell[2980009, 84119, 77, 1, 2147483647, "Output"]
}, Closed]],
Cell[2980101, 84123, 205, 4, 51200, "Text"],
Cell[2980309, 84129, 223109, 5766, 11162624, "Input",
 CellTags->"ccc"],
Cell[3203421, 89897, 101, 1, 245760, "Text"],
Cell[CellGroupData[{
Cell[3203547, 89902, 914, 15, 245760, "Input"],
Cell[3204464, 89919, 7720, 250, 1306624, "Output"]
}, Closed]],
Cell[3212199, 90172, 143, 2, 245760, "Text"],
Cell[CellGroupData[{
Cell[3212367, 90178, 625, 14, 405504, "Input"],
Cell[3212995, 90194, 174, 4, 241664, "Output"]
}, Closed]],
Cell[3213184, 90201, 874, 16, 401408, "Text"],
Cell[CellGroupData[{
Cell[3214083, 90221, 1012, 28, 405504, "Input"],
Cell[3215098, 90251, 163, 2, 241664, "Output"]
}, Closed]],
Cell[3215276, 90256, 925, 22, 557056, "Text"],
Cell[3216204, 90280, 295, 5, 401408, "Text"],
Cell[3216502, 90287, 2431, 60, 1028096, "Input",
 InitializationCell->True],
Cell[3218936, 90349, 458, 9, 663552, "Input",
 InitializationCell->True],
Cell[3219397, 90360, 308, 6, 401408, "Text"],
Cell[3219708, 90368, 289, 6, 245760, "Text"],
Cell[CellGroupData[{
Cell[3220022, 90378, 643, 17, 405504, "Input"],
Cell[3220668, 90397, 419, 11, 331776, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3221124, 90413, 547, 16, 245760, "Input"],
Cell[3221674, 90431, 144, 2, 241664, "Output"]
}, Closed]],
Cell[3221833, 90436, 330, 8, 401408, "Text"],
Cell[3222166, 90446, 97, 1, 245760, "Text"],
Cell[3222266, 90449, 366, 7, 401408, "Text"],
Cell[3222635, 90458, 685, 17, 245760, "Input",
 Evaluatable->False],
Cell[3223323, 90477, 543, 9, 401408, "Text"],
Cell[3223869, 90488, 994, 26, 245760, "Input",
 Evaluatable->False],
Cell[3224866, 90516, 1179, 27, 573440, "Text",
 CellTags->"geodc"],
Cell[3226048, 90545, 409, 9, 245760, "Text"],
Cell[3226460, 90556, 425, 14, 258048, "Input",
 Evaluatable->False],
Cell[3226888, 90572, 544, 17, 245760, "Text"],
Cell[3227435, 90591, 389, 11, 245760, "Input",
 Evaluatable->False],
Cell[3227827, 90604, 326, 6, 245760, "Text"],
Cell[3228156, 90612, 485, 9, 401408, "Text"],
Cell[3228644, 90623, 724, 21, 245760, "Input",
 Evaluatable->False],
Cell[3229371, 90646, 769, 12, 557056, "Text"],
Cell[CellGroupData[{
Cell[3230165, 90662, 1365, 36, 405504, "Input"],
Cell[3231533, 90700, 396, 10, 315392, "Output"]
}, Closed]],
Cell[3231944, 90713, 595, 10, 401408, "Text"],
Cell[3232542, 90725, 609, 18, 417792, "Input",
 Evaluatable->False],
Cell[3233154, 90745, 1640, 42, 864256, "Text"],
Cell[3234797, 90789, 502, 10, 557056, "Text"],
Cell[3235302, 90801, 352, 4, 245760, "Text"],
Cell[3235657, 90807, 271, 3, 245760, "Text"],
Cell[3235931, 90812, 555, 16, 245760, "Input",
 Evaluatable->False],
Cell[3236489, 90830, 1043, 18, 1024000, "Text"],
Cell[3237535, 90850, 458, 8, 401408, "Text"],
Cell[3237996, 90860, 375, 11, 245760, "Input",
 Evaluatable->False],
Cell[3238374, 90873, 519, 10, 401408, "Text"],
Cell[3238896, 90885, 1211, 29, 819200, "Input",
 InitializationCell->True],
Cell[3240110, 90916, 302, 7, 663552, "Input",
 InitializationCell->True],
Cell[3240415, 90925, 191, 2, 245760, "Text"],
Cell[CellGroupData[{
Cell[3240631, 90931, 621, 15, 245760, "Input"],
Cell[3241255, 90948, 307, 7, 2147483647, "Output"]
}, Closed]],
Cell[3241577, 90958, 469, 8, 360448, "Text"],
Cell[CellGroupData[{
Cell[3242071, 90970, 449, 9, 245760, "Input"],
Cell[3242523, 90981, 442, 14, 2147483647, "Output"]
}, Closed]],
Cell[3242980, 90998, 1059, 19, 827392, "Text"],
Cell[3244042, 91019, 1317, 24, 1179648, "Text"],
Cell[CellGroupData[{
Cell[3245384, 91047, 707, 18, 405504, "Input"],
Cell[3246094, 91067, 262, 8, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3246393, 91080, 658, 17, 339968, "Input"],
Cell[3247054, 91099, 645, 22, 2147483647, "Output"]
}, Closed]],
Cell[3247714, 91124, 339, 6, 360448, "Text"],
Cell[CellGroupData[{
Cell[3248078, 91134, 517, 14, 245760, "Input"],
Cell[3248598, 91150, 464, 15, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3249099, 91170, 568, 15, 180224, "Input"],
Cell[3249670, 91187, 456, 15, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3250163, 91207, 639, 14, 180224, "Input"],
Cell[3250805, 91223, 173, 4, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3251015, 91232, 641, 14, 180224, "Input"],
Cell[3251659, 91248, 213, 6, 2147483647, "Output"]
}, Closed]],
Cell[3251887, 91257, 645, 13, 360448, "Text"],
Cell[CellGroupData[{
Cell[3252557, 91274, 845, 23, 561152, "Input"],
Cell[3253405, 91299, 96, 1, 241664, "Output"]
}, Closed]],
Cell[3253516, 91303, 719, 20, 401408, "Text"],
Cell[3254238, 91325, 718, 20, 434176, "Input",
 Evaluatable->False],
Cell[3254959, 91347, 530, 11, 557056, "Text"],
Cell[CellGroupData[{
Cell[3255514, 91362, 166, 3, 245760, "Input"],
Cell[3255683, 91367, 1043, 19, 2147483647, "Print",
 CellTags->"Info3598454626-3632977"]
}, Closed]],
Cell[3256741, 91389, 129, 2, 180224, "Input"],
Cell[3256873, 91393, 762, 21, 348160, "Input",
 InitializationCell->True],
Cell[3257638, 91416, 341, 8, 663552, "Input",
 InitializationCell->True],
Cell[3257982, 91426, 1155, 27, 401408, "Text"],
Cell[CellGroupData[{
Cell[3259162, 91457, 1226, 29, 405504, "Input"],
Cell[3260391, 91488, 192, 3, 241664, "Output"]
}, Closed]],
Cell[3260598, 91494, 379, 8, 704, "Text"],
Cell[CellGroupData[{
Cell[3261002, 91506, 1081, 28, 1096, "Input"],
Cell[3262086, 91536, 95, 1, 2147483647, "Output"]
}, Closed]],
Cell[3262196, 91540, 162, 3, 400, "Text"],
Cell[3262361, 91545, 485, 12, 480, "Input"],
Cell[3262849, 91559, 347, 7, 480, "Input"],
Cell[3263199, 91568, 263, 5, 480, "Text"],
Cell[CellGroupData[{
Cell[3263487, 91577, 1516, 38, 1096, "Input"],
Cell[3265006, 91617, 228, 6, 2147483647, "Output"]
}, Closed]],
Cell[3265249, 91626, 221, 6, 400, "Text"],
Cell[3265473, 91634, 921, 25, 792, "Input"],
Cell[CellGroupData[{
Cell[3266419, 91663, 311, 8, 480, "Input"],
Cell[3266733, 91673, 483, 14, 2147483647, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3267253, 91692, 380, 10, 352, "Input"],
Cell[3267636, 91704, 146, 2, 2147483647, "Output"]
}, Closed]],
Cell[3267797, 91709, 292, 5, 704, "Text"],
Cell[3268092, 91716, 398, 7, 480, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[3268527, 91728, 260, 3, 75, "Subsection"],
Cell[3268790, 91733, 374, 6, 544, "Text"],
Cell[CellGroupData[{
Cell[3269189, 91743, 118, 2, 240, "Input"],
Cell[3269310, 91747, 290, 5, 60817408, "Print",
 CellTags->"Info3618475557-7588711"]
}, Closed]],
Cell[CellGroupData[{
Cell[3269637, 91757, 205, 5, 176, "Input"],
Cell[3269845, 91764, 252, 6, 44040192, "Output"]
}, Closed]],
Cell[3270112, 91773, 180, 2, 200, "Text"],
Cell[CellGroupData[{
Cell[3270317, 91779, 411, 9, 240, "Input"],
Cell[3270731, 91790, 1092, 37, 70254592, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3271860, 91832, 409, 9, 176, "Input"],
Cell[3272272, 91843, 5015, 172, 218103808, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3277324, 92020, 461, 9, 176, "Input"],
Cell[3277788, 92031, 2464, 85, 120586240, "Output"]
}, Closed]],
Cell[3280267, 92119, 333, 6, 352, "Text"],
Cell[3280603, 92127, 1606, 51, 584, "Input"],
Cell[CellGroupData[{
Cell[3282234, 92182, 126, 2, 240, "Input"],
Cell[3282363, 92186, 833, 26, 46661632, "Output"]
}, Closed]],
Cell[3283211, 92215, 457, 8, 504, "Text"],
Cell[CellGroupData[{
Cell[3283693, 92227, 1092, 29, 65011712, "Input"],
Cell[3284788, 92258, 399, 10, 44040192, "Output"]
}, Closed]],
Cell[3285202, 92271, 215, 6, 44564480, "Input"],
Cell[CellGroupData[{
Cell[3285442, 92281, 394, 9, 44564480, "Input"],
Cell[3285839, 92292, 1340, 46, 46661632, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3287216, 92343, 378, 10, 44564480, "Input"],
Cell[3287597, 92355, 293, 7, 44040192, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3287927, 92367, 416, 9, 44564480, "Input"],
Cell[3288346, 92378, 1983, 67, 70254592, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3290366, 92450, 378, 10, 44564480, "Input"],
Cell[3290747, 92462, 1008, 33, 44040192, "Output"]
}, Closed]],
Cell[3291770, 92498, 248, 5, 31457280, "Text"],
Cell[CellGroupData[{
Cell[3292043, 92507, 119, 2, 31457280, "Input"],
Cell[3292165, 92511, 1983, 33, 2147483647, "Print",
 CellTags->"Info3611648456-7479549"]
}, Closed]],
Cell[3294163, 92547, 140, 1, 26214400, "Text"],
Cell[3294306, 92550, 397, 10, 44564480, "Input"],
Cell[CellGroupData[{
Cell[3294728, 92564, 781, 17, 44564480, "Input"],
Cell[3295512, 92583, 1712, 51, 55574528, "Output"]
}, Closed]],
Cell[3297239, 92637, 360, 7, 51380224, "Text"],
Cell[3297602, 92646, 523, 15, 44564480, "Input"],
Cell[CellGroupData[{
Cell[3298150, 92665, 184, 4, 44564480, "Input"],
Cell[3298337, 92671, 276, 5, 44040192, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3298650, 92681, 698, 17, 44564480, "Input"],
Cell[3299351, 92700, 238, 5, 44040192, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3299626, 92710, 745, 18, 332, "Input"],
Cell[3300374, 92730, 211, 4, 44040192, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3300622, 92739, 845, 19, 332, "Input"],
Cell[3301470, 92760, 255, 5, 55574528, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3301762, 92770, 498, 15, 176, "Input"],
Cell[3302263, 92787, 386, 9, 44040192, "Output"]
}, Closed]],
Cell[3302664, 92799, 240, 6, 200, "Text"],
Cell[3302907, 92807, 510, 15, 240, "Input"],
Cell[3303420, 92824, 290, 6, 240, "Text"],
Cell[3303713, 92832, 582, 16, 240, "Input"],
Cell[3304298, 92850, 219, 6, 240, "Text"],
Cell[3304520, 92858, 605, 17, 240, "Input"],
Cell[3305128, 92877, 365, 10, 392, "Text"],
Cell[3305496, 92889, 584, 16, 240, "Input"],
Cell[3306083, 92907, 288, 5, 392, "Text"],
Cell[CellGroupData[{
Cell[3306396, 92916, 658, 16, 240, "Input"],
Cell[3307057, 92934, 2373, 74, 151519232, "Output"]
}, Closed]],
Cell[3309445, 93011, 227, 4, 176, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[3309709, 93020, 362, 4, 75, "Subsection"],
Cell[3310074, 93026, 136, 1, 240, "Text"],
Cell[CellGroupData[{
Cell[3310235, 93031, 203, 5, 240, "Input"],
Cell[3310441, 93038, 864, 24, 7733248, "Output"]
}, Closed]],
Cell[3311320, 93065, 543, 12, 176, "Input"],
Cell[CellGroupData[{
Cell[3311888, 93081, 222, 4, 240, "Input"],
Cell[3312113, 93087, 841, 24, 7733248, "Output"]
}, Closed]],
Cell[3312969, 93114, 87, 1, 200, "Text"],
Cell[3313059, 93117, 740, 15, 240, "Input"],
Cell[3313802, 93134, 200, 4, 240, "Text"],
Cell[3314005, 93140, 265, 3, 240, "Text"],
Cell[CellGroupData[{
Cell[3314295, 93147, 332, 8, 240, "Input"],
Cell[3314630, 93157, 856, 23, 7733248, "Output"]
}, Closed]],
Cell[3315501, 93183, 249, 3, 200, "Text"],
Cell[CellGroupData[{
Cell[3315775, 93190, 265, 6, 240, "Input"],
Cell[3316043, 93198, 633, 16, 7733248, "Output"]
}, Closed]],
Cell[3316691, 93217, 138, 1, 200, "Text"],
Cell[CellGroupData[{
Cell[3316854, 93222, 287, 7, 240, "Input"],
Cell[3317144, 93231, 1015, 28, 7733248, "Output"]
}, Closed]],
Cell[3318174, 93262, 138, 1, 200, "Text"],
Cell[3318315, 93265, 1675, 50, 548, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3320015, 93319, 167, 3, 480, "Input"],
Cell[3320185, 93324, 5563, 168, 40239104, "Output"]
}, Closed]],
Cell[3325763, 93495, 364, 6, 704, "Text"],
Cell[CellGroupData[{
Cell[3326152, 93505, 1568, 31, 1096, "Input"],
Cell[3327723, 93538, 2000, 57, 13893632, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3329760, 93600, 2013, 57, 968, "Input"],
Cell[3331776, 93659, 124, 2, 7733248, "Output"]
}, Closed]],
Cell[3331915, 93664, 155, 2, 400, "Text"],
Cell[CellGroupData[{
Cell[3332095, 93670, 1524, 29, 792, "Input"],
Cell[3333622, 93701, 141, 2, 7733248, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3333800, 93708, 1458, 27, 664, "Input"],
Cell[3335261, 93737, 214, 3, 7733248, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3335512, 93745, 2001, 43, 968, "Input"],
Cell[3337516, 93790, 169, 2, 7733248, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3337722, 93797, 1544, 28, 664, "Input"],
Cell[3339269, 93827, 1220, 41, 7733248, "Output"]
}, Closed]],
Cell[3340504, 93871, 160, 2, 400, "Text"],
Cell[CellGroupData[{
Cell[3340689, 93877, 776, 17, 792, "Input"],
Cell[3341468, 93896, 4692, 137, 33161216, "Output"]
}, Closed]],
Cell[3346175, 94036, 201, 5, 400, "Text"],
Cell[3346379, 94043, 5906, 158, 7480, "Input"],
Cell[3352288, 94203, 388, 7, 480, "Text"],
Cell[CellGroupData[{
Cell[3352701, 94214, 878, 19, 792, "Input"],
Cell[3353582, 94235, 167, 2, 11010048, "Output"]
}, Closed]],
Cell[3353764, 94240, 351, 8, 352, "Input"],
Cell[CellGroupData[{
Cell[3354140, 94252, 950, 20, 792, "Input"],
Cell[3355093, 94274, 4132, 127, 32374784, "Output"]
}, Closed]],
Cell[3359240, 94404, 5340, 148, 6744, "Input"],
Cell[3364583, 94554, 413, 11, 480, "Input"],
Cell[CellGroupData[{
Cell[3365021, 94569, 1002, 21, 792, "Input"],
Cell[3366026, 94592, 11316, 326, 64749568, "Output"]
}, Closed]],
Cell[3377357, 94921, 13893, 377, 16472, "Input"],
Cell[3391253, 95300, 228, 5, 480, "Text"],
Cell[CellGroupData[{
Cell[3391506, 95309, 1433, 30, 1096, "Input"],
Cell[3392942, 95341, 5037, 141, 39059456, "Output"]
}, Closed]],
Cell[3397994, 95485, 5630, 155, 6440, "Input"],
Cell[3403627, 95642, 91, 1, 480, "Text"],
Cell[CellGroupData[{
Cell[3403743, 95647, 496, 12, 480, "Input"],
Cell[3404242, 95661, 218, 3, 11010048, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3404497, 95669, 150, 3, 352, "Input"],
Cell[3404650, 95674, 4523, 136, 33292288, "Output"]
}, Closed]],
Cell[3409188, 95813, 584, 12, 704, "Text"],
Cell[3409775, 95827, 635, 18, 480, "Input",
 Evaluatable->False],
Cell[3410413, 95847, 112, 1, 480, "Text"],
Cell[3410528, 95850, 1680, 49, 888, "Input",
 Evaluatable->False],
Cell[3412211, 95901, 215, 3, 480, "Text"],
Cell[3412429, 95906, 949, 26, 480, "Input",
 Evaluatable->False],
Cell[3413381, 95934, 894, 15, 480, "Text"],
Cell[CellGroupData[{
Cell[3414300, 95953, 1832, 51, 1704, "Input"],
Cell[3416135, 96006, 314, 4, 11010048, "Output"]
}, Closed]],
Cell[3416464, 96013, 636, 10, 704, "Text"],
Cell[3417103, 96025, 273, 6, 480, "Text"],
Cell[3417379, 96033, 1567, 41, 496, "Text"],
Cell[3418949, 96076, 148, 2, 480, "Text"],
Cell[CellGroupData[{
Cell[3419122, 96082, 254, 6, 480, "Input"],
Cell[3419379, 96090, 2104, 69, 2147483647, "Output"]
}, Closed]],
Cell[3421498, 96162, 2705, 57, 2224, "Text"],
Cell[3424206, 96221, 480, 8, 1088, "Text"],
Cell[CellGroupData[{
Cell[3424711, 96233, 1410, 29, 1096, "Input"],
Cell[3426124, 96264, 15049, 407, 76021760, "Output"]
}, Closed]],
Cell[3441188, 96674, 202, 4, 400, "Text"],
Cell[CellGroupData[{
Cell[3441415, 96682, 1519, 28, 792, "Input"],
Cell[3442937, 96712, 240, 3, 11010048, "Output"]
}, Closed]],
Cell[3443192, 96718, 274, 7, 352, "Input"],
Cell[CellGroupData[{
Cell[3443491, 96729, 1414, 26, 792, "Input"],
Cell[3444908, 96757, 4258, 129, 32374784, "Output"]
}, Closed]],
Cell[3449181, 96889, 5054, 145, 6440, "Input"],
Cell[3454238, 97036, 548, 13, 480, "Input"],
Cell[CellGroupData[{
Cell[3454811, 97053, 1518, 28, 792, "Input"],
Cell[3456332, 97083, 10782, 309, 56623104, "Output"]
}, Closed]],
Cell[3467129, 97395, 13120, 355, 14952, "Input"],
Cell[3480252, 97752, 265, 5, 480, "Text"],
Cell[CellGroupData[{
Cell[3480542, 97761, 782, 21, 1096, "Input"],
Cell[3481327, 97784, 4617, 137, 33030144, "Output"]
}, Closed]],
Cell[3485959, 97924, 5282, 148, 3068, "Input"],
Cell[3491244, 98074, 119, 1, 240, "Text"],
Cell[CellGroupData[{
Cell[3491388, 98079, 1277, 30, 548, "Input"],
Cell[3492668, 98111, 11848, 337, 70254592, "Output"]
}, Closed]],
Cell[3504531, 98451, 145, 1, 200, "Text"],
Cell[CellGroupData[{
Cell[3504701, 98456, 968, 20, 396, "Input"],
Cell[3505672, 98478, 190, 3, 11010048, "Output"]
}, Closed]],
Cell[3505877, 98484, 176, 2, 200, "Text"],
Cell[CellGroupData[{
Cell[3506078, 98490, 1076, 21, 396, "Input"],
Cell[3507157, 98513, 10784, 309, 56885248, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3517978, 98827, 1476, 31, 484, "Input"],
Cell[3519457, 98860, 10808, 309, 56885248, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3530302, 99174, 294, 7, 176, "Input"],
Cell[3530599, 99183, 72, 1, 11010048, "Output"]
}, Closed]],
Cell[3530686, 99187, 85, 1, 200, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[3530808, 99193, 217, 3, 75, "Subsection"],
Cell[CellGroupData[{
Cell[3531050, 99200, 234, 3, 76, "Subsubsection"],
Cell[3531287, 99205, 453, 9, 12845056, "Text"],
Cell[3531743, 99216, 670, 18, 11141120, "Input",
 InitializationCell->True],
Cell[3532416, 99236, 356, 8, 21233664, "Input",
 InitializationCell->True],
Cell[3532775, 99246, 227, 5, 7864320, "Text"],
Cell[3533005, 99253, 301, 8, 11141120, "Input"],
Cell[3533309, 99263, 262, 5, 7864320, "Text"],
Cell[3533574, 99270, 275, 7, 11141120, "Input"],
Cell[3533852, 99279, 215, 2, 7864320, "Text"],
Cell[3534070, 99283, 408, 10, 11141120, "Input"],
Cell[3534481, 99295, 226, 5, 12845056, "Text"],
Cell[3534710, 99302, 303, 8, 11141120, "Input"],
Cell[3535016, 99312, 291, 7, 7864320, "Text"],
Cell[CellGroupData[{
Cell[3535332, 99323, 149, 3, 11141120, "Input"],
Cell[3535484, 99328, 22225, 635, 141295616, "Output"]
}, Closed]],
Cell[3557724, 99966, 785, 14, 27656192, "Text"],
Cell[CellGroupData[{
Cell[3558534, 99984, 315, 7, 7864320, "Input"],
Cell[3558852, 99993, 583, 10, 14680064, "Message"],
Cell[3559438, 100005, 581, 10, 14680064, "Message"],
Cell[3560022, 100017, 583, 10, 14680064, "Message"],
Cell[3560608, 100029, 518, 10, 5636096, "Message"],
Cell[3561129, 100041, 101, 1, 7733248, "Output"]
}, Closed]],
Cell[3561245, 100045, 317, 6, 12845056, "Text"],
Cell[3561565, 100053, 1288, 32, 8126464, "Text"],
Cell[3562856, 100087, 340, 6, 12845056, "Text"],
Cell[3563199, 100095, 461, 12, 7864320, "Input"],
Cell[3563663, 100109, 322, 6, 12845056, "Text"],
Cell[3563988, 100117, 824, 21, 7864320, "Input",
 Evaluatable->False],
Cell[3564815, 100140, 290, 5, 12845056, "Text"],
Cell[3565108, 100147, 1369, 35, 7864320, "Input",
 Evaluatable->False],
Cell[3566480, 100184, 480, 10, 12845056, "Text"],
Cell[3566963, 100196, 441, 11, 7864320, "Input"],
Cell[3567407, 100209, 194, 3, 7864320, "Text"],
Cell[3567604, 100214, 740, 23, 12976128, "Input"],
Cell[3568347, 100239, 321, 6, 12845056, "Text"],
Cell[CellGroupData[{
Cell[3568693, 100249, 946, 28, 21233664, "Input"],
Cell[3569642, 100279, 167, 2, 11010048, "Output"]
}, Closed]],
Cell[3569824, 100284, 645, 15, 18087936, "Text"],
Cell[CellGroupData[{
Cell[3570494, 100303, 1284, 33, 16252928, "Input"],
Cell[3571781, 100338, 750, 23, 11010048, "Output"]
}, Closed]],
Cell[3572546, 100364, 996, 18, 32768000, "Text"],
Cell[3573545, 100384, 710, 18, 22806528, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[3574292, 100407, 422, 6, 60, "Subsubsection",
 CellTags->"helix"],
Cell[3574717, 100415, 480, 9, 3211264, "Text"],
Cell[3575200, 100426, 575, 13, 2785280, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3575800, 100443, 122, 2, 1966080, "Input"],
Cell[3575925, 100447, 396, 12, 3047424, "Output"]
}, Closed]],
Cell[3576336, 100462, 178, 4, 1966080, "Text"],
Cell[CellGroupData[{
Cell[3576539, 100470, 356, 9, 1966080, "Input"],
Cell[3576898, 100481, 414, 6, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3577349, 100492, 115, 2, 1966080, "Input"],
Cell[3577467, 100496, 375, 6, 2147483647, "Print",
 CellTags->"Info3592989565-2940166"]
}, Closed]],
Cell[3577857, 100505, 1012, 27, 3538944, "Input",
 InitializationCell->True],
Cell[3578872, 100534, 327, 6, 3211264, "Text"],
Cell[CellGroupData[{
Cell[3579224, 100544, 276, 7, 1966080, "Input"],
Cell[3579503, 100553, 756, 21, 3047424, "Output"]
}, Closed]],
Cell[3580274, 100577, 626, 15, 3244032, "Input"],
Cell[CellGroupData[{
Cell[3580925, 100596, 287, 7, 1966080, "Input"],
Cell[3581215, 100605, 465, 12, 3244032, "Output"]
}, Closed]],
Cell[3581695, 100620, 160, 2, 1966080, "Text"],
Cell[CellGroupData[{
Cell[3581880, 100626, 722, 17, 3244032, "Input"],
Cell[3582605, 100645, 1469, 43, 3702784, "Output"]
}, Closed]],
Cell[3584089, 100691, 183, 4, 1966080, "Text"],
Cell[3584275, 100697, 2028, 55, 12779520, "Input"],
Cell[CellGroupData[{
Cell[3586328, 100756, 781, 18, 3244032, "Input"],
Cell[3587112, 100776, 581, 10, 3670016, "Message"],
Cell[3587696, 100788, 583, 10, 3670016, "Message"],
Cell[3588282, 100800, 581, 10, 3670016, "Message"],
Cell[3588866, 100812, 520, 10, 1409024, "Message"],
Cell[3589389, 100824, 10012, 292, 21856256, "Output"]
}, Closed]],
Cell[3599416, 101119, 245, 4, 1966080, "Text"],
Cell[3599664, 101125, 12764, 336, 73793536, "Input"],
Cell[CellGroupData[{
Cell[3612453, 101465, 159, 3, 1966080, "Input"],
Cell[3612615, 101470, 355, 11, 3244032, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3613007, 101486, 432, 14, 3964928, "Input"],
Cell[3613442, 101502, 121, 2, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3613600, 101509, 159, 3, 1966080, "Input"],
Cell[3613762, 101514, 94, 1, 1933312, "Output"]
}, Closed]],
Cell[3613871, 101518, 118, 1, 1966080, "Text"],
Cell[CellGroupData[{
Cell[3614014, 101523, 605, 12, 1966080, "Input"],
Cell[3614622, 101537, 7038, 198, 17596416, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3621697, 101740, 265, 7, 1966080, "Input"],
Cell[3621965, 101749, 72, 1, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3622074, 101755, 260, 7, 1966080, "Input"],
Cell[3622337, 101764, 2616, 81, 6619136, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3624990, 101850, 220, 5, 1966080, "Input"],
Cell[3625213, 101857, 96, 1, 1933312, "Output"]
}, Closed]],
Cell[3625324, 101861, 158, 3, 1966080, "Text"],
Cell[3625485, 101866, 232, 5, 1966080, "Input"],
Cell[CellGroupData[{
Cell[3625742, 101875, 118, 3, 1966080, "Input"],
Cell[3625863, 101880, 876, 32, 3145728, "Output"]
}, Closed]],
Cell[3626754, 101915, 622, 15, 3244032, "Input"],
Cell[3627379, 101932, 525, 13, 2785280, "Input"],
Cell[3627907, 101947, 303, 7, 1966080, "Input"],
Cell[CellGroupData[{
Cell[3628235, 101958, 248, 5, 1966080, "Input"],
Cell[3628486, 101965, 224, 7, 3014656, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3628747, 101977, 159, 3, 1966080, "Input"],
Cell[3628909, 101982, 239, 8, 2883584, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3629185, 101995, 512, 13, 1966080, "Input"],
Cell[3629700, 102010, 241, 3, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3629978, 102018, 529, 13, 1966080, "Input"],
Cell[3630510, 102033, 249, 6, 2981888, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3630796, 102044, 585, 14, 1966080, "Input"],
Cell[3631384, 102060, 173, 6, 3014656, "Output"]
}, Closed]],
Cell[3631572, 102069, 124, 1, 1966080, "Text"],
Cell[CellGroupData[{
Cell[3631721, 102074, 478, 12, 3244032, "Input"],
Cell[3632202, 102088, 226, 7, 3014656, "Output"]
}, Closed]],
Cell[3632443, 102098, 298, 6, 1966080, "Text"],
Cell[3632744, 102106, 652, 15, 3244032, "Input"],
Cell[3633399, 102123, 115, 2, 1966080, "Text"],
Cell[CellGroupData[{
Cell[3633539, 102129, 498, 12, 1966080, "Input"],
Cell[3634040, 102143, 396, 12, 2883584, "Output"]
}, Closed]],
Cell[3634451, 102158, 106, 1, 1966080, "Text"],
Cell[3634560, 102161, 156, 3, 2785280, "Input"],
Cell[3634719, 102166, 93, 1, 1966080, "Text"],
Cell[CellGroupData[{
Cell[3634837, 102171, 208, 4, 2785280, "Input"],
Cell[3635048, 102177, 702, 19, 4063232, "Output"]
}, Closed]],
Cell[3635765, 102199, 208, 3, 1966080, "Text"],
Cell[3635976, 102204, 926, 23, 5308416, "Input"],
Cell[3636905, 102229, 497, 10, 3211264, "Text"],
Cell[CellGroupData[{
Cell[3637427, 102243, 200, 4, 2785280, "Input"],
Cell[3637630, 102249, 654, 19, 4063232, "Output"]
}, Closed]],
Cell[3638299, 102271, 245, 3, 1966080, "Text"],
Cell[CellGroupData[{
Cell[3638569, 102278, 447, 11, 2785280, "Input"],
Cell[3639019, 102291, 2558, 81, 9764864, "Output"]
}, Closed]],
Cell[3641592, 102375, 249, 5, 1966080, "Text"],
Cell[3641844, 102382, 2070, 54, 14024704, "Input"],
Cell[3643917, 102438, 336, 6, 1966080, "Text"],
Cell[3644256, 102446, 348, 9, 2785280, "Input"],
Cell[3644607, 102457, 385, 7, 1966080, "Text"],
Cell[CellGroupData[{
Cell[3645017, 102468, 206, 4, 2785280, "Input"],
Cell[3645226, 102474, 1347, 41, 4521984, "Output"]
}, Closed]],
Cell[3646588, 102518, 674, 15, 2785280, "Input"],
Cell[CellGroupData[{
Cell[3647287, 102537, 382, 8, 2785280, "Input"],
Cell[3647672, 102547, 1627, 55, 7569408, "Output"]
}, Closed]],
Cell[3649314, 102605, 378, 8, 2785280, "Input"],
Cell[3649695, 102615, 225, 5, 1966080, "Text"],
Cell[CellGroupData[{
Cell[3649945, 102624, 260, 7, 2785280, "Input"],
Cell[3650208, 102633, 161, 2, 2752512, "Output"]
}, Closed]],
Cell[3650384, 102638, 128, 1, 1966080, "Text"],
Cell[CellGroupData[{
Cell[3650537, 102643, 759, 17, 4063232, "Input"],
Cell[3651299, 102662, 581, 10, 3670016, "Message"],
Cell[3651883, 102674, 581, 10, 3670016, "Message"],
Cell[3652467, 102686, 581, 10, 3670016, "Message"],
Cell[3653051, 102698, 518, 10, 1409024, "Message"],
Cell[3653572, 102710, 296, 4, 2752512, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3653905, 102719, 863, 18, 4063232, "Input"],
Cell[3654771, 102739, 514, 18, 4751360, "Output"]
}, Closed]],
Cell[3655300, 102760, 473, 8, 3211264, "Text"],
Cell[CellGroupData[{
Cell[3655798, 102772, 943, 21, 4063232, "Input"],
Cell[3656744, 102795, 529, 19, 3964928, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3657310, 102819, 540, 13, 3244032, "Input"],
Cell[3657853, 102834, 72, 1, 2147483647, "Output"]
}, Closed]],
Cell[3657940, 102838, 115, 2, 1638400, "Text"],
Cell[CellGroupData[{
Cell[3658080, 102844, 945, 20, 3244032, "Input"],
Cell[3659028, 102866, 562, 20, 3964928, "Output"]
}, Closed]],
Cell[3659605, 102889, 163, 2, 1966080, "Text"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3659817, 102897, 239, 3, 95, "Subsection"],
Cell[3660059, 102902, 1313, 18, 288, "Text"],
Cell[CellGroupData[{
Cell[3661397, 102924, 186, 2, 76, "Subsubsection"],
Cell[3661586, 102928, 322, 7, 3211264, "Text"],
Cell[3661911, 102937, 640, 18, 2785280, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3662576, 102959, 374, 8, 1966080, "Input"],
Cell[3662953, 102969, 348, 10, 1933312, "Output"]
}, Closed]],
Cell[3663316, 102982, 262, 7, 1966080, "Text"],
Cell[CellGroupData[{
Cell[3663603, 102993, 488, 10, 1966080, "Input"],
Cell[3664094, 103005, 207, 5, 1933312, "Output"]
}, Closed]],
Cell[3664316, 103013, 126, 1, 1966080, "Text"],
Cell[CellGroupData[{
Cell[3664467, 103018, 352, 7, 1966080, "Input"],
Cell[3664822, 103027, 453, 12, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3665312, 103044, 178, 4, 1966080, "Input"],
Cell[3665493, 103050, 429, 11, 1933312, "Output"]
}, Closed]],
Cell[3665937, 103064, 412, 10, 1966080, "Input"],
Cell[CellGroupData[{
Cell[3666374, 103078, 116, 2, 1966080, "Input"],
Cell[3666493, 103082, 827, 12, 8257536, "Print",
 CellTags->"Info3616241832-1704369"]
}, Closed]],
Cell[CellGroupData[{
Cell[3667357, 103099, 183, 5, 1966080, "Input"],
Cell[3667543, 103106, 491, 15, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3668071, 103126, 254, 6, 1966080, "Input"],
Cell[3668328, 103134, 462, 14, 1933312, "Output"]
}, Closed]],
Cell[3668805, 103151, 243, 8, 1966080, "Input"],
Cell[3669051, 103161, 1224, 24, 1966080, "Input"],
Cell[3670278, 103187, 1176, 23, 1966080, "Input"],
Cell[3671457, 103212, 116, 1, 1966080, "Text"],
Cell[3671576, 103215, 257, 6, 2785280, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3671858, 103225, 136, 4, 1966080, "Input"],
Cell[3671997, 103231, 352, 10, 1933312, "Output"]
}, Closed]],
Cell[3672364, 103244, 1576, 31, 1966080, "Input"],
Cell[CellGroupData[{
Cell[3673965, 103279, 136, 4, 1966080, "Input"],
Cell[3674104, 103285, 317, 9, 1933312, "Output"]
}, Closed]],
Cell[3674436, 103297, 1398, 26, 1966080, "Input"],
Cell[3675837, 103325, 206, 4, 3211264, "Text"],
Cell[CellGroupData[{
Cell[3676068, 103333, 674, 18, 1966080, "Input"],
Cell[3676745, 103353, 719, 22, 1933312, "Output"]
}, Closed]],
Cell[3677479, 103378, 327, 5, 3211264, "Text"],
Cell[CellGroupData[{
Cell[3677831, 103387, 553, 14, 1966080, "Input"],
Cell[3678387, 103403, 2159, 70, 3473408, "Output"]
}, Closed]],
Cell[3680561, 103476, 110, 1, 1966080, "Text"],
Cell[3680674, 103479, 533, 18, 1966080, "Input"],
Cell[3681210, 103499, 373, 7, 3211264, "Text"],
Cell[CellGroupData[{
Cell[3681608, 103510, 467, 14, 1966080, "Input"],
Cell[3682078, 103526, 578, 19, 2097152, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3682693, 103550, 1096, 30, 4489216, "Input"],
Cell[3683792, 103582, 272, 8, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3684101, 103595, 465, 14, 1966080, "Input"],
Cell[3684569, 103611, 1449, 45, 3571712, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3686055, 103661, 1291, 36, 4489216, "Input"],
Cell[3687349, 103699, 830, 26, 2097152, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3688216, 103730, 1255, 32, 5734400, "Input"],
Cell[3689474, 103764, 568, 17, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3690079, 103786, 1093, 27, 5734400, "Input"],
Cell[3691175, 103815, 143, 2, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3691355, 103822, 1298, 33, 5734400, "Input"],
Cell[3692656, 103857, 280, 8, 2818048, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3692973, 103870, 1194, 29, 4489216, "Input"],
Cell[3694170, 103901, 817, 25, 2818048, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3695024, 103931, 420, 9, 1966080, "Input"],
Cell[3695447, 103942, 1958, 60, 3571712, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3697442, 104007, 984, 26, 4489216, "Input"],
Cell[3698429, 104035, 805, 24, 2850816, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3699271, 104064, 668, 15, 3244032, "Input"],
Cell[3699942, 104081, 94, 1, 1933312, "Output"]
}, Closed]],
Cell[3700051, 104085, 384, 8, 3211264, "Text"],
Cell[CellGroupData[{
Cell[3700460, 104097, 1074, 27, 4489216, "Input"],
Cell[3701537, 104126, 855, 26, 2850816, "Output"]
}, Closed]],
Cell[3702407, 104155, 733, 14, 5701632, "Text"],
Cell[CellGroupData[{
Cell[3703165, 104173, 1171, 29, 4489216, "Input"],
Cell[3704339, 104204, 610, 19, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3704986, 104228, 190, 5, 1966080, "Input"],
Cell[3705179, 104235, 326, 10, 1933312, "Output"]
}, Closed]],
Cell[3705520, 104248, 180, 4, 1966080, "Text"],
Cell[3705703, 104254, 314, 9, 1966080, "Input"],
Cell[3706020, 104265, 349, 6, 3211264, "Text"],
Cell[CellGroupData[{
Cell[3706394, 104275, 120, 2, 1966080, "Input"],
Cell[3706517, 104279, 382, 6, 4915200, "Print",
 CellTags->"Info3616243093-1704369"]
}, Closed]],
Cell[CellGroupData[{
Cell[3706936, 104290, 1004, 24, 5734400, "Input"],
Cell[3707943, 104316, 708, 20, 1933312, "Output"]
}, Closed]],
Cell[3708666, 104339, 635, 10, 3211264, "Text"],
Cell[3709304, 104351, 526, 13, 1966080, "Input"],
Cell[3709833, 104366, 673, 10, 5701632, "Text"],
Cell[CellGroupData[{
Cell[3710531, 104380, 235, 6, 1966080, "Input"],
Cell[3710769, 104388, 2735, 82, 4554752, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3713541, 104475, 927, 28, 3571712, "Input"],
Cell[3714471, 104505, 832, 25, 2850816, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3715340, 104535, 1033, 29, 3571712, "Input"],
Cell[3716376, 104566, 855, 26, 2850816, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[3717280, 104598, 228, 3, 60, "Subsubsection"],
Cell[3717511, 104603, 580, 11, 3211264, "Text",
 CellTags->"sfrev"],
Cell[CellGroupData[{
Cell[3718116, 104618, 114, 2, 1966080, "Input"],
Cell[CellGroupData[{
Cell[3718255, 104624, 121, 2, 2654208, "Print",
 CellTags->"Info3614344124-9136096"],
Cell[3718379, 104628, 781, 22, 1409024, "Print",
 CellTags->"Info3614344124-9136096"]
}, Closed]]
}, Closed]],
Cell[3719187, 104654, 347, 10, 2785280, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3719559, 104668, 151, 4, 1966080, "Input"],
Cell[3719713, 104674, 323, 9, 1933312, "Output"]
}, Closed]],
Cell[3720051, 104686, 119, 1, 1966080, "Text"],
Cell[CellGroupData[{
Cell[3720195, 104691, 268, 6, 1966080, "Input"],
Cell[3720466, 104699, 5204, 152, 13664256, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3725707, 104856, 170, 3, 1966080, "Input"],
Cell[3725880, 104861, 996, 31, 3014656, "Output"]
}, Closed]],
Cell[3726891, 104895, 195, 4, 1966080, "Text"],
Cell[CellGroupData[{
Cell[3727111, 104903, 900, 22, 2162688, "Input"],
Cell[3728014, 104927, 2360, 65, 4653056, "Output"]
}, Closed]],
Cell[3730389, 104995, 107, 1, 1966080, "Text"],
Cell[CellGroupData[{
Cell[3730521, 105000, 516, 15, 1966080, "Input"],
Cell[3731040, 105017, 991, 28, 2654208, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3732068, 105050, 383, 11, 1966080, "Input"],
Cell[3732454, 105063, 389, 10, 2654208, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3732880, 105078, 246, 5, 1966080, "Input"],
Cell[3733129, 105085, 168, 2, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3733334, 105092, 384, 11, 1966080, "Input"],
Cell[3733721, 105105, 359, 9, 2654208, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3734117, 105119, 225, 5, 1966080, "Input"],
Cell[3734345, 105126, 150, 2, 1933312, "Output"]
}, Closed]],
Cell[3734510, 105131, 662, 15, 3211264, "Text"],
Cell[CellGroupData[{
Cell[3735197, 105150, 118, 2, 1966080, "Input"],
Cell[3735318, 105154, 288, 5, 3801088, "Print",
 CellTags->"Info3616244308-7460579"]
}, Closed]],
Cell[3735621, 105162, 277, 7, 1966080, "Input"],
Cell[3735901, 105171, 423, 12, 1966080, "Input"],
Cell[3736327, 105185, 144, 1, 1966080, "Text"],
Cell[CellGroupData[{
Cell[3736496, 105190, 320, 9, 1966080, "Input"],
Cell[3736819, 105201, 266, 6, 2490368, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3737122, 105212, 1041, 30, 3244032, "Input"],
Cell[3738166, 105244, 142, 2, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3738345, 105251, 722, 17, 1966080, "Input"],
Cell[3739070, 105270, 214, 3, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3739321, 105278, 646, 16, 1966080, "Input"],
Cell[3739970, 105296, 405, 10, 3211264, "Output"]
}, Closed]],
Cell[3740390, 105309, 528, 14, 1966080, "Input"],
Cell[3740921, 105325, 215, 5, 1966080, "Text"],
Cell[3741139, 105332, 553, 15, 1966080, "Input"],
Cell[CellGroupData[{
Cell[3741717, 105351, 175, 4, 1966080, "Input"],
Cell[3741895, 105357, 386, 10, 2654208, "Output"]
}, Closed]],
Cell[3742296, 105370, 400, 7, 3211264, "Text"],
Cell[3742699, 105379, 808, 19, 3244032, "Input"],
Cell[3743510, 105400, 112, 1, 1966080, "Text"],
Cell[CellGroupData[{
Cell[3743647, 105405, 487, 12, 1966080, "Input"],
Cell[3744137, 105419, 216, 3, 1933312, "Output"]
}, Closed]],
Cell[3744368, 105425, 474, 13, 1966080, "Input"],
Cell[3744845, 105440, 16, 0, 1966080, "Text"],
Cell[3744864, 105442, 221, 4, 1966080, "Text"],
Cell[CellGroupData[{
Cell[3745110, 105450, 420, 12, 1966080, "Input"],
Cell[3745533, 105464, 882, 27, 2654208, "Output"]
}, Closed]],
Cell[3746430, 105494, 497, 8, 4456448, "Text"],
Cell[CellGroupData[{
Cell[3746952, 105506, 388, 12, 1966080, "Input"],
Cell[3747343, 105520, 717, 21, 2654208, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3748097, 105546, 487, 11, 1966080, "Input"],
Cell[3748587, 105559, 512, 15, 2162688, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3749136, 105579, 595, 17, 1966080, "Input"],
Cell[3749734, 105598, 854, 24, 2654208, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3750625, 105627, 385, 9, 1966080, "Input"],
Cell[3751013, 105638, 341, 8, 2162688, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3751391, 105651, 1329, 35, 3571712, "Input"],
Cell[3752723, 105688, 3208, 97, 20348928, "Output"]
}, Closed]],
Cell[3755946, 105788, 500, 8, 3211264, "Text"],
Cell[3756449, 105798, 211, 4, 3211264, "Text"],
Cell[CellGroupData[{
Cell[3756685, 105806, 600, 15, 1966080, "Input"],
Cell[3757288, 105823, 716, 21, 2654208, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3758041, 105849, 203, 5, 1966080, "Input"],
Cell[3758247, 105856, 412, 11, 2654208, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3758696, 105872, 509, 12, 1966080, "Input"],
Cell[3759208, 105886, 168, 2, 1933312, "Output"]
}, Closed]],
Cell[3759391, 105891, 244, 4, 1966080, "Text"],
Cell[3759638, 105897, 494, 13, 1966080, "Input"],
Cell[CellGroupData[{
Cell[3760157, 105914, 123, 2, 1966080, "Input"],
Cell[3760283, 105918, 817, 26, 2654208, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3761137, 105949, 409, 12, 1966080, "Input"],
Cell[3761549, 105963, 668, 19, 2654208, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3762254, 105987, 487, 11, 1966080, "Input"],
Cell[3762744, 106000, 510, 15, 2162688, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3763291, 106020, 621, 17, 1966080, "Input"],
Cell[3763915, 106039, 599, 17, 2654208, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3764551, 106061, 385, 9, 1966080, "Input"],
Cell[3764939, 106072, 320, 8, 2162688, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3765296, 106085, 1381, 36, 3571712, "Input"],
Cell[3766680, 106123, 3158, 95, 20348928, "Output"]
}, Closed]],
Cell[3769853, 106221, 192, 4, 1966080, "Text"],
Cell[CellGroupData[{
Cell[3770070, 106229, 1898, 52, 10780672, "Input"],
Cell[3771971, 106283, 120, 2, 1933312, "Output"]
}, Closed]],
Cell[3772106, 106288, 323, 8, 3211264, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[3772466, 106301, 300, 4, 60, "Subsubsection"],
Cell[3772769, 106307, 250, 5, 240, "Text"],
Cell[CellGroupData[{
Cell[3773044, 106316, 178, 5, 240, "Input"],
Cell[3773225, 106323, 337, 9, 1933312, "Output"]
}, Closed]],
Cell[3773577, 106335, 108, 1, 200, "Text"],
Cell[CellGroupData[{
Cell[3773710, 106340, 276, 7, 240, "Input"],
Cell[3773989, 106349, 634, 19, 2883584, "Output"]
}, Closed]],
Cell[3774638, 106371, 153, 3, 200, "Text"],
Cell[CellGroupData[{
Cell[3774816, 106378, 281, 7, 240, "Input"],
Cell[3775100, 106387, 483, 16, 2883584, "Output"]
}, Closed]],
Cell[3775598, 106406, 283, 5, 200, "Text"],
Cell[3775884, 106413, 533, 15, 240, "Input"],
Cell[3776420, 106430, 196, 4, 240, "Text"],
Cell[3776619, 106436, 587, 16, 396, "Input"],
Cell[3777209, 106454, 127, 2, 240, "Input"],
Cell[3777339, 106458, 204, 4, 240, "Text"],
Cell[3777546, 106464, 212, 5, 240, "Input"],
Cell[CellGroupData[{
Cell[3777783, 106473, 237, 6, 240, "Input"],
Cell[3778023, 106481, 72, 1, 1933312, "Output"]
}, Closed]],
Cell[3778110, 106485, 241, 5, 200, "Text"],
Cell[3778354, 106492, 679, 19, 396, "Input"],
Cell[3779036, 106513, 129, 2, 240, "Input"],
Cell[3779168, 106517, 283, 4, 240, "Text"],
Cell[3779454, 106523, 657, 21, 240, "Input",
 InitializationCell->True],
Cell[3780114, 106546, 288, 6, 240, "Text"],
Cell[CellGroupData[{
Cell[3780427, 106556, 897, 22, 240, "Input"],
Cell[3781327, 106580, 879, 14, 6291456, "Message"],
Cell[3782209, 106596, 868, 15, 6291456, "Message"],
Cell[3783080, 106613, 37676, 997, 103743488, "Output"]
}, Closed]],
Cell[3820771, 107613, 153, 3, 176, "Input"],
Cell[CellGroupData[{
Cell[3820949, 107620, 444, 11, 240, "Input"],
Cell[3821396, 107633, 16806, 495, 48922624, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3838239, 108133, 570, 12, 176, "Input"],
Cell[3838812, 108147, 16830, 496, 48922624, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3855679, 108648, 312, 8, 176, "Input"],
Cell[3855994, 108658, 5858, 189, 19857408, "Output"]
}, Closed]],
Cell[3861867, 108850, 93, 1, 200, "Text"],
Cell[3861963, 108853, 8749, 236, 5260, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3870737, 109093, 362, 8, 240, "Input"],
Cell[3871102, 109103, 5876, 190, 23134208, "Output"]
}, Closed]],
Cell[3876993, 109296, 128, 2, 200, "Text"],
Cell[3877124, 109300, 8830, 238, 5260, "Input",
 InitializationCell->True],
Cell[3885957, 109540, 186, 3, 240, "Text"],
Cell[CellGroupData[{
Cell[3886168, 109547, 359, 10, 240, "Input"],
Cell[3886530, 109559, 70, 1, 1933312, "Output"]
}, Closed]],
Cell[3886615, 109563, 293, 7, 200, "Text"],
Cell[3886911, 109572, 441, 9, 696, "Text"],
Cell[CellGroupData[{
Cell[3887377, 109585, 187, 4, 240, "Input"],
Cell[3887567, 109591, 434, 9, 2457600, "Message"],
Cell[3888004, 109602, 432, 9, 2457600, "Message"],
Cell[3888439, 109613, 432, 9, 2457600, "Message"],
Cell[3888874, 109624, 517, 10, 1409024, "Message"],
Cell[3889394, 109636, 538, 10, 1835008, "Message"],
Cell[3889935, 109648, 82, 1, 1933312, "Output"]
}, Closed]],
Cell[3890032, 109652, 236, 4, 352, "Text"],
Cell[CellGroupData[{
Cell[3890293, 109660, 768, 20, 240, "Input"],
Cell[3891064, 109682, 266, 7, 1933312, "Output"]
}, Closed]],
Cell[3891345, 109692, 177, 2, 200, "Text"],
Cell[3891525, 109696, 373, 10, 240, "Input"],
Cell[3891901, 109708, 484, 14, 240, "Input"],
Cell[3892388, 109724, 247, 5, 240, "Text"],
Cell[CellGroupData[{
Cell[3892660, 109733, 245, 6, 240, "Input"],
Cell[3892908, 109741, 70, 1, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3893015, 109747, 269, 8, 176, "Input"],
Cell[3893287, 109757, 72, 1, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3893396, 109763, 354, 10, 176, "Input"],
Cell[3893753, 109775, 98, 1, 1933312, "Output"]
}, Closed]],
Cell[3893866, 109779, 348, 6, 352, "Text"],
Cell[CellGroupData[{
Cell[3894239, 109789, 867, 21, 240, "Input"],
Cell[3895109, 109812, 492, 9, 1409024, "Message"],
Cell[3895604, 109823, 241, 7, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3895882, 109835, 241, 5, 176, "Input"],
Cell[3896126, 109842, 2782, 95, 14090240, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3898945, 109942, 240, 5, 176, "Input"],
Cell[3899188, 109949, 458, 9, 2457600, "Message"],
Cell[3899649, 109960, 488, 9, 1409024, "Message"],
Cell[3900140, 109971, 106, 1, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3900283, 109977, 346, 10, 176, "Input"],
Cell[3900632, 109989, 437, 9, 2686976, "Message"],
Cell[3901072, 110000, 435, 9, 2686976, "Message"],
Cell[3901510, 110011, 435, 9, 2686976, "Message"],
Cell[3901948, 110022, 515, 10, 1409024, "Message"],
Cell[3902466, 110034, 474, 9, 1409024, "Message"],
Cell[3902943, 110045, 539, 10, 3964928, "Message"],
Cell[3903485, 110057, 544, 10, 3964928, "Message"],
Cell[3904032, 110069, 519, 10, 1409024, "Message"],
Cell[3904554, 110081, 106, 1, 1933312, "Output"]
}, Closed]],
Cell[3904675, 110085, 739, 14, 352, "Text"],
Cell[CellGroupData[{
Cell[3905439, 110103, 365, 10, 240, "Input"],
Cell[3905807, 110115, 72, 1, 1933312, "Output"]
}, Closed]],
Cell[3905894, 110119, 99, 1, 200, "Text"],
Cell[3905996, 110122, 160, 2, 240, "Text"],
Cell[CellGroupData[{
Cell[3906181, 110128, 123, 2, 240, "Input"],
Cell[3906307, 110132, 320, 5, 464, "Print",
 CellTags->"Info3616509861-3077392"]
}, Open  ]],
Cell[3906642, 110140, 230, 5, 240, "Input"],
Cell[3906875, 110147, 162, 2, 240, "Text"],
Cell[CellGroupData[{
Cell[3907062, 110153, 338, 6, 240, "Input"],
Cell[3907403, 110161, 621, 17, 2490368, "Output"]
}, Closed]],
Cell[3908039, 110181, 182, 2, 200, "Text"],
Cell[CellGroupData[{
Cell[3908246, 110187, 202, 5, 240, "Input"],
Cell[3908451, 110194, 290, 8, 1933312, "Output"]
}, Closed]],
Cell[3908756, 110205, 199, 2, 200, "Text"],
Cell[CellGroupData[{
Cell[3908980, 110211, 186, 4, 240, "Input"],
Cell[3909169, 110217, 388, 12, 2490368, "Output"]
}, Closed]],
Cell[3909572, 110232, 279, 6, 200, "Text"],
Cell[3909854, 110240, 689, 19, 240, "Input"],
Cell[3910546, 110261, 128, 1, 240, "Text"],
Cell[CellGroupData[{
Cell[3910699, 110266, 239, 6, 240, "Input"],
Cell[3910941, 110274, 582, 20, 2916352, "Output"]
}, Closed]],
Cell[3911538, 110297, 493, 14, 176, "Input"],
Cell[3912034, 110313, 547, 16, 240, "Input"],
Cell[3912584, 110331, 487, 12, 240, "Input"],
Cell[3913074, 110345, 138, 1, 240, "Text"],
Cell[CellGroupData[{
Cell[3913237, 110350, 155, 3, 240, "Input"],
Cell[3913395, 110355, 72, 1, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3913504, 110361, 263, 7, 176, "Input"],
Cell[3913770, 110370, 435, 9, 2686976, "Message"],
Cell[3914208, 110381, 437, 9, 2686976, "Message"],
Cell[3914648, 110392, 474, 9, 1409024, "Message"],
Cell[3915125, 110403, 82, 1, 1933312, "Output"]
}, Closed]],
Cell[3915222, 110407, 136, 2, 200, "Text"],
Cell[3915361, 110411, 414, 11, 240, "Input"],
Cell[3915778, 110424, 106, 1, 240, "Text"],
Cell[CellGroupData[{
Cell[3915909, 110429, 383, 11, 240, "Input"],
Cell[3916295, 110442, 96, 1, 1933312, "Output"]
}, Closed]],
Cell[3916406, 110446, 200, 4, 200, "Text"],
Cell[CellGroupData[{
Cell[3916631, 110454, 371, 10, 240, "Input"],
Cell[3917005, 110466, 458, 9, 2457600, "Message"],
Cell[3917466, 110477, 456, 9, 2457600, "Message"],
Cell[3917925, 110488, 458, 9, 2457600, "Message"],
Cell[3918386, 110499, 541, 10, 1409024, "Message"],
Cell[3918930, 110511, 500, 9, 1409024, "Message"],
Cell[3919433, 110522, 106, 1, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3919576, 110528, 481, 10, 176, "Input"],
Cell[3920060, 110540, 8471, 263, 22183936, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3928568, 110808, 213, 5, 176, "Input"],
Cell[3928784, 110815, 236, 6, 2686976, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3929057, 110826, 645, 14, 176, "Input"],
Cell[3929705, 110842, 430, 14, 3178496, "Output"]
}, Closed]],
Cell[3930150, 110859, 476, 10, 176, "Input"],
Cell[CellGroupData[{
Cell[3930651, 110873, 692, 14, 240, "Input"],
Cell[3931346, 110889, 566, 20, 3309568, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3931949, 110914, 541, 11, 176, "Input"],
Cell[3932493, 110927, 6773, 119, 15302656, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[3939315, 111052, 419, 7, 60, "Subsubsection"],
Cell[3939737, 111061, 409, 7, 4456448, "Text"],
Cell[CellGroupData[{
Cell[3940171, 111072, 482, 12, 1966080, "Input"],
Cell[3940656, 111086, 1528, 55, 5439488, "Output"]
}, Closed]],
Cell[3942199, 111144, 163, 2, 1966080, "Text"],
Cell[3942365, 111148, 1087, 33, 5734400, "Input"],
Cell[CellGroupData[{
Cell[3943477, 111185, 605, 16, 1966080, "Input"],
Cell[3944085, 111203, 70, 1, 1933312, "Output"]
}, Closed]],
Cell[3944170, 111207, 929, 21, 3244032, "Input"],
Cell[3945102, 111230, 397, 7, 3211264, "Text"],
Cell[CellGroupData[{
Cell[3945524, 111241, 346, 10, 1966080, "Input"],
Cell[3945873, 111253, 75, 1, 1933312, "Output"]
}, Closed]],
Cell[3945963, 111257, 105, 1, 1966080, "Text"],
Cell[CellGroupData[{
Cell[3946093, 111262, 655, 15, 1966080, "Input"],
Cell[3946751, 111279, 5973, 190, 19824640, "Output"]
}, Closed]],
Cell[3952739, 111472, 114, 1, 1966080, "Text"],
Cell[3952856, 111475, 8269, 226, 38109184, "Input"],
Cell[3961128, 111703, 815, 19, 3244032, "Input"],
Cell[3961946, 111724, 818, 20, 3244032, "Input"],
Cell[3962767, 111746, 255, 6, 1966080, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[3963059, 111757, 522, 8, 60, "Subsubsection"],
Cell[CellGroupData[{
Cell[3963606, 111769, 525, 13, 240, "Input"],
Cell[3964134, 111784, 1170, 41, 5439488, "Output"]
}, Closed]],
Cell[3965319, 111828, 112, 1, 200, "Text"],
Cell[3965434, 111831, 1096, 34, 852, "Input"],
Cell[CellGroupData[{
Cell[3966555, 111869, 590, 16, 240, "Input"],
Cell[3967148, 111887, 145, 2, 1933312, "Output"]
}, Closed]],
Cell[3967308, 111892, 1007, 23, 332, "Input"],
Cell[3968318, 111917, 260, 5, 392, "Text"],
Cell[CellGroupData[{
Cell[3968603, 111926, 679, 15, 240, "Input"],
Cell[3969285, 111943, 5882, 189, 19824640, "Output"]
}, Closed]],
Cell[3975182, 112135, 8288, 226, 4892, "Input"],
Cell[3983473, 112363, 1063, 24, 396, "Input"],
Cell[3984539, 112389, 1056, 23, 396, "Input"],
Cell[3985598, 112414, 247, 6, 240, "Input"],
Cell[3985848, 112422, 304, 6, 240, "Text"],
Cell[3986155, 112430, 205, 4, 240, "Text"],
Cell[3986363, 112436, 373, 11, 240, "Input"],
Cell[3986739, 112449, 455, 11, 240, "Input"],
Cell[CellGroupData[{
Cell[3987219, 112464, 497, 13, 240, "Input"],
Cell[3987719, 112479, 1508, 37, 5603328, "Output"]
}, Closed]],
Cell[3989242, 112519, 288, 5, 352, "Text"],
Cell[3989533, 112526, 546, 14, 240, "Input"],
Cell[3990082, 112542, 114, 2, 240, "Text"],
Cell[3990199, 112546, 459, 13, 240, "Input"],
Cell[3990661, 112561, 508, 14, 240, "Input"],
Cell[3991172, 112577, 646, 15, 240, "Input"],
Cell[3991821, 112594, 698, 16, 240, "Input"],
Cell[3992522, 112612, 798, 18, 240, "Input"],
Cell[3993323, 112632, 370, 6, 392, "Text"],
Cell[3993696, 112640, 1362, 29, 396, "Input"],
Cell[3995061, 112671, 416, 12, 240, "Input"],
Cell[3995480, 112685, 467, 13, 240, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[3995984, 112703, 190, 2, 60, "Subsubsection"],
Cell[3996177, 112707, 515, 11, 3211264, "Text"],
Cell[CellGroupData[{
Cell[3996717, 112722, 252, 6, 1966080, "Input"],
Cell[3996972, 112730, 352, 10, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3997361, 112745, 235, 6, 1966080, "Input"],
Cell[3997599, 112753, 2782, 83, 4554752, "Output"]
}, Closed]],
Cell[4000396, 112839, 830, 22, 2031616, "Text"],
Cell[CellGroupData[{
Cell[4001251, 112865, 1637, 42, 3571712, "Input"],
Cell[4002891, 112909, 239, 7, 2818048, "Output"]
}, Closed]],
Cell[4003145, 112919, 222, 5, 1966080, "Text"],
Cell[CellGroupData[{
Cell[4003392, 112928, 1613, 41, 2162688, "Input"],
Cell[4005008, 112971, 1049, 32, 1933312, "Output"]
}, Closed]],
Cell[4006072, 113006, 132, 1, 1966080, "Text"],
Cell[CellGroupData[{
Cell[4006229, 113011, 634, 17, 1966080, "Input"],
Cell[4006866, 113030, 376, 10, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4007279, 113045, 790, 19, 1966080, "Input"],
Cell[4008072, 113066, 886, 27, 1933312, "Output"]
}, Closed]],
Cell[4008973, 113096, 149, 2, 1966080, "Text"],
Cell[CellGroupData[{
Cell[4009147, 113102, 682, 13, 1966080, "Input"],
Cell[4009832, 113117, 844, 26, 2818048, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4010713, 113148, 734, 14, 1966080, "Input"],
Cell[4011450, 113164, 855, 26, 2850816, "Output"]
}, Closed]],
Cell[4012320, 113193, 94, 1, 1966080, "Text"],
Cell[CellGroupData[{
Cell[4012439, 113198, 1601, 40, 3112960, "Input"],
Cell[4014043, 113240, 97, 1, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4014177, 113246, 774, 14, 1966080, "Input"],
Cell[4014954, 113262, 334, 8, 2818048, "Output"]
}, Closed]],
Cell[4015303, 113273, 145, 4, 3211264, "Text"],
Cell[CellGroupData[{
Cell[4015473, 113281, 407, 11, 1966080, "Input"],
Cell[4015883, 113294, 478, 16, 2260992, "Output"]
}, Closed]],
Cell[4016376, 113313, 93, 1, 1966080, "Text"],
Cell[4016472, 113316, 490, 15, 1966080, "Input",
 Evaluatable->False],
Cell[4016965, 113333, 494, 8, 3211264, "Text"],
Cell[4017462, 113343, 329, 9, 1966080, "Input"],
Cell[CellGroupData[{
Cell[4017816, 113356, 413, 12, 1966080, "Input"],
Cell[4018232, 113370, 75, 1, 1933312, "Output"]
}, Closed]],
Cell[4018322, 113374, 714, 12, 3211264, "Text"],
Cell[4019039, 113388, 681, 19, 3244032, "Input"],
Cell[4019723, 113409, 175, 2, 1966080, "Text"],
Cell[4019901, 113413, 353, 10, 1966080, "Input"],
Cell[4020257, 113425, 113, 1, 1966080, "Text"],
Cell[4020373, 113428, 698, 18, 1966080, "Input"],
Cell[4021074, 113448, 534, 9, 4456448, "Text"],
Cell[CellGroupData[{
Cell[4021633, 113461, 282, 7, 1966080, "Input"],
Cell[4021918, 113470, 228, 7, 2457600, "Output"]
}, Closed]],
Cell[4022161, 113480, 105, 1, 1966080, "Text"],
Cell[CellGroupData[{
Cell[4022291, 113485, 303, 9, 1966080, "Input"],
Cell[4022597, 113496, 202, 7, 2228224, "Output"]
}, Closed]],
Cell[4022814, 113506, 239, 5, 1966080, "Text"],
Cell[CellGroupData[{
Cell[4023078, 113515, 613, 16, 1966080, "Input"],
Cell[4023694, 113533, 280, 9, 3440640, "Output"]
}, Closed]],
Cell[4023989, 113545, 267, 5, 3211264, "Text"],
Cell[4024259, 113552, 472, 14, 3244032, "Input"],
Cell[4024734, 113568, 141, 2, 1966080, "Text"],
Cell[CellGroupData[{
Cell[4024900, 113574, 616, 17, 1966080, "Input"],
Cell[4025519, 113593, 121, 2, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4025677, 113600, 293, 9, 1966080, "Input"],
Cell[4025973, 113611, 434, 9, 2457600, "Message"],
Cell[4026410, 113622, 464, 9, 1409024, "Message"],
Cell[4026877, 113633, 249, 7, 1933312, "Output"]
}, Closed]],
Cell[4027141, 113643, 194, 4, 1966080, "Text"],
Cell[4027338, 113649, 683, 20, 3244032, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[4028058, 113674, 339, 6, 114, "Subsubsection"],
Cell[4028400, 113682, 161, 3, 1966080, "Text"],
Cell[4028564, 113687, 401, 14, 3309568, "Input",
 Evaluatable->False],
Cell[4028968, 113703, 109, 1, 1966080, "Text"],
Cell[4029080, 113706, 454, 15, 3604480, "Input",
 Evaluatable->False],
Cell[4029537, 113723, 780, 21, 3276800, "Text"],
Cell[CellGroupData[{
Cell[4030342, 113748, 354, 9, 1966080, "Input"],
Cell[4030699, 113759, 170, 6, 3440640, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4030906, 113770, 608, 16, 1966080, "Input"],
Cell[4031517, 113788, 173, 3, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4031727, 113796, 999, 27, 3244032, "Input"],
Cell[4032729, 113825, 530, 16, 2490368, "Output"]
}, Closed]],
Cell[4033274, 113844, 135, 1, 1966080, "Text"],
Cell[CellGroupData[{
Cell[4033434, 113849, 330, 6, 1966080, "Input"],
Cell[4033767, 113857, 582, 16, 2490368, "Output"]
}, Closed]],
Cell[4034364, 113876, 125, 1, 1966080, "Text"],
Cell[4034492, 113879, 478, 13, 2031616, "Text"],
Cell[4034973, 113894, 202, 5, 1966080, "Text"],
Cell[4035178, 113901, 1067, 25, 3244032, "Input"],
Cell[4036248, 113928, 283, 6, 3211264, "Text"],
Cell[4036534, 113936, 379, 11, 2031616, "Text"],
Cell[4036916, 113949, 134, 1, 1966080, "Text"],
Cell[4037053, 113952, 455, 17, 4128768, "Input",
 Evaluatable->False],
Cell[4037511, 113971, 1458, 31, 5734400, "Input"],
Cell[4038972, 114004, 236, 5, 1966080, "Text"],
Cell[4039211, 114011, 745, 19, 3244032, "Input"],
Cell[4039959, 114032, 250, 5, 1966080, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[4040246, 114042, 335, 6, 114, "Subsubsection"],
Cell[4040584, 114050, 162, 3, 240, "Text"],
Cell[CellGroupData[{
Cell[4040771, 114057, 508, 13, 240, "Input"],
Cell[4041282, 114072, 478, 15, 2523136, "Output"]
}, Closed]],
Cell[4041775, 114090, 554, 16, 176, "Input"],
Cell[4042332, 114108, 200, 3, 240, "Text"],
Cell[4042535, 114113, 114, 1, 240, "Text"],
Cell[CellGroupData[{
Cell[4042674, 114118, 614, 19, 240, "Input"],
Cell[4043291, 114139, 198, 5, 2162688, "Output"]
}, Closed]],
Cell[4043504, 114147, 91, 1, 200, "Text"],
Cell[4043598, 114150, 308, 9, 240, "Input"],
Cell[CellGroupData[{
Cell[4043931, 114163, 174, 4, 240, "Input"],
Cell[4044108, 114169, 223, 6, 2162688, "Output"]
}, Closed]],
Cell[4044346, 114178, 123, 1, 200, "Text"],
Cell[4044472, 114181, 595, 16, 340, "Input"],
Cell[CellGroupData[{
Cell[4045092, 114201, 375, 10, 240, "Input"],
Cell[4045470, 114213, 760, 26, 2883584, "Output"]
}, Closed]],
Cell[4046245, 114242, 93, 1, 200, "Text"],
Cell[4046341, 114245, 1274, 40, 1156, "Input"],
Cell[4047618, 114287, 113, 1, 240, "Text"],
Cell[4047734, 114290, 718, 18, 396, "Input"],
Cell[CellGroupData[{
Cell[4048477, 114312, 484, 14, 240, "Input"],
Cell[4048964, 114328, 135, 4, 2686976, "Output"]
}, Closed]],
Cell[4049114, 114335, 160, 3, 200, "Text"],
Cell[4049277, 114340, 815, 20, 396, "Input"],
Cell[4050095, 114362, 117, 1, 240, "Text"],
Cell[4050215, 114365, 302, 7, 240, "Input"],
Cell[4050520, 114374, 16, 0, 240, "Text"],
Cell[4050539, 114376, 138, 1, 240, "Text"],
Cell[CellGroupData[{
Cell[4050702, 114381, 394, 12, 240, "Input"],
Cell[4051099, 114395, 127, 3, 1933312, "Output"]
}, Closed]],
Cell[4051241, 114401, 190, 4, 200, "Text"],
Cell[CellGroupData[{
Cell[4051456, 114409, 133, 4, 240, "Input"],
Cell[4051592, 114415, 328, 10, 1933312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4051957, 114430, 221, 6, 176, "Input"],
Cell[4052181, 114438, 370, 12, 1933312, "Output"]
}, Closed]],
Cell[4052566, 114453, 158, 3, 200, "Text"],
Cell[CellGroupData[{
Cell[4052749, 114460, 367, 9, 240, "Input"],
Cell[4053119, 114471, 370, 11, 1933312, "Output"]
}, Closed]],
Cell[4053504, 114485, 309, 6, 352, "Text"],
Cell[4053816, 114493, 381, 12, 240, "Text"],
Cell[4054200, 114507, 107, 1, 240, "Text"],
Cell[4054310, 114510, 366, 10, 240, "Input"],
Cell[CellGroupData[{
Cell[4054701, 114524, 814, 22, 396, "Input"],
Cell[4055518, 114548, 542, 18, 3833856, "Output"]
}, Closed]],
Cell[4056075, 114569, 351, 7, 504, "Text"],
Cell[CellGroupData[{
Cell[4056451, 114580, 360, 10, 240, "Input"],
Cell[4056814, 114592, 126, 2, 1933312, "Output"]
}, Closed]],
Cell[4056955, 114597, 107, 1, 200, "Text"],
Cell[4057065, 114600, 298, 8, 240, "Input"],
Cell[CellGroupData[{
Cell[4057388, 114612, 197, 5, 240, "Input"],
Cell[4057588, 114619, 168, 5, 3080192, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4057793, 114629, 875, 27, 332, "Input"],
Cell[4058671, 114658, 355, 11, 2818048, "Output"]
}, Closed]],
Cell[4059041, 114672, 611, 19, 484, "Input"],
Cell[4059655, 114693, 1056, 25, 396, "Input"],
Cell[4060714, 114720, 169, 2, 240, "Text"],
Cell[CellGroupData[{
Cell[4060908, 114726, 694, 18, 396, "Input"],
Cell[4061605, 114746, 87, 2, 1933312, "Output"]
}, Closed]],
Cell[4061707, 114751, 148, 2, 200, "Text"],
Cell[CellGroupData[{
Cell[4061880, 114757, 488, 13, 240, "Input"],
Cell[4062371, 114772, 180, 4, 2490368, "Output"]
}, Closed]],
Cell[4062566, 114779, 108, 1, 200, "Text"],
Cell[4062677, 114782, 294, 8, 240, "Input"],
Cell[CellGroupData[{
Cell[4062996, 114794, 197, 5, 240, "Input"],
Cell[4063196, 114801, 190, 5, 3080192, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4063423, 114811, 852, 23, 332, "Input"],
Cell[4064278, 114836, 4762, 145, 21331968, "Output"]
}, Closed]],
Cell[4069055, 114984, 874, 26, 636, "Input"],
Cell[4069932, 115012, 190, 2, 240, "Text"],
Cell[CellGroupData[{
Cell[4070147, 115018, 1036, 29, 396, "Input"],
Cell[4071186, 115049, 701, 24, 3014656, "Output"]
}, Closed]],
Cell[4071902, 115076, 111, 1, 200, "Text"],
Cell[4072016, 115079, 1303, 31, 456, "Input"],
Cell[4073322, 115112, 171, 2, 240, "Text"],
Cell[CellGroupData[{
Cell[4073518, 115118, 744, 19, 396, "Input"],
Cell[4074265, 115139, 89, 2, 1933312, "Output"]
}, Closed]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4074427, 115149, 511, 6, 140, "Section"],
Cell[4074941, 115157, 1594, 25, 326, "Text"],
Cell[CellGroupData[{
Cell[4076560, 115186, 292, 5, 95, "Subsection"],
Cell[4076855, 115193, 808, 22, 392, "Text"],
Cell[4077666, 115217, 620, 21, 260, "Text"],
Cell[4078289, 115240, 1766, 45, 848, "Text"],
Cell[CellGroupData[{
Cell[4080080, 115289, 439, 9, 240, "Input"],
Cell[4080522, 115300, 299, 8, 483328, "Output"]
}, Closed]],
Cell[4080836, 115311, 276, 7, 200, "Text"],
Cell[4081115, 115320, 1151, 23, 396, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[4082291, 115347, 323, 8, 240, "Input"],
Cell[4082617, 115357, 1228, 35, 794624, "Output"]
}, Closed]],
Cell[4083860, 115395, 135, 1, 200, "Text"],
Cell[CellGroupData[{
Cell[4084020, 115400, 430, 11, 240, "Input"],
Cell[4084453, 115413, 288, 4, 483328, "Output"]
}, Closed]],
Cell[4084756, 115420, 328, 8, 352, "Text"],
Cell[4085087, 115430, 815, 17, 240, "Input",
 InitializationCell->True],
Cell[4085905, 115449, 155, 5, 240, "Text"],
Cell[CellGroupData[{
Cell[4086085, 115458, 259, 6, 240, "Input"],
Cell[4086347, 115466, 635, 19, 483328, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4087019, 115490, 345, 8, 176, "Input"],
Cell[4087367, 115500, 4272, 133, 753664, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4091676, 115638, 517, 15, 176, "Input"],
Cell[4092196, 115655, 4978, 158, 1613824, "Output"]
}, Closed]],
Cell[4097189, 115816, 420, 8, 200, "Text"],
Cell[4097612, 115826, 1249, 24, 240, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[4098886, 115854, 226, 4, 240, "Input"],
Cell[4099115, 115860, 264, 4, 483328, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4099416, 115869, 244, 6, 176, "Input"],
Cell[4099663, 115877, 1695, 52, 794624, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4101395, 115934, 368, 9, 176, "Input"],
Cell[4101766, 115945, 1600, 51, 794624, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4103403, 116001, 600, 12, 176, "Input"],
Cell[4104006, 116015, 538, 10, 352256, "Message"],
Cell[4104547, 116027, 4809, 151, 1703936, "Output"]
}, Closed]],
Cell[4109371, 116181, 776, 18, 352, "Text"],
Cell[4110150, 116201, 817, 20, 240, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[4110992, 116225, 229, 5, 240, "Input"],
Cell[4111224, 116232, 416, 11, 483328, "Output"]
}, Closed]],
Cell[4111655, 116246, 576, 15, 352, "Text"],
Cell[CellGroupData[{
Cell[4112256, 116265, 838, 24, 240, "Input"],
Cell[4113097, 116291, 146, 2, 483328, "Output"]
}, Closed]],
Cell[4113258, 116296, 1349, 32, 332, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[4114632, 116332, 352, 8, 396, "Input"],
Cell[4114987, 116342, 2628, 87, 1097728, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4117652, 116434, 411, 10, 176, "Input"],
Cell[4118066, 116446, 5620, 178, 2916352, "Output"]
}, Closed]],
Cell[4123701, 116627, 207, 4, 352, "Text"],
Cell[CellGroupData[{
Cell[4123933, 116635, 355, 10, 240, "Input"],
Cell[4124291, 116647, 2716, 91, 1269760, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4127044, 116743, 405, 11, 176, "Input"],
Cell[4127452, 116756, 5129, 175, 2244608, "Output"]
}, Closed]],
Cell[4132596, 116934, 286, 7, 352, "Text",
 CellTags->"fund1"],
Cell[CellGroupData[{
Cell[4132907, 116945, 166, 3, 240, "Input"],
Cell[4133076, 116950, 492, 8, 1228800, "Print",
 CellTags->"Info3618648866-2375024"]
}, Closed]],
Cell[4133583, 116961, 262, 5, 200, "Text"],
Cell[CellGroupData[{
Cell[4133870, 116970, 435, 11, 240, "Input"],
Cell[4134308, 116983, 3722, 128, 1703936, "Output"]
}, Closed]],
Cell[4138045, 117114, 340, 8, 200, "Text"],
Cell[CellGroupData[{
Cell[4138410, 117126, 115, 2, 240, "Input"],
Cell[CellGroupData[{
Cell[4138550, 117132, 122, 2, 663552, "Print",
 CellTags->"Info3618649093-2375024"],
Cell[4138675, 117136, 2230, 59, 1048576, "Print",
 CellTags->"Info3618649093-2375024"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[4140954, 117201, 421, 11, 176, "Input"],
Cell[4141378, 117214, 7656, 259, 2244608, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4149071, 117478, 394, 11, 176, "Input"],
Cell[4149468, 117491, 293, 4, 352256, "Print"]
}, Closed]],
Cell[CellGroupData[{
Cell[4149798, 117500, 1590, 41, 636, "Input"],
Cell[4151391, 117543, 299, 5, 483328, "Output"]
}, Closed]],
Cell[4151705, 117551, 88, 1, 200, "Text"],
Cell[CellGroupData[{
Cell[4151818, 117556, 1285, 32, 548, "Input"],
Cell[4153106, 117590, 150, 2, 483328, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4153293, 117597, 1180, 33, 332, "Input"],
Cell[4154476, 117632, 267, 4, 483328, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4154780, 117641, 1159, 28, 332, "Input"],
Cell[4155942, 117671, 365, 5, 483328, "Output"]
}, Closed]],
Cell[4156322, 117679, 2206, 49, 808, "Text"],
Cell[4158531, 117730, 678, 22, 240, "Input",
 Evaluatable->False],
Cell[4159212, 117754, 2277, 58, 564, "Text"],
Cell[4161492, 117814, 1684, 36, 396, "Input",
 InitializationCell->True],
Cell[4163179, 117852, 101, 1, 240, "Text"],
Cell[4163283, 117855, 1653, 37, 396, "Input",
 InitializationCell->True],
Cell[4164939, 117894, 139, 1, 240, "Text"],
Cell[4165081, 117897, 439, 12, 491520, "Input"],
Cell[4165523, 117911, 96, 1, 491520, "Text"],
Cell[CellGroupData[{
Cell[4165644, 117916, 316, 8, 491520, "Input"],
Cell[4165963, 117926, 99, 1, 483328, "Output"]
}, Closed]],
Cell[4166077, 117930, 170, 2, 491520, "Text"],
Cell[CellGroupData[{
Cell[4166272, 117936, 393, 10, 491520, "Input"],
Cell[4166668, 117948, 122, 2, 483328, "Output"]
}, Closed]],
Cell[4166805, 117953, 204, 4, 352, "Text"],
Cell[4167012, 117959, 139, 2, 240, "Input"],
Cell[4167154, 117963, 317, 10, 248, "Text"],
Cell[CellGroupData[{
Cell[4167496, 117977, 115, 2, 240, "Input"],
Cell[4167614, 117981, 527, 8, 1785856, "Print",
 CellTags->"Info3617083932-1439888"]
}, Closed]],
Cell[CellGroupData[{
Cell[4168178, 117994, 212, 5, 176, "Input"],
Cell[4168393, 118001, 587, 16, 483328, "Output"]
}, Closed]],
Cell[4168995, 118020, 319, 8, 208, "Text"],
Cell[CellGroupData[{
Cell[4169339, 118032, 390, 10, 240, "Input"],
Cell[4169732, 118044, 717, 18, 483328, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4170486, 118067, 625, 16, 176, "Input"],
Cell[4171114, 118085, 333, 8, 483328, "Output"]
}, Closed]],
Cell[4171462, 118096, 500, 11, 200, "Text"],
Cell[CellGroupData[{
Cell[4171987, 118111, 707, 17, 240, "Input"],
Cell[4172697, 118130, 360, 9, 483328, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4173094, 118144, 704, 17, 176, "Input"],
Cell[4173801, 118163, 358, 9, 483328, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4174196, 118177, 357, 8, 176, "Input"],
Cell[4174556, 118187, 351, 9, 614400, "Output"]
}, Closed]],
Cell[4174922, 118199, 192, 2, 200, "Text"],
Cell[4175117, 118203, 148, 3, 240, "Input"],
Cell[CellGroupData[{
Cell[4175290, 118210, 1042, 27, 384, "Input"],
Cell[4176335, 118239, 297, 6, 483328, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[4176681, 118251, 346, 4, 75, "Subsection"],
Cell[4177030, 118257, 543, 9, 60, "Text"],
Cell[CellGroupData[{
Cell[4177598, 118270, 114, 2, 60, "Input"],
Cell[CellGroupData[{
Cell[4177737, 118276, 120, 2, 81, "Print",
 CellTags->"Info3620543793-1087837"],
Cell[4177860, 118280, 1040, 29, 43, "Print",
 CellTags->"Info3620543793-1087837"]
}, Open  ]]
}, Open  ]],
Cell[4178927, 118313, 196, 3, 60, "Text"],
Cell[CellGroupData[{
Cell[4179148, 118320, 155, 3, 60, "Input"],
Cell[4179306, 118325, 143, 2, 241664, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4179486, 118332, 183, 4, 44, "Input"],
Cell[4179672, 118338, 658, 17, 241664, "Output"]
}, Closed]],
Cell[4180345, 118358, 478, 8, 50, "Text"],
Cell[4180826, 118368, 371, 7, 60, "Text"],
Cell[CellGroupData[{
Cell[4181222, 118379, 630, 14, 60, "Input"],
Cell[4181855, 118395, 841, 25, 241664, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4182733, 118425, 371, 5, 60, "Subsubsection"],
Cell[4183107, 118432, 354, 5, 491520, "Text",
 InitializationCell->True],
Cell[4183464, 118439, 269, 6, 696320, "Input"],
Cell[CellGroupData[{
Cell[4183758, 118449, 204, 5, 696320, "Input"],
Cell[4183965, 118456, 4580, 149, 1605632, "Output"]
}, Closed]],
Cell[4188560, 118608, 263, 5, 491520, "Text"],
Cell[4188826, 118615, 281, 8, 696320, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[4189132, 118627, 211, 5, 696320, "Input"],
Cell[4189346, 118634, 266, 4, 688128, "Output"]
}, Closed]],
Cell[4189627, 118641, 465, 10, 802816, "Text"],
Cell[CellGroupData[{
Cell[4190117, 118655, 232, 6, 696320, "Input"],
Cell[4190352, 118663, 20575, 663, 7667712, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4210964, 119331, 131, 2, 696320, "Input"],
Cell[4211098, 119335, 210, 4, 688128, "Output"]
}, Closed]],
Cell[4211323, 119342, 258, 7, 491520, "Text"],
Cell[CellGroupData[{
Cell[4211606, 119353, 628, 19, 696320, "Input"],
Cell[4212237, 119374, 243, 3, 688128, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4212517, 119382, 454, 12, 696320, "Input"],
Cell[4212974, 119396, 21738, 682, 8273920, "Output"]
}, Closed]],
Cell[4234727, 120081, 105, 1, 491520, "Text"],
Cell[CellGroupData[{
Cell[4234857, 120086, 564, 14, 696320, "Input"],
Cell[4235424, 120102, 21692, 681, 8273920, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4257153, 120788, 117, 2, 696320, "Input"],
Cell[4257273, 120792, 170, 2, 688128, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4257480, 120799, 160, 3, 696320, "Input"],
Cell[4257643, 120804, 187, 3, 688128, "Output"]
}, Closed]],
Cell[4257845, 120810, 394, 9, 819200, "Text"],
Cell[CellGroupData[{
Cell[4258264, 120823, 385, 11, 696320, "Input"],
Cell[4258652, 120836, 3305, 113, 1605632, "Output"]
}, Closed]],
Cell[4261972, 120952, 230, 6, 491520, "Text",
 CellTags->"dtt(1)"],
Cell[4262205, 120960, 1031, 26, 901120, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[4263261, 120990, 164, 5, 696320, "Input"],
Cell[4263428, 120997, 482, 14, 688128, "Output"]
}, Closed]],
Cell[4263925, 121014, 161, 3, 491520, "Text"],
Cell[CellGroupData[{
Cell[4264111, 121021, 549, 14, 696320, "Input"],
Cell[4264663, 121037, 22710, 714, 8273920, "Output"]
}, Closed]],
Cell[4287388, 121754, 161, 2, 491520, "Text"],
Cell[CellGroupData[{
Cell[4287574, 121760, 883, 27, 1015808, "Input"],
Cell[4288460, 121789, 10966, 346, 5914624, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4299463, 122140, 133, 2, 696320, "Input"],
Cell[4299599, 122144, 189, 3, 688128, "Output"]
}, Closed]],
Cell[4299803, 122150, 206, 2, 491520, "Text"],
Cell[CellGroupData[{
Cell[4300034, 122156, 952, 28, 1015808, "Input"],
Cell[4300989, 122186, 12246, 394, 5914624, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4313272, 122585, 131, 2, 696320, "Input"],
Cell[4313406, 122589, 162, 3, 688128, "Output"]
}, Closed]],
Cell[4313583, 122595, 416, 9, 802816, "Text"],
Cell[CellGroupData[{
Cell[4314024, 122608, 2337, 67, 1949696, "Input"],
Cell[4316364, 122677, 289, 4, 688128, "Output"]
}, Closed]],
Cell[4316668, 122684, 164, 3, 491520, "Text"],
Cell[CellGroupData[{
Cell[4316857, 122691, 368, 9, 696320, "Input"],
Cell[4317228, 122702, 3689, 121, 1605632, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[4320966, 122829, 407, 6, 60, "Subsubsection"],
Cell[4321376, 122837, 1132, 27, 745472, "Text"],
Cell[CellGroupData[{
Cell[4322533, 122868, 96, 1, 245760, "Input"],
Cell[4322632, 122871, 72, 1, 241664, "Output"]
}, Closed]],
Cell[4322719, 122875, 385, 12, 245760, "Input"],
Cell[4323107, 122889, 479, 10, 262144, "Text"],
Cell[CellGroupData[{
Cell[4323611, 122903, 465, 12, 245760, "Input"],
Cell[4324079, 122917, 510, 18, 241664, "Output"]
}, Closed]],
Cell[4324604, 122938, 766, 22, 434176, "Text"],
Cell[4325373, 122962, 713, 20, 245760, "Input",
 Evaluatable->False],
Cell[4326089, 122984, 118, 1, 245760, "Text"],
Cell[4326210, 122987, 463, 10, 307200, "Input"],
Cell[4326676, 122999, 123, 1, 245760, "Text"],
Cell[4326802, 123002, 584, 16, 245760, "Input",
 Evaluatable->False],
Cell[4327389, 123020, 598, 15, 245760, "Input",
 Evaluatable->False],
Cell[4327990, 123037, 694, 20, 262144, "Text"],
Cell[4328687, 123059, 495, 12, 253952, "Input",
 Evaluatable->False],
Cell[4329185, 123073, 379, 9, 253952, "Text"],
Cell[4329567, 123084, 365, 9, 245760, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[4329957, 123097, 132, 3, 245760, "Input"],
Cell[4330092, 123102, 145, 2, 241664, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4330274, 123109, 359, 8, 245760, "Input"],
Cell[4330636, 123119, 168, 2, 241664, "Output"]
}, Closed]],
Cell[4330819, 123124, 99, 1, 245760, "Text"],
Cell[4330921, 123127, 905, 22, 253952, "Input"],
Cell[4331829, 123151, 669, 16, 417792, "Text"],
Cell[4332501, 123169, 878, 22, 266240, "Input",
 Evaluatable->False],
Cell[4333382, 123193, 346, 7, 245760, "Text"],
Cell[4333731, 123202, 1412, 36, 663552, "Input",
 InitializationCell->True],
Cell[4335146, 123240, 229, 6, 245760, "Text"],
Cell[CellGroupData[{
Cell[4335400, 123250, 1044, 23, 405504, "Input"],
Cell[4336447, 123275, 846, 24, 376832, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4337330, 123304, 970, 22, 405504, "Input"],
Cell[4338303, 123328, 897, 25, 487424, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4339237, 123358, 590, 11, 245760, "Input"],
Cell[4339830, 123371, 698, 19, 344064, "Output"]
}, Closed]],
Cell[4340543, 123393, 113, 4, 401408, "Text"],
Cell[4340659, 123399, 285, 7, 245760, "Text"],
Cell[4340947, 123408, 1278, 37, 663552, "Input",
 InitializationCell->True],
Cell[4342228, 123447, 349, 9, 253952, "Text"],
Cell[4342580, 123458, 366, 9, 245760, "Input"],
Cell[CellGroupData[{
Cell[4342971, 123471, 164, 5, 245760, "Input"],
Cell[4343138, 123478, 554, 15, 241664, "Output"]
}, Closed]],
Cell[4343707, 123496, 180, 4, 245760, "Text"],
Cell[4343890, 123502, 717, 21, 245760, "Input"],
Cell[4344610, 123525, 765, 14, 557056, "Text"],
Cell[4345378, 123541, 1076, 28, 348160, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[4346479, 123573, 439, 11, 245760, "Input"],
Cell[4346921, 123586, 2772, 98, 700416, "Output"]
}, Closed]],
Cell[4349708, 123687, 152, 2, 245760, "Text"],
Cell[CellGroupData[{
Cell[4349885, 123693, 1185, 31, 405504, "Input"],
Cell[4351073, 123726, 690, 19, 241664, "Output"]
}, Closed]],
Cell[4351778, 123748, 195, 4, 245760, "Text"],
Cell[CellGroupData[{
Cell[4351998, 123756, 1717, 45, 716800, "Input"],
Cell[4353718, 123803, 595, 17, 241664, "Output"]
}, Closed]],
Cell[4354328, 123823, 131, 1, 245760, "Text"],
Cell[4354462, 123826, 996, 28, 348160, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[4355483, 123858, 348, 9, 245760, "Input"],
Cell[4355834, 123869, 2697, 97, 700416, "Output"]
}, Closed]],
Cell[4358546, 123969, 106, 1, 245760, "Text"],
Cell[CellGroupData[{
Cell[4358677, 123974, 1380, 33, 405504, "Input"],
Cell[4360060, 124009, 666, 18, 241664, "Output"]
}, Closed]],
Cell[4360741, 124030, 343, 9, 245760, "Text"],
Cell[CellGroupData[{
Cell[4361109, 124043, 1430, 40, 561152, "Input"],
Cell[4362542, 124085, 524, 16, 241664, "Output"]
}, Closed]],
Cell[4363081, 124104, 162, 2, 245760, "Text"],
Cell[4363246, 124108, 473, 13, 245760, "Input",
 Evaluatable->False],
Cell[4363722, 124123, 197, 4, 245760, "Text"],
Cell[4363922, 124129, 567, 18, 245760, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[4364514, 124151, 2407, 62, 1028096, "Input"],
Cell[4366924, 124215, 495, 16, 241664, "Output"]
}, Closed]],
Cell[4367434, 124234, 93, 1, 245760, "Text"],
Cell[4367530, 124237, 665, 21, 245760, "Input",
 Evaluatable->False],
Cell[4368198, 124260, 147, 1, 245760, "Text"],
Cell[4368348, 124263, 1742, 49, 663552, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[4370115, 124316, 343, 9, 245760, "Input"],
Cell[4370461, 124327, 3035, 100, 655360, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4373533, 124432, 1015, 28, 405504, "Input"],
Cell[4374551, 124462, 564, 17, 241664, "Output"]
}, Closed]],
Cell[4375130, 124482, 486, 14, 286720, "Text"],
Cell[4375619, 124498, 1061, 28, 507904, "Input",
 InitializationCell->True],
Cell[4376683, 124528, 510, 10, 557056, "Text"],
Cell[CellGroupData[{
Cell[4377218, 124542, 1149, 30, 405504, "Input"],
Cell[4378370, 124574, 587, 17, 241664, "Output"]
}, Closed]],
Cell[4378972, 124594, 100, 1, 245760, "Text"],
Cell[4379075, 124597, 224, 6, 245760, "Text"],
Cell[CellGroupData[{
Cell[4379324, 124607, 929, 24, 405504, "Input"],
Cell[4380256, 124633, 3689, 102, 573440, "Output"]
}, Closed]],
Cell[4383960, 124738, 251, 7, 401408, "Text"],
Cell[CellGroupData[{
Cell[4384236, 124749, 574, 12, 245760, "Input"],
Cell[4384813, 124763, 10975, 350, 1650688, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4395825, 125118, 685, 14, 245760, "Input"],
Cell[4396513, 125134, 11034, 351, 1650688, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4407584, 125490, 127, 2, 245760, "Input"],
Cell[4407714, 125494, 193, 3, 241664, "Output"]
}, Closed]],
Cell[4407922, 125500, 254, 7, 401408, "Text"],
Cell[4408179, 125509, 153, 3, 245760, "Text"],
Cell[4408335, 125514, 233, 6, 348160, "Input",
 InitializationCell->True],
Cell[4408571, 125522, 129, 1, 245760, "Text"],
Cell[CellGroupData[{
Cell[4408725, 125527, 811, 20, 245760, "Input"],
Cell[4409539, 125549, 851, 22, 471040, "Output"]
}, Closed]],
Cell[4410405, 125574, 123, 1, 245760, "Text"],
Cell[CellGroupData[{
Cell[4410553, 125579, 953, 24, 405504, "Input"],
Cell[4411509, 125605, 7957, 227, 1159168, "Output"]
}, Closed]],
Cell[4419481, 125835, 704, 13, 557056, "Text"],
Cell[4420188, 125850, 145, 3, 245760, "Input"],
Cell[4420336, 125855, 2807, 63, 1130496, "Input",
 InitializationCell->True],
Cell[4423146, 125920, 312, 10, 245760, "Text"],
Cell[CellGroupData[{
Cell[4423483, 125934, 489, 10, 245760, "Input"],
Cell[4423975, 125946, 3542, 117, 700416, "Output"]
}, Closed]],
Cell[4427532, 126066, 225, 5, 245760, "Text"],
Cell[CellGroupData[{
Cell[4427782, 126075, 336, 9, 245760, "Input"],
Cell[4428121, 126086, 3350, 114, 700416, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4431508, 126205, 244, 6, 245760, "Input"],
Cell[4431755, 126213, 223, 4, 241664, "Output"]
}, Closed]],
Cell[4431993, 126220, 465, 9, 401408, "Text"],
Cell[CellGroupData[{
Cell[4432483, 126233, 311, 10, 245760, "Input"],
Cell[4432797, 126245, 6448, 197, 1650688, "Output"]
}, Closed]],
Cell[4439260, 126445, 421, 10, 548864, "Text"],
Cell[CellGroupData[{
Cell[4439706, 126459, 877, 22, 245760, "Input"],
Cell[4440586, 126483, 5889, 179, 1306624, "Output"]
}, Closed]],
Cell[4446490, 126665, 139, 1, 245760, "Text"],
Cell[CellGroupData[{
Cell[4446654, 126670, 623, 12, 245760, "Input"],
Cell[4447280, 126684, 2356, 70, 397312, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4449673, 126759, 572, 14, 245760, "Input"],
Cell[4450248, 126775, 2223, 71, 446464, "Output"]
}, Closed]],
Cell[4452486, 126849, 160, 3, 245760, "Text"],
Cell[CellGroupData[{
Cell[4452671, 126856, 458, 10, 245760, "Input"],
Cell[4453132, 126868, 5580, 170, 1306624, "Output"]
}, Closed]],
Cell[4458727, 127041, 143, 3, 245760, "Input"],
Cell[4458873, 127046, 104, 1, 245760, "Text"],
Cell[CellGroupData[{
Cell[4459002, 127051, 227, 4, 245760, "Input"],
Cell[4459232, 127057, 244, 5, 241664, "Output"]
}, Closed]],
Cell[4459491, 127065, 487, 11, 712704, "Text"],
Cell[CellGroupData[{
Cell[4460003, 127080, 317, 10, 245760, "Input"],
Cell[4460323, 127092, 16808, 544, 2854912, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4477168, 127641, 854, 21, 245760, "Input"],
Cell[4478025, 127664, 8003, 205, 708608, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4486065, 127874, 611, 11, 245760, "Input"],
Cell[4486679, 127887, 138226, 3715, 16330752, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4624942, 131607, 558, 13, 245760, "Input"],
Cell[4625503, 131622, 141714, 3716, 16863232, "Output"]
}, Closed]],
Cell[4767232, 135341, 143, 3, 245760, "Input"],
Cell[CellGroupData[{
Cell[4767400, 135348, 136, 2, 245760, "Input"],
Cell[4767539, 135352, 94, 2, 241664, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4767670, 135359, 215, 5, 245760, "Input"],
Cell[4767888, 135366, 117, 3, 241664, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4768042, 135374, 579, 11, 245760, "Input"],
Cell[4768624, 135387, 13402, 321, 880640, "Output"]
}, Closed]],
Cell[4782041, 135711, 143, 3, 245760, "Input"],
Cell[CellGroupData[{
Cell[4782209, 135718, 227, 4, 245760, "Input"],
Cell[4782439, 135724, 278, 5, 241664, "Output"]
}, Closed]],
Cell[4782732, 135732, 322, 9, 401408, "Text"],
Cell[CellGroupData[{
Cell[4783079, 135745, 597, 12, 348160, "Input"],
Cell[4783679, 135759, 1546, 52, 499712, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4785262, 135816, 755, 14, 348160, "Input"],
Cell[4786020, 135832, 1554, 52, 499712, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4787611, 135889, 123, 2, 348160, "Input"],
Cell[4787737, 135893, 146, 2, 344064, "Output"]
}, Closed]],
Cell[4787898, 135898, 102, 1, 245760, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[4788037, 135904, 644, 8, 60, "Subsubsection"],
Cell[4788684, 135914, 482, 8, 557056, "Text"],
Cell[CellGroupData[{
Cell[4789191, 135926, 534, 12, 348160, "Input"],
Cell[4789728, 135940, 585, 15, 479232, "Output"]
}, Closed]],
Cell[4790328, 135958, 212, 7, 245760, "Text"],
Cell[4790543, 135967, 558, 14, 245760, "Input",
 Evaluatable->False],
Cell[4791104, 135983, 316, 6, 401408, "Text"],
Cell[CellGroupData[{
Cell[4791445, 135993, 419, 11, 348160, "Input"],
Cell[4791867, 136006, 237, 5, 344064, "Output"]
}, Closed]],
Cell[4792119, 136014, 404, 10, 360448, "Text"],
Cell[CellGroupData[{
Cell[4792548, 136028, 241, 6, 348160, "Input"],
Cell[4792792, 136036, 1286, 44, 344064, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4794115, 136085, 492, 14, 282624, "Input"],
Cell[4794610, 136101, 192, 4, 344064, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4794839, 136110, 240, 6, 282624, "Input"],
Cell[4795082, 136118, 286, 8, 344064, "Output"]
}, Closed]],
Cell[4795383, 136129, 489, 9, 516096, "Text"],
Cell[4795875, 136140, 908, 24, 348160, "Input"],
Cell[4796786, 136166, 173, 4, 245760, "Text"],
Cell[4796962, 136172, 1753, 45, 716800, "Input"],
Cell[4798718, 136219, 538, 13, 409600, "Text"],
Cell[4799259, 136234, 1011, 27, 245760, "Input",
 Evaluatable->False],
Cell[4800273, 136263, 676, 15, 409600, "Text"],
Cell[4800952, 136280, 1091, 27, 262144, "Input",
 Evaluatable->False],
Cell[4802046, 136309, 1306, 34, 245760, "Input"],
Cell[4803355, 136345, 407, 7, 245760, "Text"],
Cell[4803765, 136354, 741, 19, 245760, "Input"],
Cell[4804509, 136375, 159, 2, 245760, "Text"],
Cell[4804671, 136379, 1453, 37, 405504, "Input"],
Cell[4806127, 136418, 678, 13, 253952, "Text"],
Cell[4806808, 136433, 1460, 39, 573440, "Input"],
Cell[4808271, 136474, 789, 15, 409600, "Text"],
Cell[4809063, 136491, 2016, 54, 741376, "Input"],
Cell[4811082, 136547, 323, 7, 245760, "Text"],
Cell[4811408, 136556, 2053, 61, 819200, "Input",
 InitializationCell->True],
Cell[4813464, 136619, 597, 13, 712704, "Text"],
Cell[4814064, 136634, 976, 23, 446464, "Text"],
Cell[4815043, 136659, 679, 19, 438272, "Input",
 Evaluatable->False],
Cell[4815725, 136680, 493, 8, 557056, "Text"],
Cell[4816221, 136690, 192, 6, 245760, "Text"],
Cell[CellGroupData[{
Cell[4816438, 136700, 524, 12, 245760, "Input"],
Cell[4816965, 136714, 18037, 513, 4575232, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4835039, 137232, 184, 3, 282624, "Input"],
Cell[4835226, 137237, 173842, 4451, 22749184, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5009105, 141693, 325, 8, 180224, "Input"],
Cell[5009433, 141703, 118, 2, 241664, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5009588, 141710, 327, 8, 180224, "Input"],
Cell[5009918, 141720, 121, 2, 241664, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5010076, 141727, 325, 8, 180224, "Input"],
Cell[5010404, 141737, 191, 5, 241664, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5010632, 141747, 376, 9, 180224, "Input"],
Cell[5011011, 141758, 119, 2, 241664, "Output"]
}, Closed]],
Cell[5011145, 141763, 288, 6, 204800, "Text"],
Cell[CellGroupData[{
Cell[5011458, 141773, 868, 23, 663552, "Input"],
Cell[5012329, 141798, 388, 10, 344064, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5012754, 141813, 719, 18, 442368, "Input"],
Cell[5013476, 141833, 785, 22, 462848, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5014298, 141860, 692, 17, 180224, "Input"],
Cell[5014993, 141879, 206, 4, 241664, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5015236, 141888, 722, 18, 180224, "Input"],
Cell[5015961, 141908, 280, 8, 241664, "Output"]
}, Closed]],
Cell[5016256, 141919, 265, 5, 204800, "Text"],
Cell[5016524, 141926, 243, 6, 245760, "Text"],
Cell[5016770, 141934, 1045, 29, 507904, "Input",
 InitializationCell->True],
Cell[5017818, 141965, 189, 4, 245760, "Text"],
Cell[CellGroupData[{
Cell[5018032, 141973, 772, 18, 507904, "Input"],
Cell[5018807, 141993, 942, 28, 479232, "Output"]
}, Closed]],
Cell[5019764, 142024, 116, 1, 204800, "Text"],
Cell[CellGroupData[{
Cell[5019905, 142029, 1017, 26, 507904, "Input"],
Cell[5020925, 142057, 676, 19, 446464, "Output"]
}, Closed]],
Cell[5021616, 142079, 124, 1, 204800, "Text"],
Cell[CellGroupData[{
Cell[5021765, 142084, 1051, 28, 663552, "Input"],
Cell[5022819, 142114, 704, 19, 446464, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5023560, 142138, 1049, 28, 598016, "Input"],
Cell[5024612, 142168, 653, 18, 446464, "Output"]
}, Closed]],
Cell[5025280, 142189, 393, 9, 516096, "Text"],
Cell[CellGroupData[{
Cell[5025698, 142202, 409, 9, 348160, "Input"],
Cell[5026110, 142213, 12494, 304, 1007616, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5038641, 142522, 133, 2, 282624, "Input"],
Cell[5038777, 142526, 229049, 6549, 29069312, "Output"]
}, Closed]],
Cell[5267841, 149078, 129, 2, 204800, "Text"],
Cell[5267973, 149082, 556, 11, 557056, "Text"],
Cell[CellGroupData[{
Cell[5268554, 149097, 861, 23, 507904, "Input"],
Cell[5269418, 149122, 146, 2, 344064, "Output"]
}, Closed]],
Cell[5269579, 149127, 104, 1, 245760, "Text"],
Cell[5269686, 149130, 105, 1, 245760, "Text"],
Cell[CellGroupData[{
Cell[5269816, 149135, 632, 16, 348160, "Input"],
Cell[5270451, 149153, 189, 4, 438272, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5270677, 149162, 304, 7, 245760, "Input"],
Cell[5270984, 149171, 116, 3, 335872, "Output"]
}, Closed]],
Cell[5271115, 149177, 132, 1, 245760, "Text"],
Cell[CellGroupData[{
Cell[5271272, 149182, 97, 1, 348160, "Input"],
Cell[5271372, 149185, 163, 2, 344064, "Output"]
}, Closed]],
Cell[5271550, 149190, 214, 2, 245760, "Text"],
Cell[5271767, 149194, 921, 25, 245760, "Input",
 Evaluatable->False],
Cell[5272691, 149221, 275, 5, 401408, "Text"],
Cell[5272969, 149228, 489, 16, 245760, "Input",
 Evaluatable->False],
Cell[5273461, 149246, 125, 2, 245760, "Text"],
Cell[5273589, 149250, 410, 8, 401408, "Text"],
Cell[5274002, 149260, 514, 10, 557056, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[5274553, 149275, 665, 8, 60, "Subsubsection"],
Cell[5275221, 149285, 1025, 16, 1179648, "Text"],
Cell[5276249, 149303, 343, 8, 348160, "Input"],
Cell[5276595, 149313, 118, 1, 245760, "Text"],
Cell[CellGroupData[{
Cell[5276738, 149318, 195, 4, 245760, "Input"],
Cell[5276936, 149324, 425, 13, 241664, "Output"]
}, Closed]],
Cell[5277376, 149340, 283, 7, 360448, "Text"],
Cell[5277662, 149349, 748, 13, 1597440, "Input",
 InitializationCell->True],
Cell[5278413, 149364, 5530, 110, 1441792, "Input",
 InitializationCell->True],
Cell[5283946, 149476, 184, 6, 245760, "Text"],
Cell[CellGroupData[{
Cell[5284155, 149486, 114, 2, 245760, "Input"],
Cell[5284272, 149490, 638, 10, 753664, "Print",
 CellTags->"Info3613289226-3398588"]
}, Closed]],
Cell[CellGroupData[{
Cell[5284947, 149505, 1063, 25, 442368, "Input"],
Cell[5286013, 149532, 1291, 37, 499712, "Output"]
}, Closed]],
Cell[5287319, 149572, 1182, 26, 339968, "Input"],
Cell[CellGroupData[{
Cell[5288526, 149602, 1106, 25, 507904, "Input"],
Cell[5289635, 149629, 449, 11, 344064, "Output"]
}, Closed]],
Cell[5290099, 149643, 226, 5, 516096, "Text"],
Cell[5290328, 149650, 469, 11, 401408, "Text"],
Cell[5290800, 149663, 964, 19, 577536, "Text"],
Cell[5291767, 149684, 722, 18, 266240, "Text"],
Cell[5292492, 149704, 367, 6, 245760, "Text"],
Cell[5292862, 149712, 336, 8, 245760, "Text"],
Cell[5293201, 149722, 244, 6, 245760, "Input"],
Cell[5293448, 149730, 391, 7, 401408, "Text"],
Cell[5293842, 149739, 615, 16, 245760, "Input",
 Evaluatable->False],
Cell[5294460, 149757, 405, 9, 557056, "Text"],
Cell[5294868, 149768, 562, 16, 348160, "Input"],
Cell[5295433, 149786, 72, 1, 245760, "Text"],
Cell[CellGroupData[{
Cell[5295530, 149791, 276, 7, 348160, "Input"],
Cell[5295809, 149800, 1216, 36, 499712, "Output"]
}, Closed]],
Cell[5297040, 149839, 179, 2, 245760, "Text"],
Cell[5297222, 149843, 1358, 40, 507904, "Input"],
Cell[5298583, 149885, 239, 5, 245760, "Text"],
Cell[CellGroupData[{
Cell[5298847, 149894, 1415, 34, 663552, "Input"],
Cell[5300265, 149930, 167, 2, 344064, "Output"]
}, Closed]],
Cell[5300447, 149935, 142, 4, 360448, "Text"],
Cell[5300592, 149941, 372, 7, 245760, "Text"],
Cell[CellGroupData[{
Cell[5300989, 149952, 2680, 67, 1130496, "Input"],
Cell[5303672, 150021, 123689, 3169, 16621568, "Output"]
}, Closed]],
Cell[5427376, 153193, 291, 6, 204800, "Text"],
Cell[CellGroupData[{
Cell[5427692, 153203, 1424, 34, 663552, "Input"],
Cell[5429119, 153239, 145, 2, 479232, "Output"]
}, Closed]],
Cell[5429279, 153244, 533, 8, 516096, "Text"],
Cell[CellGroupData[{
Cell[5429837, 153256, 960, 29, 561152, "Input"],
Cell[5430800, 153287, 125, 2, 241664, "Output"]
}, Closed]],
Cell[5430940, 153292, 1353, 30, 827392, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[5432330, 153327, 765, 10, 60, "Subsubsection"],
Cell[5433098, 153339, 1110, 23, 1152, "Text"],
Cell[5434211, 153364, 343, 8, 240, "Input"],
Cell[5434557, 153374, 176, 5, 240, "Text"],
Cell[CellGroupData[{
Cell[5434758, 153383, 457, 9, 240, "Input"],
Cell[5435218, 153394, 461, 11, 344064, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5435716, 153410, 453, 12, 176, "Input"],
Cell[5436172, 153424, 550, 17, 344064, "Output"]
}, Closed]],
Cell[5436737, 153444, 247, 5, 200, "Text"],
Cell[5436987, 153451, 165, 5, 240, "Text"],
Cell[CellGroupData[{
Cell[5437177, 153460, 442, 10, 240, "Input"],
Cell[5437622, 153472, 1166, 33, 344064, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5438825, 153510, 451, 12, 176, "Input"],
Cell[5439279, 153524, 1358, 39, 696320, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5440674, 153568, 1387, 40, 372, "Input"],
Cell[5442064, 153610, 1358, 39, 696320, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5443459, 153654, 1937, 55, 532, "Input"],
Cell[5445399, 153711, 1782, 51, 548864, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5447218, 153767, 1811, 52, 544, "Input"],
Cell[5449032, 153821, 1780, 51, 548864, "Output"]
}, Closed]],
Cell[5450827, 153875, 133, 1, 200, "Text"],
Cell[CellGroupData[{
Cell[5450985, 153880, 2195, 60, 596, "Input"],
Cell[5453183, 153942, 20849, 410, 1425408, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5474069, 154357, 345, 9, 176, "Input"],
Cell[5474417, 154368, 10032, 200, 761856, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5484486, 154573, 347, 9, 176, "Input"],
Cell[5484836, 154584, 9899, 198, 761856, "Output"]
}, Closed]],
Cell[5494750, 154785, 683, 16, 176, "Input"],
Cell[5495436, 154803, 138, 3, 240, "Input"],
Cell[5495577, 154808, 298, 7, 240, "Text"],
Cell[CellGroupData[{
Cell[5495900, 154819, 270, 7, 240, "Input"],
Cell[5496173, 154828, 166, 4, 241664, "Output"]
}, Closed]],
Cell[5496354, 154835, 762, 20, 332, "Input"],
Cell[5497119, 154857, 255, 6, 240, "Input"],
Cell[5497377, 154865, 1038, 28, 396, "Input"],
Cell[5498418, 154895, 138, 1, 240, "Text"],
Cell[CellGroupData[{
Cell[5498581, 154900, 715, 16, 240, "Input"],
Cell[5499299, 154918, 462, 8, 344064, "Output"]
}, Closed]],
Cell[5499776, 154929, 382, 6, 352, "Text"],
Cell[5500161, 154937, 273, 5, 240, "Input"],
Cell[5500437, 154944, 1435, 33, 856, "Text"],
Cell[5501875, 154979, 249, 6, 240, "Text"],
Cell[5502127, 154987, 147, 3, 240, "Input"],
Cell[5502277, 154992, 457, 13, 240, "Input",
 InitializationCell->True],
Cell[5502737, 155007, 294, 8, 240, "Input"],
Cell[CellGroupData[{
Cell[5503056, 155019, 145, 3, 240, "Input"],
Cell[5503204, 155024, 902, 28, 344064, "Output"]
}, Closed]],
Cell[5504121, 155055, 200, 4, 352, "Text"],
Cell[CellGroupData[{
Cell[5504346, 155063, 462, 12, 240, "Input"],
Cell[5504811, 155077, 190, 4, 344064, "Output"]
}, Closed]],
Cell[5505016, 155084, 366, 7, 200, "Text"],
Cell[CellGroupData[{
Cell[5505407, 155095, 629, 15, 240, "Input"],
Cell[5506039, 155112, 11901, 346, 2207744, "Output"]
}, Closed]],
Cell[5517955, 155461, 492, 8, 504, "Text"],
Cell[5518450, 155471, 3522, 99, 756, "Input"],
Cell[CellGroupData[{
Cell[5521997, 155574, 547, 9, 240, "Input"],
Cell[5522547, 155585, 1031, 29, 344064, "Output"]
}, Closed]],
Cell[5523593, 155617, 844, 16, 664, "Text"],
Cell[5524440, 155635, 760, 22, 240, "Input",
 Evaluatable->False],
Cell[5525203, 155659, 533, 11, 240, "Text"],
Cell[5525739, 155672, 169, 3, 240, "Text"],
Cell[5525911, 155677, 477, 14, 240, "Input"],
Cell[CellGroupData[{
Cell[5526413, 155695, 429, 9, 240, "Input"],
Cell[5526845, 155706, 1424, 45, 536576, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5528306, 155756, 166, 3, 176, "Input"],
Cell[5528475, 155761, 939, 30, 614400, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5529451, 155796, 623, 15, 176, "Input"],
Cell[5530077, 155813, 240, 3, 344064, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5530354, 155821, 720, 19, 176, "Input"],
Cell[5531077, 155842, 647, 19, 479232, "Output"]
}, Closed]],
Cell[5531739, 155864, 229, 6, 200, "Text"],
Cell[5531971, 155872, 181, 4, 240, "Text"],
Cell[CellGroupData[{
Cell[5532177, 155880, 529, 14, 240, "Input"],
Cell[5532709, 155896, 190, 4, 344064, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5532936, 155905, 581, 15, 176, "Input"],
Cell[5533520, 155922, 190, 4, 344064, "Output"]
}, Closed]],
Cell[5533725, 155929, 138, 2, 200, "Text"],
Cell[5533866, 155933, 155, 3, 240, "Input"],
Cell[5534024, 155938, 416, 12, 240, "Input"],
Cell[5534443, 155952, 140, 3, 240, "Input"],
Cell[5534586, 155957, 205, 3, 240, "Text"],
Cell[CellGroupData[{
Cell[5534816, 155964, 149, 4, 240, "Input"],
Cell[5534968, 155970, 282, 6, 344064, "Output"]
}, Closed]],
Cell[5535265, 155979, 338, 9, 176, "Input"],
Cell[5535606, 155990, 197, 2, 240, "Text"],
Cell[CellGroupData[{
Cell[5535828, 155996, 628, 15, 240, "Input"],
Cell[5536459, 156013, 301, 6, 344064, "Output"]
}, Closed]],
Cell[5536775, 156022, 114, 1, 200, "Text"],
Cell[5536892, 156025, 147, 3, 240, "Input"],
Cell[CellGroupData[{
Cell[5537064, 156032, 843, 21, 240, "Input"],
Cell[5537910, 156055, 1233, 34, 458752, "Output"]
}, Closed]],
Cell[5539158, 156092, 144, 1, 200, "Text"],
Cell[CellGroupData[{
Cell[5539327, 156097, 1150, 26, 240, "Input"],
Cell[5540480, 156125, 1496, 43, 700416, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5542013, 156173, 1498, 43, 560, "Input"],
Cell[5543514, 156218, 1469, 42, 700416, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5545020, 156265, 1477, 37, 332, "Input"],
Cell[5546500, 156304, 1785, 52, 700416, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5548322, 156361, 1788, 52, 560, "Input"],
Cell[5550113, 156415, 1761, 51, 700416, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5551911, 156471, 945, 21, 176, "Input"],
Cell[5552859, 156494, 1261, 37, 458752, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5554157, 156536, 1290, 38, 560, "Input"],
Cell[5555450, 156576, 1235, 37, 458752, "Output"]
}, Closed]],
Cell[5556700, 156616, 111, 1, 200, "Text"],
Cell[CellGroupData[{
Cell[5556836, 156621, 1543, 40, 396, "Input"],
Cell[5558382, 156663, 23360, 456, 1425408, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5581779, 157124, 345, 9, 176, "Input"],
Cell[5582127, 157135, 11150, 221, 761856, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5593314, 157361, 347, 9, 176, "Input"],
Cell[5593664, 157372, 11220, 223, 761856, "Output"]
}, Closed]],
Cell[5604899, 157598, 107, 1, 200, "Text"],
Cell[5605009, 157601, 881, 20, 240, "Input"],
Cell[5605893, 157623, 144, 3, 240, "Input"],
Cell[5606040, 157628, 128, 1, 240, "Text"],
Cell[5606171, 157631, 181, 4, 240, "Input"],
Cell[5606355, 157637, 169, 3, 240, "Text"],
Cell[5606527, 157642, 617, 16, 240, "Input"],
Cell[5607147, 157660, 530, 15, 240, "Input"],
Cell[5607680, 157677, 233, 5, 392, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[5607950, 157687, 754, 10, 60, "Subsubsection"],
Cell[5608707, 157699, 410, 9, 240, "Text"],
Cell[5609120, 157710, 401, 9, 240, "Input"],
Cell[5609524, 157721, 275, 7, 240, "Input"],
Cell[5609802, 157730, 389, 9, 248, "Text"],
Cell[CellGroupData[{
Cell[5610216, 157743, 436, 11, 240, "Input"],
Cell[5610655, 157756, 7444, 246, 163328, "Output"]
}, Closed]],
Cell[5618114, 158005, 660, 10, 656, "Text"],
Cell[5618777, 158017, 7807, 249, 1680, "Input"],
Cell[5626587, 158268, 421, 10, 240, "Text"],
Cell[CellGroupData[{
Cell[5627033, 158282, 340, 8, 240, "Input"],
Cell[5627376, 158292, 223, 3, 30208, "Output"]
}, Closed]],
Cell[5627614, 158298, 114, 1, 200, "Text"],
Cell[CellGroupData[{
Cell[5627753, 158303, 938, 22, 396, "Input"],
Cell[5628694, 158327, 180379, 4647, 3298304, "Output"]
}, Closed]],
Cell[5809088, 162977, 138, 2, 200, "Text"],
Cell[5809229, 162981, 189004, 4651, 31884, "Input"],
Cell[5998236, 167634, 1299, 32, 1312, "Text"],
Cell[CellGroupData[{
Cell[5999560, 167670, 1255, 30, 548, "Input"],
Cell[6000818, 167702, 94, 1, 30208, "Output"]
}, Closed]],
Cell[6000927, 167706, 104, 1, 200, "Text"],
Cell[6001034, 167709, 281, 5, 240, "Text"],
Cell[CellGroupData[{
Cell[6001340, 167718, 131, 2, 240, "Input"],
Cell[6001474, 167722, 225, 6, 30208, "Output"]
}, Closed]],
Cell[6001714, 167731, 182, 4, 200, "Text"],
Cell[6001899, 167737, 4095, 93, 1612, "Input",
 InitializationCell->True],
Cell[6005997, 167832, 797, 13, 1000, "Text"],
Cell[CellGroupData[{
Cell[6006819, 167849, 117, 2, 240, "Input"],
Cell[6006939, 167853, 373, 6, 614400, "Print",
 CellTags->"Info3617368136-1949107"]
}, Closed]],
Cell[6007327, 167862, 721, 18, 176, "Input"],
Cell[CellGroupData[{
Cell[6008073, 167884, 128, 2, 240, "Input"],
Cell[6008204, 167888, 756, 22, 30208, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6008997, 167915, 176, 3, 176, "Input"],
Cell[6009176, 167920, 17961, 524, 337920, "Output"]
}, Closed]],
Cell[6027152, 168447, 504, 14, 504, "Text"],
Cell[CellGroupData[{
Cell[6027681, 168465, 877, 21, 396, "Input"],
Cell[6028561, 168488, 119, 2, 30208, "Output"]
}, Closed]],
Cell[6028695, 168493, 263, 6, 352, "Text"],
Cell[CellGroupData[{
Cell[6028983, 168503, 808, 21, 396, "Input"],
Cell[6029794, 168526, 165, 2, 30208, "Output"]
}, Closed]],
Cell[6029974, 168531, 803, 14, 656, "Text"],
Cell[6030780, 168547, 290, 5, 392, "Text"],
Cell[CellGroupData[{
Cell[6031095, 168556, 1459, 41, 548, "Input"],
Cell[6032557, 168599, 172, 2, 241664, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6032766, 168606, 484, 10, 176, "Input"],
Cell[6033253, 168618, 172, 2, 241664, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6033462, 168625, 563, 13, 176, "Input"],
Cell[6034028, 168640, 77, 1, 241664, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6034142, 168646, 1500, 41, 484, "Input"],
Cell[6035645, 168689, 126, 2, 60416, "Output"]
}, Closed]],
Cell[6035786, 168694, 394, 7, 352, "Text"],
Cell[6036183, 168703, 377, 8, 240, "Text"],
Cell[CellGroupData[{
Cell[6036585, 168715, 180, 4, 240, "Input"],
Cell[6036768, 168721, 407, 11, 43008, "Output"]
}, Closed]],
Cell[6037190, 168735, 188, 2, 200, "Text"],
Cell[6037381, 168739, 293, 8, 240, "Input"],
Cell[CellGroupData[{
Cell[6037699, 168751, 260, 6, 340, "Input"],
Cell[6037962, 168759, 183, 5, 47104, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6038182, 168769, 636, 17, 332, "Input"],
Cell[6038821, 168788, 2118, 42, 410112, "Output"]
}, Closed]],
Cell[6040954, 168833, 150, 3, 176, "Input"],
Cell[CellGroupData[{
Cell[6041129, 168840, 723, 19, 396, "Input"],
Cell[6041855, 168861, 36476, 609, 424448, "Output"]
}, Closed]],
Cell[6078346, 169473, 147, 3, 176, "Input"],
Cell[CellGroupData[{
Cell[6078518, 169480, 251, 6, 240, "Input"],
Cell[6078772, 169488, 38076, 637, 424448, "Output"]
}, Closed]],
Cell[6116863, 170128, 126, 1, 200, "Text"],
Cell[CellGroupData[{
Cell[6117014, 170133, 808, 16, 240, "Input"],
Cell[6117825, 170151, 92, 1, 43008, "Output"]
}, Closed]],
Cell[6117932, 170155, 123, 1, 200, "Text"],
Cell[CellGroupData[{
Cell[6118080, 170160, 529, 11, 240, "Input"],
Cell[6118612, 170173, 292, 5, 43008, "Output"]
}, Closed]],
Cell[6118919, 170181, 141, 2, 200, "Text"],
Cell[CellGroupData[{
Cell[6119085, 170187, 344, 8, 240, "Input"],
Cell[6119432, 170197, 284, 7, 68608, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6119753, 170209, 549, 12, 176, "Input"],
Cell[6120305, 170223, 432, 12, 66560, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6120774, 170240, 611, 15, 176, "Input"],
Cell[6121388, 170257, 1216, 36, 68096, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6122641, 170298, 382, 10, 176, "Input"],
Cell[6123026, 170310, 408, 10, 59392, "Output"]
}, Closed]],
Cell[6123449, 170323, 115, 1, 200, "Text"],
Cell[CellGroupData[{
Cell[6123589, 170328, 201, 5, 240, "Input"],
Cell[6123793, 170335, 620, 19, 59392, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6124450, 170359, 327, 9, 176, "Input"],
Cell[6124780, 170370, 145, 2, 43008, "Output"]
}, Closed]],
Cell[6124940, 170375, 486, 9, 200, "Text"],
Cell[6125429, 170386, 303, 6, 392, "Text"],
Cell[6125735, 170394, 1062, 24, 396, "Input"],
Cell[CellGroupData[{
Cell[6126822, 170422, 382, 7, 240, "Input"],
Cell[6127207, 170431, 677, 25, 68096, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6127921, 170461, 614, 13, 176, "Input"],
Cell[6128538, 170476, 1698, 57, 68608, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6130273, 170538, 697, 14, 176, "Input"],
Cell[6130973, 170554, 1236, 43, 68608, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6132246, 170602, 282, 7, 176, "Input"],
Cell[6132531, 170611, 169, 2, 43008, "Output"]
}, Closed]],
Cell[6132715, 170616, 153, 2, 200, "Text"],
Cell[6132871, 170620, 254, 7, 240, "Input"],
Cell[6133128, 170629, 1193, 26, 396, "Input"],
Cell[6134324, 170657, 419, 12, 240, "Input"],
Cell[CellGroupData[{
Cell[6134768, 170673, 160, 3, 240, "Input"],
Cell[6134931, 170678, 390, 12, 43008, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6135358, 170695, 225, 5, 176, "Input"],
Cell[6135586, 170702, 305, 11, 63488, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6135928, 170718, 819, 16, 176, "Input"],
Cell[6136750, 170736, 797, 22, 68608, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6137584, 170763, 722, 14, 176, "Input"],
Cell[6138309, 170779, 513, 16, 60928, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6138859, 170800, 282, 7, 176, "Input"],
Cell[6139144, 170809, 194, 3, 43008, "Output"]
}, Closed]],
Cell[6139353, 170815, 89, 1, 200, "Text"],
Cell[6139445, 170818, 461, 9, 240, "Text"],
Cell[6139909, 170829, 282, 8, 240, "Text"],
Cell[CellGroupData[{
Cell[6140216, 170841, 124, 2, 240, "Input"],
Cell[6140343, 170845, 323, 11, 11776, "Output"]
}, Closed]],
Cell[6140681, 170859, 123, 1, 200, "Text"],
Cell[6140807, 170862, 231, 5, 240, "Input"],
Cell[CellGroupData[{
Cell[6141063, 170871, 522, 12, 240, "Input"],
Cell[6141588, 170885, 757, 22, 11776, "Output"]
}, Closed]],
Cell[6142360, 170910, 540, 13, 176, "Input"],
Cell[6142903, 170925, 148, 3, 240, "Input"],
Cell[6143054, 170930, 578, 13, 240, "Input"],
Cell[6143635, 170945, 145, 3, 240, "Input"],
Cell[6143783, 170950, 253, 6, 240, "Input"],
Cell[6144039, 170958, 255, 5, 240, "Text"],
Cell[6144297, 170965, 569, 11, 240, "Input"],
Cell[CellGroupData[{
Cell[6144891, 170980, 251, 5, 240, "Input"],
Cell[6145145, 170987, 545, 15, 11776, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6145727, 171007, 665, 11, 176, "Input"],
Cell[6146395, 171020, 448, 8, 11648, "Output"]
}, Closed]],
Cell[6146858, 171031, 114, 1, 200, "Text"],
Cell[6146975, 171034, 1173, 20, 240, "Input"],
Cell[CellGroupData[{
Cell[6148173, 171058, 1123, 20, 240, "Input"],
Cell[6149299, 171080, 399, 6, 7552, "Output"]
}, Closed]],
Cell[6149713, 171089, 159, 2, 200, "Text"],
Cell[CellGroupData[{
Cell[6149897, 171095, 1176, 20, 240, "Input"],
Cell[6151076, 171117, 199, 4, 11648, "Output"]
}, Closed]],
Cell[6151290, 171124, 132, 1, 200, "Text"],
Cell[CellGroupData[{
Cell[6151447, 171129, 151, 3, 240, "Input"],
Cell[6151601, 171134, 595, 20, 11776, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6152233, 171159, 1189, 22, 332, "Input"],
Cell[6153425, 171183, 143, 2, 7552, "Output"]
}, Closed]],
Cell[6153583, 171188, 126, 1, 200, "Text"],
Cell[6153712, 171191, 328, 7, 240, "Input"],
Cell[CellGroupData[{
Cell[6154065, 171202, 123, 2, 240, "Input"],
Cell[6154191, 171206, 165, 5, 8192, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6154393, 171216, 366, 8, 176, "Input"],
Cell[6154762, 171226, 457, 15, 12416, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6155256, 171246, 118, 2, 176, "Input"],
Cell[6155377, 171250, 292, 5, 14848, "Print",
 CellTags->"Info3614339427-8121375"]
}, Closed]],
Cell[CellGroupData[{
Cell[6155706, 171260, 331, 7, 176, "Input"],
Cell[6156040, 171269, 200, 6, 11520, "Output"]
}, Closed]],
Cell[6156255, 171278, 297, 6, 200, "Text"],
Cell[6156555, 171286, 481, 12, 240, "Input"],
Cell[6157039, 171300, 148, 3, 240, "Input"],
Cell[6157190, 171305, 317, 7, 240, "Input"],
Cell[CellGroupData[{
Cell[6157532, 171316, 1461, 26, 396, "Input"],
Cell[6158996, 171344, 386, 11, 13824, "Output"]
}, Closed]],
Cell[6159397, 171358, 330, 6, 200, "Text"],
Cell[CellGroupData[{
Cell[6159752, 171368, 441, 10, 240, "Input"],
Cell[6160196, 171380, 228, 6, 11648, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6160461, 171391, 450, 11, 176, "Input"],
Cell[6160914, 171404, 140, 2, 7552, "Output"]
}, Closed]],
Cell[6161069, 171409, 87, 1, 200, "Text"],
Cell[6161159, 171412, 504, 10, 240, "Text"],
Cell[CellGroupData[{
Cell[6161688, 171426, 179, 4, 240, "Input"],
Cell[6161870, 171432, 442, 12, 9984, "Output"]
}, Closed]],
Cell[6162327, 171447, 425, 12, 176, "Input"],
Cell[CellGroupData[{
Cell[6162777, 171463, 551, 14, 240, "Input"],
Cell[6163331, 171479, 316, 8, 12416, "Output"]
}, Closed]],
Cell[6163662, 171490, 150, 3, 200, "Text"],
Cell[CellGroupData[{
Cell[6163837, 171497, 637, 15, 240, "Input"],
Cell[6164477, 171514, 94, 1, 7552, "Output"]
}, Closed]],
Cell[6164586, 171518, 147, 2, 200, "Text"],
Cell[CellGroupData[{
Cell[6164758, 171524, 791, 20, 548, "Input"],
Cell[6165552, 171546, 192, 3, 7552, "Output"]
}, Closed]],
Cell[6165759, 171552, 115, 1, 200, "Text"],
Cell[6165877, 171555, 157, 2, 240, "Text"],
Cell[CellGroupData[{
Cell[6166059, 171561, 737, 17, 396, "Input"],
Cell[6166799, 171580, 248, 6, 12288, "Output"]
}, Closed]],
Cell[6167062, 171589, 406, 8, 176, "Input"],
Cell[CellGroupData[{
Cell[6167493, 171601, 123, 2, 240, "Input"],
Cell[6167619, 171605, 425, 12, 10240, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6168081, 171622, 523, 13, 176, "Input"],
Cell[6168607, 171637, 507, 15, 14592, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6169151, 171657, 303, 7, 176, "Input"],
Cell[6169457, 171666, 192, 3, 7552, "Output"]
}, Closed]],
Cell[6169664, 171672, 145, 1, 200, "Text"],
Cell[CellGroupData[{
Cell[6169834, 171677, 904, 22, 548, "Input"],
Cell[6170741, 171701, 388, 10, 11904, "Output"]
}, Closed]],
Cell[6171144, 171714, 117, 1, 200, "Text"],
Cell[CellGroupData[{
Cell[6171286, 171719, 960, 23, 548, "Input"],
Cell[6172249, 171744, 273, 8, 12288, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6172559, 171757, 247, 6, 176, "Input"],
Cell[6172809, 171765, 427, 12, 9984, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6173273, 171782, 478, 12, 176, "Input"],
Cell[6173754, 171796, 195, 5, 11904, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6173986, 171806, 426, 12, 176, "Input"],
Cell[6174415, 171820, 121, 2, 7552, "Output"]
}, Closed]],
Cell[6174551, 171825, 87, 1, 200, "Text"],
Cell[6174641, 171828, 513, 10, 240, "Text"],
Cell[6175157, 171840, 472, 11, 392, "Text"],
Cell[CellGroupData[{
Cell[6175654, 171855, 151, 4, 240, "Input"],
Cell[6175808, 171861, 370, 10, 7552, "Output"]
}, Closed]],
Cell[6176193, 171874, 167, 2, 200, "Text"],
Cell[6176363, 171878, 629, 10, 240, "Input"],
Cell[CellGroupData[{
Cell[6177017, 171892, 1058, 21, 396, "Input"],
Cell[6178078, 171915, 189, 3, 7552, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6178304, 171923, 791, 15, 176, "Input"],
Cell[6179098, 171940, 991, 26, 11648, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6180126, 171971, 654, 16, 332, "Input"],
Cell[6180783, 171989, 595, 17, 13696, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6181415, 172011, 202, 5, 176, "Input"],
Cell[6181620, 172018, 119, 2, 7552, "Output"]
}, Closed]],
Cell[6181754, 172023, 145, 1, 200, "Text"],
Cell[6181902, 172026, 629, 10, 240, "Input"],
Cell[CellGroupData[{
Cell[6182556, 172040, 1325, 29, 396, "Input"],
Cell[6183884, 172071, 482, 13, 17792, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6184403, 172089, 816, 15, 176, "Input"],
Cell[6185222, 172106, 744, 19, 13440, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6186003, 172130, 874, 22, 332, "Input"],
Cell[6186880, 172154, 338, 7, 11008, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6187255, 172166, 336, 8, 176, "Input"],
Cell[6187594, 172176, 123, 2, 7552, "Output"]
}, Closed]],
Cell[6187732, 172181, 87, 1, 200, "Text"],
Cell[6187822, 172184, 549, 10, 240, "Text"],
Cell[6188374, 172196, 374, 5, 240, "Text"],
Cell[CellGroupData[{
Cell[6188773, 172205, 123, 2, 240, "Input"],
Cell[6188899, 172209, 320, 5, 464, "Print",
 CellTags->"Info3617438205-2838022"]
}, Closed]],
Cell[CellGroupData[{
Cell[6189256, 172219, 261, 6, 240, "Input"],
Cell[6189520, 172227, 619, 17, 9984, "Output"]
}, Closed]],
Cell[6190154, 172247, 476, 14, 176, "Input"],
Cell[6190633, 172263, 1700, 51, 396, "Input"],
Cell[CellGroupData[{
Cell[6192358, 172318, 160, 4, 240, "Input"],
Cell[6192521, 172324, 528, 16, 13184, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6193086, 172345, 543, 14, 176, "Input"],
Cell[6193632, 172361, 135, 4, 13696, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6193804, 172370, 708, 16, 176, "Input"],
Cell[6194515, 172388, 625, 17, 13568, "Output"]
}, Closed]],
Cell[6195155, 172408, 270, 5, 200, "Text"],
Cell[CellGroupData[{
Cell[6195450, 172417, 357, 10, 240, "Input"],
Cell[6195810, 172429, 277, 6, 13696, "Output"]
}, Closed]],
Cell[6196102, 172438, 426, 10, 200, "Text"],
Cell[6196531, 172450, 87, 1, 240, "Text"],
Cell[6196621, 172453, 264, 5, 392, "Text"],
Cell[CellGroupData[{
Cell[6196910, 172462, 1370, 29, 396, "Input"],
Cell[6198283, 172493, 163, 3, 13568, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6198483, 172501, 1265, 24, 176, "Input"],
Cell[6199751, 172527, 264, 8, 16128, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6200052, 172540, 725, 18, 332, "Input"],
Cell[6200780, 172560, 370, 12, 16896, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[6201187, 172577, 431, 12, 176, "Input"],
Cell[6201621, 172591, 143, 2, 10752, "Output"]
}, Closed]],
Cell[6201779, 172596, 85, 1, 200, "Text"],
Cell[6201867, 172599, 1254, 25, 544, "Text"],
Cell[6203124, 172626, 269, 6, 392, "Text"],
Cell[6203396, 172634, 176, 4, 240, "Input",
 InitializationCell->True]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6203633, 172645, 397, 5, 111, "Subtitle"],
Cell[6204033, 172652, 350, 7, 98, "Text",
 CellTags->"B-R"],
Cell[6204386, 172661, 609, 13, 136, "Text",
 CellTags->"Gray"],
Cell[6204998, 172676, 827, 18, 136, "Text",
 CellTags->"Gray2"],
Cell[6205828, 172696, 533, 9, 136, "Text",
 CellTags->"Gray3"],
Cell[6206364, 172707, 274, 6, 98, "Text",
 CellTags->"Kr"],
Cell[6206641, 172715, 292, 6, 98, "Text",
 CellTags->"K-N1"],
Cell[6206936, 172723, 417, 8, 98, "Text",
 CellTags->"OS3"],
Cell[CellGroupData[{
Cell[6207378, 172735, 172, 3, 65, "Subsubtitle"],
Cell[6207553, 172740, 372, 7, 60, "Text",
 CellTags->"Home"],
Cell[6207928, 172749, 121, 1, 60, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
